package pf::util::radius_dictionary;

=head1 NAME

pf::util::radius_dictionary - 

=cut

=head1 DESCRIPTION

pf::util::radius_dictionary



=cut

use strict;
use warnings;

use Net::Radius::Dictionary;
use Exporter qw(import);
our @EXPORT_OK = qw($RADIUS_DICTIONARY);

our $RADIUS_DICTIONARY = bless(
    {
        attr => {
            "Acct-Authentic"                         => [ 45,   "integer" ],
            "Acct-Delay-Time"                        => [ 41,   "integer" ],
            "Acct-Input-Gigawords"                   => [ 52,   "integer" ],
            "Acct-Input-Octets"                      => [ 42,   "integer" ],
            "Acct-Input-Octets64"                    => [ 1148, "integer64" ],
            "Acct-Input-Packets"                     => [ 47,   "integer" ],
            "Acct-Interim-Interval"                  => [ 85,   "integer" ],
            "Acct-Link-Count"                        => [ 51,   "integer" ],
            "Acct-Multi-Session-Id"                  => [ 50,   "string" ],
            "Acct-Output-Gigawords"                  => [ 53,   "integer" ],
            "Acct-Output-Octets"                     => [ 43,   "integer" ],
            "Acct-Output-Octets64"                   => [ 1149, "integer64" ],
            "Acct-Output-Packets"                    => [ 48,   "integer" ],
            "Acct-Session-Id"                        => [ 44,   "string" ],
            "Acct-Session-Start-Time"                => [ 1050, "date" ],
            "Acct-Session-Time"                      => [ 46,   "integer" ],
            "Acct-Status-Type"                       => [ 40,   "integer" ],
            "Acct-Terminate-Cause"                   => [ 49,   "integer" ],
            "Acct-Tunnel-Connection"                 => [ 68,   "string" ],
            "Acct-Tunnel-Packets-Lost"               => [ 86,   "integer" ],
            "Acct-Type"                              => [ 1012, "integer" ],
            "Acct-Unique-Session-Id"                 => [ 1051, "string" ],
            "AD-Samaccountname"                      => [ 3003, "string" ],
            "Add-Prefix"                             => [ 1008, "string" ],
            "Add-Suffix"                             => [ 1009, "string" ],
            "Allow-Session-Resumption"               => [ 1127, "integer" ],
            "Allowed-Called-Station-Id"              => [ 174,  "string" ],
            "ARAP-Challenge-Response"                => [ 84,   "octets" ],
            "ARAP-Features"                          => [ 71,   "octets" ],
            "ARAP-Password"                          => [ 70,   "octets" ],
            "ARAP-Security"                          => [ 73,   "integer" ],
            "ARAP-Security-Data"                     => [ 74,   "string" ],
            "ARAP-Zone-Access"                       => [ 72,   "integer" ],
            "Attribute-Map"                          => [ 1112, "string" ],
            "Auth-Type"                              => [ 1000, "integer" ],
            "Autz-Type"                              => [ 1011, "integer" ],
            "Basic-Location-Policy-Rules"            => [ 129,  "octets" ],
            "Cache-Created"                          => [ 1171, "date" ],
            "Cache-Entry-Hits"                       => [ 1175, "integer" ],
            "Cache-Expires"                          => [ 1170, "date" ],
            "Cache-Merge"                            => [ 1174, "integer" ],
            "Cache-Read-Only"                        => [ 1176, "integer" ],
            "Cache-Status-Only"                      => [ 1173, "integer" ],
            "Cache-TTL"                              => [ 1172, "signed" ],
            "Cached-Session-Policy"                  => [ 1135, "string" ],
            "Callback-Id"                            => [ 20,   "string" ],
            "Callback-Number"                        => [ 19,   "string" ],
            "Called-Station-Id"                      => [ 30,   "string" ],
            "Called-Station-MAC"                     => [ 1140, "octets" ],
            "Called-Station-SSID"                    => [ 1139, "string" ],
            "Caller-ID"                              => [ 31,   "string" ],
            "Calling-Station-Id"                     => [ 31,   "string" ],
            "Challenge-State"                        => [ 24,   "octets" ],
            "CHAP-Challenge"                         => [ 60,   "octets" ],
            "CHAP-Password"                          => [ 3,    "octets" ],
            "Char-Noecho"                            => [ 250,  "integer" ],
            "Chargeable-User-Identity"               => [ 89,   "octets" ],
            "Chbind-Response-Code"                   => [ 1147, "integer" ],
            "Class"                                  => [ 25,   "octets" ],
            "Cleartext-Password"                     => [ 1100, "string" ],
            "Client-Id"                              => [ 4,    "ipaddr" ],
            "Client-IP-Address"                      => [ 1052, "ipaddr" ],
            "Client-Port-DNIS"                       => [ 30,   "string" ],
            "Client-Port-Id"                         => [ 5,    "integer" ],
            "Client-Shortname"                       => [ 1024, "string" ],
            "CoA-Acct-Session-Id"                    => [ 1116, "string" ],
            "CoA-Packet-DST-IP-Address"              => [ 1114, "ipaddr" ],
            "CoA-Packet-DST-IPv6-Address"            => [ 1117, "ipv6addr" ],
            "CoA-Packet-DST-Port"                    => [ 1115, "integer" ],
            "CoA-Packet-Type"                        => [ 1113, "string" ],
            "Configuration-Token"                    => [ 78,   "string" ],
            "Connect-Info"                           => [ 77,   "string" ],
            "Crypt-Password"                         => [ 1006, "string" ],
            "Current-Time"                           => [ 1044, "string" ],
            "Delegated-IPv6-Prefix"                  => [ 123,  "ipv6prefix" ],
            "Delegated-IPv6-Prefix-Pool"             => [ 171,  "string" ],
            "Dialback-Name"                          => [ 20,   "string" ],
            "Dialback-No"                            => [ 19,   "string" ],
            "Digest-Algorithm"                       => [ 1068, "string" ],
            "Digest-Attributes"                      => [ 207,  "octets" ],
            "Digest-Body-Digest"                     => [ 1069, "string" ],
            "Digest-CNonce"                          => [ 1070, "string" ],
            "Digest-HA1"                             => [ 1081, "string" ],
            "Digest-Method"                          => [ 1065, "string" ],
            "Digest-Nonce"                           => [ 1064, "string" ],
            "Digest-Nonce-Count"                     => [ 1071, "string" ],
            "Digest-QOP"                             => [ 1067, "string" ],
            "Digest-Realm"                           => [ 1063, "string" ],
            "Digest-Response"                        => [ 206,  "string" ],
            "Digest-URI"                             => [ 1066, "string" ],
            "Digest-User-Name"                       => [ 1072, "string" ],
            "DNS-Server-IPv6-Address"                => [ 169,  "ipv6addr" ],
            "DS-Lite-Tunnel-Name"                    => [ 144,  "octets" ],
            "EAP-Code"                               => [ 1021, "integer" ],
            "EAP-EMSK"                               => [ 1130, "octets" ],
            "EAP-Id"                                 => [ 1020, "integer" ],
            "EAP-IKEv2-AuthType"                     => [ 1106, "integer" ],
            "EAP-IKEv2-ID"                           => [ 1104, "string" ],
            "EAP-IKEv2-IDType"                       => [ 1103, "integer" ],
            "EAP-IKEv2-Secret"                       => [ 1105, "string" ],
            "EAP-Key-Name"                           => [ 102,  "octets" ],
            "EAP-Lower-Layer"                        => [ 163,  "integer" ],
            "EAP-MD5-Password"                       => [ 1022, "string" ],
            "EAP-Message"                            => [ 79,   "octets" ],
            "EAP-MSK"                                => [ 1129, "octets" ],
            "EAP-Peer-Id"                            => [ 175,  "octets" ],
            "EAP-Pwd-Password-Hash"                  => [ 1220, "octets" ],
            "EAP-Pwd-Password-Prep"                  => [ 1222, "byte" ],
            "EAP-Pwd-Password-Salt"                  => [ 1221, "octets" ],
            "EAP-Server-Id"                          => [ 176,  "octets" ],
            "EAP-Session-Id"                         => [ 1146, "octets" ],
            "EAP-Session-Resumed"                    => [ 1128, "integer" ],
            "EAP-Sim-Algo-Version"                   => [ 1216, "integer" ],
            "EAP-Sim-ANY_ID_REQ"                     => [ 1549, "octets" ],
            "EAP-Sim-CHECKCODE"                      => [ 1670, "octets" ],
            "EAP-Sim-COUNTER"                        => [ 1555, "octets" ],
            "EAP-Sim-COUNTER_TOO_SMALL"              => [ 1556, "octets" ],
            "EAP-Sim-ENCR_DATA"                      => [ 1666, "octets" ],
            "EAP-Sim-EXTRA"                          => [ 1211, "octets" ],
            "EAP-Sim-FULLAUTH_ID_REQ"                => [ 1553, "octets" ],
            "EAP-Sim-HMAC"                           => [ 1209, "string" ],
            "EAP-Sim-IDENTITY"                       => [ 1550, "octets" ],
            "EAP-Sim-IMSI"                           => [ 1208, "string" ],
            "EAP-Sim-IV"                             => [ 1665, "octets" ],
            "EAP-Sim-KC1"                            => [ 1212, "octets" ],
            "EAP-Sim-KC2"                            => [ 1213, "octets" ],
            "EAP-Sim-KC3"                            => [ 1214, "octets" ],
            "EAP-Sim-KEY"                            => [ 1210, "octets" ],
            "EAP-Sim-Ki"                             => [ 1215, "octets" ],
            "EAP-Sim-MAC"                            => [ 1547, "octets" ],
            "EAP-Sim-NEXT_PSEUDONUM"                 => [ 1668, "octets" ],
            "EAP-Sim-NEXT_REAUTH_ID"                 => [ 1669, "octets" ],
            "EAP-Sim-NONCE_MT"                       => [ 1543, "octets" ],
            "EAP-Sim-NONCE_S"                        => [ 1557, "octets" ],
            "EAP-Sim-NOTIFICATION"                   => [ 1548, "octets" ],
            "EAP-Sim-PADDING"                        => [ 1542, "octets" ],
            "EAP-Sim-PERMANENT_ID_REQ"               => [ 1546, "octets" ],
            "EAP-Sim-RAND"                           => [ 1537, "octets" ],
            "EAP-Sim-Rand1"                          => [ 1201, "octets" ],
            "EAP-Sim-Rand2"                          => [ 1202, "octets" ],
            "EAP-Sim-Rand3"                          => [ 1203, "octets" ],
            "EAP-Sim-SELECTED_VERSION"               => [ 1552, "octets" ],
            "EAP-Sim-SRES1"                          => [ 1204, "octets" ],
            "EAP-Sim-SRES2"                          => [ 1205, "octets" ],
            "EAP-Sim-SRES3"                          => [ 1206, "octets" ],
            "EAP-Sim-State"                          => [ 1207, "integer" ],
            "EAP-Sim-Subtype"                        => [ 1200, "integer" ],
            "EAP-Sim-VERSION_LIST"                   => [ 1551, "octets" ],
            "EAP-TLS-Require-Client-Cert"            => [ 1019, "integer" ],
            "EAP-Type"                               => [ 1018, "integer" ],
            "EAP-Type-AirFortress-EAP"               => [ 1317, "octets" ],
            "EAP-Type-AKA"                           => [ 1303, "octets" ],
            "EAP-Type-Arcot-Systems-EAP"             => [ 1296, "octets" ],
            "EAP-Type-Base"                          => [ 1280, "octets" ],
            "EAP-Type-Cisco-LEAP"                    => [ 1297, "octets" ],
            "EAP-Type-Cisco-MS-CHAPv2"               => [ 1309, "octets" ],
            "EAP-Type-Cogent-Biomentric-EAP"         => [ 1316, "octets" ],
            "EAP-Type-CRYPTOCard"                    => [ 1308, "octets" ],
            "EAP-Type-Defender-Token"                => [ 1294, "octets" ],
            "EAP-Type-DeviceConnect-EAP"             => [ 1320, "octets" ],
            "EAP-Type-DSS-Unilateral"                => [ 1290, "octets" ],
            "EAP-Type-DynamID"                       => [ 1310, "octets" ],
            "EAP-Type-EAP-3Com-Wireless"             => [ 1304, "octets" ],
            "EAP-Type-EAP-Actiontec-Wireless"        => [ 1315, "octets" ],
            "EAP-Type-EAP-AKA2"                      => [ 1330, "octets" ],
            "EAP-Type-EAP-EVEv1"                     => [ 1333, "octets" ],
            "EAP-Type-EAP-FAST"                      => [ 1323, "octets" ],
            "EAP-Type-EAP-GPSK"                      => [ 1331, "octets" ],
            "EAP-Type-EAP-HTTP-Digest"               => [ 1318, "octets" ],
            "EAP-Type-EAP-IKEv2"                     => [ 1329, "octets" ],
            "EAP-Type-EAP-Link"                      => [ 1325, "octets" ],
            "EAP-Type-EAP-MOBAC"                     => [ 1322, "octets" ],
            "EAP-Type-EAP-MSCHAP-V2"                 => [ 1309, "octets" ],
            "EAP-Type-EAP-PAX"                       => [ 1326, "octets" ],
            "EAP-Type-EAP-PSK"                       => [ 1327, "octets" ],
            "EAP-Type-EAP-PT-EAP"                    => [ 1334, "octets" ],
            "EAP-Type-EAP-PWD"                       => [ 1332, "octets" ],
            "EAP-Type-EAP-SAKE"                      => [ 1328, "octets" ],
            "EAP-Type-EAP-SPEKE"                     => [ 1321, "octets" ],
            "EAP-Type-EAP-TEAP"                      => [ 1335, "octets" ],
            "EAP-Type-EAP-TLS"                       => [ 1293, "octets" ],
            "EAP-Type-EAP-TTLS"                      => [ 1301, "octets" ],
            "EAP-Type-Generic-Token-Card"            => [ 1286, "octets" ],
            "EAP-Type-Identity"                      => [ 1281, "octets" ],
            "EAP-Type-KEA"                           => [ 1291, "octets" ],
            "EAP-Type-KEA-Validate"                  => [ 1292, "octets" ],
            "EAP-Type-MAKE"                          => [ 1307, "octets" ],
            "EAP-Type-MD5-Challenge"                 => [ 1284, "octets" ],
            "EAP-Type-Microsoft-MS-CHAPv2"           => [ 1306, "octets" ],
            "EAP-Type-MS-Authentication-TLV"         => [ 1313, "octets" ],
            "EAP-Type-MS-CHAP-V2"                    => [ 1306, "octets" ],
            "EAP-Type-MS-EAP-Authentication"         => [ 1306, "octets" ],
            "EAP-Type-NAK"                           => [ 1283, "octets" ],
            "EAP-Type-Nokia-IP-Smart-Card"           => [ 1298, "octets" ],
            "EAP-Type-None"                          => [ 1280, "octets" ],
            "EAP-Type-Notification"                  => [ 1282, "octets" ],
            "EAP-Type-One-Time-Password"             => [ 1285, "octets" ],
            "EAP-Type-PEAP"                          => [ 1305, "octets" ],
            "EAP-Type-Remote-Access-Service"         => [ 1302, "octets" ],
            "EAP-Type-Rob-EAP"                       => [ 1311, "octets" ],
            "EAP-Type-RSA-Public-Key"                => [ 1289, "octets" ],
            "EAP-Type-RSA-SecurID-EAP"               => [ 1295, "octets" ],
            "EAP-Type-SecurID-EAP"                   => [ 1312, "octets" ],
            "EAP-Type-SecuriSuite-EAP"               => [ 1319, "octets" ],
            "EAP-Type-SentriNET"                     => [ 1314, "octets" ],
            "EAP-Type-SIM"                           => [ 1298, "octets" ],
            "EAP-Type-SRP-SHA1"                      => [ 1299, "octets" ],
            "EAP-Type-VALUE"                         => [ 1280, "octets" ],
            "EAP-Type-Zonelabs"                      => [ 1324, "octets" ],
            "EAP_Sim-Base"                           => [ 1536, "octets" ],
            "EAPoL-Announcement"                     => [ 180,  "octets" ],
            "Egress-VLAN-Name"                       => [ 58,   "string" ],
            "Egress-VLANID"                          => [ 56,   "integer" ],
            "Error-Cause"                            => [ 101,  "integer" ],
            "Event-Timestamp"                        => [ 55,   "date" ],
            "Exec-Program"                           => [ 502,  "string" ],
            "Exec-Program-Wait"                      => [ 503,  "string" ],
            "Expiration"                             => [ 1010, "date" ],
            "Extended-Location-Policy-Rules"         => [ 130,  "string" ],
            "Fall-Through"                           => [ 500,  "integer" ],
            "Filter-Id"                              => [ 11,   "string" ],
            "Frag-Status"                            => [ 241,  "integer" ],
            "Framed-Address"                         => [ 8,    "ipaddr" ],
            "Framed-AppleTalk-Link"                  => [ 37,   "integer" ],
            "Framed-AppleTalk-Network"               => [ 38,   "integer" ],
            "Framed-AppleTalk-Zone"                  => [ 39,   "string" ],
            "Framed-Callback-Id"                     => [ 20,   "string" ],
            "Framed-Compression"                     => [ 13,   "integer" ],
            "Framed-Filter-Id"                       => [ 11,   "string" ],
            "Framed-Interface-Id"                    => [ 96,   "ifid" ],
            "Framed-IP-Address"                      => [ 8,    "ipaddr" ],
            "Framed-IP-Netmask"                      => [ 9,    "ipaddr" ],
            "Framed-IPv6-Address"                    => [ 168,  "ipv6addr" ],
            "Framed-IPv6-Pool"                       => [ 100,  "string" ],
            "Framed-IPv6-Prefix"                     => [ 97,   "ipv6prefix" ],
            "Framed-IPv6-Route"                      => [ 99,   "string" ],
            "Framed-IPX-Network"                     => [ 23,   "ipaddr" ],
            "Framed-Management"                      => [ 133,  "integer" ],
            "Framed-MTU"                             => [ 12,   "integer" ],
            "Framed-Netmask"                         => [ 9,    "ipaddr" ],
            "Framed-Pool"                            => [ 88,   "string" ],
            "Framed-Protocol"                        => [ 7,    "integer" ],
            "Framed-Route"                           => [ 22,   "string" ],
            "Framed-Routing"                         => [ 10,   "integer" ],
            "FreeRADIUS-Client-IP-Address"           => [ 1120, "ipaddr" ],
            "FreeRADIUS-Client-IP-Prefix"            => [ 1150, "ipv4prefix" ],
            "FreeRADIUS-Client-IPv6-Address"         => [ 1121, "ipv6addr" ],
            "FreeRADIUS-Client-IPv6-Prefix"          => [ 1151, "ipv6prefix" ],
            "FreeRADIUS-Client-NAS-Type"             => [ 1125, "string" ],
            "FreeRADIUS-Client-Require-MA"           => [ 1122, "integer" ],
            "FreeRADIUS-Client-Secret"               => [ 1123, "string" ],
            "FreeRADIUS-Client-Shortname"            => [ 1124, "string" ],
            "FreeRADIUS-Client-Src-IP-Address"       => [ 1153, "ipaddr" ],
            "FreeRADIUS-Client-Src-IPv6-Address"     => [ 1154, "ipv6addr" ],
            "FreeRADIUS-Client-Virtual-Server"       => [ 1126, "string" ],
            "FreeRADIUS-Response-Delay"              => [ 1152, "integer" ],
            "FreeRADIUS-Response-Delay-USec"         => [ 1155, "integer" ],
            "Group"                                  => [ 1005, "string" ],
            "Group-Name"                             => [ 1030, "string" ],
            "GSS-Acceptor-Host-Name"                 => [ 165,  "string" ],
            "GSS-Acceptor-Realm-Name"                => [ 167,  "string" ],
            "GSS-Acceptor-Service-Name"              => [ 164,  "string" ],
            "GSS-Acceptor-Service-Specifics"         => [ 166,  "string" ],
            "Hint"                                   => [ 1040, "string" ],
            "Home-Server-Name"                       => [ 1193, "string" ],
            "Home-Server-Pool"                       => [ 1111, "string" ],
            "Huntgroup-Name"                         => [ 1031, "string" ],
            "Idle-Timeout"                           => [ 28,   "integer" ],
            "Ingress-Filters"                        => [ 57,   "integer" ],
            "Inner-Realm-Name"                       => [ 1219, "string" ],
            "Inner-Tunnel-User-Name"                 => [ 1102, "string" ],
            "IP-Port-Alloc"                          => [ 241,  "integer" ],
            "IP-Port-Ext-IPv4-Addr"                  => [ 241,  "ipaddr" ],
            "IP-Port-Ext-Port"                       => [ 241,  "integer" ],
            "IP-Port-Forwarding-Map"                 => [ 241,  "tlv" ],
            "IP-Port-Int-IPv4-Addr"                  => [ 241,  "ipaddr" ],
            "IP-Port-Int-IPv6-Addr"                  => [ 241,  "ipv6addr" ],
            "IP-Port-Int-Port"                       => [ 241,  "integer" ],
            "IP-Port-Limit"                          => [ 241,  "integer" ],
            "IP-Port-Limit-Info"                     => [ 241,  "tlv" ],
            "IP-Port-Local-Id"                       => [ 241,  "string" ],
            "IP-Port-Map-Alloc"                      => [ 241,  "integer" ],
            "IP-Port-Map-Ext-IPv4-Addr"              => [ 241,  "ipaddr" ],
            "IP-Port-Map-Ext-Port"                   => [ 241,  "integer" ],
            "IP-Port-Map-Int-IPv4-Addr"              => [ 241,  "ipaddr" ],
            "IP-Port-Map-Int-IPv6-Addr"              => [ 241,  "ipv6addr" ],
            "IP-Port-Map-Int-Port"                   => [ 241,  "integer" ],
            "IP-Port-Map-Limit"                      => [ 241,  "integer" ],
            "IP-Port-Map-Local-Id"                   => [ 241,  "string" ],
            "IP-Port-Map-Range-End"                  => [ 241,  "integer" ],
            "IP-Port-Map-Range-Start"                => [ 241,  "integer" ],
            "IP-Port-Map-Type"                       => [ 241,  "integer" ],
            "IP-Port-Range"                          => [ 241,  "tlv" ],
            "IP-Port-Range-Alloc"                    => [ 241,  "integer" ],
            "IP-Port-Range-End"                      => [ 241,  "integer" ],
            "IP-Port-Range-Ext-IPv4-Addr"            => [ 241,  "ipaddr" ],
            "IP-Port-Range-Ext-Port"                 => [ 241,  "integer" ],
            "IP-Port-Range-Int-IPv4-Addr"            => [ 241,  "ipaddr" ],
            "IP-Port-Range-Int-IPv6-Addr"            => [ 241,  "ipv6addr" ],
            "IP-Port-Range-Int-Port"                 => [ 241,  "integer" ],
            "IP-Port-Range-Limit"                    => [ 241,  "integer" ],
            "IP-Port-Range-Local-Id"                 => [ 241,  "string" ],
            "IP-Port-Range-Range-End"                => [ 241,  "integer" ],
            "IP-Port-Range-Range-Start"              => [ 241,  "integer" ],
            "IP-Port-Range-Start"                    => [ 241,  "integer" ],
            "IP-Port-Range-Type"                     => [ 241,  "integer" ],
            "IP-Port-Type"                           => [ 241,  "integer" ],
            "IPv6-6rd-BR-IPv4-Address"               => [ 173,  "ipaddr" ],
            "IPv6-6rd-Configuration"                 => [ 173,  "tlv" ],
            "IPv6-6rd-IPv4MaskLen"                   => [ 173,  "integer" ],
            "IPv6-6rd-Prefix"                        => [ 173,  "ipv6prefix" ],
            "LDAP-UserDN"                            => [ 1053, "string" ],
            "LM-Password"                            => [ 1057, "octets" ],
            "Load-Balance-Key"                       => [ 1025, "string" ],
            "Location-Capable"                       => [ 131,  "integer" ],
            "Location-Data"                          => [ 128,  "octets" ],
            "Location-Information"                   => [ 127,  "octets" ],
            "Login-Callback-Number"                  => [ 19,   "string" ],
            "Login-Host"                             => [ 14,   "ipaddr" ],
            "Login-IP-Host"                          => [ 14,   "ipaddr" ],
            "Login-IPv6-Host"                        => [ 98,   "ipv6addr" ],
            "Login-LAT-Group"                        => [ 36,   "octets" ],
            "Login-LAT-Node"                         => [ 35,   "string" ],
            "Login-LAT-Port"                         => [ 63,   "string" ],
            "Login-LAT-Service"                      => [ 34,   "string" ],
            "Login-Port"                             => [ 16,   "integer" ],
            "Login-Service"                          => [ 15,   "integer" ],
            "Login-TCP-Port"                         => [ 16,   "integer" ],
            "Login-Time"                             => [ 1042, "string" ],
            "Management-Policy-Id"                   => [ 135,  "string" ],
            "Management-Privilege-Level"             => [ 136,  "integer" ],
            "Management-Transport-Protection"        => [ 134,  "integer" ],
            "MD5-Password"                           => [ 1095, "octets" ],
            "Menu"                                   => [ 1001, "string" ],
            "Message-Authenticator"                  => [ 80,   "octets" ],
            "MIP6-Feature-Vector"                    => [ 124,  "integer64" ],
            "MIP6-Home-Link-Prefix"                  => [ 125,  "octets" ],
            "Mobile-Node-Identifier"                 => [ 145,  "octets" ],
            "Mobility-Domain-Id"                     => [ 177,  "integer" ],
            "Module-Failure-Message"                 => [ 1076, "string" ],
            "Module-Return-Code"                     => [ 1108, "integer" ],
            "Module-Success-Message"                 => [ 1075, "string" ],
            "MS-CHAP-New-Cleartext-Password"         => [ 1136, "string" ],
            "MS-CHAP-New-NT-Password"                => [ 1137, "octets" ],
            "MS-CHAP-Password"                       => [ 1133, "string" ],
            "MS-CHAP-Peer-Challenge"                 => [ 1192, "octets" ],
            "MS-CHAP-Use-NTLM-Auth"                  => [ 1082, "integer" ],
            "MS-CHAP-User-Name"                      => [ 1083, "string" ],
            "Multi-Link-Flag"                        => [ 126,  "integer" ],
            "NAS-Filter-Rule"                        => [ 92,   "string" ],
            "NAS-Identifier"                         => [ 32,   "string" ],
            "NAS-IP-Address"                         => [ 4,    "ipaddr" ],
            "NAS-IPv6-Address"                       => [ 95,   "ipv6addr" ],
            "NAS-Port"                               => [ 5,    "integer" ],
            "NAS-Port-Id"                            => [ 87,   "string" ],
            "NAS-Port-Type"                          => [ 61,   "integer" ],
            "Network-Id-Name"                        => [ 179,  "octets" ],
            "No-Such-Attribute"                      => [ 1046, "string" ],
            "NS-MTA-MD5-Password"                    => [ 1054, "string" ],
            "NT-Password"                            => [ 1058, "octets" ],
            "NTLM-User-Name"                         => [ 1083, "string" ],
            "OAuth2-Group"                           => [ 3001, "string" ],
            "OAuth2-Password-Last-Modified"          => [ 3000, "date" ],
            "Old-Password"                           => [ 17,   "string" ],
            "Operator-Name"                          => [ 126,  "string" ],
            "Operator-NAS-Identifier"                => [ 241,  "octets" ],
            "Original-Packet-Code"                   => [ 241,  "integer" ],
            "Originating-Line-Info"                  => [ 94,   "octets" ],
            "Originating-Realm-Key"                  => [ 1194, "string" ],
            "OTP-Challenge"                          => [ 1145, "string" ],
            "Outer-Realm-Name"                       => [ 1218, "string" ],
            "Packet-Authentication-Vector"           => [ 1088, "octets" ],
            "Packet-Dst-IP-Address"                  => [ 1085, "ipaddr" ],
            "Packet-Dst-IPv6-Address"                => [ 1098, "ipv6addr" ],
            "Packet-Dst-Port"                        => [ 1087, "integer" ],
            "Packet-Original-Timestamp"              => [ 1109, "date" ],
            "Packet-Src-IP-Address"                  => [ 1084, "ipaddr" ],
            "Packet-Src-IPv6-Address"                => [ 1097, "ipv6addr" ],
            "Packet-Src-Port"                        => [ 1086, "integer" ],
            "Packet-Transmit-Counter"                => [ 1134, "integer" ],
            "Packet-Type"                            => [ 1047, "integer" ],
            "Pairwise-Master-Key"                    => [ 1142, "octets" ],
            "Pam-Auth"                               => [ 1041, "string" ],
            "Password-Retry"                         => [ 75,   "integer" ],
            "Password-With-Header"                   => [ 1101, "string" ],
            "PBKDF2-Password"                        => [ 1181, "octets" ],
            "PEAP-Version"                           => [ 1023, "integer" ],
            "PKM-Auth-Key"                           => [ 143,  "octets" ],
            "PKM-CA-Cert"                            => [ 138,  "octets" ],
            "PKM-Config-Settings"                    => [ 139,  "octets" ],
            "PKM-Cryptosuite-List"                   => [ 140,  "octets" ],
            "PKM-SA-Descriptor"                      => [ 142,  "octets" ],
            "PKM-SAID"                               => [ 141,  "short" ],
            "PKM-SS-Cert"                            => [ 137,  "octets" ],
            "PMIP6-Home-DHCP4-Server-Address"        => [ 157,  "ipaddr" ],
            "PMIP6-Home-DHCP6-Server-Address"        => [ 159,  "ipv6addr" ],
            "PMIP6-Home-HN-Prefix"                   => [ 151,  "ipv6prefix" ],
            "PMIP6-Home-Interface-ID"                => [ 153,  "ifid" ],
            "PMIP6-Home-IPv4-Gateway"                => [ 161,  "ipaddr" ],
            "PMIP6-Home-IPv4-HoA"                    => [ 155,  "ipv4prefix" ],
            "PMIP6-Home-LMA-IPv4-Address"            => [ 149,  "ipaddr" ],
            "PMIP6-Home-LMA-IPv6-Address"            => [ 147,  "ipv6addr" ],
            "PMIP6-Visited-DHCP4-Server-Address"     => [ 158,  "ipaddr" ],
            "PMIP6-Visited-DHCP6-Server-Address"     => [ 160,  "ipv6addr" ],
            "PMIP6-Visited-HN-Prefix"                => [ 152,  "ipv6prefix" ],
            "PMIP6-Visited-Interface-ID"             => [ 154,  "ifid" ],
            "PMIP6-Visited-IPv4-Gateway"             => [ 162,  "ipaddr" ],
            "PMIP6-Visited-IPv4-HoA"                 => [ 156,  "ipv4prefix" ],
            "PMIP6-Visited-LMA-IPv4-Address"         => [ 150,  "ipaddr" ],
            "PMIP6-Visited-LMA-IPv6-Address"         => [ 148,  "ipv6addr" ],
            "Pool-Name"                              => [ 1073, "string" ],
            "Port-Limit"                             => [ 62,   "integer" ],
            "Port-Message"                           => [ 18,   "string" ],
            "Post-Auth-Type"                         => [ 1014, "integer" ],
            "Post-Proxy-Type"                        => [ 1016, "integer" ],
            "Pre-Acct-Type"                          => [ 1017, "integer" ],
            "Pre-Proxy-Type"                         => [ 1015, "integer" ],
            "Pre-Shared-Key"                         => [ 1141, "string" ],
            "Preauth-Timeout"                        => [ 178,  "integer" ],
            "Prefix"                                 => [ 1003, "string" ],
            "Prompt"                                 => [ 76,   "integer" ],
            "Proxy-State"                            => [ 33,   "octets" ],
            "Proxy-State-Length"                     => [ 241,  "integer" ],
            "Proxy-To-Originating-Realm"             => [ 1195, "string" ],
            "Proxy-To-Realm"                         => [ 1048, "string" ],
            "Proxy-Tunneled-Request-As-EAP"          => [ 1197, "integer" ],
            "PSK-Identity"                           => [ 1143, "string" ],
            "Radclient-Test-Name"                    => [ 2200, "string" ],
            "Raw-Attribute"                          => [ 1026, "octets" ],
            "Realm"                                  => [ 1045, "string" ],
            "Recv-CoA-Type"                          => [ 1131, "integer" ],
            "Relax-Filter"                           => [ 501,  "integer" ],
            "Replicate-To-Realm"                     => [ 1049, "string" ],
            "Reply-Message"                          => [ 18,   "string" ],
            "Request-Processing-Stage"               => [ 1090, "string" ],
            "Requested-Location-Info"                => [ 132,  "integer" ],
            "Response-Length"                        => [ 241,  "integer" ],
            "Response-Packet-Type"                   => [ 1080, "integer" ],
            "REST-HTTP-Body"                         => [ 1161, "string" ],
            "REST-HTTP-Header"                       => [ 1160, "string" ],
            "REST-HTTP-Status-Code"                  => [ 1162, "integer" ],
            "Rewrite-Rule"                           => [ 1078, "string" ],
            "Route-IPv6-Information"                 => [ 170,  "ipv6prefix" ],
            "Send-CoA-Request"                       => [ 1107, "integer" ],
            "Send-CoA-Type"                          => [ 1132, "integer" ],
            "Send-Disconnect-Request"                => [ 1107, "integer" ],
            "Service-Selection"                      => [ 146,  "string" ],
            "Service-Type"                           => [ 6,    "integer" ],
            "Session-Timeout"                        => [ 27,   "integer" ],
            "Session-Type"                           => [ 1013, "integer" ],
            "SHA-Password"                           => [ 1093, "octets" ],
            "SHA1-Password"                          => [ 1093, "octets" ],
            "SHA2-Password"                          => [ 1092, "octets" ],
            "Simultaneous-Use"                       => [ 1034, "integer" ],
            "SMB-Account-CTRL"                       => [ 1059, "integer" ],
            "SMB-Account-CTRL-TEXT"                  => [ 1061, "string" ],
            "SMD5-Password"                          => [ 1096, "octets" ],
            "SoH-MS-Correlation-Id"                  => [ 2108, "octets" ],
            "SoH-MS-Health-Other"                    => [ 2129, "string" ],
            "SoH-MS-Machine-Name"                    => [ 2107, "string" ],
            "SoH-MS-Machine-OS-build"                => [ 2103, "integer" ],
            "SoH-MS-Machine-OS-release"              => [ 2102, "integer" ],
            "SoH-MS-Machine-OS-vendor"               => [ 2100, "integer" ],
            "SoH-MS-Machine-OS-version"              => [ 2101, "integer" ],
            "SoH-MS-Machine-Processor"               => [ 2106, "integer" ],
            "SoH-MS-Machine-Role"                    => [ 2109, "integer" ],
            "SoH-MS-Machine-SP-release"              => [ 2105, "integer" ],
            "SoH-MS-Machine-SP-version"              => [ 2104, "integer" ],
            "SoH-MS-Windows-Health-Status"           => [ 2120, "string" ],
            "SoH-Supported"                          => [ 2119, "integer" ],
            "SQL-Table-Name"                         => [ 1110, "string" ],
            "SQL-User-Name"                          => [ 1055, "string" ],
            "SSHA-Password"                          => [ 1094, "octets" ],
            "SSHA1-Password"                         => [ 1094, "octets" ],
            "SSHA2-224-Password"                     => [ 1177, "octets" ],
            "SSHA2-256-Password"                     => [ 1178, "octets" ],
            "SSHA2-384-Password"                     => [ 1179, "octets" ],
            "SSHA2-512-Password"                     => [ 1180, "octets" ],
            "SSHA3-224-Password"                     => [ 1182, "octets" ],
            "SSHA3-256-Password"                     => [ 1183, "octets" ],
            "SSHA3-384-Password"                     => [ 1184, "octets" ],
            "SSHA3-512-Password"                     => [ 1185, "octets" ],
            "State"                                  => [ 24,   "octets" ],
            "Stateful-IPv6-Address-Pool"             => [ 172,  "string" ],
            "Strip-User-Name"                        => [ 1035, "integer" ],
            "Stripped-User-Domain"                   => [ 1138, "string" ],
            "Stripped-User-Name"                     => [ 1043, "string" ],
            "Suffix"                                 => [ 1004, "string" ],
            "TEAP-Type-Machine"                      => [ 1223, "integer" ],
            "TEAP-Type-User"                         => [ 1224, "integer" ],
            "Temp-Home-Server-String"                => [ 1198, "string" ],
            "Termination-Action"                     => [ 29,   "integer" ],
            "Termination-Menu"                       => [ 1002, "string" ],
            "Time-Of-Day"                            => [ 1089, "string" ],
            "TLS-Cache-Filename"                     => [ 1946, "string" ],
            "TLS-Cache-Method"                       => [ 1938, "integer" ],
            "TLS-Cert-Common-Name"                   => [ 1914, "string" ],
            "TLS-Cert-Expiration"                    => [ 1911, "string" ],
            "TLS-Cert-Issuer"                        => [ 1912, "string" ],
            "TLS-Cert-Serial"                        => [ 1910, "string" ],
            "TLS-Cert-Subject"                       => [ 1913, "string" ],
            "TLS-Cert-Subject-Alt-Name-Dns"          => [ 1916, "string" ],
            "TLS-Cert-Subject-Alt-Name-Email"        => [ 1915, "string" ],
            "TLS-Cert-Subject-Alt-Name-Upn"          => [ 1917, "string" ],
            "TLS-Cert-Subject-Alt-Name-Uri"          => [ 1934, "string" ],
            "TLS-Cert-Valid-Since"                   => [ 1918, "string" ],
            "TLS-Client-Cert-Common-Name"            => [ 1924, "string" ],
            "TLS-Client-Cert-Expiration"             => [ 1921, "string" ],
            "TLS-Client-Cert-Filename"               => [ 1925, "string" ],
            "TLS-Client-Cert-Issuer"                 => [ 1922, "string" ],
            "TLS-Client-Cert-Serial"                 => [ 1920, "string" ],
            "TLS-Client-Cert-Subject"                => [ 1923, "string" ],
            "TLS-Client-Cert-Subject-Alt-Name-Dns"   => [ 1931, "string" ],
            "TLS-Client-Cert-Subject-Alt-Name-Email" => [ 1926, "string" ],
            "TLS-Client-Cert-Subject-Alt-Name-Upn"   => [ 1932, "string" ],
            "TLS-Client-Cert-Subject-Alt-Name-Uri"   => [ 1935, "string" ],
            "TLS-Client-Cert-Valid-Since"            => [ 1937, "string" ],
            "TLS-Client-Cert-X509v3-Authority-Key-Identifier" =>
              [ 1929, "string" ],
            "TLS-Client-Cert-X509v3-Basic-Constraints"    => [ 1930, "string" ],
            "TLS-Client-Cert-X509v3-Certificate-Policies" => [ 1939, "string" ],
            "TLS-Client-Cert-X509v3-Extended-Key-Usage"   => [ 1927, "string" ],
            "TLS-Client-Cert-X509v3-Extended-Key-Usage-OID" =>
              [ 1936, "string" ],
            "TLS-Client-Cert-X509v3-Subject-Key-Identifier" =>
              [ 1928, "string" ],
            "TLS-OCSP-Cert-Valid"               => [ 1943, "integer" ],
            "TLS-PSK-Identity"                  => [ 1933, "string" ],
            "TLS-Server-Name-Indication"        => [ 1951, "string" ],
            "TLS-Session-Cert-File"             => [ 1949, "string" ],
            "TLS-Session-Cert-Private-Key-File" => [ 1950, "string" ],
            "TLS-Session-Cipher-Suite"          => [ 1948, "string" ],
            "TLS-Session-Data"                  => [ 1942, "octets" ],
            "TLS-Session-ID"                    => [ 1940, "octets" ],
            "TLS-Session-Information"           => [ 1919, "string" ],
            "TLS-Session-Version"               => [ 1947, "string" ],
            "Tmp-Cast-Abinary"                  => [ 1855, "abinary" ],
            "Tmp-Cast-Byte"                     => [ 1860, "byte" ],
            "Tmp-Cast-Date"                     => [ 1854, "date" ],
            "Tmp-Cast-Ethernet"                 => [ 1862, "ether" ],
            "Tmp-Cast-Ifid"                     => [ 1857, "ifid" ],
            "Tmp-Cast-Integer"                  => [ 1852, "integer" ],
            "Tmp-Cast-Integer64"                => [ 1869, "integer64" ],
            "Tmp-Cast-Ipaddr"                   => [ 1853, "ipaddr" ],
            "Tmp-Cast-IPv4Prefix"               => [ 1870, "ipv4prefix" ],
            "Tmp-Cast-IPv6Addr"                 => [ 1858, "ipv6addr" ],
            "Tmp-Cast-IPv6Prefix"               => [ 1859, "ipv6prefix" ],
            "Tmp-Cast-Octets"                   => [ 1856, "octets" ],
            "Tmp-Cast-Short"                    => [ 1861, "short" ],
            "Tmp-Cast-Signed"                   => [ 1863, "signed" ],
            "Tmp-Cast-String"                   => [ 1851, "string" ],
            "Tmp-Date-0"                        => [ 1840, "date" ],
            "Tmp-Date-1"                        => [ 1841, "date" ],
            "Tmp-Date-2"                        => [ 1842, "date" ],
            "Tmp-Date-3"                        => [ 1843, "date" ],
            "Tmp-Date-4"                        => [ 1844, "date" ],
            "Tmp-Date-5"                        => [ 1845, "date" ],
            "Tmp-Date-6"                        => [ 1846, "date" ],
            "Tmp-Date-7"                        => [ 1847, "date" ],
            "Tmp-Date-8"                        => [ 1848, "date" ],
            "Tmp-Date-9"                        => [ 1849, "date" ],
            "Tmp-Integer-0"                     => [ 1810, "integer" ],
            "Tmp-Integer-1"                     => [ 1811, "integer" ],
            "Tmp-Integer-2"                     => [ 1812, "integer" ],
            "Tmp-Integer-3"                     => [ 1813, "integer" ],
            "Tmp-Integer-4"                     => [ 1814, "integer" ],
            "Tmp-Integer-5"                     => [ 1815, "integer" ],
            "Tmp-Integer-6"                     => [ 1816, "integer" ],
            "Tmp-Integer-7"                     => [ 1817, "integer" ],
            "Tmp-Integer-8"                     => [ 1818, "integer" ],
            "Tmp-Integer-9"                     => [ 1819, "integer" ],
            "Tmp-Integer64-0"                   => [ 1871, "integer64" ],
            "Tmp-Integer64-1"                   => [ 1872, "integer64" ],
            "Tmp-Integer64-2"                   => [ 1873, "integer64" ],
            "Tmp-Integer64-3"                   => [ 1874, "integer64" ],
            "Tmp-Integer64-4"                   => [ 1875, "integer64" ],
            "Tmp-Integer64-5"                   => [ 1876, "integer64" ],
            "Tmp-Integer64-6"                   => [ 1877, "integer64" ],
            "Tmp-Integer64-7"                   => [ 1878, "integer64" ],
            "Tmp-Integer64-8"                   => [ 1879, "integer64" ],
            "Tmp-Integer64-9"                   => [ 1880, "integer64" ],
            "Tmp-IP-Address-0"                  => [ 1820, "ipaddr" ],
            "Tmp-IP-Address-1"                  => [ 1821, "ipaddr" ],
            "Tmp-IP-Address-2"                  => [ 1822, "ipaddr" ],
            "Tmp-IP-Address-3"                  => [ 1823, "ipaddr" ],
            "Tmp-IP-Address-4"                  => [ 1824, "ipaddr" ],
            "Tmp-IP-Address-5"                  => [ 1825, "ipaddr" ],
            "Tmp-IP-Address-6"                  => [ 1826, "ipaddr" ],
            "Tmp-IP-Address-7"                  => [ 1827, "ipaddr" ],
            "Tmp-IP-Address-8"                  => [ 1828, "ipaddr" ],
            "Tmp-IP-Address-9"                  => [ 1829, "ipaddr" ],
            "Tmp-Octets-0"                      => [ 1830, "octets" ],
            "Tmp-Octets-1"                      => [ 1831, "octets" ],
            "Tmp-Octets-2"                      => [ 1832, "octets" ],
            "Tmp-Octets-3"                      => [ 1833, "octets" ],
            "Tmp-Octets-4"                      => [ 1834, "octets" ],
            "Tmp-Octets-5"                      => [ 1835, "octets" ],
            "Tmp-Octets-6"                      => [ 1836, "octets" ],
            "Tmp-Octets-7"                      => [ 1837, "octets" ],
            "Tmp-Octets-8"                      => [ 1838, "octets" ],
            "Tmp-Octets-9"                      => [ 1839, "octets" ],
            "Tmp-String-0"                      => [ 1800, "string" ],
            "Tmp-String-1"                      => [ 1801, "string" ],
            "Tmp-String-2"                      => [ 1802, "string" ],
            "Tmp-String-3"                      => [ 1803, "string" ],
            "Tmp-String-4"                      => [ 1804, "string" ],
            "Tmp-String-5"                      => [ 1805, "string" ],
            "Tmp-String-6"                      => [ 1806, "string" ],
            "Tmp-String-7"                      => [ 1807, "string" ],
            "Tmp-String-8"                      => [ 1808, "string" ],
            "Tmp-String-9"                      => [ 1809, "string" ],
            "TNC-VLAN-Access"                   => [ 1027, "string" ],
            "TNC-VLAN-Isolate"                  => [ 1028, "string" ],
            "TOTP-Key"                          => [ 1195, "octets" ],
            "TOTP-Password"                     => [ 1196, "string" ],
            "TOTP-Secret"                       => [ 1194, "string" ],
            "TOTP-Time-Offset"                  => [ 1199, "signed" ],
            "Tunnel-Assignment-Id"              => [ 82,   "string" ],
            "Tunnel-Client-Auth-Id"             => [ 90,   "string" ],
            "Tunnel-Client-Endpoint"            => [ 66,   "string" ],
            "Tunnel-Medium-Type"                => [ 65,   "integer" ],
            "Tunnel-Password"                   => [ 69,   "string" ],
            "Tunnel-Preference"                 => [ 83,   "integer" ],
            "Tunnel-Private-Group-Id"           => [ 81,   "string" ],
            "Tunnel-Server-Auth-Id"             => [ 91,   "string" ],
            "Tunnel-Server-Endpoint"            => [ 67,   "string" ],
            "Tunnel-Type"                       => [ 64,   "integer" ],
            "User-Category"                     => [ 1029, "string" ],
            "User-Name"                         => [ 1,    "string" ],
            "User-Password"                     => [ 2,    "string" ],
            "User-Priority-Table"               => [ 59,   "octets" ],
            "User-Profile"                      => [ 1062, "string" ],
            "User-Service-Type"                 => [ 6,    "integer" ],
            "Vendor-Specific"                   => [ 26,   "vsa" ],
            "Virtual-Server"                    => [ 1099, "string" ],
            "WiMAX-MN-NAI"                      => [ 1900, "string" ],
            "WiMAX-SIM-AMF"                     => [ 1903, "octets" ],
            "WiMAX-SIM-Ki"                      => [ 1901, "octets" ],
            "WiMAX-SIM-OPc"                     => [ 1902, "octets" ],
            "WiMAX-SIM-RAND"                    => [ 1905, "octets" ],
            "WiMAX-SIM-SQN"                     => [ 1904, "octets" ],
            "WLAN-AKM-Suite"                    => [ 188,  "integer" ],
            "WLAN-Group-Cipher"                 => [ 187,  "integer" ],
            "WLAN-Group-Mgmt-Cipher"            => [ 189,  "integer" ],
            "WLAN-HESSID"                       => [ 181,  "string" ],
            "WLAN-Pairwise-Cipher"              => [ 186,  "integer" ],
            "WLAN-Reason-Code"                  => [ 185,  "integer" ],
            "WLAN-RF-Band"                      => [ 190,  "integer" ],
            "WLAN-Venue-Info"                   => [ 182,  "integer" ],
            "WLAN-Venue-Language"               => [ 183,  "octets" ],
            "WLAN-Venue-Name"                   => [ 184,  "string" ],
            "X-Ascend-Add-Seconds"              => [ 240,  "integer" ],
            "X-Ascend-Ara-PW"                   => [ 181,  "string" ],
            "X-Ascend-Assign-IP-Client"         => [ 144,  "ipaddr" ],
            "X-Ascend-Assign-IP-Global-Pool"    => [ 146,  "string" ],
            "X-Ascend-Assign-IP-Pool"           => [ 218,  "integer" ],
            "X-Ascend-Assign-IP-Server"         => [ 145,  "ipaddr" ],
            "X-Ascend-Authen-Alias"             => [ 203,  "string" ],
            "X-Ascend-Backup"                   => [ 176,  "string" ],
            "X-Ascend-BACP-Enable"              => [ 133,  "integer" ],
            "X-Ascend-Base-Channel-Count"       => [ 172,  "integer" ],
            "X-Ascend-Billing-Number"           => [ 249,  "string" ],
            "X-Ascend-Bridge"                   => [ 230,  "integer" ],
            "X-Ascend-Bridge-Address"           => [ 168,  "string" ],
            "X-Ascend-Call-Attempt-Limit"       => [ 123,  "integer" ],
            "X-Ascend-Call-Block-Duration"      => [ 124,  "integer" ],
            "X-Ascend-Call-By-Call"             => [ 250,  "integer" ],
            "X-Ascend-Call-Filter"              => [ 243,  "abinary" ],
            "X-Ascend-Call-Type"                => [ 177,  "integer" ],
            "X-Ascend-Callback"                 => [ 246,  "integer" ],
            "X-Ascend-Client-Assign-DNS"        => [ 137,  "integer" ],
            "X-Ascend-Client-Gateway"           => [ 132,  "ipaddr" ],
            "X-Ascend-Client-Primary-DNS"       => [ 135,  "ipaddr" ],
            "X-Ascend-Client-Secondary-DNS"     => [ 136,  "ipaddr" ],
            "X-Ascend-Connect-Progress"         => [ 196,  "integer" ],
            "X-Ascend-Data-Filter"              => [ 242,  "abinary" ],
            "X-Ascend-Data-Rate"                => [ 197,  "integer" ],
            "X-Ascend-Data-Svc"                 => [ 247,  "integer" ],
            "X-Ascend-DBA-Monitor"              => [ 171,  "integer" ],
            "X-Ascend-Dec-Channel-Count"        => [ 237,  "integer" ],
            "X-Ascend-DHCP-Maximum-Leases"      => [ 134,  "integer" ],
            "X-Ascend-DHCP-Pool-Number"         => [ 148,  "integer" ],
            "X-Ascend-DHCP-Reply"               => [ 147,  "integer" ],
            "X-Ascend-Dial-Number"              => [ 227,  "string" ],
            "X-Ascend-Dialout-Allowed"          => [ 131,  "integer" ],
            "X-Ascend-Disconnect-Cause"         => [ 195,  "integer" ],
            "X-Ascend-Event-Type"               => [ 150,  "integer" ],
            "X-Ascend-Expect-Callback"          => [ 149,  "integer" ],
            "X-Ascend-FCP-Parameter"            => [ 119,  "string" ],
            "X-Ascend-First-Dest"               => [ 189,  "ipaddr" ],
            "X-Ascend-Force-56"                 => [ 248,  "integer" ],
            "X-Ascend-FR-Circuit-Name"          => [ 156,  "string" ],
            "X-Ascend-FR-DCE-N392"              => [ 162,  "integer" ],
            "X-Ascend-FR-DCE-N393"              => [ 164,  "integer" ],
            "X-Ascend-FR-Direct"                => [ 219,  "integer" ],
            "X-Ascend-FR-Direct-DLCI"           => [ 221,  "integer" ],
            "X-Ascend-FR-Direct-Profile"        => [ 220,  "string" ],
            "X-Ascend-FR-DLCI"                  => [ 179,  "integer" ],
            "X-Ascend-FR-DTE-N392"              => [ 163,  "integer" ],
            "X-Ascend-FR-DTE-N393"              => [ 165,  "integer" ],
            "X-Ascend-FR-Link-Mgt"              => [ 160,  "integer" ],
            "X-Ascend-FR-LinkUp"                => [ 157,  "integer" ],
            "X-Ascend-FR-N391"                  => [ 161,  "integer" ],
            "X-Ascend-FR-Nailed-Grp"            => [ 158,  "integer" ],
            "X-Ascend-FR-Profile-Name"          => [ 180,  "string" ],
            "X-Ascend-FR-T391"                  => [ 166,  "integer" ],
            "X-Ascend-FR-T392"                  => [ 167,  "integer" ],
            "X-Ascend-FR-Type"                  => [ 159,  "integer" ],
            "X-Ascend-FT1-Caller"               => [ 175,  "integer" ],
            "X-Ascend-Group"                    => [ 178,  "string" ],
            "X-Ascend-Handle-IPX"               => [ 222,  "integer" ],
            "X-Ascend-History-Weigh-Type"       => [ 239,  "integer" ],
            "X-Ascend-Home-Agent-IP-Addr"       => [ 183,  "ipaddr" ],
            "X-Ascend-Home-Agent-Password"      => [ 184,  "string" ],
            "X-Ascend-Home-Agent-UDP-Port"      => [ 186,  "integer" ],
            "X-Ascend-Home-Network-Name"        => [ 185,  "string" ],
            "X-Ascend-Host-Info"                => [ 252,  "string" ],
            "X-Ascend-Idle-Limit"               => [ 244,  "integer" ],
            "X-Ascend-IF-Netmask"               => [ 153,  "ipaddr" ],
            "X-Ascend-Inc-Channel-Count"        => [ 236,  "integer" ],
            "X-Ascend-IP-Direct"                => [ 209,  "ipaddr" ],
            "X-Ascend-IP-Pool-Definition"       => [ 217,  "string" ],
            "X-Ascend-IPX-Alias"                => [ 224,  "integer" ],
            "X-Ascend-IPX-Node-Addr"            => [ 182,  "string" ],
            "X-Ascend-IPX-Peer-Mode"            => [ 216,  "integer" ],
            "X-Ascend-IPX-Route"                => [ 174,  "string" ],
            "X-Ascend-Link-Compression"         => [ 233,  "integer" ],
            "X-Ascend-Maximum-Call-Duration"    => [ 125,  "integer" ],
            "X-Ascend-Maximum-Channels"         => [ 235,  "integer" ],
            "X-Ascend-Maximum-Time"             => [ 194,  "integer" ],
            "X-Ascend-Menu-Item"                => [ 206,  "string" ],
            "X-Ascend-Menu-Selector"            => [ 205,  "string" ],
            "X-Ascend-Metric"                   => [ 225,  "integer" ],
            "X-Ascend-Minimum-Channels"         => [ 173,  "integer" ],
            "X-Ascend-Modem-PortNo"             => [ 120,  "integer" ],
            "X-Ascend-Modem-ShelfNo"            => [ 122,  "integer" ],
            "X-Ascend-Modem-SlotNo"             => [ 121,  "integer" ],
            "X-Ascend-MPP-Idle-Percent"         => [ 254,  "integer" ],
            "X-Ascend-Multicast-Client"         => [ 155,  "integer" ],
            "X-Ascend-Multicast-Rate-Limit"     => [ 152,  "integer" ],
            "X-Ascend-Multilink-ID"             => [ 187,  "integer" ],
            "X-Ascend-Netware-timeout"          => [ 223,  "integer" ],
            "X-Ascend-Num-In-Multilink"         => [ 188,  "integer" ],
            "X-Ascend-Number-Sessions"          => [ 202,  "string" ],
            "X-Ascend-PPP-Address"              => [ 253,  "ipaddr" ],
            "X-Ascend-PPP-Async-Map"            => [ 212,  "integer" ],
            "X-Ascend-PPP-VJ-1172"              => [ 211,  "integer" ],
            "X-Ascend-PPP-VJ-Slot-Comp"         => [ 210,  "integer" ],
            "X-Ascend-Pre-Input-Octets"         => [ 190,  "integer" ],
            "X-Ascend-Pre-Input-Packets"        => [ 192,  "integer" ],
            "X-Ascend-Pre-Output-Octets"        => [ 191,  "integer" ],
            "X-Ascend-Pre-Output-Packets"       => [ 193,  "integer" ],
            "X-Ascend-Preempt-Limit"            => [ 245,  "integer" ],
            "X-Ascend-PreSession-Time"          => [ 198,  "integer" ],
            "X-Ascend-PRI-Number-Type"          => [ 226,  "integer" ],
            "X-Ascend-Primary-Home-Agent"       => [ 129,  "string" ],
            "X-Ascend-PW-Lifetime"              => [ 208,  "integer" ],
            "X-Ascend-PW-Warntime"              => [ 207,  "integer" ],
            "X-Ascend-Receive-Secret"           => [ 215,  "string" ],
            "X-Ascend-Remote-Addr"              => [ 154,  "ipaddr" ],
            "X-Ascend-Remove-Seconds"           => [ 241,  "integer" ],
            "X-Ascend-Require-Auth"             => [ 201,  "integer" ],
            "X-Ascend-Route-IP"                 => [ 228,  "integer" ],
            "X-Ascend-Route-IPX"                => [ 229,  "integer" ],
            "X-Ascend-Secondary-Home-Agent"     => [ 130,  "string" ],
            "X-Ascend-Seconds-Of-History"       => [ 238,  "integer" ],
            "X-Ascend-Send-Auth"                => [ 231,  "integer" ],
            "X-Ascend-Send-Passwd"              => [ 232,  "string" ],
            "X-Ascend-Send-Secret"              => [ 214,  "string" ],
            "X-Ascend-Session-Svr-Key"          => [ 151,  "string" ],
            "X-Ascend-Shared-Profile-Enable"    => [ 128,  "integer" ],
            "X-Ascend-Target-Util"              => [ 234,  "integer" ],
            "X-Ascend-Temporary-Rtes"           => [ 126,  "integer" ],
            "X-Ascend-Third-Prompt"             => [ 213,  "string" ],
            "X-Ascend-Token-Expiry"             => [ 204,  "integer" ],
            "X-Ascend-Token-Idle"               => [ 199,  "integer" ],
            "X-Ascend-Token-Immediate"          => [ 200,  "integer" ],
            "X-Ascend-Transit-Number"           => [ 251,  "string" ],
            "X-Ascend-TS-Idle-Limit"            => [ 169,  "integer" ],
            "X-Ascend-TS-Idle-Mode"             => [ 170,  "integer" ],
            "X-Ascend-Tunneling-Protocol"       => [ 127,  "integer" ],
            "X-Ascend-User-Acct-Base"           => [ 142,  "integer" ],
            "X-Ascend-User-Acct-Host"           => [ 139,  "ipaddr" ],
            "X-Ascend-User-Acct-Key"            => [ 141,  "string" ],
            "X-Ascend-User-Acct-Port"           => [ 140,  "integer" ],
            "X-Ascend-User-Acct-Time"           => [ 143,  "integer" ],
            "X-Ascend-User-Acct-Type"           => [ 138,  "integer" ],
            "X-Ascend-Xmit-Rate"                => [ 255,  "integer" ],
        },
        avendors => {
            "3Com-Connect_Id"                                        => "3com",
            "3Com-Encryption-Type"                                   => "3com",
            "3Com-End-Date"                                          => "3com",
            "3Com-Ip-Host-Addr"                                      => "3com",
            "3Com-Mobility-Profile"                                  => "3com",
            "3Com-NAS-Startup-Timestamp"                             => "3com",
            "3Com-Product-ID"                                        => "3com",
            "3Com-SSID"                                              => "3com",
            "3Com-Time-Of-Day"                                       => "3com",
            "3Com-URL"                                               => "3com",
            "3Com-User-Access-Level"                                 => "3com",
            "3Com-VLAN-Name"                                         => "3com",
            "3GGP2-Hot-Line-Capability"                              => "3GPP2",
            "3GPP-Allocate-IP-Type"                                  => "3GPP",
            "3GPP-Camel-Charging-Info"                               => "3GPP",
            "3GPP-Charging-Characteristics"                          => "3GPP",
            "3GPP-Charging-Gateway-Address"                          => "3GPP",
            "3GPP-Charging-Gateway-IPv6-Address"                     => "3GPP",
            "3GPP-Charging-ID"                                       => "3GPP",
            "3GPP-GGSN-Address"                                      => "3GPP",
            "3GPP-GGSN-IPv6-Address"                                 => "3GPP",
            "3GPP-GGSN-MCC-MNC"                                      => "3GPP",
            "3GPP-GPRS-Negotiated-QoS-profile"                       => "3GPP",
            "3GPP-IMEISV"                                            => "3GPP",
            "3GPP-IMSI"                                              => "3GPP",
            "3GPP-IMSI-MCC-MNC"                                      => "3GPP",
            "3GPP-IPv6-DNS-Servers"                                  => "3GPP",
            "3GPP-Location-Info"                                     => "3GPP",
            "3GPP-MS-Time-Zone"                                      => "3GPP",
            "3GPP-Negotiated-DSCP"                                   => "3GPP",
            "3GPP-NSAPI"                                             => "3GPP",
            "3GPP-Packet-Filter"                                     => "3GPP",
            "3GPP-PDP-Type"                                          => "3GPP",
            "3GPP-RAT-Type"                                          => "3GPP",
            "3GPP-Selection-Mode"                                    => "3GPP",
            "3GPP-Session-Stop-Indicator"                            => "3GPP",
            "3GPP-SGSN-Address"                                      => "3GPP",
            "3GPP-SGSN-IPv6-Address"                                 => "3GPP",
            "3GPP-SGSN-MCC-MNC"                                      => "3GPP",
            "3GPP-Teardown-Indicator"                                => "3GPP",
            "3GPP-User-Location-Info"                                => "3GPP",
            "3GPP2-Accounting-Container"                             => "3GPP2",
            "3GPP2-Acct-Stop-Trigger"                                => "3GPP2",
            "3GPP2-Active-Time"                                      => "3GPP2",
            "3GPP2-Airlink-Priority"                                 => "3GPP2",
            "3GPP2-Airlink-Record-Type"                              => "3GPP2",
            "3GPP2-Airlink-Sequence-Number"                          => "3GPP2",
            "3GPP2-Allowed-Diffserv-Marking"                         => "3GPP2",
            "3GPP2-Allowed-Diffserv-Marking-Allowed"                 => "3GPP2",
            "3GPP2-Allowed-Diffserv-Marking-Max-Class"               => "3GPP2",
            "3GPP2-Allowed-Diffserv-Marking-Reverse-Runnel"          => "3GPP2",
            "3GPP2-Allowed-Persistent-TFTs"                          => "3GPP2",
            "3GPP2-Always-On"                                        => "3GPP2",
            "3GPP2-AT-Hardware-Identifier"                           => "3GPP2",
            "3GPP2-AT-Hardware-Identifier-Type"                      => "3GPP2",
            "3GPP2-AT-Hardware-Identifier-Value"                     => "3GPP2",
            "3GPP2-Auth-Flow-Profile-ID"                             => "3GPP2",
            "3GPP2-Auth-Flow-Profile-ID-Bi-Direction"                => "3GPP2",
            "3GPP2-Auth-Flow-Profile-ID-Forward"                     => "3GPP2",
            "3GPP2-Auth-Flow-Profile-ID-Reverse"                     => "3GPP2",
            "3GPP2-Bad-PPP-Frame-Count"                              => "3GPP2",
            "3GPP2-Begin-Session"                                    => "3GPP2",
            "3GPP2-BSID"                                             => "3GPP2",
            "3GPP2-Carrier-ID"                                       => "3GPP2",
            "3GPP2-Compulsory-Tunnel-Indicator"                      => "3GPP2",
            "3GPP2-Correlation-Id"                                   => "3GPP2",
            "3GPP2-DCCH-Frame-Size"                                  => "3GPP2",
            "3GPP2-Diffserv-Class-Option"                            => "3GPP2",
            "3GPP2-Disconnect-Reason"                                => "3GPP2",
            "3GPP2-DNS-Server-Entity-Type"                           => "3GPP2",
            "3GPP2-DNS-Server-Flag"                                  => "3GPP2",
            "3GPP2-DNS-Server-IP-Address"                            => "3GPP2",
            "3GPP2-DNS-Server-IPv6-Address"                          => "3GPP2",
            "3GPP2-DNS-Server-IPv6-Address-Entity-Type"              => "3GPP2",
            "3GPP2-DNS-Server-IPv6-Address-Flag"                     => "3GPP2",
            "3GPP2-DNS-Server-IPv6-Address-Primary"                  => "3GPP2",
            "3GPP2-DNS-Server-IPv6-Address-Secondary"                => "3GPP2",
            "3GPP2-DNS-Server-Primary-IP-Address"                    => "3GPP2",
            "3GPP2-DNS-Server-Secondary-IP-Address"                  => "3GPP2",
            "3GPP2-DNS-Update-Capability"                            => "3GPP2",
            "3GPP2-DNS-Update-Required"                              => "3GPP2",
            "3GPP2-ESN"                                              => "3GPP2",
            "3GPP2-FCH-Frame-Size"                                   => "3GPP2",
            "3GPP2-Filter-Rule"                                      => "3GPP2",
            "3GPP2-Filtered-Octet-Count-Originating"                 => "3GPP2",
            "3GPP2-Filtered-Octet-Count-Terminating"                 => "3GPP2",
            "3GPP2-Flow-ID"                                          => "3GPP2",
            "3GPP2-Flow-ID-Direction"                                => "3GPP2",
            "3GPP2-Flow-ID-Flow-ID"                                  => "3GPP2",
            "3GPP2-Flow-Status"                                      => "3GPP2",
            "3GPP2-Foreign-Agent-Address"                            => "3GPP2",
            "3GPP2-Forward-DCCH-Mux-Option"                          => "3GPP2",
            "3GPP2-Forward-DCCH-RC"                                  => "3GPP2",
            "3GPP2-Forward-FCH-Mux-Option"                           => "3GPP2",
            "3GPP2-Forward-FCH-RC"                                   => "3GPP2",
            "3GPP2-Forward-PDCH-RC"                                  => "3GPP2",
            "3GPP2-Forward-Traffic-Type"                             => "3GPP2",
            "3GPP2-GMT-Time-Zone-Offset"                             => "3GPP2",
            "3GPP2-Granted-QoS-Params"                               => "3GPP2",
            "3GPP2-Granted-QoS-Params-Bucket-Size"                   => "3GPP2",
            "3GPP2-Granted-QoS-Params-Delay-Var-Sensitive"           => "3GPP2",
            "3GPP2-Granted-QoS-Params-Direction"                     => "3GPP2",
            "3GPP2-Granted-QoS-Params-Flow-Id"                       => "3GPP2",
            "3GPP2-Granted-QoS-Params-Flow-Profile-ID"               => "3GPP2",
            "3GPP2-Granted-QoS-Params-Max-IP-Packet-Loss-Rate"       => "3GPP2",
            "3GPP2-Granted-QoS-Params-Max-Latency"                   => "3GPP2",
            "3GPP2-Granted-QoS-Params-Packet-Size"                   => "3GPP2",
            "3GPP2-Granted-QoS-Params-Peak-Rate"                     => "3GPP2",
            "3GPP2-Granted-QoS-Params-Token-Rate"                    => "3GPP2",
            "3GPP2-Granted-QoS-Params-Traffic-Class"                 => "3GPP2",
            "3GPP2-HA-Authorised"                                    => "3GPP2",
            "3GPP2-HA-Request"                                       => "3GPP2",
            "3GPP2-HAAA-MIP6-HA-Protocol-Capability-Indication"      => "3GPP2",
            "3GPP2-Home-Agent-IP-Address"                            => "3GPP2",
            "3GPP2-HRPD-Access-Authorization"                        => "3GPP2",
            "3GPP2-HTTP-Redirection-Rule"                            => "3GPP2",
            "3GPP2-Ike-Preshared-Secret-Request"                     => "3GPP2",
            "3GPP2-Inbound-Mobile-IP-Sig-Octets"                     => "3GPP2",
            "3GPP2-Inter-User-Priority"                              => "3GPP2",
            "3GPP2-IP-QoS"                                           => "3GPP2",
            "3GPP2-IP-Redirection-Rule"                              => "3GPP2",
            "3GPP2-IP-Technology"                                    => "3GPP2",
            "3GPP2-IP-Ver-Authorised"                                => "3GPP2",
            "3GPP2-KeyID"                                            => "3GPP2",
            "3GPP2-Last-User-Activity-Time"                          => "3GPP2",
            "3GPP2-Max-Auth-Aggregate-Bandwidth"                     => "3GPP2",
            "3GPP2-Max-Per-Flow-Priority"                            => "3GPP2",
            "3GPP2-MEID"                                             => "3GPP2",
            "3GPP2-MIP-Lifetime"                                     => "3GPP2",
            "3GPP2-MIP6-Accounting-Indication"                       => "3GPP2",
            "3GPP2-MIP6-Authenticator"                               => "3GPP2",
            "3GPP2-MIP6-CoA"                                         => "3GPP2",
            "3GPP2-MIP6-HA-Local-Assigment-Capability"               => "3GPP2",
            "3GPP2-MIP6-HoA"                                         => "3GPP2",
            "3GPP2-MIP6-HoA-Not-Authorized"                          => "3GPP2",
            "3GPP2-MIP6-Home-Agent"                                  => "3GPP2",
            "3GPP2-MIP6-Home-Agent-Attr-B"                           => "3GPP2",
            "3GPP2-MIP6-Home-Link-Prefix"                            => "3GPP2",
            "3GPP2-MIP6-MAC-Mobility-Data"                           => "3GPP2",
            "3GPP2-MIP6-Mesg-ID"                                     => "3GPP2",
            "3GPP2-MIP6-Session-Key"                                 => "3GPP2",
            "3GPP2-MIPv4-Mesg-Id"                                    => "3GPP2",
            "3GPP2-MN-AAA-Removal-Indication"                        => "3GPP2",
            "3GPP2-MN-HA-Shared-Key"                                 => "3GPP2",
            "3GPP2-MN-HA-SPI"                                        => "3GPP2",
            "3GPP2-Module-Orig-Term-Indicator"                       => "3GPP2",
            "3GPP2-Number-Active-Transitions"                        => "3GPP2",
            "3GPP2-Originating-Number-SDBs"                          => "3GPP2",
            "3GPP2-Originating-SDB-OCtet-Count"                      => "3GPP2",
            "3GPP2-Outbound-Mobile-IP-Sig-Octets"                    => "3GPP2",
            "3GPP2-PCF-IP-Address"                                   => "3GPP2",
            "3GPP2-Pre-Shared-Secret"                                => "3GPP2",
            "3GPP2-Prepaid-acct-Capability"                          => "3GPP2",
            "3GPP2-Prepaid-Acct-Quota"                               => "3GPP2",
            "3GPP2-Prepaid-Acct-Quota-QuotaIDentifier"               => "3GPP2",
            "3GPP2-Prepaid-Acct-Quota-UpdateReason"                  => "3GPP2",
            "3GPP2-Prepaid-Acct-Quota-VolumeQuota"                   => "3GPP2",
            "3GPP2-Prepaid-Acct-Quota-VolumeQuotaOverflow"           => "3GPP2",
            "3GPP2-Prepaid-Acct-Quota-VolumeThreshold"               => "3GPP2",
            "3GPP2-Prepaid-Acct-Quota-VolumeThresholdOverflow"       => "3GPP2",
            "3GPP2-Prepaid-Quota-Identifier"                         => "3GPP2",
            "3GPP2-Prepaid-Tariff-Switch-Interval"                   => "3GPP2",
            "3GPP2-PrePaid-Tariff-Switching"                         => "3GPP2",
            "3GPP2-Prepaid-Time-Interval-After-Tariff-Switch-Update" => "3GPP2",
            "3GPP2-Prepaid-Volume-Used-After-Tariff-Switch"          => "3GPP2",
            "3GPP2-Prepaid-Volume-Used-ATS-Overflow"                 => "3GPP2",
            "3GPP2-R-P-Session-ID"                                   => "3GPP2",
            "3GPP2-Received-HDLC-Octets"                             => "3GPP2",
            "3GPP2-Release-Indicator"                                => "3GPP2",
            "3GPP2-Remote-Address-Table-Index"                       => "3GPP2",
            "3GPP2-Remote-Address-Table-Index-Qualifier"             => "3GPP2",
            "3GPP2-Remote-Address-Table-Index-Value"                 => "3GPP2",
            "3GPP2-Remote-IP-Address"                                => "3GPP2",
            "3GPP2-Remote-IP-Address-Mask"                           => "3GPP2",
            "3GPP2-Remote-IP-Address-Value"                          => "3GPP2",
            "3GPP2-Remote-IP-Qualifier"                              => "3GPP2",
            "3GPP2-Remote-IPv4-Addr-Octet-Count"                     => "3GPP2",
            "3GPP2-Remote-IPv4-Addr-Octet-Count-Address"             => "3GPP2",
            "3GPP2-Remote-IPv4-Addr-Octet-Count-Forward"             => "3GPP2",
            "3GPP2-Remote-IPv4-Addr-Octet-Count-Forward-Overflow"    => "3GPP2",
            "3GPP2-Remote-IPv4-Addr-Octet-Count-Mask"                => "3GPP2",
            "3GPP2-Remote-IPv4-Addr-Octet-Count-Reverse"             => "3GPP2",
            "3GPP2-Remote-IPv4-Addr-Octet-Count-Reverse-Overflow"    => "3GPP2",
            "3GPP2-Remote-IPv4-Addr-Octet-Count-Table-Index"         => "3GPP2",
            "3GPP2-Remote-IPv6-Address"                              => "3GPP2",
            "3GPP2-Remote-IPv6-Address-Prefix-Length"                => "3GPP2",
            "3GPP2-Remote-IPv6-Address-Qualifier"                    => "3GPP2",
            "3GPP2-Remote-IPv6-Address-Value"                        => "3GPP2",
            "3GPP2-Remote-IPv6-Count-Address"                        => "3GPP2",
            "3GPP2-Remote-IPv6-Forward-Octet-Count"                  => "3GPP2",
            "3GPP2-Remote-IPv6-Octet-Count"                          => "3GPP2",
            "3GPP2-Remote-IPv6-Prefix-Length"                        => "3GPP2",
            "3GPP2-Remote-IPv6-Reverse-Octet-Count"                  => "3GPP2",
            "3GPP2-Remote-IPv6-Reverse-Octet-Count-Overflow"         => "3GPP2",
            "3GPP2-Remote-IPv6-Table-Index"                          => "3GPP2",
            "3GPP2-Reverse-DCCH-Mux-Option"                          => "3GPP2",
            "3GPP2-Reverse-DHHC-RC"                                  => "3GPP2",
            "3GPP2-Reverse-FCH-Mux-Option"                           => "3GPP2",
            "3GPP2-Reverse-FCH-RC"                                   => "3GPP2",
            "3GPP2-Reverse-Traffic-Type"                             => "3GPP2",
            "3GPP2-Reverse-Tunnel-Spec"                              => "3GPP2",
            "3GPP2-RN-Packet-Data-Inactivity-Timer"                  => "3GPP2",
            "3GPP2-RSVP-Inbound-Octet-Count"                         => "3GPP2",
            "3GPP2-RSVP-Outbound-Octet-Count"                        => "3GPP2",
            "3GPP2-RSVP-Outbound-Packet-Count"                       => "3GPP2",
            "3GPP2-S-Key"                                            => "3GPP2",
            "3GPP2-S-Lifetime"                                       => "3GPP2",
            "3GPP2-S-Request"                                        => "3GPP2",
            "3GPP2-Security-Level"                                   => "3GPP2",
            "3GPP2-Service-Option"                                   => "3GPP2",
            "3GPP2-Service-Option-Profile"                           => "3GPP2",
            "3GPP2-Service-Option-Profile-Option"                    => "3GPP2",
            "3GPP2-Service-Reference-Id"                             => "3GPP2",
            "3GPP2-Service-Reference-Id-Value"                       => "3GPP2",
            "3GPP2-Service-Reference-Main-SC-Indicator"              => "3GPP2",
            "3GPP2-Session-Continue"                                 => "3GPP2",
            "3GPP2-Session-Termination-Capability"                   => "3GPP2",
            "3GPP2-Subnet"                                           => "3GPP2",
            "3GPP2-Subnet-Sector-ID"                                 => "3GPP2",
            "3GPP2-Subnet-Subnet"                                    => "3GPP2",
            "3GPP2-Terminating-Number-SDBs"                          => "3GPP2",
            "3GPP2-Terminating-SDB-Octet-Count"                      => "3GPP2",
            "3GPP2-User-Id"                                          => "3GPP2",
            "3GPP2-VAAA-Assigned-MIP6-HA"                            => "3GPP2",
            "3GPP2-VAAA-Assigned-MIP6-HL"                            => "3GPP2",
            "3GPP2-VAAA-MIP6-HA-Protocol-Capability-Indication"      => "3GPP2",
            "A-AL-AAA"                                  => "Alcatel-ESAM",
            "A-AL-Alarm"                                => "Alcatel-ESAM",
            "A-AL-ATM"                                  => "Alcatel-ESAM",
            "A-AL-Cluster"                              => "Alcatel-ESAM",
            "A-AL-CPEProxy"                             => "Alcatel-ESAM",
            "A-AL-Description"                          => "Alcatel-ESAM",
            "A-AL-DHCP"                                 => "Alcatel-ESAM",
            "A-AL-EQP"                                  => "Alcatel-ESAM",
            "A-AL-IGMP"                                 => "Alcatel-ESAM",
            "A-AL-IP"                                   => "Alcatel-ESAM",
            "A-AL-Maintenance"                          => "Alcatel-ESAM",
            "A-AL-MAINTENANCE-BACKWARD"                 => "Alcatel-ESAM",
            "A-AL-PPPoE"                                => "Alcatel-ESAM",
            "A-AL-Prompt"                               => "Alcatel-ESAM",
            "A-AL-Provisioning"                         => "Alcatel-ESAM",
            "A-AL-PROVISIONING-BACKWARD"                => "Alcatel-ESAM",
            "A-AL-Pwd-Timeout"                          => "Alcatel-ESAM",
            "A-AL-QoS"                                  => "Alcatel-ESAM",
            "A-AL-Security"                             => "Alcatel-ESAM",
            "A-AL-SLOT-NUMBERING"                       => "Alcatel-ESAM",
            "A-AL-SWMgt"                                => "Alcatel-ESAM",
            "A-AL-Test"                                 => "Alcatel-ESAM",
            "A-AL-TEST-BACKWARD"                        => "Alcatel-ESAM",
            "A-AL-TL1-Security"                         => "Alcatel-ESAM",
            "A-AL-TL1-SECURITY-BACKWARD"                => "Alcatel-ESAM",
            "A-AL-Transport"                            => "Alcatel-ESAM",
            "A-AL-VLAN"                                 => "Alcatel-ESAM",
            "A-AL-XDSL"                                 => "Alcatel-ESAM",
            "A-ESAM-QOS-Params"                         => "Alcatel-ESAM",
            "A-ESAM-QOS-Profile-Name"                   => "Alcatel-ESAM",
            "A-ESAM-Termination-Cause"                  => "Alcatel-ESAM",
            "A-ESAM-Vlan-Id"                            => "Alcatel-ESAM",
            "A-ESAM-VRF-Name"                           => "Alcatel-ESAM",
            "AAT-Assign-IP-Pool"                        => "Alcatel",
            "AAT-ATM-Direct"                            => "Alcatel",
            "AAT-ATM-Traffic-Profile"                   => "Alcatel",
            "AAT-ATM-VCI"                               => "Alcatel",
            "AAT-ATM-VPI"                               => "Alcatel",
            "AAT-Auth-Type"                             => "Alcatel",
            "AAT-Client-Assign-DNS"                     => "Alcatel",
            "AAT-Client-Primary-DNS"                    => "Alcatel",
            "AAT-Client-Primary-WINS-NBNS"              => "Alcatel",
            "AAT-Client-Secondary-DNS"                  => "Alcatel",
            "AAT-Client-Secondary-WINS-NBNS"            => "Alcatel",
            "AAT-Data-Filter"                           => "Alcatel",
            "AAT-Filter"                                => "Alcatel",
            "AAT-FR-Direct"                             => "Alcatel",
            "AAT-FR-Direct-DLCI"                        => "Alcatel",
            "AAT-FR-Direct-Profile"                     => "Alcatel",
            "AAT-Home-Agent-Password"                   => "Alcatel",
            "AAT-Home-Agent-UDP-Port"                   => "Alcatel",
            "AAT-Home-Network-Name"                     => "Alcatel",
            "AAT-Input-Octets-Diff"                     => "Alcatel",
            "AAT-IP-Direct"                             => "Alcatel",
            "AAT-IP-Pool-Definition"                    => "Alcatel",
            "AAT-IP-TOS"                                => "Alcatel",
            "AAT-IP-TOS-Apply-To"                       => "Alcatel",
            "AAT-IP-TOS-Precedence"                     => "Alcatel",
            "AAT-MCast-Client"                          => "Alcatel",
            "AAT-Modem-Answer-String"                   => "Alcatel",
            "AAT-Modem-Port-No"                         => "Alcatel",
            "AAT-Modem-Shelf-No"                        => "Alcatel",
            "AAT-Modem-Slot-No"                         => "Alcatel",
            "AAT-Output-Octets-Diff"                    => "Alcatel",
            "AAT-PPP-Address"                           => "Alcatel",
            "AAT-PPP-Netmask"                           => "Alcatel",
            "AAT-Primary-Home-Agent"                    => "Alcatel",
            "AAT-Qoa"                                   => "Alcatel",
            "AAT-Qos"                                   => "Alcatel",
            "AAT-Require-Auth"                          => "Alcatel",
            "AAT-Secondary-Home-Agent"                  => "Alcatel",
            "AAT-Source-IP-Check"                       => "Alcatel",
            "AAT-User-MAC-Address"                      => "Alcatel",
            "AAT-Vrouter-Name"                          => "Alcatel",
            "Acc-Access-Community"                      => "Acc",
            "Acc-Access-Partition"                      => "Acc",
            "Acc-Acct-On-Off-Reason"                    => "Acc",
            "Acc-Ace-Token"                             => "Acc",
            "Acc-Ace-Token-Ttl"                         => "Acc",
            "Acc-Apsm-Oversubscribed"                   => "Acc",
            "Acc-Bridging-Support"                      => "Acc",
            "Acc-Callback-CBCP-Type"                    => "Acc",
            "Acc-Callback-Delay"                        => "Acc",
            "Acc-Callback-Mode"                         => "Acc",
            "Acc-Callback-Num-Valid"                    => "Acc",
            "Acc-Calling-Station-Category"              => "Acc",
            "Acc-Ccp-Option"                            => "Acc",
            "Acc-Clearing-Cause"                        => "Acc",
            "Acc-Clearing-Location"                     => "Acc",
            "Acc-Connect-Rx-Speed"                      => "Acc",
            "Acc-Connect-Tx-Speed"                      => "Acc",
            "Acc-Customer-Id"                           => "Acc",
            "Acc-Dial-Port-Index"                       => "Acc",
            "Acc-Dialout-Auth-Mode"                     => "Acc",
            "Acc-Dialout-Auth-Password"                 => "Acc",
            "Acc-Dialout-Auth-Username"                 => "Acc",
            "Acc-Dns-Server-Pri"                        => "Acc",
            "Acc-Dns-Server-Sec"                        => "Acc",
            "Acc-Igmp-Admin-State"                      => "Acc",
            "Acc-Igmp-Version"                          => "Acc",
            "Acc-Input-Errors"                          => "Acc",
            "Acc-Ip-Compression"                        => "Acc",
            "Acc-Ip-Gateway-Pri"                        => "Acc",
            "Acc-Ip-Gateway-Sec"                        => "Acc",
            "Acc-Ip-Pool-Name"                          => "Acc",
            "Acc-Ipx-Compression"                       => "Acc",
            "Acc-Location-Id"                           => "Acc",
            "Acc-ML-Call-Threshold"                     => "Acc",
            "Acc-ML-Clear-Threshold"                    => "Acc",
            "Acc-ML-Damping-Factor"                     => "Acc",
            "Acc-ML-MLX-Admin-State"                    => "Acc",
            "Acc-MN-HA-Secret"                          => "Acc",
            "Acc-Modem-Error-Protocol"                  => "Acc",
            "Acc-Modem-Modulation-Type"                 => "Acc",
            "Acc-Nbns-Server-Pri"                       => "Acc",
            "Acc-Nbns-Server-Sec"                       => "Acc",
            "Acc-Output-Errors"                         => "Acc",
            "Acc-Reason-Code"                           => "Acc",
            "Acc-Request-Type"                          => "Acc",
            "Acc-Route-Policy"                          => "Acc",
            "Acc-Service-Profile"                       => "Acc",
            "Acc-Tunnel-Port"                           => "Acc",
            "Acc-Tunnel-Secret"                         => "Acc",
            "Acc-Vpsm-Reject-Cause"                     => "Acc",
            "Access-Loop-Encapsulation"                 => "ADSL-Forum",
            "Acct-Alt-Session-ID"                       => "Ericsson-AB",
            "Acct-Dyn-Ac-Ent"                           => "Ericsson-AB",
            "Acct-Input-IPv4-Gigawords"                 => "Ericsson-AB",
            "Acct-Input-IPv4-Octets"                    => "Ericsson-AB",
            "Acct-Input-IPv4-Packets"                   => "Ericsson-AB",
            "Acct-Input-IPv6-Gigawords"                 => "Ericsson-AB",
            "Acct-Input-IPv6-Octets"                    => "Ericsson-AB",
            "Acct-Input-IPv6-Packets"                   => "Ericsson-AB",
            "Acct-Input-Octets-64"                      => "Ericsson-AB",
            "Acct-Input-Packets-64"                     => "Ericsson-AB",
            "Acct-Interim-Record-Number"                => "VerizonWireless",
            "Acct-Mcast-In-Octets"                      => "Ericsson-AB",
            "Acct-Mcast-In-Octets-64"                   => "Ericsson-AB",
            "Acct-Mcast-In-Packets"                     => "Ericsson-AB",
            "Acct-Mcast-In-Packets-64"                  => "Ericsson-AB",
            "Acct-Mcast-Out-Octets"                     => "Ericsson-AB",
            "Acct-Mcast-Out-Octets-64"                  => "Ericsson-AB",
            "Acct-Mcast-Out-Packets"                    => "Ericsson-AB",
            "Acct-Mcast-Out-Packets-64"                 => "Ericsson-AB",
            "Acct-Output-IPv4-Gigawords"                => "Ericsson-AB",
            "Acct-Output-IPv4-Octets"                   => "Ericsson-AB",
            "Acct-Output-IPv4-Packets"                  => "Ericsson-AB",
            "Acct-Output-IPv6-Gigawords"                => "Ericsson-AB",
            "Acct-Output-IPv6-Octets"                   => "Ericsson-AB",
            "Acct-Output-IPv6-Packets"                  => "Ericsson-AB",
            "Acct-Output-Octets-64"                     => "Ericsson-AB",
            "Acct-Output-Packets-64"                    => "Ericsson-AB",
            "Acct-Session-Gigawords"                    => "Gemtek",
            "Acct-Session-Input-Gigawords"              => "Gemtek",
            "Acct-Session-Input-Octets"                 => "Gemtek",
            "Acct-Session-Octets"                       => "Gemtek",
            "Acct-Session-Output-Gigawords"             => "Gemtek",
            "Acct-Session-Output-Octets"                => "Gemtek",
            "Acct-Update-Reason"                        => "Ericsson-AB",
            "ACL-Auth-Level"                            => "AudioCodes",
            "ACL-Definition"                            => "Ericsson-AB",
            "Acme-Called-MOS"                           => "Acme",
            "Acme-Called-Octets_FS1"                    => "Acme",
            "Acme-Called-Octets_FS2"                    => "Acme",
            "Acme-Called-Packets_FS1"                   => "Acme",
            "Acme-Called-Packets_FS2"                   => "Acme",
            "Acme-Called-R-Factor"                      => "Acme",
            "Acme-Called-RTCP-Avg-Jitter_FS1"           => "Acme",
            "Acme-Called-RTCP-Avg-Jitter_FS2"           => "Acme",
            "Acme-Called-RTCP-Avg-Latency_FS1"          => "Acme",
            "Acme-Called-RTCP-Avg-Latency_FS2"          => "Acme",
            "Acme-Called-RTCP-MaxJitter_FS1"            => "Acme",
            "Acme-Called-RTCP-MaxJitter_FS2"            => "Acme",
            "Acme-Called-RTCP-MaxLatency_FS1"           => "Acme",
            "Acme-Called-RTCP-MaxLatency_FS2"           => "Acme",
            "Acme-Called-RTCP-Packets-Lost_FS1"         => "Acme",
            "Acme-Called-RTCP-Packets-Lost_FS2"         => "Acme",
            "Acme-Called-RTP-Avg-Jitter_FS1"            => "Acme",
            "Acme-Called-RTP-Avg-Jitter_FS2"            => "Acme",
            "Acme-Called-RTP-MaxJitter_FS1"             => "Acme",
            "Acme-Called-RTP-MaxJitter_FS2"             => "Acme",
            "Acme-Called-RTP-Packets-Lost_FS1"          => "Acme",
            "Acme-Called-RTP-Packets-Lost_FS2"          => "Acme",
            "Acme-Calling-MOS"                          => "Acme",
            "Acme-Calling-Octets_FS1"                   => "Acme",
            "Acme-Calling-Octets_FS2"                   => "Acme",
            "Acme-Calling-Packets_FS1"                  => "Acme",
            "Acme-Calling-Packets_FS2"                  => "Acme",
            "Acme-Calling-R-Factor"                     => "Acme",
            "Acme-Calling-RTCP-Avg-Jitter_FS1"          => "Acme",
            "Acme-Calling-RTCP-Avg-Jitter_FS2"          => "Acme",
            "Acme-Calling-RTCP-Avg-Latency_FS1"         => "Acme",
            "Acme-Calling-RTCP-Avg-Latency_FS2"         => "Acme",
            "Acme-Calling-RTCP-MaxJitter_FS1"           => "Acme",
            "Acme-Calling-RTCP-MaxJitter_FS2"           => "Acme",
            "Acme-Calling-RTCP-MaxLatency_FS1"          => "Acme",
            "Acme-Calling-RTCP-MaxLatency_FS2"          => "Acme",
            "Acme-Calling-RTCP-Packets-Lost_FS1"        => "Acme",
            "Acme-Calling-RTCP-Packets-Lost_FS2"        => "Acme",
            "Acme-Calling-RTP-Avg-Jitter_FS1"           => "Acme",
            "Acme-Calling-RTP-Avg-Jitter_FS2"           => "Acme",
            "Acme-Calling-RTP-MaxJitter_FS1"            => "Acme",
            "Acme-Calling-RTP-MaxJitter_FS2"            => "Acme",
            "Acme-Calling-RTP-Packets-Lost_FS1"         => "Acme",
            "Acme-Calling-RTP-Packets-Lost_FS2"         => "Acme",
            "Acme-CDR-Sequence-Number"                  => "Acme",
            "Acme-Custom-VSA-200"                       => "Acme",
            "Acme-Custom-VSA-201"                       => "Acme",
            "Acme-Custom-VSA-202"                       => "Acme",
            "Acme-Custom-VSA-203"                       => "Acme",
            "Acme-Custom-VSA-204"                       => "Acme",
            "Acme-Custom-VSA-205"                       => "Acme",
            "Acme-Custom-VSA-206"                       => "Acme",
            "Acme-Custom-VSA-207"                       => "Acme",
            "Acme-Custom-VSA-208"                       => "Acme",
            "Acme-Custom-VSA-209"                       => "Acme",
            "Acme-Custom-VSA-210"                       => "Acme",
            "Acme-Custom-VSA-211"                       => "Acme",
            "Acme-Custom-VSA-212"                       => "Acme",
            "Acme-Custom-VSA-213"                       => "Acme",
            "Acme-Custom-VSA-214"                       => "Acme",
            "Acme-Custom-VSA-215"                       => "Acme",
            "Acme-Custom-VSA-216"                       => "Acme",
            "Acme-Custom-VSA-217"                       => "Acme",
            "Acme-Custom-VSA-218"                       => "Acme",
            "Acme-Custom-VSA-219"                       => "Acme",
            "Acme-Custom-VSA-220"                       => "Acme",
            "Acme-Custom-VSA-221"                       => "Acme",
            "Acme-Custom-VSA-222"                       => "Acme",
            "Acme-Custom-VSA-223"                       => "Acme",
            "Acme-Custom-VSA-224"                       => "Acme",
            "Acme-Custom-VSA-225"                       => "Acme",
            "Acme-Custom-VSA-226"                       => "Acme",
            "Acme-Custom-VSA-227"                       => "Acme",
            "Acme-Custom-VSA-228"                       => "Acme",
            "Acme-Custom-VSA-229"                       => "Acme",
            "Acme-Custom-VSA-230"                       => "Acme",
            "Acme-Disconnect-Cause"                     => "Acme",
            "Acme-Disconnect-Initiator"                 => "Acme",
            "Acme-Domain-Name"                          => "Acme",
            "Acme-Egress-Final-Routing-Number"          => "Acme",
            "Acme-Egress-Local-Addr"                    => "Acme",
            "Acme-Egress-Network-Interface-Id"          => "Acme",
            "Acme-Egress-Remote-Addr"                   => "Acme",
            "Acme-Egress-Vlan-Tag-Value"                => "Acme",
            "Acme-Firmware-Version"                     => "Acme",
            "Acme-Flow-Called-Media-Stop-Time-FS1"      => "Acme",
            "Acme-Flow-Called-Media-Stop-Time-FS2"      => "Acme",
            "Acme-Flow-Calling-Media-Stop-Time-FS1"     => "Acme",
            "Acme-Flow-Calling-Media-Stop-Time-FS2"     => "Acme",
            "Acme-Flow-In-Dst-Addr_FS1_F"               => "Acme",
            "Acme-Flow-In-Dst-Addr_FS1_R"               => "Acme",
            "Acme-Flow-In-Dst-Addr_FS2_F"               => "Acme",
            "Acme-Flow-In-Dst-Addr_FS2_R"               => "Acme",
            "Acme-Flow-In-Dst-IPv6_Addr_FS1_F"          => "Acme",
            "Acme-Flow-In-Dst-IPv6_Addr_FS1_R"          => "Acme",
            "Acme-Flow-In-Dst-IPv6_Addr_FS2_F"          => "Acme",
            "Acme-Flow-In-Dst-IPv6_Addr_FS2_R"          => "Acme",
            "Acme-Flow-In-Dst-Port_FS1_F"               => "Acme",
            "Acme-Flow-In-Dst-Port_FS1_R"               => "Acme",
            "Acme-Flow-In-Dst-Port_FS2_F"               => "Acme",
            "Acme-Flow-In-Dst-Port_FS2_R"               => "Acme",
            "Acme-Flow-In-Realm_FS1_F"                  => "Acme",
            "Acme-Flow-In-Realm_FS1_R"                  => "Acme",
            "Acme-Flow-In-Realm_FS2_F"                  => "Acme",
            "Acme-Flow-In-Realm_FS2_R"                  => "Acme",
            "Acme-Flow-In-Src-Addr_FS1_F"               => "Acme",
            "Acme-Flow-In-Src-Addr_FS1_R"               => "Acme",
            "Acme-Flow-In-Src-Addr_FS2_F"               => "Acme",
            "Acme-Flow-In-Src-Addr_FS2_R"               => "Acme",
            "Acme-Flow-In-Src-IPv6_Addr_FS1_F"          => "Acme",
            "Acme-Flow-In-Src-IPv6_Addr_FS1_R"          => "Acme",
            "Acme-Flow-In-Src-IPv6_Addr_FS2_F"          => "Acme",
            "Acme-Flow-In-Src-IPv6_Addr_FS2_R"          => "Acme",
            "Acme-Flow-In-Src-Port_FS1_F"               => "Acme",
            "Acme-Flow-In-Src-Port_FS1_R"               => "Acme",
            "Acme-Flow-In-Src-Port_FS2_F"               => "Acme",
            "Acme-Flow-In-Src-Port_FS2_R"               => "Acme",
            "Acme-Flow-Out-Dst-Addr_FS1_F"              => "Acme",
            "Acme-Flow-Out-Dst-Addr_FS1_R"              => "Acme",
            "Acme-Flow-Out-Dst-Addr_FS2_F"              => "Acme",
            "Acme-Flow-Out-Dst-Addr_FS2_R"              => "Acme",
            "Acme-Flow-Out-Dst-IPv6_Addr_FS1_F"         => "Acme",
            "Acme-Flow-Out-Dst-IPv6_Addr_FS1_R"         => "Acme",
            "Acme-Flow-Out-Dst-IPv6_Addr_FS2_F"         => "Acme",
            "Acme-Flow-Out-Dst-IPv6_Addr_FS2_R"         => "Acme",
            "Acme-Flow-Out-Dst-Port_FS1_F"              => "Acme",
            "Acme-Flow-Out-Dst-Port_FS1_R"              => "Acme",
            "Acme-Flow-Out-Dst-Port_FS2_F"              => "Acme",
            "Acme-Flow-Out-Dst-Port_FS2_R"              => "Acme",
            "Acme-Flow-Out-Realm_FS1_F"                 => "Acme",
            "Acme-Flow-Out-Realm_FS1_R"                 => "Acme",
            "Acme-Flow-Out-Realm_FS2_F"                 => "Acme",
            "Acme-Flow-Out-Realm_FS2_R"                 => "Acme",
            "Acme-Flow-Out-Src-Addr_FS1_F"              => "Acme",
            "Acme-Flow-Out-Src-Addr_FS1_R"              => "Acme",
            "Acme-Flow-Out-Src-Addr_FS2_F"              => "Acme",
            "Acme-Flow-Out-Src-Addr_FS2_R"              => "Acme",
            "Acme-Flow-Out-Src-IPv6_Addr_FS1_F"         => "Acme",
            "Acme-Flow-Out-Src-IPv6_Addr_FS1_R"         => "Acme",
            "Acme-Flow-Out-Src-IPv6_Addr_FS2_F"         => "Acme",
            "Acme-Flow-Out-Src-IPv6_Addr_FS2_R"         => "Acme",
            "Acme-Flow-Out-Src-Port_FS1_F"              => "Acme",
            "Acme-Flow-Out-Src-Port_FS1_R"              => "Acme",
            "Acme-Flow-Out-Src-Port_FS2_F"              => "Acme",
            "Acme-Flow-Out-Src-Port_FS2_R"              => "Acme",
            "Acme-Flow-PTime_FS1_F"                     => "Acme",
            "Acme-Flow-PTime_FS1_R"                     => "Acme",
            "Acme-Flow-PTime_FS2_F"                     => "Acme",
            "Acme-Flow-PTime_FS2_R"                     => "Acme",
            "Acme-FlowID_FS1_F"                         => "Acme",
            "Acme-FlowID_FS1_R"                         => "Acme",
            "Acme-FlowID_FS2_F"                         => "Acme",
            "Acme-FlowID_FS2_R"                         => "Acme",
            "Acme-FlowMediaType_FS1_F"                  => "Acme",
            "Acme-FlowMediaType_FS1_R"                  => "Acme",
            "Acme-FlowMediaType_FS2_F"                  => "Acme",
            "Acme-FlowMediaType_FS2_R"                  => "Acme",
            "Acme-FlowType_FS1_F"                       => "Acme",
            "Acme-FlowType_FS1_R"                       => "Acme",
            "Acme-FlowType_FS2_F"                       => "Acme",
            "Acme-FlowType_FS2_R"                       => "Acme",
            "Acme-Ingress-Local-Addr"                   => "Acme",
            "Acme-Ingress-Network-Interface-Id"         => "Acme",
            "Acme-Ingress-Remote-Addr"                  => "Acme",
            "Acme-Ingress-Vlan-Tag-Value"               => "Acme",
            "Acme-Intermediate_Time"                    => "Acme",
            "Acme-Local-Time-Zone"                      => "Acme",
            "Acme-Originating-Trunk-Context"            => "Acme",
            "Acme-Originating-Trunk-Group"              => "Acme",
            "Acme-P-Asserted-ID"                        => "Acme",
            "Acme-Post-Dial-Delay"                      => "Acme",
            "Acme-Primary-Routing-Number"               => "Acme",
            "Acme-Reason-Phrase"                        => "Acme",
            "Acme-Refer-Call-Transfer-Id"               => "Acme",
            "Acme-Session-Charging-Function_Address"    => "Acme",
            "Acme-Session-Charging-Vector"              => "Acme",
            "Acme-Session-Disposition"                  => "Acme",
            "Acme-Session-Egress-CallId"                => "Acme",
            "Acme-Session-Egress-Realm"                 => "Acme",
            "Acme-Session-Egress-RPH"                   => "Acme",
            "Acme-Session-Forked-Call-Id"               => "Acme",
            "Acme-Session-Generic-Id"                   => "Acme",
            "Acme-Session-Ingress-CallId"               => "Acme",
            "Acme-Session-Ingress-Realm"                => "Acme",
            "Acme-Session-Ingress-RPH"                  => "Acme",
            "Acme-Session-Media-Process"                => "Acme",
            "Acme-Session-Protocol-Type"                => "Acme",
            "Acme-SIP-Contact"                          => "Acme",
            "Acme-SIP-Diversion"                        => "Acme",
            "Acme-SIP-Expires"                          => "Acme",
            "Acme-SIP-Method-Type"                      => "Acme",
            "Acme-SIP-Status"                           => "Acme",
            "Acme-Terminating-Trunk-Context"            => "Acme",
            "Acme-Terminating-Trunk-Group"              => "Acme",
            "Acme-User-Class"                           => "Acme",
            "Acme-User-Privilege"                       => "Acme",
            "Actelis-Privilege"                         => "Actelis",
            "Actual-Data-Rate-Downstream"               => "ADSL-Forum",
            "Actual-Data-Rate-Upstream"                 => "ADSL-Forum",
            "Actual-Interleaving-Delay-Downstream"      => "ADSL-Forum",
            "Actual-Interleaving-Delay-Upstream"        => "ADSL-Forum",
            "ADSL-Agent-Circuit-Id"                     => "ADSL-Forum",
            "ADSL-Agent-Remote-Id"                      => "ADSL-Forum",
            "ADSL-Forum-Device-Manufacturer-OUI"        => "ADSL-Forum",
            "ADSL-Forum-Device-Product-Class"           => "ADSL-Forum",
            "ADSL-Forum-Device-Serial-Number"           => "ADSL-Forum",
            "ADSL-Forum-DHCP-Vendor-Specific"           => "ADSL-Forum",
            "ADSL-Forum-Gateway-Manufacturer-OUI"       => "ADSL-Forum",
            "Adtran-AP-IP"                              => "Adtran",
            "Adtran-AP-Name"                            => "Adtran",
            "Adtran-AP-Template"                        => "Adtran",
            "Adtran-Role"                               => "Adtran",
            "Adtran-SSID"                               => "Adtran",
            "Adva-Auth-Level-NM"                        => "Adva",
            "Adva-User-Level"                           => "Adva",
            "Adva-UUM-User-Level"                       => "Adva",
            "Agent-Circuit-Id"                          => "Ericsson-AB",
            "Agent-Remote-Id"                           => "Ericsson-AB",
            "AH-HM-Admin-Group-Id"                      => "Aerohive",
            "Airespace-8021p-Tag"                       => "Airespace",
            "Airespace-ACL-Name"                        => "Airespace",
            "Airespace-Data-Bandwidth-Average-Contract" => "Airespace",
            "Airespace-Data-Bandwidth-Average-Contract-Upstream" => "Airespace",
            "Airespace-Data-Bandwidth-Burst-Contract"            => "Airespace",
            "Airespace-Data-Bandwidth-Burst-Contract-Upstream"   => "Airespace",
            "Airespace-DSCP"                                     => "Airespace",
            "Airespace-Guest-Role-Name"                          => "Airespace",
            "Airespace-Interface-Name"                           => "Airespace",
            "Airespace-QOS-Level"                                => "Airespace",
            "Airespace-Real-Time-Bandwidth-Average-Contract"     => "Airespace",
            "Airespace-Real-Time-Bandwidth-Average-Contract-Upstream" =>
              "Airespace",
            "Airespace-Real-Time-Bandwidth-Burst-Contract" => "Airespace",
            "Airespace-Real-Time-Bandwidth-Burst-Contract-Upstream" =>
              "Airespace",
            "Airespace-Wlan-Id"              => "Airespace",
            "Alc-AA-Group-Partition-Isa-Id"  => "Alcatel-Lucent-Service-Router",
            "Alc-AA-Peer-Identifier"         => "Alcatel-Lucent-Service-Router",
            "Alc-AA-Transit-IP"              => "Alcatel-Lucent-Service-Router",
            "Alc-Access-Loop-Encap-Offset"   => "Alcatel-Lucent-Service-Router",
            "Alc-Access-Loop-Rate-Down"      => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-All-Octets-Offer_64" => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-All-Octets_64"       => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-All-Pack-Offer_64"   => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-All-Packets_64"      => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-High-Octets-Drop_64" => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-High-Octets-Offer_64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-High-Pack-Drop_64"   => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-High-Pack-Offer_64"  => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-Hiprio-Octets_64"    => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-Hiprio-Packets_64"   => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-Inprof-Octets-64"    => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-Inprof-Pkts-64"      => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-Low-Octets-Drop_64"  => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-Low-Octets-Offer_64" => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-Low-Pack-Drop_64"    => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-Low-Pack-Offer_64"   => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-Lowprio-Octets_64"   => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-Lowprio-Packets_64"  => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-Outprof-Octets-64"   => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-Outprof-Pkts-64"     => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-statmode"            => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-Unc-Octets-Offer_64" => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-I-Unc-Pack-Offer_64"   => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-Interim-Level"         => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-All-Octets_64"       => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-All-Packets_64"      => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-Hiprio-Octets_64"    => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-Hiprio-Packets_64"   => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-Inprof-Octets-64"    => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-Inprof-Octs-Drop_64" => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-Inprof-Pack-Drop_64" => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-Inprof-Pkts-64"      => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-Lowprio-Octets_64"   => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-Lowprio-Packets_64"  => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-Outprof-Octets-64"   => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-Outprof-Octs-Drop_64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-Outprof-Pack-Drop_64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-Outprof-Pkts-64" => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-O-statmode"        => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-I-All-Octs-Offer_64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-I-All-Pack-Offer_64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-I-Inpr-Octs-Drop_64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-I-Inpr-Pack-Drop_64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-I-Inprof-Octets-64" => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-I-Inprof-Pkts-64"   => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-I-Outpr-Octs-Drop_64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-I-Outpr-Pack-Drop_64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-I-Outprof-Octets-64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-I-Outprof-Pkts-64" => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-O-Inpr-Octs-Drop_64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-O-Inpr-Pack-Drop_64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-O-Inprof-Octets-64" => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-O-Inprof-Pkts-64"   => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-O-Outpr-Octs-Drop_64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-O-Outpr-Pack-Drop_64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-O-Outprof-Octets-64" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Acct-OC-O-Outprof-Pkts-64" => "Alcatel-Lucent-Service-Router",
            "Alc-Acct-Triggered-Reason"     => "Alcatel-Lucent-Service-Router",
            "Alc-ANCP-Str"                  => "Alcatel-Lucent-Service-Router",
            "Alc-APN-Name"                  => "Alcatel-Lucent-Service-Router",
            "Alc-APN-Password"              => "Alcatel-Lucent-Service-Router",
            "Alc-App-Prof-Str"              => "Alcatel-Lucent-Service-Router",
            "Alc-Ascend-Data-Filter-Host-Spec" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-ATM-Egress-TD-Profile"      => "Alcatel-Lucent-Service-Router",
            "Alc-ATM-Ingress-TD-Profile"     => "Alcatel-Lucent-Service-Router",
            "Alc-Authentication-Policy-Name" => "Alcatel-Lucent-Service-Router",
            "Alc-BGP-Auth-Key"               => "Alcatel-Lucent-Service-Router",
            "Alc-BGP-Auth-Keychain"          => "Alcatel-Lucent-Service-Router",
            "Alc-BGP-Export-Policy"          => "Alcatel-Lucent-Service-Router",
            "Alc-BGP-Import-Policy"          => "Alcatel-Lucent-Service-Router",
            "Alc-BGP-PeerAS"                 => "Alcatel-Lucent-Service-Router",
            "Alc-BGP-Policy"                 => "Alcatel-Lucent-Service-Router",
            "Alc-Charging-Prof-ID"           => "Alcatel-Lucent-Service-Router",
            "Alc-Client-Hardware-Addr"       => "Alcatel-Lucent-Service-Router",
            "Alc-Create-Host"                => "Alcatel-Lucent-Service-Router",
            "Alc-Credit-Control-CategoryMap" => "Alcatel-Lucent-Service-Router",
            "Alc-Credit-Control-Quota"       => "Alcatel-Lucent-Service-Router",
            "Alc-Default-Router"             => "Alcatel-Lucent-Service-Router",
            "Alc-Delegated-IPv6-Pool"        => "Alcatel-Lucent-Service-Router",
            "Alc-DHCP-Vendor-Class-Id"       => "Alcatel-Lucent-Service-Router",
            "Alc-Dhcp6-Rebind-Time"          => "Alcatel-Lucent-Service-Router",
            "Alc-Dhcp6-Renew-Time"           => "Alcatel-Lucent-Service-Router",
            "Alc-DNAT-Override"              => "Alcatel-Lucent-Service-Router",
            "Alc-DSL-Line-State"             => "Alcatel-Lucent-Service-Router",
            "Alc-DSL-Type"                   => "Alcatel-Lucent-Service-Router",
            "Alc-Force-DHCP-Relay"           => "Alcatel-Lucent-Service-Router",
            "Alc-Force-Nak"                  => "Alcatel-Lucent-Service-Router",
            "Alc-Force-Renew"                => "Alcatel-Lucent-Service-Router",
            "Alc-Int-Dest-Id-Str"            => "Alcatel-Lucent-Service-Router",
            "Alc-Interface"                  => "Alcatel-Lucent-Service-Router",
            "Alc-IPsec-Interface"            => "Alcatel-Lucent-Service-Router",
            "Alc-IPsec-SA-Auth-Algorithm"    => "Alcatel-Lucent-Service-Router",
            "Alc-IPsec-SA-Encr-Algorithm"    => "Alcatel-Lucent-Service-Router",
            "Alc-IPsec-SA-Lifetime"          => "Alcatel-Lucent-Service-Router",
            "Alc-IPsec-SA-PFS-Group"         => "Alcatel-Lucent-Service-Router",
            "Alc-IPsec-SA-Replay-Window"     => "Alcatel-Lucent-Service-Router",
            "Alc-IPsec-Serv-Id"              => "Alcatel-Lucent-Service-Router",
            "Alc-IPsec-Tunnel-Template-Id"   => "Alcatel-Lucent-Service-Router",
            "Alc-Ipv6-Address"               => "Alcatel-Lucent-Service-Router",
            "Alc-Ipv6-Portal-Url"            => "Alcatel-Lucent-Service-Router",
            "Alc-Ipv6-Primary-Dns"           => "Alcatel-Lucent-Service-Router",
            "Alc-Ipv6-Secondary-Dns"         => "Alcatel-Lucent-Service-Router",
            "Alc-Lease-Time"                 => "Alcatel-Lucent-Service-Router",
            "Alc-LI-Action"                  => "Alcatel-Lucent-Service-Router",
            "Alc-LI-Destination"             => "Alcatel-Lucent-Service-Router",
            "Alc-LI-Direction"               => "Alcatel-Lucent-Service-Router",
            "Alc-LI-FC"                      => "Alcatel-Lucent-Service-Router",
            "Alc-LI-Intercept-Id"            => "Alcatel-Lucent-Service-Router",
            "Alc-LI-Session-Id"              => "Alcatel-Lucent-Service-Router",
            "Alc-Mgw-Interface-Type"         => "Alcatel-Lucent-Service-Router",
            "Alc-MSAP-Interface"             => "Alcatel-Lucent-Service-Router",
            "Alc-MSAP-Policy"                => "Alcatel-Lucent-Service-Router",
            "Alc-MSAP-Serv-Id"               => "Alcatel-Lucent-Service-Router",
            "Alc-MsIsdn"                     => "Alcatel-Lucent-Service-Router",
            "Alc-Nas-Filter-Rule-Shared"     => "Alcatel-Lucent-Service-Router",
            "Alc-Nat-Outside-Ip-Addr"        => "Alcatel-Lucent-Service-Router",
            "Alc-Nat-Outside-Serv-Id"        => "Alcatel-Lucent-Service-Router",
            "Alc-Nat-Port-Range"             => "Alcatel-Lucent-Service-Router",
            "Alc-Num-Attached-UEs"           => "Alcatel-Lucent-Service-Router",
            "Alc-Onetime-Http-Redirect-Reactivate" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Onetime-Http-Redirection-Filter-Id" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Portal-Url"               => "Alcatel-Lucent-Service-Router",
            "Alc-PPP-Force-IPv6CP"         => "Alcatel-Lucent-Service-Router",
            "Alc-PPPoE-PADO-Delay"         => "Alcatel-Lucent-Service-Router",
            "Alc-PPPoE-Service-Name"       => "Alcatel-Lucent-Service-Router",
            "Alc-Primary-Dns"              => "Alcatel-Lucent-Service-Router",
            "Alc-Primary-Nbns"             => "Alcatel-Lucent-Service-Router",
            "Alc-Radius-Py"                => "Alcatel-Lucent-Service-Router",
            "Alc-Relative-Session-Timeout" => "Alcatel-Lucent-Service-Router",
            "Alc-Remove-Override"          => "Alcatel-Lucent-Service-Router",
            "Alc-Retail-Serv-Id"           => "Alcatel-Lucent-Service-Router",
            "Alc-RSSI"                     => "Alcatel-Lucent-Service-Router",
            "Alc-SAP-Session-Index"        => "Alcatel-Lucent-Service-Router",
            "Alc-Secondary-Dns"            => "Alcatel-Lucent-Service-Router",
            "Alc-Secondary-Nbns"           => "Alcatel-Lucent-Service-Router",
            "Alc-Serv-Id"                  => "Alcatel-Lucent-Service-Router",
            "Alc-SLA-Prof-Str"             => "Alcatel-Lucent-Service-Router",
            "Alc-SLAAC-IPv6-Pool"          => "Alcatel-Lucent-Service-Router",
            "Alc-Subsc-ID-Str"             => "Alcatel-Lucent-Service-Router",
            "Alc-Subsc-Prof-Str"           => "Alcatel-Lucent-Service-Router",
            "Alc-Subscriber-Filter"        => "Alcatel-Lucent-Service-Router",
            "Alc-Subscriber-QoS-Override"  => "Alcatel-Lucent-Service-Router",
            "Alc-ToClient-Dhcp-Options"    => "Alcatel-Lucent-Service-Router",
            "Alc-ToClient-Dhcp6-Options"   => "Alcatel-Lucent-Service-Router",
            "Alc-ToServer-Dhcp-Options"    => "Alcatel-Lucent-Service-Router",
            "Alc-ToServer-Dhcp6-Options"   => "Alcatel-Lucent-Service-Router",
            "Alc-Trigger-Acct-Interim"     => "Alcatel-Lucent-Service-Router",
            "Alc-Tunnel-Acct-Policy"       => "Alcatel-Lucent-Service-Router",
            "Alc-Tunnel-Algorithm"         => "Alcatel-Lucent-Service-Router",
            "Alc-Tunnel-AVP-Hiding"        => "Alcatel-Lucent-Service-Router",
            "Alc-Tunnel-Challenge"         => "Alcatel-Lucent-Service-Router",
            "Alc-Tunnel-Destruct-Timeout"  => "Alcatel-Lucent-Service-Router",
            "Alc-Tunnel-Group"             => "Alcatel-Lucent-Service-Router",
            "Alc-Tunnel-Hello-Interval"    => "Alcatel-Lucent-Service-Router",
            "Alc-Tunnel-Idle-Timeout"      => "Alcatel-Lucent-Service-Router",
            "Alc-Tunnel-Max-Retries-Estab" => "Alcatel-Lucent-Service-Router",
            "Alc-Tunnel-Max-Retries-Not-Estab" =>
              "Alcatel-Lucent-Service-Router",
            "Alc-Tunnel-Max-Sessions"       => "Alcatel-Lucent-Service-Router",
            "Alc-Tunnel-Rx-Window-Size"     => "Alcatel-Lucent-Service-Router",
            "Alc-Tunnel-Serv-Id"            => "Alcatel-Lucent-Service-Router",
            "Alc-UPnP-Sub-Override-Policy"  => "Alcatel-Lucent-Service-Router",
            "Alc-v6-Preferred-Lifetime"     => "Alcatel-Lucent-Service-Router",
            "Alc-v6-Valid-Lifetime"         => "Alcatel-Lucent-Service-Router",
            "Alc-Wlan-APN-Name"             => "Alcatel-Lucent-Service-Router",
            "Alc-Wlan-Portal-Redirect"      => "Alcatel-Lucent-Service-Router",
            "Alc-Wlan-Portal-Url"           => "Alcatel-Lucent-Service-Router",
            "Alc-Wlan-SSID-VLAN"            => "Alcatel-Lucent-Service-Router",
            "Alc-WPP-ErrorCode"             => "Alcatel-Lucent-Service-Router",
            "Alphion-ACL-Server-Query-Info" => "Alphion",
            "Alphion-Admin-Path"            => "Alphion",
            "Alphion-Admin-Role"            => "Alphion",
            "Alphion-AirGroup-Device-Type"  => "Alphion",
            "Alphion-AirGroup-Shared-Group" => "Alphion",
            "Alphion-AirGroup-Shared-Role"  => "Alphion",
            "Alphion-AirGroup-Shared-User"  => "Alphion",
            "Alphion-AirGroup-User-Name"    => "Alphion",
            "Alphion-AirGroup-Version"      => "Alphion",
            "Alphion-AP-Group"              => "Alphion",
            "Alphion-AP-IP-Address"         => "Alphion",
            "Alphion-AS-Credential-Hash"    => "Alphion",
            "Alphion-AS-User-Name"          => "Alphion",
            "Alphion-Auth-Survivability"    => "Alphion",
            "Alphion-Calea-Server-Ip"       => "Alphion",
            "Alphion-Captive-Portal-URL"    => "Alphion",
            "Alphion-Command-String"        => "Alphion",
            "Alphion-CPPM-Role"             => "Alphion",
            "Alphion-Device-Type"           => "Alphion",
            "Alphion-Essid-Name"            => "Alphion",
            "Alphion-Framed-IPv6-Address"   => "Alphion",
            "Alphion-Location-Id"           => "Alphion",
            "Alphion-Mdps-Device-Iccid"     => "Alphion",
            "Alphion-Mdps-Device-Imei"      => "Alphion",
            "Alphion-Mdps-Device-Name"      => "Alphion",
            "Alphion-Mdps-Device-Product"   => "Alphion",
            "Alphion-Mdps-Device-Profile"   => "Alphion",
            "Alphion-Mdps-Device-Serial"    => "Alphion",
            "Alphion-Mdps-Device-Udid"      => "Alphion",
            "Alphion-Mdps-Device-Version"   => "Alphion",
            "Alphion-Mdps-Max-Devices"      => "Alphion",
            "Alphion-Mdps-Provisioning-Settings"             => "Alphion",
            "Alphion-MMS-User-Template"                      => "Alphion",
            "Alphion-MPSK-Passphrase"                        => "Alphion",
            "Alphion-Named-User-Vlan"                        => "Alphion",
            "Alphion-Network-SSO-Token"                      => "Alphion",
            "Alphion-No-DHCP-Fingerprint"                    => "Alphion",
            "Alphion-Port-Bounce-Host"                       => "Alphion",
            "Alphion-Port-Identifier"                        => "Alphion",
            "Alphion-Priv-Admin-User"                        => "Alphion",
            "Alphion-User-Group"                             => "Alphion",
            "Alphion-User-Role"                              => "Alphion",
            "Alphion-User-Vlan"                              => "Alphion",
            "Alphion-WorkSpace-App-Name"                     => "Alphion",
            "Alteon-Client-IP-Address"                       => "Alteon",
            "Alteon-Client-Netmask"                          => "Alteon",
            "Alteon-Domain-Name"                             => "Alteon",
            "Alteon-Group-Mapping"                           => "Alteon",
            "Alteon-Primary-DNS-Server"                      => "Alteon",
            "Alteon-Primary-NBNS-Server"                     => "Alteon",
            "Alteon-Secondary-DNS-Server"                    => "Alteon",
            "Alteon-Secondary-NBNS-Server"                   => "Alteon",
            "Alteon-Service-Type"                            => "Alteon",
            "Alteon-VPN-Id"                                  => "Alteon",
            "Altiga-Access-Hours-G/U"                        => "Altiga",
            "Altiga-Allow-Alpha-Only-Passwords-G"            => "Altiga",
            "Altiga-Argument-Authentication-Server-Priority" => "Altiga",
            "Altiga-Argument-Authentication-Server-Type"     => "Altiga",
            "Altiga-Argument-IPSec-Group-Name"               => "Altiga",
            "Altiga-Group-Name"                              => "Altiga",
            "Altiga-IPSec-Allow-Passwd-Store-G/U"            => "Altiga",
            "Altiga-IPSec-Authentication-G"                  => "Altiga",
            "Altiga-IPSec-Banner-G"                          => "Altiga",
            "Altiga-IPSec-Default-Domain-G"                  => "Altiga",
            "Altiga-IPSec-L2L-Keepalives-G"                  => "Altiga",
            "Altiga-IPSec-Mode-Config-G"                     => "Altiga",
            "Altiga-IPSec-Over-NAT-G"                        => "Altiga",
            "Altiga-IPSec-Over-NAT-Port-Num-G"               => "Altiga",
            "Altiga-IPSec-Sec-Association-G/U"               => "Altiga",
            "Altiga-IPSec-Secondary-Domains-G"               => "Altiga",
            "Altiga-IPSec-Split-Tunnel-List-G"               => "Altiga",
            "Altiga-IPSec-Tunnel-Type-G"                     => "Altiga",
            "Altiga-IPSec-User-Group-Lock-G"                 => "Altiga",
            "Altiga-L2TP-Encryption-G"                       => "Altiga",
            "Altiga-L2TP-Min-Authentication-G/U"             => "Altiga",
            "Altiga-Min-Password-Length-G"                   => "Altiga",
            "Altiga-Partitioning-Group"                      => "Altiga",
            "Altiga-Partitioning-Mobile-IP-Address"          => "Altiga",
            "Altiga-Partitioning-Mobile-IP-Key"              => "Altiga",
            "Altiga-Partitioning-Mobile-IP-SPI"              => "Altiga",
            "Altiga-Partitioning-Partition-Max-Sessions"     => "Altiga",
            "Altiga-Partitioning-Premise-Rout"               => "Altiga",
            "Altiga-Partitioning-Primary-DHCP"               => "Altiga",
            "Altiga-Partitioning-Secondary-DHCP"             => "Altiga",
            "Altiga-Partitioning-Strip-Realm"                => "Altiga",
            "Altiga-PPTP-Encryption-G"                       => "Altiga",
            "Altiga-PPTP-Min-Authentication-G/U"             => "Altiga",
            "Altiga-Primary-DNS-G"                           => "Altiga",
            "Altiga-Primary-WINS-G"                          => "Altiga",
            "Altiga-Priority-on-SEP-G/U"                     => "Altiga",
            "Altiga-Secondary-DNS-G"                         => "Altiga",
            "Altiga-Secondary-WINS-G"                        => "Altiga",
            "Altiga-SEP-Card-Assignment-G/U"                 => "Altiga",
            "Altiga-Simultaneous-Logins-G/U"                 => "Altiga",
            "Altiga-Tunneling-Protocols-G/U"                 => "Altiga",
            "Altiga-Use-Client-Address-G/U"                  => "Altiga",
            "ALU-AAA-Access-Rule"                            => "ALU-AAA",
            "ALU-AAA-AKA-AUTS"                               => "ALU-AAA",
            "ALU-AAA-AKA-Quintet"                            => "ALU-AAA",
            "ALU-AAA-AKA-Quintets-Needed"                    => "ALU-AAA",
            "ALU-AAA-AKA-RAND"                               => "ALU-AAA",
            "ALU-AAA-AV-Pair"                                => "ALU-AAA",
            "ALU-AAA-Called-Station-Id"                      => "ALU-AAA",
            "ALU-AAA-Civic-Location"                         => "ALU-AAA",
            "ALU-AAA-Client-Error-Action"                    => "ALU-AAA",
            "ALU-AAA-Client-OS"                              => "ALU-AAA",
            "ALU-AAA-Client-Program"                         => "ALU-AAA",
            "ALU-AAA-Client-Version"                         => "ALU-AAA",
            "ALU-AAA-Delta-Session"                          => "ALU-AAA",
            "ALU-AAA-DF-CC-Address"                          => "ALU-AAA",
            "ALU-AAA-DF-CC-Port"                             => "ALU-AAA",
            "ALU-AAA-Eval-0"                                 => "ALU-AAA",
            "ALU-AAA-Eval-1"                                 => "ALU-AAA",
            "ALU-AAA-Eval-2"                                 => "ALU-AAA",
            "ALU-AAA-Eval-3"                                 => "ALU-AAA",
            "ALU-AAA-Event"                                  => "ALU-AAA",
            "ALU-AAA-Exec-0"                                 => "ALU-AAA",
            "ALU-AAA-Exec-1"                                 => "ALU-AAA",
            "ALU-AAA-Exec-2"                                 => "ALU-AAA",
            "ALU-AAA-Exec-3"                                 => "ALU-AAA",
            "ALU-AAA-Femto-Associated-User-Name"             => "ALU-AAA",
            "ALU-AAA-Femto-Public-Key-Hash"                  => "ALU-AAA",
            "ALU-AAA-Geospatial-Location"                    => "ALU-AAA",
            "ALU-AAA-GSM-Triplet"                            => "ALU-AAA",
            "ALU-AAA-GSM-Triplets-Needed"                    => "ALU-AAA",
            "ALU-AAA-Integer-0"                              => "ALU-AAA",
            "ALU-AAA-Integer-1"                              => "ALU-AAA",
            "ALU-AAA-Integer-2"                              => "ALU-AAA",
            "ALU-AAA-Integer-3"                              => "ALU-AAA",
            "ALU-AAA-Key-0"                                  => "ALU-AAA",
            "ALU-AAA-Key-1"                                  => "ALU-AAA",
            "ALU-AAA-Key-2"                                  => "ALU-AAA",
            "ALU-AAA-Key-3"                                  => "ALU-AAA",
            "ALU-AAA-Lawful-Intercept-Status"                => "ALU-AAA",
            "ALU-AAA-NAS-IP-Address"                         => "ALU-AAA",
            "ALU-AAA-NAS-Port"                               => "ALU-AAA",
            "ALU-AAA-New-State"                              => "ALU-AAA",
            "ALU-AAA-New-Timestamp"                          => "ALU-AAA",
            "ALU-AAA-Nonce"                                  => "ALU-AAA",
            "ALU-AAA-Old-State"                              => "ALU-AAA",
            "ALU-AAA-Old-Timestamp"                          => "ALU-AAA",
            "ALU-AAA-Opaque-0"                               => "ALU-AAA",
            "ALU-AAA-Opaque-1"                               => "ALU-AAA",
            "ALU-AAA-Opaque-2"                               => "ALU-AAA",
            "ALU-AAA-Opaque-3"                               => "ALU-AAA",
            "ALU-AAA-Original-Receipt-Time"                  => "ALU-AAA",
            "ALU-AAA-Reply-Message"                          => "ALU-AAA",
            "ALU-AAA-Service-Profile"                        => "ALU-AAA",
            "ALU-AAA-String-0"                               => "ALU-AAA",
            "ALU-AAA-String-1"                               => "ALU-AAA",
            "ALU-AAA-String-2"                               => "ALU-AAA",
            "ALU-AAA-String-3"                               => "ALU-AAA",
            "ALU-AAA-Value-0"                                => "ALU-AAA",
            "ALU-AAA-Value-1"                                => "ALU-AAA",
            "ALU-AAA-Value-2"                                => "ALU-AAA",
            "ALU-AAA-Value-3"                                => "ALU-AAA",
            "Alvarion-VSA-1"                                 => "Alvarion",
            "Alvarion-VSA-10"                                => "Alvarion",
            "Alvarion-VSA-100"                               => "Alvarion",
            "Alvarion-VSA-101"                               => "Alvarion",
            "Alvarion-VSA-102"                               => "Alvarion",
            "Alvarion-VSA-103"                               => "Alvarion",
            "Alvarion-VSA-104"                               => "Alvarion",
            "Alvarion-VSA-105"                               => "Alvarion",
            "Alvarion-VSA-106"                               => "Alvarion",
            "Alvarion-VSA-107"                               => "Alvarion",
            "Alvarion-VSA-108"                               => "Alvarion",
            "Alvarion-VSA-109"                               => "Alvarion",
            "Alvarion-VSA-11"                                => "Alvarion",
            "Alvarion-VSA-110"                               => "Alvarion",
            "Alvarion-VSA-111"                               => "Alvarion",
            "Alvarion-VSA-112"                               => "Alvarion",
            "Alvarion-VSA-113"                               => "Alvarion",
            "Alvarion-VSA-114"                               => "Alvarion",
            "Alvarion-VSA-115"                               => "Alvarion",
            "Alvarion-VSA-116"                               => "Alvarion",
            "Alvarion-VSA-117"                               => "Alvarion",
            "Alvarion-VSA-118"                               => "Alvarion",
            "Alvarion-VSA-119"                               => "Alvarion",
            "Alvarion-VSA-12"                                => "Alvarion",
            "Alvarion-VSA-120"                               => "Alvarion",
            "Alvarion-VSA-121"                               => "Alvarion",
            "Alvarion-VSA-122"                               => "Alvarion",
            "Alvarion-VSA-123"                               => "Alvarion",
            "Alvarion-VSA-124"                               => "Alvarion",
            "Alvarion-VSA-125"                               => "Alvarion",
            "Alvarion-VSA-126"                               => "Alvarion",
            "Alvarion-VSA-127"                               => "Alvarion",
            "Alvarion-VSA-128"                               => "Alvarion",
            "Alvarion-VSA-129"                               => "Alvarion",
            "Alvarion-VSA-13"                                => "Alvarion",
            "Alvarion-VSA-130"                               => "Alvarion",
            "Alvarion-VSA-131"                               => "Alvarion",
            "Alvarion-VSA-132"                               => "Alvarion",
            "Alvarion-VSA-133"                               => "Alvarion",
            "Alvarion-VSA-134"                               => "Alvarion",
            "Alvarion-VSA-135"                               => "Alvarion",
            "Alvarion-VSA-136"                               => "Alvarion",
            "Alvarion-VSA-137"                               => "Alvarion",
            "Alvarion-VSA-138"                               => "Alvarion",
            "Alvarion-VSA-139"                               => "Alvarion",
            "Alvarion-VSA-14"                                => "Alvarion",
            "Alvarion-VSA-140"                               => "Alvarion",
            "Alvarion-VSA-141"                               => "Alvarion",
            "Alvarion-VSA-142"                               => "Alvarion",
            "Alvarion-VSA-143"                               => "Alvarion",
            "Alvarion-VSA-144"                               => "Alvarion",
            "Alvarion-VSA-145"                               => "Alvarion",
            "Alvarion-VSA-146"                               => "Alvarion",
            "Alvarion-VSA-147"                               => "Alvarion",
            "Alvarion-VSA-148"                               => "Alvarion",
            "Alvarion-VSA-149"                               => "Alvarion",
            "Alvarion-VSA-15"                                => "Alvarion",
            "Alvarion-VSA-150"                               => "Alvarion",
            "Alvarion-VSA-151"                               => "Alvarion",
            "Alvarion-VSA-152"                               => "Alvarion",
            "Alvarion-VSA-153"                               => "Alvarion",
            "Alvarion-VSA-154"                               => "Alvarion",
            "Alvarion-VSA-155"                               => "Alvarion",
            "Alvarion-VSA-156"                               => "Alvarion",
            "Alvarion-VSA-157"                               => "Alvarion",
            "Alvarion-VSA-158"                               => "Alvarion",
            "Alvarion-VSA-159"                               => "Alvarion",
            "Alvarion-VSA-16"                                => "Alvarion",
            "Alvarion-VSA-160"                               => "Alvarion",
            "Alvarion-VSA-161"                               => "Alvarion",
            "Alvarion-VSA-162"                               => "Alvarion",
            "Alvarion-VSA-163"                               => "Alvarion",
            "Alvarion-VSA-164"                               => "Alvarion",
            "Alvarion-VSA-165"                               => "Alvarion",
            "Alvarion-VSA-166"                               => "Alvarion",
            "Alvarion-VSA-167"                               => "Alvarion",
            "Alvarion-VSA-168"                               => "Alvarion",
            "Alvarion-VSA-169"                               => "Alvarion",
            "Alvarion-VSA-17"                                => "Alvarion",
            "Alvarion-VSA-170"                               => "Alvarion",
            "Alvarion-VSA-171"                               => "Alvarion",
            "Alvarion-VSA-172"                               => "Alvarion",
            "Alvarion-VSA-173"                               => "Alvarion",
            "Alvarion-VSA-174"                               => "Alvarion",
            "Alvarion-VSA-175"                               => "Alvarion",
            "Alvarion-VSA-176"                               => "Alvarion",
            "Alvarion-VSA-177"                               => "Alvarion",
            "Alvarion-VSA-178"                               => "Alvarion",
            "Alvarion-VSA-179"                               => "Alvarion",
            "Alvarion-VSA-18"                                => "Alvarion",
            "Alvarion-VSA-180"                               => "Alvarion",
            "Alvarion-VSA-181"                               => "Alvarion",
            "Alvarion-VSA-182"                               => "Alvarion",
            "Alvarion-VSA-183"                               => "Alvarion",
            "Alvarion-VSA-184"                               => "Alvarion",
            "Alvarion-VSA-185"                               => "Alvarion",
            "Alvarion-VSA-186"                               => "Alvarion",
            "Alvarion-VSA-187"                               => "Alvarion",
            "Alvarion-VSA-188"                               => "Alvarion",
            "Alvarion-VSA-189"                               => "Alvarion",
            "Alvarion-VSA-19"                                => "Alvarion",
            "Alvarion-VSA-190"                               => "Alvarion",
            "Alvarion-VSA-191"                               => "Alvarion",
            "Alvarion-VSA-192"                               => "Alvarion",
            "Alvarion-VSA-193"                               => "Alvarion",
            "Alvarion-VSA-194"                               => "Alvarion",
            "Alvarion-VSA-195"                               => "Alvarion",
            "Alvarion-VSA-196"                               => "Alvarion",
            "Alvarion-VSA-197"                               => "Alvarion",
            "Alvarion-VSA-198"                               => "Alvarion",
            "Alvarion-VSA-199"                               => "Alvarion",
            "Alvarion-VSA-2"                                 => "Alvarion",
            "Alvarion-VSA-20"                                => "Alvarion",
            "Alvarion-VSA-200"                               => "Alvarion",
            "Alvarion-VSA-201"                               => "Alvarion",
            "Alvarion-VSA-202"                               => "Alvarion",
            "Alvarion-VSA-203"                               => "Alvarion",
            "Alvarion-VSA-204"                               => "Alvarion",
            "Alvarion-VSA-205"                               => "Alvarion",
            "Alvarion-VSA-206"                               => "Alvarion",
            "Alvarion-VSA-207"                               => "Alvarion",
            "Alvarion-VSA-208"                               => "Alvarion",
            "Alvarion-VSA-209"                               => "Alvarion",
            "Alvarion-VSA-21"                                => "Alvarion",
            "Alvarion-VSA-210"                               => "Alvarion",
            "Alvarion-VSA-211"                               => "Alvarion",
            "Alvarion-VSA-212"                               => "Alvarion",
            "Alvarion-VSA-213"                               => "Alvarion",
            "Alvarion-VSA-214"                               => "Alvarion",
            "Alvarion-VSA-215"                               => "Alvarion",
            "Alvarion-VSA-216"                               => "Alvarion",
            "Alvarion-VSA-217"                               => "Alvarion",
            "Alvarion-VSA-218"                               => "Alvarion",
            "Alvarion-VSA-219"                               => "Alvarion",
            "Alvarion-VSA-22"                                => "Alvarion",
            "Alvarion-VSA-220"                               => "Alvarion",
            "Alvarion-VSA-221"                               => "Alvarion",
            "Alvarion-VSA-222"                               => "Alvarion",
            "Alvarion-VSA-223"                               => "Alvarion",
            "Alvarion-VSA-224"                               => "Alvarion",
            "Alvarion-VSA-225"                               => "Alvarion",
            "Alvarion-VSA-226"                               => "Alvarion",
            "Alvarion-VSA-227"                               => "Alvarion",
            "Alvarion-VSA-228"                               => "Alvarion",
            "Alvarion-VSA-229"                               => "Alvarion",
            "Alvarion-VSA-23"                                => "Alvarion",
            "Alvarion-VSA-230"                               => "Alvarion",
            "Alvarion-VSA-231"                               => "Alvarion",
            "Alvarion-VSA-232"                               => "Alvarion",
            "Alvarion-VSA-233"                               => "Alvarion",
            "Alvarion-VSA-234"                               => "Alvarion",
            "Alvarion-VSA-235"                               => "Alvarion",
            "Alvarion-VSA-236"                               => "Alvarion",
            "Alvarion-VSA-237"                               => "Alvarion",
            "Alvarion-VSA-238"                               => "Alvarion",
            "Alvarion-VSA-239"                               => "Alvarion",
            "Alvarion-VSA-24"                                => "Alvarion",
            "Alvarion-VSA-240"                               => "Alvarion",
            "Alvarion-VSA-241"                               => "Alvarion",
            "Alvarion-VSA-242"                               => "Alvarion",
            "Alvarion-VSA-243"                               => "Alvarion",
            "Alvarion-VSA-244"                               => "Alvarion",
            "Alvarion-VSA-245"                               => "Alvarion",
            "Alvarion-VSA-246"                               => "Alvarion",
            "Alvarion-VSA-247"                               => "Alvarion",
            "Alvarion-VSA-248"                               => "Alvarion",
            "Alvarion-VSA-249"                               => "Alvarion",
            "Alvarion-VSA-25"                                => "Alvarion",
            "Alvarion-VSA-250"                               => "Alvarion",
            "Alvarion-VSA-251"                               => "Alvarion",
            "Alvarion-VSA-252"                               => "Alvarion",
            "Alvarion-VSA-253"                               => "Alvarion",
            "Alvarion-VSA-254"                               => "Alvarion",
            "Alvarion-VSA-255"                               => "Alvarion",
            "Alvarion-VSA-26"                                => "Alvarion",
            "Alvarion-VSA-27"                                => "Alvarion",
            "Alvarion-VSA-28"                                => "Alvarion",
            "Alvarion-VSA-29"                                => "Alvarion",
            "Alvarion-VSA-3"                                 => "Alvarion",
            "Alvarion-VSA-30"                                => "Alvarion",
            "Alvarion-VSA-31"                                => "Alvarion",
            "Alvarion-VSA-32"                                => "Alvarion",
            "Alvarion-VSA-33"                                => "Alvarion",
            "Alvarion-VSA-34"                                => "Alvarion",
            "Alvarion-VSA-35"                                => "Alvarion",
            "Alvarion-VSA-36"                                => "Alvarion",
            "Alvarion-VSA-37"                                => "Alvarion",
            "Alvarion-VSA-38"                                => "Alvarion",
            "Alvarion-VSA-39"                                => "Alvarion",
            "Alvarion-VSA-4"                                 => "Alvarion",
            "Alvarion-VSA-40"                                => "Alvarion",
            "Alvarion-VSA-41"                                => "Alvarion",
            "Alvarion-VSA-42"                                => "Alvarion",
            "Alvarion-VSA-43"                                => "Alvarion",
            "Alvarion-VSA-44"                                => "Alvarion",
            "Alvarion-VSA-45"                                => "Alvarion",
            "Alvarion-VSA-46"                                => "Alvarion",
            "Alvarion-VSA-47"                                => "Alvarion",
            "Alvarion-VSA-48"                                => "Alvarion",
            "Alvarion-VSA-49"                                => "Alvarion",
            "Alvarion-VSA-5"                                 => "Alvarion",
            "Alvarion-VSA-50"                                => "Alvarion",
            "Alvarion-VSA-51"                                => "Alvarion",
            "Alvarion-VSA-52"                                => "Alvarion",
            "Alvarion-VSA-53"                                => "Alvarion",
            "Alvarion-VSA-54"                                => "Alvarion",
            "Alvarion-VSA-55"                                => "Alvarion",
            "Alvarion-VSA-56"                                => "Alvarion",
            "Alvarion-VSA-57"                                => "Alvarion",
            "Alvarion-VSA-58"                                => "Alvarion",
            "Alvarion-VSA-59"                                => "Alvarion",
            "Alvarion-VSA-6"                                 => "Alvarion",
            "Alvarion-VSA-60"                                => "Alvarion",
            "Alvarion-VSA-61"                                => "Alvarion",
            "Alvarion-VSA-62"                                => "Alvarion",
            "Alvarion-VSA-63"                                => "Alvarion",
            "Alvarion-VSA-64"                                => "Alvarion",
            "Alvarion-VSA-65"                                => "Alvarion",
            "Alvarion-VSA-66"                                => "Alvarion",
            "Alvarion-VSA-67"                                => "Alvarion",
            "Alvarion-VSA-68"                                => "Alvarion",
            "Alvarion-VSA-69"                                => "Alvarion",
            "Alvarion-VSA-7"                                 => "Alvarion",
            "Alvarion-VSA-70"                                => "Alvarion",
            "Alvarion-VSA-71"                                => "Alvarion",
            "Alvarion-VSA-72"                                => "Alvarion",
            "Alvarion-VSA-73"                                => "Alvarion",
            "Alvarion-VSA-74"                                => "Alvarion",
            "Alvarion-VSA-75"                                => "Alvarion",
            "Alvarion-VSA-76"                                => "Alvarion",
            "Alvarion-VSA-77"                                => "Alvarion",
            "Alvarion-VSA-78"                                => "Alvarion",
            "Alvarion-VSA-79"                                => "Alvarion",
            "Alvarion-VSA-8"                                 => "Alvarion",
            "Alvarion-VSA-80"                                => "Alvarion",
            "Alvarion-VSA-81"                                => "Alvarion",
            "Alvarion-VSA-82"                                => "Alvarion",
            "Alvarion-VSA-83"                                => "Alvarion",
            "Alvarion-VSA-84"                                => "Alvarion",
            "Alvarion-VSA-85"                                => "Alvarion",
            "Alvarion-VSA-86"                                => "Alvarion",
            "Alvarion-VSA-87"                                => "Alvarion",
            "Alvarion-VSA-88"                                => "Alvarion",
            "Alvarion-VSA-89"                                => "Alvarion",
            "Alvarion-VSA-9"                                 => "Alvarion",
            "Alvarion-VSA-90"                                => "Alvarion",
            "Alvarion-VSA-91"                                => "Alvarion",
            "Alvarion-VSA-92"                                => "Alvarion",
            "Alvarion-VSA-93"                                => "Alvarion",
            "Alvarion-VSA-94"                                => "Alvarion",
            "Alvarion-VSA-95"                                => "Alvarion",
            "Alvarion-VSA-96"                                => "Alvarion",
            "Alvarion-VSA-97"                                => "Alvarion",
            "Alvarion-VSA-98"                                => "Alvarion",
            "Alvarion-VSA-99"                                => "Alvarion",
            "AM-ACK-HTMLFile"                                => "IEA-Software",
            "AM-Bandwidth-Pool"                              => "IEA-Software",
            "AM-Bandwidth-Pool-Max-Down"                     => "IEA-Software",
            "AM-Bandwidth-Pool-Max-Up"                       => "IEA-Software",
            "AM-Disconnect-Access"                           => "IEA-Software",
            "AM-HTTP-Proxy-Port"                             => "IEA-Software",
            "AM-Interrupt-HTMLFile"                          => "IEA-Software",
            "AM-Interrupt-Interval"                          => "IEA-Software",
            "AM-Interrupt-Timeout"                           => "IEA-Software",
            "AM-Mirroring"                                   => "IEA-Software",
            "AM-NAK-HTMLFile"                                => "IEA-Software",
            "AM-Status-HTMLFile"                             => "IEA-Software",
            "Annex-Acct-Servers"                             => "Bay-Networks",
            "Annex-Addr-Resolution-Protocol"                 => "Bay-Networks",
            "Annex-Addr-Resolution-Servers"                  => "Bay-Networks",
            "Annex-Audit-Level"                              => "Bay-Networks",
            "Annex-Authen-Servers"                           => "Bay-Networks",
            "Annex-Begin-Modulation"                         => "Bay-Networks",
            "Annex-Begin-Receive-Line-Level"                 => "Bay-Networks",
            "Annex-Callback-Portlist"                        => "Bay-Networks",
            "Annex-CLI-Command"                              => "Bay-Networks",
            "Annex-Cli-Commands"                             => "Bay-Networks",
            "Annex-CLI-Filter"                               => "Bay-Networks",
            "Annex-Command-Access"                           => "Bay-Networks",
            "Annex-Compression-Protocol"                     => "Bay-Networks",
            "Annex-Connect-Progress"                         => "Bay-Networks",
            "Annex-Disconnect-Reason"                        => "Bay-Networks",
            "Annex-Domain-Name"                              => "Bay-Networks",
            "Annex-EDO"                                      => "Bay-Networks",
            "Annex-End-Modulation"                           => "Bay-Networks",
            "Annex-End-Receive-Line-Level"                   => "Bay-Networks",
            "Annex-Error-Correction-Prot"                    => "Bay-Networks",
            "Annex-Filter"                                   => "Bay-Networks",
            "Annex-Gwy-Selection-Mode"                       => "Bay-Networks",
            "Annex-Host-Allow"                               => "Bay-Networks",
            "Annex-Host-Restrict"                            => "Bay-Networks",
            "Annex-Input-Filter"                             => "Bay-Networks",
            "Annex-Keypress-Timeout"                         => "Bay-Networks",
            "Annex-Local-IP-Address"                         => "Bay-Networks",
            "Annex-Local-Username"                           => "Bay-Networks",
            "Annex-Logical-Channel-Number"                   => "Bay-Networks",
            "Annex-Maximum-Call-Duration"                    => "Bay-Networks",
            "Annex-Modem-Disc-Reason"                        => "Bay-Networks",
            "Annex-MRRU"                                     => "Bay-Networks",
            "Annex-Multicast-Rate-Limit"                     => "Bay-Networks",
            "Annex-Multilink-Id"                             => "Bay-Networks",
            "Annex-Num-In-Multilink"                         => "Bay-Networks",
            "Annex-Output-Filter"                            => "Bay-Networks",
            "Annex-Pool-Id"                                  => "Bay-Networks",
            "Annex-Port"                                     => "Bay-Networks",
            "Annex-PPP-Trace-Level"                          => "Bay-Networks",
            "Annex-Pre-Input-Octets"                         => "Bay-Networks",
            "Annex-Pre-Input-Packets"                        => "Bay-Networks",
            "Annex-Pre-Output-Octets"                        => "Bay-Networks",
            "Annex-Pre-Output-Packets"                       => "Bay-Networks",
            "Annex-Primary-DNS-Server"                       => "Bay-Networks",
            "Annex-Primary-NBNS-Server"                      => "Bay-Networks",
            "Annex-Product-Name"                             => "Bay-Networks",
            "Annex-Rate-Reneg-Req-Rcvd"                      => "Bay-Networks",
            "Annex-Rate-Reneg-Req-Sent"                      => "Bay-Networks",
            "Annex-Re-CHAP-Timeout"                          => "Bay-Networks",
            "Annex-Receive-Speed"                            => "Bay-Networks",
            "Annex-Retrain-Requests-Rcvd"                    => "Bay-Networks",
            "Annex-Retrain-Requests-Sent"                    => "Bay-Networks",
            "Annex-Retransmitted-Packets"                    => "Bay-Networks",
            "Annex-Sec-Profile-Index"                        => "Bay-Networks",
            "Annex-Secondary-DNS-Server"                     => "Bay-Networks",
            "Annex-Secondary-NBNS-Server"                    => "Bay-Networks",
            "Annex-Secondary-Srv-Endpoint"                   => "Bay-Networks",
            "Annex-Signal-to-Noise-Ratio"                    => "Bay-Networks",
            "Annex-SW-Version"                               => "Bay-Networks",
            "Annex-Syslog-Tap"                               => "Bay-Networks",
            "Annex-System-Disc-Reason"                       => "Bay-Networks",
            "Annex-Transmit-Speed"                           => "Bay-Networks",
            "Annex-Transmitted-Packets"                      => "Bay-Networks",
            "Annex-Tunnel-Authen-Mode"                       => "Bay-Networks",
            "Annex-Tunnel-Authen-Type"                       => "Bay-Networks",
            "Annex-Unauthenticated-Time"                     => "Bay-Networks",
            "Annex-User-Level"                               => "Bay-Networks",
            "Annex-User-Server-Location"                     => "Bay-Networks",
            "Annex-Wan-Number"                               => "Bay-Networks",
            "APC-ACCPX-Access1"                              => "APC",
            "APC-ACCPX-Access2"                              => "APC",
            "APC-ACCPX-Access3"                              => "APC",
            "APC-ACCPX-Access4"                              => "APC",
            "APC-ACCPX-Access5"                              => "APC",
            "APC-ACCPX-Access6"                              => "APC",
            "APC-ACCPX-Access7"                              => "APC",
            "APC-ACCPX-Doors"                                => "APC",
            "APC-ACCPX-Status"                               => "APC",
            "APC-Contact"                                    => "APC",
            "APC-Outlets"                                    => "APC",
            "APC-Perms"                                      => "APC",
            "APC-Service-Type"                               => "APC",
            "APC-Username"                                   => "APC",
            "Aptilo-Access-Profile"                          => "Aptilo",
            "Aptilo-Access-Profile-ID"                       => "Aptilo",
            "Aptilo-Ap-ID"                                   => "Aptilo",
            "Aptilo-Apc-ID"                                  => "Aptilo",
            "Aptilo-Auth-Param"                              => "Aptilo",
            "Aptilo-Auth-Result"                             => "Aptilo",
            "Aptilo-Auth-Type"                               => "Aptilo",
            "Aptilo-Automatic-Service"                       => "Aptilo",
            "Aptilo-Bw-Max-Down"                             => "Aptilo",
            "Aptilo-Bw-Max-Up"                               => "Aptilo",
            "Aptilo-Bw-Min-Down"                             => "Aptilo",
            "Aptilo-Bw-Min-Up"                               => "Aptilo",
            "Aptilo-Circuit-ID"                              => "Aptilo",
            "Aptilo-Debug-Option"                            => "Aptilo",
            "Aptilo-Denied-Cause"                            => "Aptilo",
            "Aptilo-Duration-Balance"                        => "Aptilo",
            "Aptilo-Duration-Quota"                          => "Aptilo",
            "Aptilo-Duration-Request"                        => "Aptilo",
            "Aptilo-Duration-Threshold"                      => "Aptilo",
            "Aptilo-Duration-Used"                           => "Aptilo",
            "Aptilo-Email"                                   => "Aptilo",
            "Aptilo-Exclusive-Count"                         => "Aptilo",
            "Aptilo-First-Name"                              => "Aptilo",
            "Aptilo-Gigawords-Limit"                         => "Aptilo",
            "Aptilo-Hotline-Indicator"                       => "Aptilo",
            "Aptilo-Input-Gigawords-Limit"                   => "Aptilo",
            "Aptilo-Input-Octets-Limit"                      => "Aptilo",
            "Aptilo-Key-Integer-1"                           => "Aptilo",
            "Aptilo-Key-Integer-2"                           => "Aptilo",
            "Aptilo-Key-Integer-3"                           => "Aptilo",
            "Aptilo-Key-Integer-4"                           => "Aptilo",
            "Aptilo-Key-Integer-5"                           => "Aptilo",
            "Aptilo-Key-IP-1"                                => "Aptilo",
            "Aptilo-Key-IP-2"                                => "Aptilo",
            "Aptilo-Key-IP-3"                                => "Aptilo",
            "Aptilo-Key-IP-4"                                => "Aptilo",
            "Aptilo-Key-IP-5"                                => "Aptilo",
            "Aptilo-Key-IPv6-1"                              => "Aptilo",
            "Aptilo-Key-IPv6-2"                              => "Aptilo",
            "Aptilo-Key-IPv6-3"                              => "Aptilo",
            "Aptilo-Key-IPv6-4"                              => "Aptilo",
            "Aptilo-Key-IPv6-5"                              => "Aptilo",
            "Aptilo-Key-Octets-1"                            => "Aptilo",
            "Aptilo-Key-Octets-2"                            => "Aptilo",
            "Aptilo-Key-Octets-3"                            => "Aptilo",
            "Aptilo-Key-Octets-4"                            => "Aptilo",
            "Aptilo-Key-Octets-5"                            => "Aptilo",
            "Aptilo-Key-String-1"                            => "Aptilo",
            "Aptilo-Key-String-2"                            => "Aptilo",
            "Aptilo-Key-String-3"                            => "Aptilo",
            "Aptilo-Key-String-4"                            => "Aptilo",
            "Aptilo-Key-String-5"                            => "Aptilo",
            "Aptilo-Last-Name"                               => "Aptilo",
            "Aptilo-Limit-Mode"                              => "Aptilo",
            "Aptilo-Location-Name"                           => "Aptilo",
            "Aptilo-NAS-Capabilities"                        => "Aptilo",
            "Aptilo-NAS-Model"                               => "Aptilo",
            "Aptilo-Octets-Balance"                          => "Aptilo",
            "Aptilo-Octets-Limit"                            => "Aptilo",
            "Aptilo-Octets-Quota"                            => "Aptilo",
            "Aptilo-Octets-Request"                          => "Aptilo",
            "Aptilo-Octets-Threshold"                        => "Aptilo",
            "Aptilo-Octets-Used"                             => "Aptilo",
            "Aptilo-Opaque-Key"                              => "Aptilo",
            "Aptilo-Organization"                            => "Aptilo",
            "Aptilo-Output-Gigawords-Limit"                  => "Aptilo",
            "Aptilo-Output-Octets-Limit"                     => "Aptilo",
            "Aptilo-Phone"                                   => "Aptilo",
            "Aptilo-Prepaid-Capabilities"                    => "Aptilo",
            "Aptilo-QoS-Indicator"                           => "Aptilo",
            "Aptilo-Quota-ID"                                => "Aptilo",
            "Aptilo-Realm-Concurrent-Login"                  => "Aptilo",
            "Aptilo-Realm-ID"                                => "Aptilo",
            "Aptilo-Remote-ID"                               => "Aptilo",
            "Aptilo-Resource-Balance"                        => "Aptilo",
            "Aptilo-Resource-Quota"                          => "Aptilo",
            "Aptilo-Resource-Request"                        => "Aptilo",
            "Aptilo-Resource-Threshold"                      => "Aptilo",
            "Aptilo-Resource-Used"                           => "Aptilo",
            "Aptilo-RX-Limit"                                => "Aptilo",
            "Aptilo-RX-Volume-Quota"                         => "Aptilo",
            "Aptilo-Service"                                 => "Aptilo",
            "Aptilo-Service-Profile"                         => "Aptilo",
            "Aptilo-Service-Profile-ID"                      => "Aptilo",
            "Aptilo-Session-Id"                              => "Aptilo",
            "Aptilo-Subnet-Name"                             => "Aptilo",
            "Aptilo-TRX-Limit"                               => "Aptilo",
            "Aptilo-TX-Limit"                                => "Aptilo",
            "Aptilo-TX-Volume-Quota"                         => "Aptilo",
            "Aptilo-User-ID"                                 => "Aptilo",
            "Aptilo-User-Type"                               => "Aptilo",
            "Aptilo-Volume-Quota"                            => "Aptilo",
            "Aptilo-Zone"                                    => "Aptilo",
            "Arbor-Privilege-Level"                          => "Arbor",
            "Arista-AVPair"                                  => "Arista",
            "Arista-BlockMac"                                => "Arista",
            "Arista-Captive-Portal"                          => "Arista",
            "Arista-Command"                                 => "Arista",
            "Arista-CVP-Role"                                => "Arista",
            "Arista-PortFlap"                                => "Arista",
            "Arista-UnblockMac"                              => "Arista",
            "Arista-User-Priv-Level"                         => "Arista",
            "Arista-User-Role"                               => "Arista",
            "Arista-WebAuth"                                 => "Arista",
            "Aruba-ACL-Server-Query-Info"                    => "Aruba",
            "Aruba-Admin-Device-Group"                       => "Aruba",
            "Aruba-Admin-Path"                               => "Aruba",
            "Aruba-Admin-Role"                               => "Aruba",
            "Aruba-AirGroup-Device-Type"                     => "Aruba",
            "Aruba-AirGroup-Shared-Group"                    => "Aruba",
            "Aruba-AirGroup-Shared-Role"                     => "Aruba",
            "Aruba-AirGroup-Shared-User"                     => "Aruba",
            "Aruba-AirGroup-User-Name"                       => "Aruba",
            "Aruba-AirGroup-Version"                         => "Aruba",
            "Aruba-AP-Group"                                 => "Aruba",
            "Aruba-AP-IP-Address"                            => "Aruba",
            "Aruba-AP-MAC-Address"                           => "Aruba",
            "Aruba-AS-Credential-Hash"                       => "Aruba",
            "Aruba-AS-User-Name"                             => "Aruba",
            "Aruba-Auth-Survivability"                       => "Aruba",
            "Aruba-Auth-SurvMethod"                          => "Aruba",
            "Aruba-AVPair"                                   => "Aruba",
            "Aruba-Calea-Server-Ip"                          => "Aruba",
            "Aruba-Captive-Portal-URL"                       => "Aruba",
            "Aruba-Command-String"                           => "Aruba",
            "Aruba-CPPM-Role"                                => "Aruba",
            "Aruba-Device-MAC-Address"                       => "Aruba",
            "Aruba-Device-Traffic-Class"                     => "Aruba",
            "Aruba-Device-Type"                              => "Aruba",
            "Aruba-DPP-AKMs"                                 => "Aruba",
            "Aruba-DPP-Bootstrapping-Key-B64"                => "Aruba",
            "Aruba-DPP-Bootstrapping-Key-SHA256"             => "Aruba",
            "Aruba-DPP-Bootstrapping-Net-Access-Key-SHA256"  => "Aruba",
            "Aruba-DPP-Passphrase"                           => "Aruba",
            "Aruba-DPP-Service-Type"                         => "Aruba",
            "Aruba-Essid-Name"                               => "Aruba",
            "Aruba-Framed-IPv6-Address"                      => "Aruba",
            "Aruba-Gateway-Zone"                             => "Aruba",
            "Aruba-Location-Id"                              => "Aruba",
            "Aruba-Mdps-Device-Iccid"                        => "Aruba",
            "Aruba-Mdps-Device-Imei"                         => "Aruba",
            "Aruba-Mdps-Device-Name"                         => "Aruba",
            "Aruba-Mdps-Device-Product"                      => "Aruba",
            "Aruba-Mdps-Device-Profile"                      => "Aruba",
            "Aruba-Mdps-Device-Serial"                       => "Aruba",
            "Aruba-Mdps-Device-Udid"                         => "Aruba",
            "Aruba-Mdps-Device-Version"                      => "Aruba",
            "Aruba-Mdps-Max-Devices"                         => "Aruba",
            "Aruba-Mdps-Provisioning-Settings"               => "Aruba",
            "Aruba-MMS-User-Template"                        => "Aruba",
            "Aruba-MPSK-Key-Name"                            => "Aruba",
            "Aruba-MPSK-Lookup-Info"                         => "Aruba",
            "Aruba-MPSK-Passphrase"                          => "Aruba",
            "Aruba-Named-User-Vlan"                          => "Aruba",
            "Aruba-NAS-Filter-Rule"                          => "Aruba",
            "Aruba-Network-Profile"                          => "Aruba",
            "Aruba-Network-SSO-Token"                        => "Aruba",
            "Aruba-Network-Test"                             => "Aruba",
            "Aruba-No-DHCP-Fingerprint"                      => "Aruba",
            "Aruba-Poe-Allocate-By-Method"                   => "Aruba",
            "Aruba-PoE-Priority"                             => "Aruba",
            "Aruba-Port-Auth-Mode"                           => "Aruba",
            "Aruba-Port-Bounce-Host"                         => "Aruba",
            "Aruba-Port-Identifier"                          => "Aruba",
            "Aruba-Priv-Admin-User"                          => "Aruba",
            "Aruba-PVLAN-Port-Type"                          => "Aruba",
            "Aruba-QoS-Trust-Mode"                           => "Aruba",
            "Aruba-STP-Admin-Edge-Port"                      => "Aruba",
            "Aruba-UBT-Gateway-CPPM-Role"                    => "Aruba",
            "Aruba-UBT-Gateway-Role"                         => "Aruba",
            "Aruba-User-Group"                               => "Aruba",
            "Aruba-User-Mgmt-Interface"                      => "Aruba",
            "Aruba-User-Role"                                => "Aruba",
            "Aruba-User-Vlan"                                => "Aruba",
            "Aruba-WorkSpace-App-Name"                       => "Aruba",
            "ASA-Access-List-Inbound"                        => "Cisco-ASA",
            "ASA-Access-List-Outbound"                       => "Cisco-ASA",
            "ASA-Address-Pools"                              => "Cisco-ASA",
            "ASA-Allow-Network-Extension-Mode"               => "Cisco-ASA",
            "ASA-Authenticated-User-Idle-Timeout"            => "Cisco-ASA",
            "ASA-Authorization-DN-Field"                     => "Cisco-ASA",
            "ASA-Authorization-Required"                     => "Cisco-ASA",
            "ASA-Authorization-Type"                         => "Cisco-ASA",
            "ASA-Banner1"                                    => "Cisco-ASA",
            "ASA-Banner2"                                    => "Cisco-ASA",
            "ASA-Cisco-IP-Phone-Bypass"                      => "Cisco-ASA",
            "ASA-Cisco-LEAP-Bypass"                          => "Cisco-ASA",
            "ASA-Client-Type-Version-Limiting"               => "Cisco-ASA",
            "ASA-ClientType"                                 => "Cisco-ASA",
            "ASA-DHCP-Network-Scope"                         => "Cisco-ASA",
            "ASA-Extended-Authentication-On-Rekey"           => "Cisco-ASA",
            "ASA-Group-Policy"                               => "Cisco-ASA",
            "ASA-IE-Proxy-Bypass-Local"                      => "Cisco-ASA",
            "ASA-IE-Proxy-Exception-List"                    => "Cisco-ASA",
            "ASA-IE-Proxy-PAC-URL"                           => "Cisco-ASA",
            "ASA-IE-Proxy-Server"                            => "Cisco-ASA",
            "ASA-IE-Proxy-Server-Policy"                     => "Cisco-ASA",
            "ASA-IKE-Keep-Alives"                            => "Cisco-ASA",
            "ASA-IKE-KeepAlive-Confidence-Interval"          => "Cisco-ASA",
            "ASA-IKE-Keepalive-Retry-Interval"               => "Cisco-ASA",
            "ASA-Intercept-DHCP-Configure-Msg"               => "Cisco-ASA",
            "ASA-IPsec-Allow-Passwd-Store"                   => "Cisco-ASA",
            "ASA-IPsec-Auth-On-Rekey"                        => "Cisco-ASA",
            "ASA-IPsec-Authentication"                       => "Cisco-ASA",
            "ASA-IPsec-Backup-Server-List"                   => "Cisco-ASA",
            "ASA-IPsec-Backup-Servers"                       => "Cisco-ASA",
            "ASA-IPsec-Client-Firewall-Filter-Name"          => "Cisco-ASA",
            "ASA-IPsec-Client-Firewall-Filter-Optional"      => "Cisco-ASA",
            "ASA-IPsec-Default-Domain"                       => "Cisco-ASA",
            "ASA-IPsec-IKE-Peer-ID-Check"                    => "Cisco-ASA",
            "ASA-IPsec-IP-Compression"                       => "Cisco-ASA",
            "ASA-IPsec-Mode-Config"                          => "Cisco-ASA",
            "ASA-IPsec-Over-UDP"                             => "Cisco-ASA",
            "ASA-IPsec-Over-UDP-Port"                        => "Cisco-ASA",
            "ASA-IPsec-Required-Client-Firewall-Capability"  => "Cisco-ASA",
            "ASA-IPsec-Sec-Association"                      => "Cisco-ASA",
            "ASA-IPsec-Split-DNS-Names"                      => "Cisco-ASA",
            "ASA-IPsec-Split-Tunnel-List"                    => "Cisco-ASA",
            "ASA-IPsec-Split-Tunneling-Policy"               => "Cisco-ASA",
            "ASA-IPsec-Tunnel-Type"                          => "Cisco-ASA",
            "ASA-IPv6-Address-Pools"                         => "Cisco-ASA",
            "ASA-IPv6-VPN-Filter"                            => "Cisco-ASA",
            "ASA-L2TP-Encryption"                            => "Cisco-ASA",
            "ASA-L2TP-MPPC-Compression"                      => "Cisco-ASA",
            "ASA-Member-Of"                                  => "Cisco-ASA",
            "ASA-MS-Client-Subnet-Mask"                      => "Cisco-ASA",
            "ASA-NAC-Default-ACL"                            => "Cisco-ASA",
            "ASA-NAC-Enable"                                 => "Cisco-ASA",
            "ASA-NAC-Revalidation-Timer"                     => "Cisco-ASA",
            "ASA-NAC-Settings"                               => "Cisco-ASA",
            "ASA-NAC-Status-Query-Timer"                     => "Cisco-ASA",
            "ASA-Perfect-Forward-Secrecy-Enable"             => "Cisco-ASA",
            "ASA-PPTP-Encryption"                            => "Cisco-ASA",
            "ASA-PPTP-MPPC-Compression"                      => "Cisco-ASA",
            "ASA-Primary-DNS"                                => "Cisco-ASA",
            "ASA-Primary-WINS"                               => "Cisco-ASA",
            "ASA-Privilege-Level"                            => "Cisco-ASA",
            "ASA-Require-HW-Client-Auth"                     => "Cisco-ASA",
            "ASA-Required-Client-Firewall-Description"       => "Cisco-ASA",
            "ASA-Required-Client-Firewall-Product-Code"      => "Cisco-ASA",
            "ASA-Required-Client-Firewall-Vendor-Code"       => "Cisco-ASA",
            "ASA-Required-Individual-User-Auth"              => "Cisco-ASA",
            "ASA-Secondary-DNS"                              => "Cisco-ASA",
            "ASA-Secondary-WINS"                             => "Cisco-ASA",
            "ASA-SEP-Card-Assignment"                        => "Cisco-ASA",
            "ASA-SessionSubtype"                             => "Cisco-ASA",
            "ASA-SessionType"                                => "Cisco-ASA",
            "ASA-Simultaneous-Logins"                        => "Cisco-ASA",
            "ASA-Smart-Tunnel"                               => "Cisco-ASA",
            "ASA-Smart-Tunnel-Auto"                          => "Cisco-ASA",
            "ASA-Smart-Tunnel-Auto-Signon-Enable"            => "Cisco-ASA",
            "ASA-Strip-Realm"                                => "Cisco-ASA",
            "ASA-SVC-Ask"                                    => "Cisco-ASA",
            "ASA-SVC-Ask-Timeout"                            => "Cisco-ASA",
            "ASA-SVC-DPD-Interval-Client"                    => "Cisco-ASA",
            "ASA-SVC-DPD-Interval-Gateway"                   => "Cisco-ASA",
            "ASA-SVC-DTLS"                                   => "Cisco-ASA",
            "ASA-SVC-Keepalive"                              => "Cisco-ASA",
            "ASA-SVC-Modules"                                => "Cisco-ASA",
            "ASA-SVC-MTU"                                    => "Cisco-ASA",
            "ASA-SVC-Profiles"                               => "Cisco-ASA",
            "ASA-SVC-Rekey-Time"                             => "Cisco-ASA",
            "ASA-Tunnel-Group-Lock"                          => "Cisco-ASA",
            "ASA-TunnelGroupName"                            => "Cisco-ASA",
            "ASA-Tunneling-Protocols"                        => "Cisco-ASA",
            "ASA-Use-Client-Address"                         => "Cisco-ASA",
            "ASA-VLAN"                                       => "Cisco-ASA",
            "ASA-WebVPN-Access-List"                         => "Cisco-ASA",
            "ASA-WebVPN-ActiveX-Relay"                       => "Cisco-ASA",
            "ASA-WebVPN-Apply-ACL"                           => "Cisco-ASA",
            "ASA-WebVPN-Auto-HTTP-Signon"                    => "Cisco-ASA",
            "ASA-WebVPN-Citrix-Metaframe-Enable"             => "Cisco-ASA",
            "ASA-WebVPN-Content-Filter-Parameters"           => "Cisco-ASA",
            "ASA-WebVPN-Customization"                       => "Cisco-ASA",
            "ASA-WebVPN-Default-Homepage"                    => "Cisco-ASA",
            "ASA-WebVPN-Deny-Message"                        => "Cisco-ASA",
            "ASA-WebVPN-Download_Max-Size"                   => "Cisco-ASA",
            "ASA-WebVPN-File-Access-Enable"                  => "Cisco-ASA",
            "ASA-WebVPN-File-Server-Browsing-Enable"         => "Cisco-ASA",
            "ASA-WebVPN-File-Server-Entry-Enable"            => "Cisco-ASA",
            "ASA-WebVPN-Group-based-HTTP/HTTPS-Proxy-Exception-List" =>
              "Cisco-ASA",
            "ASA-WebVPN-Hidden-Shares"                         => "Cisco-ASA",
            "ASA-WebVPN-Home-Page-Use-Smart-Tunnel"            => "Cisco-ASA",
            "ASA-WebVPN-HTML-Filter"                           => "Cisco-ASA",
            "ASA-WebVPN-HTTP-Compression"                      => "Cisco-ASA",
            "ASA-WebVPN-HTTP-Proxy-IP-Address"                 => "Cisco-ASA",
            "ASA-WebVPN-Idle-Timeout-Alert-Interval"           => "Cisco-ASA",
            "ASA-WebVPN-Keepalive-Ignore"                      => "Cisco-ASA",
            "ASA-WebVPN-Macro-Substitution-Value1"             => "Cisco-ASA",
            "ASA-WebVPN-Macro-Substitution-Value2"             => "Cisco-ASA",
            "ASA-WebVPN-Port-Forwarding-Enable"                => "Cisco-ASA",
            "ASA-WebVPN-Port-Forwarding-Exchange-Proxy-Enable" => "Cisco-ASA",
            "ASA-WebVPN-Port-Forwarding-HTTP-Proxy"            => "Cisco-ASA",
            "ASA-WebVPN-Port-Forwarding-List"                  => "Cisco-ASA",
            "ASA-WebVPN-Port-Forwarding-Name"                  => "Cisco-ASA",
            "ASA-WebVPN-Post-Max-Size"                         => "Cisco-ASA",
            "ASA-WebVPN-Session-Timeout-Alert-Interval"        => "Cisco-ASA",
            "ASA-WebVPN-Smart-Tunnel"                          => "Cisco-ASA",
            "ASA-WebVPN-Smart-Tunnel-Auto-Sign-On"             => "Cisco-ASA",
            "ASA-WebVPN-Smart-Tunnel-Auto-Start"               => "Cisco-ASA",
            "ASA-WebVPN-Smart-Tunnel-Tunnel-Policy"            => "Cisco-ASA",
            "ASA-WebVPN-SSL-VPN-Client-Enable"                 => "Cisco-ASA",
            "ASA-WebVPN-SSL-VPN-Client-Keep-Installation"      => "Cisco-ASA",
            "ASA-WebVPN-SSL-VPN-Client-Required"               => "Cisco-ASA",
            "ASA-WebVPN-SSO-Server-Name"                       => "Cisco-ASA",
            "ASA-WebVPN-Storage-Key"                           => "Cisco-ASA",
            "ASA-WebVPN-Storage-Objects"                       => "Cisco-ASA",
            "ASA-WebVPN-SVC-Client-DPD-Frequency"              => "Cisco-ASA",
            "ASA-WebVPN-SVC-Compression"                       => "Cisco-ASA",
            "ASA-WebVPN-SVC-DTLS-Enable"                       => "Cisco-ASA",
            "ASA-WebVPN-SVC-DTLS-MTU"                          => "Cisco-ASA",
            "ASA-WebVPN-SVC-Gateway-DPD-Frequency"             => "Cisco-ASA",
            "ASA-WebVPN-SVC-Keepalive-Frequency"               => "Cisco-ASA",
            "ASA-WebVPN-SVC-Rekey-Method"                      => "Cisco-ASA",
            "ASA-WebVPN-SVC-Rekey-Time"                        => "Cisco-ASA",
            "ASA-WebVPN-UNIX-Group-ID"                         => "Cisco-ASA",
            "ASA-WebVPN-UNIX-User-ID"                          => "Cisco-ASA",
            "ASA-WebVPN-Upload-Max-Size"                       => "Cisco-ASA",
            "ASA-WebVPN-URL-Entry-Enable"                      => "Cisco-ASA",
            "ASA-WebVPN-URL-List"                              => "Cisco-ASA",
            "ASA-WebVPN-User-Storage"                          => "Cisco-ASA",
            "ASA-WebVPN-VDI"                                   => "Cisco-ASA",
            "ASA-WebVPNACL"                                    => "Cisco-ASA",
            "ASA-WebVPNSmart-Card-Removal-Disconnect"          => "Cisco-ASA",
            "Ascend-Access-Intercept-LEA"                      => "Ascend",
            "Ascend-Access-Intercept-Log"                      => "Ascend",
            "Ascend-Add-Seconds"                               => "Ascend",
            "Ascend-Appletalk-Peer-Mode"                       => "Ascend",
            "Ascend-Appletalk-Route"                           => "Ascend",
            "Ascend-Ara-PW"                                    => "Ascend",
            "Ascend-Assign-IP-Client"                          => "Ascend",
            "Ascend-Assign-IP-Global-Pool"                     => "Ascend",
            "Ascend-Assign-IP-Pool"                            => "Ascend",
            "Ascend-Assign-IP-Server"                          => "Ascend",
            "Ascend-ATM-Connect-Group"                         => "Ascend",
            "Ascend-ATM-Connect-Vci"                           => "Ascend",
            "Ascend-ATM-Connect-Vpi"                           => "Ascend",
            "Ascend-ATM-Direct"                                => "Ascend",
            "Ascend-ATM-Direct-Profile"                        => "Ascend",
            "Ascend-ATM-Fault-Management"                      => "Ascend",
            "Ascend-ATM-Group"                                 => "Ascend",
            "Ascend-ATM-Loopback-Cell-Loss"                    => "Ascend",
            "Ascend-ATM-Vci"                                   => "Ascend",
            "Ascend-ATM-Vpi"                                   => "Ascend",
            "Ascend-Auth-Delay"                                => "Ascend",
            "Ascend-Auth-Type"                                 => "Ascend",
            "Ascend-Authen-Alias"                              => "Ascend",
            "Ascend-Backup"                                    => "Ascend",
            "Ascend-BACP-Enable"                               => "Ascend",
            "Ascend-Base-Channel-Count"                        => "Ascend",
            "Ascend-Bi-Directional-Auth"                       => "Ascend",
            "Ascend-Billing-Number"                            => "Ascend",
            "Ascend-BIR-Bridge-Group"                          => "Ascend",
            "Ascend-BIR-Enable"                                => "Ascend",
            "Ascend-BIR-Proxy"                                 => "Ascend",
            "Ascend-Bridge"                                    => "Ascend",
            "Ascend-Bridge-Address"                            => "Ascend",
            "Ascend-Bridge-Non-PPPoE"                          => "Ascend",
            "Ascend-Cache-Refresh"                             => "Ascend",
            "Ascend-Cache-Time"                                => "Ascend",
            "Ascend-Call-Attempt-Limit"                        => "Ascend",
            "Ascend-Call-Block-Duration"                       => "Ascend",
            "Ascend-Call-By-Call"                              => "Ascend",
            "Ascend-Call-Direction"                            => "Ascend",
            "Ascend-Call-Filter"                               => "Ascend",
            "Ascend-Call-Type"                                 => "Ascend",
            "Ascend-Callback"                                  => "Ascend",
            "Ascend-Callback-Delay"                            => "Ascend",
            "Ascend-Calling-Id-Number-Plan"                    => "Ascend",
            "Ascend-Calling-Id-Presentatn"                     => "Ascend",
            "Ascend-Calling-Id-Screening"                      => "Ascend",
            "Ascend-Calling-Id-Type-Of-Num"                    => "Ascend",
            "Ascend-Calling-Subaddress"                        => "Ascend",
            "Ascend-CBCP-Delay"                                => "Ascend",
            "Ascend-CBCP-Enable"                               => "Ascend",
            "Ascend-CBCP-Mode"                                 => "Ascend",
            "Ascend-CBCP-Trunk-Group"                          => "Ascend",
            "Ascend-CIR-Timer"                                 => "Ascend",
            "Ascend-Ckt-Type"                                  => "Ascend",
            "Ascend-Client-Assign-DNS"                         => "Ascend",
            "Ascend-Client-Assign-WINS"                        => "Ascend",
            "Ascend-Client-Gateway"                            => "Ascend",
            "Ascend-Client-Primary-DNS"                        => "Ascend",
            "Ascend-Client-Primary-WINS"                       => "Ascend",
            "Ascend-Client-Secondary-DNS"                      => "Ascend",
            "Ascend-Client-Secondary-WINS"                     => "Ascend",
            "Ascend-Connect-Progress"                          => "Ascend",
            "Ascend-Data-Filter"                               => "Ascend",
            "Ascend-Data-Rate"                                 => "Ascend",
            "Ascend-Data-Svc"                                  => "Ascend",
            "Ascend-DBA-Monitor"                               => "Ascend",
            "Ascend-Dec-Channel-Count"                         => "Ascend",
            "Ascend-Destination-Nas-Port"                      => "Ascend",
            "Ascend-DHCP-Maximum-Leases"                       => "Ascend",
            "Ascend-DHCP-Pool-Number"                          => "Ascend",
            "Ascend-DHCP-Reply"                                => "Ascend",
            "Ascend-Dial-Number"                               => "Ascend",
            "Ascend-Dialed-Number"                             => "Ascend",
            "Ascend-Dialout-Allowed"                           => "Ascend",
            "Ascend-Disconnect-Cause"                          => "Ascend",
            "Ascend-Dropped-Octets"                            => "Ascend",
            "Ascend-Dropped-Packets"                           => "Ascend",
            "Ascend-Dsl-CIR-Recv-Limit"                        => "Ascend",
            "Ascend-Dsl-CIR-Xmit-Limit"                        => "Ascend",
            "Ascend-Dsl-Downstream-Limit"                      => "Ascend",
            "Ascend-Dsl-Rate-Mode"                             => "Ascend",
            "Ascend-Dsl-Rate-Type"                             => "Ascend",
            "Ascend-Dsl-Upstream-Limit"                        => "Ascend",
            "Ascend-Egress-Enabled"                            => "Ascend",
            "Ascend-Endpoint-Disc"                             => "Ascend",
            "Ascend-Event-Type"                                => "Ascend",
            "Ascend-Expect-Callback"                           => "Ascend",
            "Ascend-FCP-Parameter"                             => "Ascend",
            "Ascend-Filter"                                    => "Ascend",
            "Ascend-Filter-Required"                           => "Ascend",
            "Ascend-First-Dest"                                => "Ascend",
            "Ascend-Force-56"                                  => "Ascend",
            "Ascend-FR-08-Mode"                                => "Ascend",
            "Ascend-FR-Circuit-Name"                           => "Ascend",
            "Ascend-FR-DCE-N392"                               => "Ascend",
            "Ascend-FR-DCE-N393"                               => "Ascend",
            "Ascend-FR-Direct"                                 => "Ascend",
            "Ascend-FR-Direct-DLCI"                            => "Ascend",
            "Ascend-FR-Direct-Profile"                         => "Ascend",
            "Ascend-FR-DLCI"                                   => "Ascend",
            "Ascend-FR-DTE-N392"                               => "Ascend",
            "Ascend-FR-DTE-N393"                               => "Ascend",
            "Ascend-FR-Link-Mgt"                               => "Ascend",
            "Ascend-FR-Link-Status-DLCI"                       => "Ascend",
            "Ascend-FR-LinkUp"                                 => "Ascend",
            "Ascend-FR-N391"                                   => "Ascend",
            "Ascend-FR-Nailed-Grp"                             => "Ascend",
            "Ascend-FR-Profile-Name"                           => "Ascend",
            "Ascend-FR-SVC-Addr"                               => "Ascend",
            "Ascend-FR-T391"                                   => "Ascend",
            "Ascend-FR-T392"                                   => "Ascend",
            "Ascend-FR-Type"                                   => "Ascend",
            "Ascend-FT1-Caller"                                => "Ascend",
            "Ascend-Global-Call-Id"                            => "Ascend",
            "Ascend-Group"                                     => "Ascend",
            "Ascend-H323-Conference-Id"                        => "Ascend",
            "Ascend-H323-Dialed-Time"                          => "Ascend",
            "Ascend-H323-Fegw-Address"                         => "Ascend",
            "Ascend-H323-Gatekeeper"                           => "Ascend",
            "Ascend-Handle-IPX"                                => "Ascend",
            "Ascend-History-Weigh-Type"                        => "Ascend",
            "Ascend-Home-Agent-IP-Addr"                        => "Ascend",
            "Ascend-Home-Agent-Password"                       => "Ascend",
            "Ascend-Home-Agent-UDP-Port"                       => "Ascend",
            "Ascend-Home-Network-Name"                         => "Ascend",
            "Ascend-Host-Info"                                 => "Ascend",
            "Ascend-Idle-Limit"                                => "Ascend",
            "Ascend-IF-Netmask"                                => "Ascend",
            "Ascend-Inc-Channel-Count"                         => "Ascend",
            "Ascend-Inter-Arrival-Jitter"                      => "Ascend",
            "Ascend-IP-Direct"                                 => "Ascend",
            "Ascend-IP-Pool-Chaining"                          => "Ascend",
            "Ascend-IP-Pool-Definition"                        => "Ascend",
            "Ascend-IP-TOS"                                    => "Ascend",
            "Ascend-IP-TOS-Apply-To"                           => "Ascend",
            "Ascend-IP-TOS-Precedence"                         => "Ascend",
            "Ascend-IPSEC-Profile"                             => "Ascend",
            "Ascend-IPX-Alias"                                 => "Ascend",
            "Ascend-IPX-Header-Compression"                    => "Ascend",
            "Ascend-IPX-Node-Addr"                             => "Ascend",
            "Ascend-IPX-Peer-Mode"                             => "Ascend",
            "Ascend-IPX-Route"                                 => "Ascend",
            "Ascend-Link-Compression"                          => "Ascend",
            "Ascend-Max-Shared-Users"                          => "Ascend",
            "Ascend-Maximum-Call-Duration"                     => "Ascend",
            "Ascend-Maximum-Channels"                          => "Ascend",
            "Ascend-Maximum-Time"                              => "Ascend",
            "Ascend-Menu-Item"                                 => "Ascend",
            "Ascend-Menu-Selector"                             => "Ascend",
            "Ascend-Metric"                                    => "Ascend",
            "Ascend-Minimum-Channels"                          => "Ascend",
            "Ascend-Modem-PortNo"                              => "Ascend",
            "Ascend-Modem-ShelfNo"                             => "Ascend",
            "Ascend-Modem-SlotNo"                              => "Ascend",
            "Ascend-MPP-Idle-Percent"                          => "Ascend",
            "Ascend-MTU"                                       => "Ascend",
            "Ascend-Multicast-Client"                          => "Ascend",
            "Ascend-Multicast-GLeave-Delay"                    => "Ascend",
            "Ascend-Multicast-Rate-Limit"                      => "Ascend",
            "Ascend-Multilink-ID"                              => "Ascend",
            "Ascend-NAS-Port-Format"                           => "Ascend",
            "Ascend-Netware-timeout"                           => "Ascend",
            "Ascend-Num-In-Multilink"                          => "Ascend",
            "Ascend-Number-Sessions"                           => "Ascend",
            "Ascend-Numbering-Plan-ID"                         => "Ascend",
            "Ascend-Owner-IP-Addr"                             => "Ascend",
            "Ascend-Port-Redir-Portnum"                        => "Ascend",
            "Ascend-Port-Redir-Protocol"                       => "Ascend",
            "Ascend-Port-Redir-Server"                         => "Ascend",
            "Ascend-PPP-Address"                               => "Ascend",
            "Ascend-PPP-Async-Map"                             => "Ascend",
            "Ascend-PPP-VJ-1172"                               => "Ascend",
            "Ascend-PPP-VJ-Slot-Comp"                          => "Ascend",
            "Ascend-PPPoE-Enable"                              => "Ascend",
            "Ascend-Pre-Input-Octets"                          => "Ascend",
            "Ascend-Pre-Input-Packets"                         => "Ascend",
            "Ascend-Pre-Output-Octets"                         => "Ascend",
            "Ascend-Pre-Output-Packets"                        => "Ascend",
            "Ascend-Preempt-Limit"                             => "Ascend",
            "Ascend-PreSession-Time"                           => "Ascend",
            "Ascend-PRI-Number-Type"                           => "Ascend",
            "Ascend-Primary-Home-Agent"                        => "Ascend",
            "Ascend-Private-Route"                             => "Ascend",
            "Ascend-Private-Route-Required"                    => "Ascend",
            "Ascend-Private-Route-Table-ID"                    => "Ascend",
            "Ascend-PW-Lifetime"                               => "Ascend",
            "Ascend-PW-Warntime"                               => "Ascend",
            "Ascend-QOS-Downstream"                            => "Ascend",
            "Ascend-QOS-Upstream"                              => "Ascend",
            "Ascend-Receive-Secret"                            => "Ascend",
            "Ascend-Recv-Name"                                 => "Ascend",
            "Ascend-Redirect-Number"                           => "Ascend",
            "Ascend-Remote-Addr"                               => "Ascend",
            "Ascend-Remote-FW"                                 => "Ascend",
            "Ascend-Remove-Seconds"                            => "Ascend",
            "Ascend-Require-Auth"                              => "Ascend",
            "Ascend-Route-Appletalk"                           => "Ascend",
            "Ascend-Route-IP"                                  => "Ascend",
            "Ascend-Route-IPX"                                 => "Ascend",
            "Ascend-Secondary-Home-Agent"                      => "Ascend",
            "Ascend-Seconds-Of-History"                        => "Ascend",
            "Ascend-Send-Auth"                                 => "Ascend",
            "Ascend-Send-Passwd"                               => "Ascend",
            "Ascend-Send-Secret"                               => "Ascend",
            "Ascend-Service-Type"                              => "Ascend",
            "Ascend-Session-Svr-Key"                           => "Ascend",
            "Ascend-Session-Type"                              => "Ascend",
            "Ascend-Shared-Profile-Enable"                     => "Ascend",
            "Ascend-Source-Auth"                               => "Ascend",
            "Ascend-Source-IP-Check"                           => "Ascend",
            "Ascend-SVC-Enabled"                               => "Ascend",
            "Ascend-Target-Util"                               => "Ascend",
            "Ascend-Telnet-Profile"                            => "Ascend",
            "Ascend-Temporary-Rtes"                            => "Ascend",
            "Ascend-Third-Prompt"                              => "Ascend",
            "Ascend-Token-Expiry"                              => "Ascend",
            "Ascend-Token-Idle"                                => "Ascend",
            "Ascend-Token-Immediate"                           => "Ascend",
            "Ascend-Traffic-Shaper"                            => "Ascend",
            "Ascend-Transit-Number"                            => "Ascend",
            "Ascend-TS-Idle-Limit"                             => "Ascend",
            "Ascend-TS-Idle-Mode"                              => "Ascend",
            "Ascend-Tunnel-VRouter-Name"                       => "Ascend",
            "Ascend-Tunneling-Protocol"                        => "Ascend",
            "Ascend-User-Acct-Base"                            => "Ascend",
            "Ascend-User-Acct-Host"                            => "Ascend",
            "Ascend-User-Acct-Key"                             => "Ascend",
            "Ascend-User-Acct-Port"                            => "Ascend",
            "Ascend-User-Acct-Time"                            => "Ascend",
            "Ascend-User-Acct-Type"                            => "Ascend",
            "Ascend-UU-Info"                                   => "Ascend",
            "Ascend-VRouter-Name"                              => "Ascend",
            "Ascend-X25-Cug"                                   => "Ascend",
            "Ascend-X25-Nui"                                   => "Ascend",
            "Ascend-X25-Nui-Password-Prompt"                   => "Ascend",
            "Ascend-X25-Nui-Prompt"                            => "Ascend",
            "Ascend-X25-Pad-Alias-1"                           => "Ascend",
            "Ascend-X25-Pad-Alias-2"                           => "Ascend",
            "Ascend-X25-Pad-Alias-3"                           => "Ascend",
            "Ascend-X25-Pad-Banner"                            => "Ascend",
            "Ascend-X25-Pad-Prompt"                            => "Ascend",
            "Ascend-X25-Pad-X3-Parameters"                     => "Ascend",
            "Ascend-X25-Pad-X3-Profile"                        => "Ascend",
            "Ascend-X25-Profile-Name"                          => "Ascend",
            "Ascend-X25-Reverse-Charging"                      => "Ascend",
            "Ascend-X25-Rpoa"                                  => "Ascend",
            "Ascend-X25-X121-Address"                          => "Ascend",
            "Ascend-Xmit-Rate"                                 => "Ascend",
            "ASN-Firewall-Available"                           => "ASN",
            "ASN-Firewall-Block-Ping"                          => "ASN",
            "ASN-Firewall-Open"                                => "ASN",
            "ASN-Firewall-State"                               => "ASN",
            "ASN-IP-Pool-Name"                                 => "ASN",
            "ASN-IP-Redirect"                                  => "ASN",
            "ASN-Kbps-Down"                                    => "ASN",
            "ASN-Kbps-Down-Localmedia"                         => "ASN",
            "ASN-Kbps-Up"                                      => "ASN",
            "ASN-Pps-Down"                                     => "ASN",
            "ASN-Pps-Up"                                       => "ASN",
            "ASN-QoS-Available"                                => "ASN",
            "ASN-QoS-State"                                    => "ASN",
            "ASN-TCP-Connlimit"                                => "ASN",
            "ASN-Webfilter-Destination"                        => "ASN",
            "ASN-Webfilter-Domain"                             => "ASN",
            "ASN-Webfilter-Mode"                               => "ASN",
            "ASN-Webfilter-Redirect"                           => "ASN",
            "Assigned-IP-Address"                              => "Ericsson-AB",
            "Asterisk-Acc-Code"                                => "Digium",
            "Asterisk-AMA-Flags"                               => "Digium",
            "Asterisk-Answer-Time"                             => "Digium",
            "Asterisk-Bill-Sec"                                => "Digium",
            "Asterisk-Chan"                                    => "Digium",
            "Asterisk-Clid"                                    => "Digium",
            "Asterisk-Disposition"                             => "Digium",
            "Asterisk-Dst"                                     => "Digium",
            "Asterisk-Dst-Chan"                                => "Digium",
            "Asterisk-Dst-Ctx"                                 => "Digium",
            "Asterisk-Duration"                                => "Digium",
            "Asterisk-End-Time"                                => "Digium",
            "Asterisk-Last-App"                                => "Digium",
            "Asterisk-Last-Data"                               => "Digium",
            "Asterisk-Src"                                     => "Digium",
            "Asterisk-Start-Time"                              => "Digium",
            "Asterisk-Unique-ID"                               => "Digium",
            "Asterisk-User-Field"                              => "Digium",
            "Attainable-Data-Rate-Downstream"                  => "ADSL-Forum",
            "Attainable-Data-Rate-Upstream"                    => "ADSL-Forum",
            "Avaya-PortPriority-Type"                          => "Cajun_p330",
            "Avaya-StaticVlan-Type"                            => "Cajun_p330",
            "Azaire-APN"                                       => "Azaire",
            "Azaire-APN-OI"                                    => "Azaire",
            "Azaire-APN-Resolution-Req"                        => "Azaire",
            "Azaire-Auth-Type"                                 => "Azaire",
            "Azaire-Brand-Code"                                => "Azaire",
            "Azaire-Client-Local-IP"                           => "Azaire",
            "Azaire-Gn-User-Name"                              => "Azaire",
            "Azaire-IMSI"                                      => "Azaire",
            "Azaire-MSISDN"                                    => "Azaire",
            "Azaire-NAS-Type"                                  => "Azaire",
            "Azaire-Policy-Name"                               => "Azaire",
            "Azaire-QoS"                                       => "Azaire",
            "Azaire-Selection-Mode"                            => "Azaire",
            "Azaire-Start-Time"                                => "Azaire",
            "Azaire-Status"                                    => "Azaire",
            "Azaire-Triplets"                                  => "Azaire",
            "BELRAS-Acct"                                      => "Cnergee",
            "BELRAS-AKAMAI-Speed"                              => "Cnergee",
            "BELRAS-Auth"                                      => "Cnergee",
            "BELRAS-BELCACHE-Speed"                            => "Cnergee",
            "BELRAS-BL"                                        => "Cnergee",
            "BELRAS-CACHE-Speed"                               => "Cnergee",
            "BELRAS-CacheFly-Speed"                            => "Cnergee",
            "BELRAS-CO"                                        => "Cnergee",
            "BELRAS-DHCP-Lease-Time"                           => "Cnergee",
            "BELRAS-DHCP-Mask"                                 => "Cnergee",
            "BELRAS-DHCP-Option82"                             => "Cnergee",
            "BELRAS-DHCP-Router-IP-Address"                    => "Cnergee",
            "BELRAS-Down-Speed-Limit"                          => "Cnergee",
            "BELRAS-Framed-IP-Address"                         => "Cnergee",
            "BELRAS-GGC-Speed"                                 => "Cnergee",
            "BELRAS-GOOGLE-Speed"                              => "Cnergee",
            "BELRAS-Group"                                     => "Cnergee",
            "BELRAS-IN"                                        => "Cnergee",
            "BELRAS-Incapsula-Speed"                           => "Cnergee",
            "BELRAS-LIMELIGHT-Speed"                           => "Cnergee",
            "BELRAS-LIMIT"                                     => "Cnergee",
            "BELRAS-Octets-Direction"                          => "Cnergee",
            "BELRAS-OTHERS-Speed"                              => "Cnergee",
            "BELRAS-Qos-Speed"                                 => "Cnergee",
            "BELRAS-REDIFF-Speed"                              => "Cnergee",
            "BELRAS-Redirect"                                  => "Cnergee",
            "BELRAS-redirect-Pool"                             => "Cnergee",
            "BELRAS-Session-Octets-Limit"                      => "Cnergee",
            "BELRAS-TORRENT-Speed"                             => "Cnergee",
            "BELRAS-Up-Speed-Limit"                            => "Cnergee",
            "BELRAS-User"                                      => "Cnergee",
            "BG-Aging-Time"                                    => "Ericsson-AB",
            "BG-Cct-Addr-Max"                                  => "Ericsson-AB",
            "BG-Path-Cost"                                     => "Ericsson-AB",
            "BG-Span-Dis"                                      => "Ericsson-AB",
            "BG-Trans-BPDU"                                    => "Ericsson-AB",
            "Bind-Auth-Context"                                => "Ericsson-AB",
            "Bind-Auth-Max-Sessions"                           => "Ericsson-AB",
            "Bind-Auth-Protocol"                               => "Ericsson-AB",
            "Bind-Auth-Service-Grp"                            => "Ericsson-AB",
            "Bind-Auto-Sub-Context"                            => "Ericsson-AB",
            "Bind-Auto-Sub-Password"                           => "Ericsson-AB",
            "Bind-Auto-Sub-User"                               => "Ericsson-AB",
            "Bind-Bypass-Bypass"                               => "Ericsson-AB",
            "Bind-Bypass-Context"                              => "Ericsson-AB",
            "Bind-Dot1q-Port"                                  => "Ericsson-AB",
            "Bind-Dot1q-Slot"                                  => "Ericsson-AB",
            "Bind-Dot1q-Vlan-Tag-Id"                           => "Ericsson-AB",
            "Bind-Int-Context"                                 => "Ericsson-AB",
            "Bind-Int-Interface-Name"                          => "Ericsson-AB",
            "Bind-L2TP-Flow-Control"                           => "Ericsson-AB",
            "Bind-L2TP-Tunnel-Name"                            => "Ericsson-AB",
            "Bind-Ses-Context"                                 => "Ericsson-AB",
            "Bind-Sub-Password"                                => "Ericsson-AB",
            "Bind-Sub-User-At-Context"                         => "Ericsson-AB",
            "Bind-Tun-Context"                                 => "Ericsson-AB",
            "Bind-Type"                                        => "Ericsson-AB",
            "BinTec-biboDialTable"                             => "BinTec",
            "BinTec-biboPPPTable"                              => "BinTec",
            "BinTec-ipExtIfTable"                              => "BinTec",
            "BinTec-ipExtRtTable"                              => "BinTec",
            "BinTec-ipFilterTable"                             => "BinTec",
            "BinTec-ipNatPresetTable"                          => "BinTec",
            "BinTec-ipQoSTable"                                => "BinTec",
            "BinTec-ipRouteTable"                              => "BinTec",
            "BinTec-ipxCircTable"                              => "BinTec",
            "BinTec-ipxStaticRouteTable"                       => "BinTec",
            "BinTec-ipxStaticServTable"                        => "BinTec",
            "BinTec-ospfIfTable"                               => "BinTec",
            "BinTec-pppExtIfTable"                             => "BinTec",
            "BinTec-qosIfTable"                                => "BinTec",
            "BinTec-qosPolicyTable"                            => "BinTec",
            "BinTec-ripCircTable"                              => "BinTec",
            "BinTec-sapCircTable"                              => "BinTec",
            "Blue-Coat-Authorization"                          => "BlueCoat",
            "Blue-Coat-Group"                                  => "BlueCoat",
            "Breezecom-Attr1"                                  => "Alvarion",
            "Breezecom-Attr10"                                 => "Alvarion",
            "Breezecom-Attr11"                                 => "Alvarion",
            "Breezecom-Attr2"                                  => "Alvarion",
            "Breezecom-Attr3"                                  => "Alvarion",
            "Breezecom-Attr4"                                  => "Alvarion",
            "Breezecom-Attr5"                                  => "Alvarion",
            "Breezecom-Attr6"                                  => "Alvarion",
            "Breezecom-Attr7"                                  => "Alvarion",
            "Breezecom-Attr8"                                  => "Alvarion",
            "Breezecom-Attr9"                                  => "Alvarion",
            "Bridge-Group"                                     => "Ericsson-AB",
            "BroadSoft-Attr-255"                               => "BroadSoft",
            "Brocade-Auth-Role"                                => "Brocade",
            "Brocade-AVPairs1"                                 => "Brocade",
            "Brocade-AVPairs2"                                 => "Brocade",
            "Brocade-AVPairs3"                                 => "Brocade",
            "Brocade-AVPairs4"                                 => "Brocade",
            "Brocade-Passwd-ExpiryDate"                        => "Brocade",
            "Brocade-Passwd-WarnPeriod"                        => "Brocade",
            "BSN-AVPair"                    => "Big-Switch-Networks",
            "BSN-User-Role"                 => "Big-Switch-Networks",
            "BW-Area-Code"                  => "Boingo",
            "BW-Category"                   => "Boingo",
            "BW-City-Name"                  => "Boingo",
            "BW-Class"                      => "Boingo",
            "BW-e164-Country-Code"          => "Boingo",
            "BW-ISO-Country-Code"           => "Boingo",
            "BW-Operator-Name"              => "Boingo",
            "BW-Service-Type"               => "Boingo",
            "BW-State-Name"                 => "Boingo",
            "BW-User-Group"                 => "Boingo",
            "BW-User-Name"                  => "Boingo",
            "BW-User-Password"              => "Boingo",
            "BW-User-Prefix"                => "Boingo",
            "BW-User-Realm"                 => "Boingo",
            "BW-User-Role"                  => "Boingo",
            "BW-Venue-Description"          => "Boingo",
            "BW-Venue-Id"                   => "Boingo",
            "BW-Venue-Name"                 => "Boingo",
            "BW-Venue-Port-Type"            => "Boingo",
            "BW-Venue-Price-Type"           => "Boingo",
            "BW-Venue-TZ"                   => "Boingo",
            "BWAS-Acb-Act-Fac-Result"       => "BroadSoft",
            "BWAS-Acb-Act-Invoke-Time"      => "BroadSoft",
            "BWAS-Acb-Deact-Fac-Result"     => "BroadSoft",
            "BWAS-Acb-Deact-Invoke-Time"    => "BroadSoft",
            "BWAS-Acc-Per-Call-Fac-Result"  => "BroadSoft",
            "BWAS-Acc-Per-Call-Invoke-Time" => "BroadSoft",
            "BWAS-Access-Callid"            => "BroadSoft",
            "BWAS-Access-Device-Address"    => "BroadSoft",
            "BWAS-Access-Network-Info"      => "BroadSoft",
            "BWAS-Account-Code"             => "BroadSoft",
            "BWAS-Acr-Act-Fac-Result"       => "BroadSoft",
            "BWAS-Acr-Act-Invoke-Time"      => "BroadSoft",
            "BWAS-Acr-Deact-Fac-Result"     => "BroadSoft",
            "BWAS-Acr-Deact-Invoke-Time"    => "BroadSoft",
            "BWAS-AHR-Action"               => "BroadSoft",
            "BWAS-AHR-Invoke-Time"          => "BroadSoft",
            "BWAS-Answer-Indic"             => "BroadSoft",
            "BWAS-Answer-Time"              => "BroadSoft",
            "BWAS-AOC-Activation-Time"      => "BroadSoft",
            "BWAS-AOC-Charge"               => "BroadSoft",
            "BWAS-AOC-Currency"             => "BroadSoft",
            "BWAS-AOC-Result"               => "BroadSoft",
            "BWAS-AOC-Sum"                  => "BroadSoft",
            "BWAS-AOC-Time"                 => "BroadSoft",
            "BWAS-AOC-Type"                 => "BroadSoft",
            "BWAS-AS-Call-Type"             => "BroadSoft",
            "BWAS-Authorization-Code"       => "BroadSoft",
            "BWAS-BA-Related-Call-Id"       => "BroadSoft",
            "BWAS-Body-Content-Disposition" => "BroadSoft",
            "BWAS-Body-Content-Length"      => "BroadSoft",
            "BWAS-Body-Content-Type"        => "BroadSoft",
            "BWAS-Body-Originator"          => "BroadSoft",
            "BWAS-Call-Bridge-Result"       => "BroadSoft",
            "BWAS-Call-Category"            => "BroadSoft",
            "BWAS-Call-Center-Forced-Forwarding-Act-Result"      => "BroadSoft",
            "BWAS-Call-Center-Forced-Forwarding-Deact-Result"    => "BroadSoft",
            "BWAS-Call-Center-Night-Service-Act-Result"          => "BroadSoft",
            "BWAS-Call-Center-Night-Service-Deact-Result"        => "BroadSoft",
            "BWAS-Call-Center-Outgoing-Call-Fac-Result"          => "BroadSoft",
            "BWAS-Call-Center-Outgoing-Personal-Call-Fac-Result" => "BroadSoft",
            "BWAS-Call-Center-Outgoing-Phone-Number"             => "BroadSoft",
            "BWAS-Call-Park-Fac-Result"                          => "BroadSoft",
            "BWAS-Call-Park-Invoke-Time"                         => "BroadSoft",
            "BWAS-Call-Park-Retr-Fac-Result"                     => "BroadSoft",
            "BWAS-Call-Park-Retr-Invoke-Time"                    => "BroadSoft",
            "BWAS-Call-Parked-Invoke-Time"                       => "BroadSoft",
            "BWAS-Call-Pickup-Fac-Result"                        => "BroadSoft",
            "BWAS-Call-Pickup-Invoke-Time"                       => "BroadSoft",
            "BWAS-Call-Retrieve-Result"                          => "BroadSoft",
            "BWAS-Call-Waiting-Act-Fac-Result"                   => "BroadSoft",
            "BWAS-Call-Waiting-Act-Invoke-Time"                  => "BroadSoft",
            "BWAS-Call-Waiting-Deact-Fac-Result"                 => "BroadSoft",
            "BWAS-Call-Waiting-Deact-Invoke-Time"                => "BroadSoft",
            "BWAS-Called-Asserted-Identity"                      => "BroadSoft",
            "BWAS-Called-Asserted-Pres-Indicator"                => "BroadSoft",
            "BWAS-Called-Number"                                 => "BroadSoft",
            "BWAS-Called-Number-Context"                         => "BroadSoft",
            "BWAS-Calling-Number"                                => "BroadSoft",
            "BWAS-Calling-Number-Context"                        => "BroadSoft",
            "BWAS-Calling-Party-Category"                        => "BroadSoft",
            "BWAS-Calling-Presentation-Indic"                    => "BroadSoft",
            "BWAS-Cancel-Cwt-Per-Call-Fac-Result"                => "BroadSoft",
            "BWAS-Cancel-Cwt-Per-Call-Invoke-Time"               => "BroadSoft",
            "BWAS-Carrier-Identification-Code"                   => "BroadSoft",
            "BWAS-CBF-Auth-Code"                                 => "BroadSoft",
            "BWAS-Cfa-Act-Fac-Result"                            => "BroadSoft",
            "BWAS-Cfa-Act-Invoke-Time"                           => "BroadSoft",
            "BWAS-Cfa-Deact-Fac-Result"                          => "BroadSoft",
            "BWAS-Cfa-Deact-Invoke-Time"                         => "BroadSoft",
            "BWAS-Cfa-Inter-Fac-Result"                          => "BroadSoft",
            "BWAS-Cfa-Inter-Invoke-Time"                         => "BroadSoft",
            "BWAS-Cfb-Act-Fac-Result"                            => "BroadSoft",
            "BWAS-Cfb-Act-Invoke-Time"                           => "BroadSoft",
            "BWAS-Cfb-Deact-Fac-Result"                          => "BroadSoft",
            "BWAS-Cfb-Deact-Invoke-Time"                         => "BroadSoft",
            "BWAS-Cfb-Inter-Fac-Result"                          => "BroadSoft",
            "BWAS-Cfb-Inter-Invoke-Time"                         => "BroadSoft",
            "BWAS-Cfna-Act-Fac-Result"                           => "BroadSoft",
            "BWAS-Cfna-Act-Invoke-Time"                          => "BroadSoft",
            "BWAS-Cfna-Deact-Fac-Result"                         => "BroadSoft",
            "BWAS-Cfna-Deact-Invoke-Time"                        => "BroadSoft",
            "BWAS-Cfna-Inter-Fac-Result"                         => "BroadSoft",
            "BWAS-Cfna-Inter-Invoke-Time"                        => "BroadSoft",
            "BWAS-Cfnrc-Act-Fac-Result"                          => "BroadSoft",
            "BWAS-Cfnrc-Act-Invoke-Time"                         => "BroadSoft",
            "BWAS-Cfnrc-Deact-Fac-Result"                        => "BroadSoft",
            "BWAS-Cfnrc-Deact-Invoke-Time"                       => "BroadSoft",
            "BWAS-Charge-Indic"                                  => "BroadSoft",
            "BWAS-Charge-Number"                                 => "BroadSoft",
            "BWAS-Charging-Function-Addresses"                   => "BroadSoft",
            "BWAS-Charging-Vection-Creator"                      => "BroadSoft",
            "BWAS-Charging-Vection-Orig"                         => "BroadSoft",
            "BWAS-Charging-Vection-Term"                         => "BroadSoft",
            "BWAS-Charging-Vector-Key"                           => "BroadSoft",
            "BWAS-Clear-Mwi-Fac-Result"                          => "BroadSoft",
            "BWAS-Clear-Mwi-Invoke-Time"                         => "BroadSoft",
            "BWAS-Clid-Blocking-Act-Fac-Result"                  => "BroadSoft",
            "BWAS-Clid-Blocking-Act-Invoke-Time"                 => "BroadSoft",
            "BWAS-Clid-Blocking-Deact-Fac-Result"                => "BroadSoft",
            "BWAS-Clid-Blocking-Deact-Invoke-Time"               => "BroadSoft",
            "BWAS-Clid-Blocking-Per-Call-Fac-Result"             => "BroadSoft",
            "BWAS-Clid-Blocking-Per-Call-Invoke-Time"            => "BroadSoft",
            "BWAS-Clid-Delivery-Per-Call-Fac-Result"             => "BroadSoft",
            "BWAS-Clid-Delivery-Per-Call-Invoke-Time"            => "BroadSoft",
            "BWAS-CLID-Permitted"                                => "BroadSoft",
            "BWAS-Codec"                                         => "BroadSoft",
            "BWAS-Codec-Usage"                                   => "BroadSoft",
            "BWAS-Conf-Id"                                       => "BroadSoft",
            "BWAS-Conf-Start-Time"                               => "BroadSoft",
            "BWAS-Conf-Stop-Time"                                => "BroadSoft",
            "BWAS-Conf-Type"                                     => "BroadSoft",
            "BWAS-Conference-Bridge"                             => "BroadSoft",
            "BWAS-Conference-Callid"                             => "BroadSoft",
            "BWAS-Conference-From"                               => "BroadSoft",
            "BWAS-Conference-Id"                                 => "BroadSoft",
            "BWAS-Conference-Invoke-Time"                        => "BroadSoft",
            "BWAS-Conference-Owner"                              => "BroadSoft",
            "BWAS-Conference-Owner-Dn"                           => "BroadSoft",
            "BWAS-Conference-Project-Code"                       => "BroadSoft",
            "BWAS-Conference-Role"                               => "BroadSoft",
            "BWAS-Conference-Title"                              => "BroadSoft",
            "BWAS-Conference-To"                                 => "BroadSoft",
            "BWAS-Configurable-CLID"                             => "BroadSoft",
            "BWAS-Cot-Fac-Result"                                => "BroadSoft",
            "BWAS-Cot-Invoke-Time"                               => "BroadSoft",
            "BWAS-CustomRingback-Invoke-Time"                    => "BroadSoft",
            "BWAS-CustomRingback-Media-Selection"                => "BroadSoft",
            "BWAS-Department"                                    => "BroadSoft",
            "BWAS-Dialed-Digits"                                 => "BroadSoft",
            "BWAS-Dialed-Digits-Context"                         => "BroadSoft",
            "BWAS-Direct-Vm-Xfer-Fac-Result"                     => "BroadSoft",
            "BWAS-Direct-Vm-Xfer-Invoke-Time"                    => "BroadSoft",
            "BWAS-Directed-Call-Pickup-Fac-Result"               => "BroadSoft",
            "BWAS-Directed-Call-Pickup-Invoke-Time"              => "BroadSoft",
            "BWAS-Direction"                                     => "BroadSoft",
            "BWAS-Diversion-Inhibitor-Fac-Result"                => "BroadSoft",
            "BWAS-Diversion-Inhibitor-Invoke-time"               => "BroadSoft",
            "BWAS-Dnd-Act-Fac-Result"                            => "BroadSoft",
            "BWAS-Dnd-Act-Invoke-Time"                           => "BroadSoft",
            "BWAS-Dnd-Deact-Fac-Result"                          => "BroadSoft",
            "BWAS-Dnd-Deact-Invoke-Time"                         => "BroadSoft",
            "BWAS-Dpubi-Fac-Result"                              => "BroadSoft",
            "BWAS-Dpubi-Invoke-Time"                             => "BroadSoft",
            "BWAS-Early-Media-Initiator-Flag"                    => "BroadSoft",
            "BWAS-Early-Media-SDP"                               => "BroadSoft",
            "BWAS-Failover-Correlation-Id"                       => "BroadSoft",
            "BWAS-Fax-Messaging"                                 => "BroadSoft",
            "BWAS-Flash-Call-Hold-Fac-Result"                    => "BroadSoft",
            "BWAS-Flash-Call-Hold-Invoke-Time"                   => "BroadSoft",
            "BWAS-Group"                                         => "BroadSoft",
            "BWAS-Group-Number"                                  => "BroadSoft",
            "BWAS-Hoteling-Group"                                => "BroadSoft",
            "BWAS-Hoteling-Group-Number"                         => "BroadSoft",
            "BWAS-Hoteling-Invoke-Time"                          => "BroadSoft",
            "BWAS-Hoteling-User-Number"                          => "BroadSoft",
            "BWAS-Hoteling-UserId"                               => "BroadSoft",
            "BWAS-InstantGroupCall-Invoke-Time"                  => "BroadSoft",
            "BWAS-InstantGroupCall-PushToTalk"                   => "BroadSoft",
            "BWAS-InstantGroupCall-Related-Callid"               => "BroadSoft",
            "BWAS-Last-Number-Redial-Fac-Result"                 => "BroadSoft",
            "BWAS-Last-Number-Redial-Invoke-Time"                => "BroadSoft",
            "BWAS-Local-Callid"                                  => "BroadSoft",
            "BWAS-Location-Control-Act-Result"                   => "BroadSoft",
            "BWAS-Location-Control-Deact-Result"                 => "BroadSoft",
            "BWAS-Media-Initiator-Flag"                          => "BroadSoft",
            "BWAS-Moh-Deact-Fac-Result"                          => "BroadSoft",
            "BWAS-Network-Call-Type"                             => "BroadSoft",
            "BWAS-Network-Callid"                                => "BroadSoft",
            "BWAS-Network-Translated-Group"                      => "BroadSoft",
            "BWAS-Network-Translated-Number"                     => "BroadSoft",
            "BWAS-Network-Translated-Number-Context"             => "BroadSoft",
            "BWAS-Network-Type"                                  => "BroadSoft",
            "BWAS-No-Answer-Set-Fac-Result"                      => "BroadSoft",
            "BWAS-No-Answer-Set-Invoke-Time"                     => "BroadSoft",
            "BWAS-Original-Called-Number"                        => "BroadSoft",
            "BWAS-Original-Called-Number-Context"                => "BroadSoft",
            "BWAS-Original-Called-Presentation-Indic"            => "BroadSoft",
            "BWAS-Original-Called-Reason"                        => "BroadSoft",
            "BWAS-Origination-Method"                            => "BroadSoft",
            "BWAS-Other-Party-Name"                              => "BroadSoft",
            "BWAS-Other-Party-Name-Pres-Indic"                   => "BroadSoft",
            "BWAS-OtherInfoInPCV"                                => "BroadSoft",
            "BWAS-Outside-Access-Code"                           => "BroadSoft",
            "BWAS-Prepaid-Status"                                => "BroadSoft",
            "BWAS-Primary-Device-Line-Port"                      => "BroadSoft",
            "BWAS-Push-to-Talk-Fac-Result"                       => "BroadSoft",
            "BWAS-Push-to-Talk-Invoke-Time"                      => "BroadSoft",
            "BWAS-Q850-Cause"                                    => "BroadSoft",
            "BWAS-Recall-Type"                                   => "BroadSoft",
            "BWAS-Received-Calling-Number"                       => "BroadSoft",
            "BWAS-Record-id"                                     => "BroadSoft",
            "BWAS-Redirecting-Number"                            => "BroadSoft",
            "BWAS-Redirecting-Number-Context"                    => "BroadSoft",
            "BWAS-Redirecting-Presentation-Indic"                => "BroadSoft",
            "BWAS-Redirecting-Reason"                            => "BroadSoft",
            "BWAS-Related-CallId"                                => "BroadSoft",
            "BWAS-Related-CallId-Reason"                         => "BroadSoft",
            "BWAS-Release-Time"                                  => "BroadSoft",
            "BWAS-Releasing-Party"                               => "BroadSoft",
            "BWAS-Remote-Callid"                                 => "BroadSoft",
            "BWAS-Return-Call-Fac-Result"                        => "BroadSoft",
            "BWAS-Return-Call-Invoke-Time"                       => "BroadSoft",
            "BWAS-Return-Call-Number-Deletion-Fac-Result"        => "BroadSoft",
            "BWAS-Return-Call-Number-Deletion-Invoke-Time"       => "BroadSoft",
            "BWAS-Route"                                         => "BroadSoft",
            "BWAS-Routing-Number"                                => "BroadSoft",
            "BWAS-Sac-Lock-Fac-Result"                           => "BroadSoft",
            "BWAS-Sac-Lock-Invoke-Time"                          => "BroadSoft",
            "BWAS-Sac-Unlock-Fac-Result"                         => "BroadSoft",
            "BWAS-Sac-Unlock-Invoke-Time"                        => "BroadSoft",
            "BWAS-Scf-Act-Fac-Result"                            => "BroadSoft",
            "BWAS-Scf-Act-Invoke-Time"                           => "BroadSoft",
            "BWAS-Scf-Deact-Fac-Result"                          => "BroadSoft",
            "BWAS-Scf-Deact-Invoke-Time"                         => "BroadSoft",
            "BWAS-Sd100-Programming-Fac-Result"                  => "BroadSoft",
            "BWAS-Sd100-Programming-Invoke-Time"                 => "BroadSoft",
            "BWAS-Sd8-Programming-Fac-Result"                    => "BroadSoft",
            "BWAS-Sd8-Programming-Invoke-Time"                   => "BroadSoft",
            "BWAS-SDP"                                           => "BroadSoft",
            "BWAS-SDP-Answer-Timestamp"                          => "BroadSoft",
            "BWAS-SDP-Offer-Timestamp"                           => "BroadSoft",
            "BWAS-Service-provider"                              => "BroadSoft",
            "BWAS-SIP-Error-Code"                                => "BroadSoft",
            "BWAS-Spare-136"                                     => "BroadSoft",
            "BWAS-Spare-29"                                      => "BroadSoft",
            "BWAS-Spare-31"                                      => "BroadSoft",
            "BWAS-Start-Time"                                    => "BroadSoft",
            "BWAS-Termination-Cause"                             => "BroadSoft",
            "BWAS-Transfer-Invoke-Time"                          => "BroadSoft",
            "BWAS-Transfer-Related-CallId"                       => "BroadSoft",
            "BWAS-Transfer-Result"                               => "BroadSoft",
            "BWAS-Transfer-Type"                                 => "BroadSoft",
            "BWAS-Trunk-Group-Info"                              => "BroadSoft",
            "BWAS-Trunk-Group-Name"                              => "BroadSoft",
            "BWAS-TSD-Digits"                                    => "BroadSoft",
            "BWAS-Type"                                          => "BroadSoft",
            "BWAS-Type-Of-Network"                               => "BroadSoft",
            "BWAS-User-Number"                                   => "BroadSoft",
            "BWAS-User-Timezone"                                 => "BroadSoft",
            "BWAS-UserId"                                        => "BroadSoft",
            "BWAS-Vma-Act-Fac-Result"                            => "BroadSoft",
            "BWAS-Vma-Act-Invoke-Time"                           => "BroadSoft",
            "BWAS-Vma-Deact-Fac-Result"                          => "BroadSoft",
            "BWAS-Vma-Deact-Invoke-Time"                         => "BroadSoft",
            "BWAS-Vmb-Act-Fac-Result"                            => "BroadSoft",
            "BWAS-Vmb-Act-Invoke-Time"                           => "BroadSoft",
            "BWAS-Vmb-Deact-Fac-Result"                          => "BroadSoft",
            "BWAS-Vmb-Deact-Invoke-Time"                         => "BroadSoft",
            "BWAS-Vmna-Act-Fac-Result"                           => "BroadSoft",
            "BWAS-Vmna-Act-Invoke-Time"                          => "BroadSoft",
            "BWAS-Vmna-Deact-Fac-Result"                         => "BroadSoft",
            "BWAS-Vmna-Deact-Invoke-Time"                        => "BroadSoft",
            "BWAS-VP-Calling-Invoke-Time"                        => "BroadSoft",
            "CableLabs-Account-Code"                             => "CableLabs",
            "CableLabs-Alerting-Signal"                          => "CableLabs",
            "CableLabs-AM-Opaque-Data"                           => "CableLabs",
            "CableLabs-Application-Manager-ID"                   => "CableLabs",
            "CableLabs-Authorization-Code"                       => "CableLabs",
            "CableLabs-Call-Termination-Cause"                   => "CableLabs",
            "CableLabs-Called-Party-Number"                      => "CableLabs",
            "CableLabs-Calling-Party-Number"                     => "CableLabs",
            "CableLabs-Carrier-Identification-Code"              => "CableLabs",
            "CableLabs-CCC-ID"                                   => "CableLabs",
            "CableLabs-Channel-State"                            => "CableLabs",
            "CableLabs-Charge-Number"                            => "CableLabs",
            "CableLabs-Database-ID"                              => "CableLabs",
            "CableLabs-Dial-Around-Code"                         => "CableLabs",
            "CableLabs-Dialed-Digits"                            => "CableLabs",
            "CableLabs-Direction-indicator"                      => "CableLabs",
            "CableLabs-El-Surveillance-DF-Security"              => "CableLabs",
            "CableLabs-Electronic-Surveillance-Ind"              => "CableLabs",
            "CableLabs-Element-Requesting-QoS"                   => "CableLabs",
            "CableLabs-Error-Description"                        => "CableLabs",
            "CableLabs-Event-Message"                            => "CableLabs",
            "CableLabs-Financial-Entity-ID"                      => "CableLabs",
            "CableLabs-First-Call-Calling-Party-Num"             => "CableLabs",
            "CableLabs-Flow-Direction"                           => "CableLabs",
            "CableLabs-Forwarded-Number"                         => "CableLabs",
            "CableLabs-Gate-Time-Info"                           => "CableLabs",
            "CableLabs-Gate-Usage-Info"                          => "CableLabs",
            "CableLabs-Intl-Code"                                => "CableLabs",
            "CableLabs-Location-Routing-Number"                  => "CableLabs",
            "CableLabs-Misc-Signaling-Information"               => "CableLabs",
            "CableLabs-MTA-Endpoint-Name"                        => "CableLabs",
            "CableLabs-MTA-UDP-Portnum"                          => "CableLabs",
            "CableLabs-Policy-Decision-Status"                   => "CableLabs",
            "CableLabs-Policy-Deleted-Reason"                    => "CableLabs",
            "CableLabs-Policy-Denied-Reason"                     => "CableLabs",
            "CableLabs-Policy-Update-Reason"                     => "CableLabs",
            "CableLabs-QoS-Descriptor"                           => "CableLabs",
            "CableLabs-QoS-Release-Reason"                       => "CableLabs",
            "CableLabs-Query-Type"                               => "CableLabs",
            "CableLabs-Redirected-From-Info"                     => "CableLabs",
            "CableLabs-Redirected-From-Party-Number"             => "CableLabs",
            "CableLabs-Redirected-To-Party-Number"               => "CableLabs",
            "CableLabs-Related-Call-Billing-Crl-ID"              => "CableLabs",
            "CableLabs-Reserved"                                 => "CableLabs",
            "CableLabs-Returned-Number"                          => "CableLabs",
            "CableLabs-Routing-Number"                           => "CableLabs",
            "CableLabs-SDP-Downstream"                           => "CableLabs",
            "CableLabs-SDP-Upstream"                             => "CableLabs",
            "CableLabs-Second-Call-Calling-Party-Num"            => "CableLabs",
            "CableLabs-Service-Name"                             => "CableLabs",
            "CableLabs-SF-ID"                                    => "CableLabs",
            "CableLabs-Signal-Type"                              => "CableLabs",
            "CableLabs-Subject-Audible-Signal"                   => "CableLabs",
            "CableLabs-Subscriber-ID"                            => "CableLabs",
            "CableLabs-Switch-Hook-Flash"                        => "CableLabs",
            "CableLabs-Terminal-Display-Info"                    => "CableLabs",
            "CableLabs-Time-Adjustment"                          => "CableLabs",
            "CableLabs-Time-Usage-Limit"                         => "CableLabs",
            "CableLabs-Translation-Input"                        => "CableLabs",
            "CableLabs-Trunk-Group-ID"                           => "CableLabs",
            "CableLabs-User-Input"                               => "CableLabs",
            "CableLabs-Volume-Usage-Limit"                       => "CableLabs",
            "Cabletron-Protocol-Callable"                        => "Cabletron",
            "Cabletron-Protocol-Enable"                          => "Cabletron",
            "Cajun-Service-Type"                             => "Cajun_p330",
            "Calix-CMS-Alarm-Filter"                         => "Calix",
            "Calix-CMS-Event-Filter"                         => "Calix",
            "Calix-CMS-Threshold-Event-Filter"               => "Calix",
            "Calix-CMS-User-Group"                           => "Calix",
            "Calix-Role"                                     => "Calix",
            "call-id"                                        => "Cisco",
            "Cambium-Acct-Class-Name"                        => "Cambium",
            "Cambium-Acct-Input-Octets"                      => "Cambium",
            "Cambium-Acct-Input-Packets"                     => "Cambium",
            "Cambium-Acct-Output-Octets"                     => "Cambium",
            "Cambium-Acct-Output-Packets"                    => "Cambium",
            "Cambium-Auth-Role"                              => "Cambium",
            "Cambium-Authorize-Bytes-Left"                   => "Cambium",
            "Cambium-Authorize-Class-Name"                   => "Cambium",
            "Cambium-Authorize-Classes"                      => "Cambium",
            "Cambium-ePMP-Data-VLAN-Id"                      => "Cambium",
            "Cambium-ePMP-Data-VLAN-Priority"                => "Cambium",
            "Cambium-ePMP-Management-VLAN-Id"                => "Cambium",
            "Cambium-ePMP-Management-VLAN-Priority"          => "Cambium",
            "Cambium-ePMP-Max-Burst-Downlink-Rate"           => "Cambium",
            "Cambium-ePMP-Max-Burst-Uplink-Rate"             => "Cambium",
            "Cambium-ePMP-Multicast-VLAN-Id"                 => "Cambium",
            "Cambium-ePMP-Separate-Management-VLAN-Id"       => "Cambium",
            "Cambium-ePMP-Separate-Management-VLAN-Priority" => "Cambium",
            "Cambium-ePMP-SM-Priority"                       => "Cambium",
            "Cambium-ePMP-UserLevel"                         => "Cambium",
            "Cambium-ePMP-VLAN-Mapping"                      => "Cambium",
            "Cambium-ePMP-VLAN-Membersip-Set"                => "Cambium",
            "Cambium-Traffic-Classes-Acct"                   => "Cambium",
            "Cambium-Traffic-Quota-Limit-Down"               => "Cambium",
            "Cambium-Traffic-Quota-Limit-Down-Gigwords"      => "Cambium",
            "Cambium-Traffic-Quota-Limit-Total"              => "Cambium",
            "Cambium-Traffic-Quota-Limit-Total-Gigwords"     => "Cambium",
            "Cambium-Traffic-Quota-Limit-Up"                 => "Cambium",
            "Cambium-Traffic-Quota-Limit-Up-Gigwords"        => "Cambium",
            "Cambium-VLAN-Pool-Id"                           => "Cambium",
            "Cambium-Walled-Garden-State"                    => "Cambium",
            "Camiant-MI-role"                                => "Camiant",
            "Camiant-MI-scope"                               => "Camiant",
            "Camiant-SUI-role"                               => "Camiant",
            "CBBSM-Bandwidth"                                => "Cisco-BBSM",
            "Centec-Exec-Privilege"                          => "Centec",
            "CES-Group"                                      => "Bay-Networks",
            "Charging-Group-ID"                     => "VerizonWireless",
            "ChilliSpot-Bandwidth-Max-Down"         => "ChilliSpot",
            "ChilliSpot-Bandwidth-Max-Up"           => "ChilliSpot",
            "ChilliSpot-Config"                     => "ChilliSpot",
            "ChilliSpot-Interval"                   => "ChilliSpot",
            "ChilliSpot-Lang"                       => "ChilliSpot",
            "ChilliSpot-MAC-Allowed"                => "ChilliSpot",
            "ChilliSpot-Max-Input-Octets"           => "ChilliSpot",
            "ChilliSpot-Max-Output-Octets"          => "ChilliSpot",
            "ChilliSpot-Max-Total-Octets"           => "ChilliSpot",
            "ChilliSpot-OriginalURL"                => "ChilliSpot",
            "ChilliSpot-UAM-Allowed"                => "ChilliSpot",
            "ChilliSpot-Version"                    => "ChilliSpot",
            "Ciena-BP-Role"                         => "Ciena",
            "Ciena-CES-NACM-Groups"                 => "Ciena",
            "Ciena-CES-Priv-Level"                  => "Ciena",
            "Ciena-CN4200-Priv-Level"               => "Ciena",
            "Ciena-CS-Acc-Level"                    => "Ciena",
            "Ciena-CS-Client-IP"                    => "Ciena",
            "Ciena-CS-Priv-Level"                   => "Ciena",
            "Ciena-NCS-Role"                        => "Ciena",
            "Ciena-OC-Role"                         => "Ciena",
            "Circuit-Group-Member"                  => "Ericsson-AB",
            "Circuit-Protocol-Encap"                => "Ericsson-AB",
            "Cisco-Abort-Cause"                     => "Cisco",
            "Cisco-Account-Info"                    => "Cisco",
            "Cisco-Assign-IP-Pool"                  => "Cisco",
            "Cisco-AVPair"                          => "Cisco",
            "Cisco-Call-Filter"                     => "Cisco",
            "Cisco-Call-Type"                       => "Cisco",
            "Cisco-Command-Code"                    => "Cisco",
            "Cisco-Control-Info"                    => "Cisco",
            "Cisco-Data-Filter"                     => "Cisco",
            "Cisco-Data-Rate"                       => "Cisco",
            "Cisco-DHCP-Relay-GiAddr"               => "Cisco",
            "Cisco-DHCP-Subscriber-Id"              => "Cisco",
            "Cisco-DHCP-User-Class"                 => "Cisco",
            "Cisco-DHCP-Vendor-Class"               => "Cisco",
            "Cisco-DHCPv6-Link-Address"             => "Cisco",
            "Cisco-Disconnect-Cause"                => "Cisco",
            "Cisco-Email-Server-Ack-Flag"           => "Cisco",
            "Cisco-Email-Server-Address"            => "Cisco",
            "Cisco-Fax-Account-Id-Origin"           => "Cisco",
            "Cisco-Fax-Auth-Status"                 => "Cisco",
            "Cisco-Fax-Connect-Speed"               => "Cisco",
            "Cisco-Fax-Coverpage-Flag"              => "Cisco",
            "Cisco-Fax-Dsn-Address"                 => "Cisco",
            "Cisco-Fax-Dsn-Flag"                    => "Cisco",
            "Cisco-Fax-Mdn-Address"                 => "Cisco",
            "Cisco-Fax-Mdn-Flag"                    => "Cisco",
            "Cisco-Fax-Modem-Time"                  => "Cisco",
            "Cisco-Fax-Msg-Id"                      => "Cisco",
            "Cisco-Fax-Pages"                       => "Cisco",
            "Cisco-Fax-Process-Abort-Flag"          => "Cisco",
            "Cisco-Fax-Recipient-Count"             => "Cisco",
            "Cisco-Gateway-Id"                      => "Cisco",
            "Cisco-Idle-Limit"                      => "Cisco",
            "Cisco-In-ACL"                          => "Cisco",
            "Cisco-IP-Direct"                       => "Cisco",
            "Cisco-IP-Pool-Definition"              => "Cisco",
            "Cisco-IPv6-In-ACL"                     => "Cisco",
            "Cisco-IPv6-Out-ACL"                    => "Cisco",
            "Cisco-Link-Compression"                => "Cisco",
            "Cisco-Maximum-Channels"                => "Cisco",
            "Cisco-Maximum-Time"                    => "Cisco",
            "Cisco-Multilink-ID"                    => "Cisco",
            "Cisco-NAS-Port"                        => "Cisco",
            "Cisco-Num-In-Multilink"                => "Cisco",
            "Cisco-Out-ACL"                         => "Cisco",
            "Cisco-Parent-Session-Id"               => "Cisco",
            "Cisco-Policy-Down"                     => "Cisco",
            "Cisco-Policy-Up"                       => "Cisco",
            "Cisco-Port-Used"                       => "Cisco",
            "Cisco-PPP-Async-Map"                   => "Cisco",
            "Cisco-PPP-VJ-Slot-Comp"                => "Cisco",
            "Cisco-Pre-Input-Octets"                => "Cisco",
            "Cisco-Pre-Input-Packets"               => "Cisco",
            "Cisco-Pre-Output-Octets"               => "Cisco",
            "Cisco-Pre-Output-Packets"              => "Cisco",
            "Cisco-PreSession-Time"                 => "Cisco",
            "Cisco-PW-Lifetime"                     => "Cisco",
            "Cisco-Relay-Information-Option"        => "Cisco",
            "Cisco-Route-IP"                        => "Cisco",
            "Cisco-Service-Info"                    => "Cisco",
            "Cisco-Service-Name"                    => "Cisco",
            "Cisco-Sub-Activate-Service"            => "Cisco",
            "Cisco-Sub-Deactivate-Service"          => "Cisco",
            "Cisco-Sub-PBR-Policy-In"               => "Cisco",
            "Cisco-Sub-QoS-Pol-In"                  => "Cisco",
            "Cisco-Sub-QoS-Pol-Out"                 => "Cisco",
            "Cisco-Subscriber-Password"             => "Cisco",
            "Cisco-Target-Util"                     => "Cisco",
            "Cisco-Xmit-Rate"                       => "Cisco",
            "Citrix-GID"                            => "Citrix",
            "Citrix-Group-Ids"                      => "Citrix",
            "Citrix-Group-Names"                    => "Citrix",
            "Citrix-Home"                           => "Citrix",
            "Citrix-Shell"                          => "Citrix",
            "Citrix-UID"                            => "Citrix",
            "Citrix-User-Groups"                    => "Citrix",
            "CKey-Auth-Info"                        => "Ckey",
            "CL-APDB-Version"                       => "Boingo",
            "CL-Brand"                              => "Boingo",
            "CL-Method-Version"                     => "Boingo",
            "CL-Reg-Number"                         => "Boingo",
            "CL-Software-Version"                   => "Boingo",
            "CL-SSC"                                => "Boingo",
            "CL-Token-Version"                      => "Boingo",
            "CL-User-Agent"                         => "Boingo",
            "Class-Volume-In-Counter"               => "Ericsson-AB",
            "Class-Volume-limit"                    => "Ericsson-AB",
            "Class-Volume-Out-Counter"              => "Ericsson-AB",
            "Clavister-User-Group"                  => "Clavister",
            "Client-DNS-Pri"                        => "Ericsson-AB",
            "Client-DNS-Sec"                        => "Ericsson-AB",
            "Client-NBNS-Pri"                       => "Ericsson-AB",
            "Client-NBNS-Sec"                       => "Ericsson-AB",
            "Cluster-Partition-ID"                  => "Ericsson-AB",
            "Colubris-AVPair"                       => "Colubris",
            "Colubris-Intercept"                    => "Colubris",
            "Commands"                              => "Bay-Networks",
            "Compatible-Echo"                       => "Compatible",
            "Compatible-Tunnel-Delay"               => "Compatible",
            "Compatible-Tunnel-Group-Info"          => "Compatible",
            "Compatible-Tunnel-IPX"                 => "Compatible",
            "Compatible-Tunnel-Password"            => "Compatible",
            "Compatible-Tunnel-Server-Endpoint"     => "Compatible",
            "Compatible-Tunnel-Throughput"          => "Compatible",
            "Context-Name"                          => "Ericsson-AB",
            "Cosine-Address-Pool-Name"              => "Cosine",
            "Cosine-CLI-User-Permission-ID"         => "Cosine",
            "Cosine-Connection-Profile-Name"        => "Cosine",
            "Cosine-DLCI"                           => "Cosine",
            "Cosine-DS-Byte"                        => "Cosine",
            "Cosine-Enterprise-ID"                  => "Cosine",
            "Cosine-LNS-IP-Address"                 => "Cosine",
            "Cosine-VPI-VCI"                        => "Cosine",
            "Covaro-Inhibit-Dbchg"                  => "Covaro",
            "Covaro-Inhibit-Message"                => "Covaro",
            "Covaro-Inhibit-Pmrept"                 => "Covaro",
            "Covaro-Max-Sessions"                   => "Covaro",
            "Covaro-Session-Timeout"                => "Covaro",
            "Covaro-User-Privilege"                 => "Covaro",
            "CP-Gaia-SuperUser-Access"              => "CheckPoint",
            "CP-Gaia-User-Role"                     => "CheckPoint",
            "CVPN5000-Client-Assigned-IP"           => "Cisco-VPN5000",
            "CVPN5000-Client-Assigned-IPX"          => "Cisco-VPN5000",
            "CVPN5000-Client-Real-IP"               => "Cisco-VPN5000",
            "CVPN5000-Echo"                         => "Cisco-VPN5000",
            "CVPN5000-Tunnel-Throughput"            => "Cisco-VPN5000",
            "CVPN5000-VPN-GroupInfo"                => "Cisco-VPN5000",
            "CVPN5000-VPN-Password"                 => "Cisco-VPN5000",
            "CVX-Assign-IP-Pool"                    => "Aptis",
            "CVX-Client-Assign-DNS"                 => "Aptis",
            "CVX-Data-Filter"                       => "Aptis",
            "CVX-Data-Rate"                         => "Aptis",
            "CVX-Disconnect-Cause"                  => "Aptis",
            "CVX-Identification"                    => "Aptis",
            "CVX-Idle-Limit"                        => "Aptis",
            "CVX-IPSVC-AZNLVL"                      => "Aptis",
            "CVX-IPSVC-Mask"                        => "Aptis",
            "CVX-Maximum-Channels"                  => "Aptis",
            "CVX-Modem-Begin-Modulation"            => "Aptis",
            "CVX-Modem-Begin-Recv-Line-Lvl"         => "Aptis",
            "CVX-Modem-Data-Compression"            => "Aptis",
            "CVX-Modem-End-Modulation"              => "Aptis",
            "CVX-Modem-End-Recv-Line-Lvl"           => "Aptis",
            "CVX-Modem-Error-Correction"            => "Aptis",
            "CVX-Modem-Local-Rate-Negs"             => "Aptis",
            "CVX-Modem-Local-Retrains"              => "Aptis",
            "CVX-Modem-Remote-Rate-Negs"            => "Aptis",
            "CVX-Modem-Remote-Retrains"             => "Aptis",
            "CVX-Modem-ReTx-Packets"                => "Aptis",
            "CVX-Modem-SNR"                         => "Aptis",
            "CVX-Modem-Tx-Packets"                  => "Aptis",
            "CVX-Multicast-Client"                  => "Aptis",
            "CVX-Multicast-Rate-Limit"              => "Aptis",
            "CVX-Multilink-Group-Number"            => "Aptis",
            "CVX-Multilink-Match-Info"              => "Aptis",
            "CVX-PPP-Address"                       => "Aptis",
            "CVX-PPP-Log-Mask"                      => "Aptis",
            "CVX-PreSession-Time"                   => "Aptis",
            "CVX-Primary-DNS"                       => "Aptis",
            "CVX-Radius-Redirect"                   => "Aptis",
            "CVX-Reject-Reason"                     => "Aptis",
            "CVX-Secondary-DNS"                     => "Aptis",
            "CVX-SS7-Session-ID-Type"               => "Aptis",
            "CVX-Terminate-Cause"                   => "Aptis",
            "CVX-Terminate-Component"               => "Aptis",
            "CVX-VPOP-ID"                           => "Aptis",
            "CVX-Xmit-Rate"                         => "Aptis",
            "CW-Account-Id"                         => "USR",
            "CW-Acct-Balance-Decr-Curr"             => "USR",
            "CW-Acct-Balance-Start-Amt"             => "USR",
            "CW-Acct-Balance-Start-Curr"            => "USR",
            "CW-Acct-Balance-Start-Dec"             => "USR",
            "CW-Acct-Identification-Code"           => "USR",
            "CW-Acct-Type"                          => "USR",
            "CW-ARQ-Token"                          => "USR",
            "CW-Audio-Bytes-In-Frame"               => "USR",
            "CW-Audio-Packets-In-Frame"             => "USR",
            "CW-Audio-Packets-Lost"                 => "USR",
            "CW-Audio-Packets-Received"             => "USR",
            "CW-Audio-Packets-Sent"                 => "USR",
            "CW-Audio-Signal-In-Packet"             => "USR",
            "CW-Authentication-Fail-Cnt"            => "USR",
            "CW-Call-Durn-Connect-Disc"             => "USR",
            "CW-Call-End-Time-Msec"                 => "USR",
            "CW-Call-End-Time-Sec"                  => "USR",
            "CW-Call-Identifier"                    => "USR",
            "CW-Call-Model"                         => "USR",
            "CW-Call-Plan-Id"                       => "USR",
            "CW-Call-Start-Ingr-GW-Msec"            => "USR",
            "CW-Call-Start-Ingr-GW-Sec"             => "USR",
            "CW-Call-Start-Time-Ans-Msec"           => "USR",
            "CW-Call-Start-Time-Ans-Sec"            => "USR",
            "CW-Call-Termination-Cause"             => "USR",
            "CW-Call-Type"                          => "USR",
            "CW-Cld-Party-E164-Number"              => "USR",
            "CW-Cld-Party-E164-Type"                => "USR",
            "CW-Cld-Party-Trans-DNS"                => "USR",
            "CW-Cld-Party-Trans-IP"                 => "USR",
            "CW-Cld-Party-Trans-Port"               => "USR",
            "CW-Cld-Party-Trans-Protocol"           => "USR",
            "CW-Clg-Party-E164-Number"              => "USR",
            "CW-Clg-Party-E164-Type"                => "USR",
            "CW-Clg-Party-Trans-DNS"                => "USR",
            "CW-Clg-Party-Trans-IP"                 => "USR",
            "CW-Clg-Party-Trans-Port"               => "USR",
            "CW-Clg-Party-Trans-Protocol"           => "USR",
            "CW-Codec-Type"                         => "USR",
            "CW-Egr-Gtkpr-Trans-DNS"                => "USR",
            "CW-Egr-Gtkpr-Trans-IP"                 => "USR",
            "CW-Egr-Gtkpr-Trans-Port"               => "USR",
            "CW-Egr-Gtkpr-Trans-Protocol"           => "USR",
            "CW-Egr-Gway-Trans-DNS"                 => "USR",
            "CW-Egr-Gway-Trans-IP"                  => "USR",
            "CW-Egr-Gway-Trans-Port"                => "USR",
            "CW-Egr-Gway-Trans-Protocol"            => "USR",
            "CW-Ingr-Gtkpr-Trans-DNS"               => "USR",
            "CW-Ingr-Gtkpr-Trans-IP"                => "USR",
            "CW-Ingr-Gtkpr-Trans-Port"              => "USR",
            "CW-Ingr-Gtkpr-Trans-Protocol"          => "USR",
            "CW-Ingr-Gway-E164-Number"              => "USR",
            "CW-Ingr-Gway-E164-Type"                => "USR",
            "CW-Ingr-Gway-Trans-DNS"                => "USR",
            "CW-Ingr-Gway-Trans-IP"                 => "USR",
            "CW-Ingr-Gway-Trans-Port"               => "USR",
            "CW-Ingr-Gway-Trans-Protocol"           => "USR",
            "CW-Local-MG-RTP-DNS"                   => "USR",
            "CW-Local-MG-RTP-IP"                    => "USR",
            "CW-Local-MG-RTP-Port"                  => "USR",
            "CW-Local-MG-RTP-Protocol"              => "USR",
            "CW-Local-Sig-Trans-DNS"                => "USR",
            "CW-Local-Sig-Trans-IP"                 => "USR",
            "CW-Local-Sig-Trans-Port"               => "USR",
            "CW-Local-Sig-Trans-Protocol"           => "USR",
            "CW-LRQ-Token"                          => "USR",
            "CW-MG-Id"                              => "USR",
            "CW-MGC-Id"                             => "USR",
            "CW-Num-Call-Attempt-Session"           => "USR",
            "CW-Orig-Line-Identifier"               => "USR",
            "CW-OSP-Source-Device"                  => "USR",
            "CW-Port-Id-For-Call"                   => "USR",
            "CW-Protocol-Transport"                 => "USR",
            "CW-PSTN-Interface-Number"              => "USR",
            "CW-Rate-Plan-Id"                       => "USR",
            "CW-Remote-MG-RTP-DNS"                  => "USR",
            "CW-Remote-MG-RTP-IP"                   => "USR",
            "CW-Remote-MG-RTP-Port"                 => "USR",
            "CW-Remote-MG-RTP-Protocol"             => "USR",
            "CW-Remote-Sig-Trans-DNS"               => "USR",
            "CW-Remote-Sig-Trans-IP"                => "USR",
            "CW-Remote-Sig-Trans-Port"              => "USR",
            "CW-Remote-Sig-Trans-Protocol"          => "USR",
            "CW-Service-Type"                       => "USR",
            "CW-Session-Id"                         => "USR",
            "CW-Session-Sequence-End"               => "USR",
            "CW-Session-Sequence-Num"               => "USR",
            "CW-Signaling-Protocol"                 => "USR",
            "CW-Slot-Id-For-Call"                   => "USR",
            "CW-Source-Identifier"                  => "USR",
            "CW-SS7-CIC"                            => "USR",
            "CW-SS7-Destn-Ptcode-Address"           => "USR",
            "CW-SS7-Destn-Ptcode-Type"              => "USR",
            "CW-SS7-Orig-Ptcode-Address"            => "USR",
            "CW-SS7-Orig-Ptcode-Type"               => "USR",
            "CW-Token-Status"                       => "USR",
            "CW-Trans-Cld-Party-E164-Num"           => "USR",
            "CW-Trans-Cld-Party-E164-Type"          => "USR",
            "CW-Version-Id"                         => "USR",
            "Deactivate-Service-Name"               => "Ericsson-AB",
            "Default-TTL"                           => "DANTE",
            "Delegated-Max-Prefix"                  => "Ericsson-AB",
            "DellEMC-AVpair"                        => "DellEMC",
            "DellEMC-Group-Name"                    => "DellEMC",
            "DHCP-Field"                            => "Ericsson-AB",
            "DHCP-Max-Leases"                       => "Ericsson-AB",
            "DHCP-Option"                           => "Ericsson-AB",
            "DHCP-Vendor-Class-ID"                  => "Ericsson-AB",
            "DHCP-Vendor-Encap-Option"              => "Ericsson-AB",
            "Dlink-1p-Priority"                     => "Dlink",
            "Dlink-ACL-Profile"                     => "Dlink",
            "Dlink-ACL-Rule"                        => "Dlink",
            "Dlink-ACL-Script"                      => "Dlink",
            "Dlink-Egress-Bandwidth-Assignment"     => "Dlink",
            "Dlink-Ingress-Bandwidth-Assignment"    => "Dlink",
            "Dlink-User-Level"                      => "Dlink",
            "Dlink-VLAN-ID"                         => "Dlink",
            "Dlink-VLAN-Name"                       => "Dlink",
            "Double-Authentication"                 => "Ericsson-AB",
            "DragonWave-Privilege-Level"            => "DragonWave",
            "DSL-Actual-Inter-Delay-Down"           => "Ericsson-AB",
            "DSL-Actual-Inter-Delay-Up"             => "Ericsson-AB",
            "DSL-Actual-Rate-Down"                  => "Ericsson-AB",
            "DSL-Actual-Rate-Down-Factor"           => "Ericsson-AB",
            "DSL-Actual-Rate-Up"                    => "Ericsson-AB",
            "DSL-Attainable-Rate-Down"              => "Ericsson-AB",
            "DSL-Attainable-Rate-Up"                => "Ericsson-AB",
            "DSL-Combined-Line-Info"                => "Ericsson-AB",
            "DSL-L2-Encapsulation"                  => "Ericsson-AB",
            "DSL-Line-State"                        => "Ericsson-AB",
            "DSL-Max-Inter-Delay-Down"              => "Ericsson-AB",
            "DSL-Max-Inter-Delay-Up"                => "Ericsson-AB",
            "DSL-Max-Rate-Down"                     => "Ericsson-AB",
            "DSL-Max-Rate-Up"                       => "Ericsson-AB",
            "DSL-Min-Low-Power-Rate-Down"           => "Ericsson-AB",
            "DSL-Min-Low-Power-Rate-Up"             => "Ericsson-AB",
            "DSL-Min-Rate-Down"                     => "Ericsson-AB",
            "DSL-Min-Rate-Up"                       => "Ericsson-AB",
            "DSL-PPPOA-PPPOE-Inter-Work-Flag"       => "Ericsson-AB",
            "DSL-Transmission-System"               => "Ericsson-AB",
            "dsp-id"                                => "Cisco",
            "Dynamic-Address-Flag"                  => "VerizonWireless",
            "Dynamic-Policy-Filter"                 => "Ericsson-AB",
            "Dynamic-QoS-Param"                     => "Ericsson-AB",
            "EAP-Channel-Binding-Message"           => "UKERNA",
            "Eduroam-Monitoring-Inflate"            => "TERENA",
            "Eduroam-SP-Country"                    => "TERENA",
            "EfficientIP-Admin-Group"               => "EfficientIP",
            "EfficientIP-Email"                     => "EfficientIP",
            "EfficientIP-Extra-Blob"                => "EfficientIP",
            "EfficientIP-First-Login-Path"          => "EfficientIP",
            "EfficientIP-First-Name"                => "EfficientIP",
            "EfficientIP-Groups"                    => "EfficientIP",
            "EfficientIP-Identity-Type"             => "EfficientIP",
            "EfficientIP-IP-Host"                   => "EfficientIP",
            "EfficientIP-Last-Name"                 => "EfficientIP",
            "EfficientIP-Maintainer-Group"          => "EfficientIP",
            "EfficientIP-Pseudonym"                 => "EfficientIP",
            "EfficientIP-Service-Class"             => "EfficientIP",
            "EfficientIP-Version"                   => "EfficientIP",
            "Eleven-Authentication-Find-Key"        => "Eleven",
            "Eleven-EAPOL-Anonce"                   => "Eleven",
            "Eleven-EAPOL-APMAC"                    => "Eleven",
            "Eleven-EAPOL-Frame-2"                  => "Eleven",
            "Eleven-EAPOL-SSID"                     => "Eleven",
            "Eleven-EAPOL-STMAC"                    => "Eleven",
            "Eltex-AVPair"                          => "Eltex",
            "Eltex-Disconnect-Code-Local"           => "Eltex",
            "Epygi-AccessType"                      => "Epygi",
            "Epygi-AVPair"                          => "Epygi",
            "Epygi-CallDisconnectReason"            => "Epygi",
            "Epygi-CalledPartyNumber"               => "Epygi",
            "Epygi-CallInfo"                        => "Epygi",
            "Epygi-CallingPartyNumber"              => "Epygi",
            "Epygi-CallRedirectReason"              => "Epygi",
            "Epygi-CallType"                        => "Epygi",
            "Epygi-DateTimeConnect"                 => "Epygi",
            "Epygi-DateTimeDisconnect"              => "Epygi",
            "Epygi-DateTimeOrigination"             => "Epygi",
            "Epygi-DestIpAddr"                      => "Epygi",
            "Epygi-DestIpPort"                      => "Epygi",
            "Epygi-DeviceName"                      => "Epygi",
            "Epygi-Duration"                        => "Epygi",
            "Epygi-FiadID"                          => "Epygi",
            "Epygi-h323-billing-model"              => "Epygi",
            "Epygi-h323-call-origin"                => "Epygi",
            "Epygi-h323-call-type"                  => "Epygi",
            "Epygi-h323-conf-id"                    => "Epygi",
            "Epygi-h323-connect-time"               => "Epygi",
            "Epygi-h323-credit-amount"              => "Epygi",
            "Epygi-h323-credit-time"                => "Epygi",
            "Epygi-h323-currency"                   => "Epygi",
            "Epygi-h323-disconnect-cause"           => "Epygi",
            "Epygi-h323-disconnect-time"            => "Epygi",
            "Epygi-h323-gw-id"                      => "Epygi",
            "Epygi-h323-incoming-conf-id"           => "Epygi",
            "Epygi-h323-preferred-lang"             => "Epygi",
            "Epygi-h323-prompt-id"                  => "Epygi",
            "Epygi-h323-redirect-ip-address"        => "Epygi",
            "Epygi-h323-redirect-number"            => "Epygi",
            "Epygi-h323-remote-address"             => "Epygi",
            "Epygi-h323-return-code"                => "Epygi",
            "Epygi-h323-setup-time"                 => "Epygi",
            "Epygi-h323-time-and-day"               => "Epygi",
            "Epygi-h323-voice-quality"              => "Epygi",
            "Epygi-InDestRTP_IP"                    => "Epygi",
            "Epygi-InDestRTP_port"                  => "Epygi",
            "Epygi-InRTP_Jitter"                    => "Epygi",
            "Epygi-InRTP_Latency"                   => "Epygi",
            "Epygi-InRTP_Octets"                    => "Epygi",
            "Epygi-InRTP_Packets"                   => "Epygi",
            "Epygi-InRTP_PacketsDupl"               => "Epygi",
            "Epygi-InRTP_PacketSize"                => "Epygi",
            "Epygi-InRTP_PacketsLost"               => "Epygi",
            "Epygi-InRTP_Payload"                   => "Epygi",
            "Epygi-InSourceRTP_IP"                  => "Epygi",
            "Epygi-InSourceRTP_port"                => "Epygi",
            "Epygi-InterfaceName"                   => "Epygi",
            "Epygi-InterfaceNumber"                 => "Epygi",
            "Epygi-NAS-Port"                        => "Epygi",
            "Epygi-OrigCallID"                      => "Epygi",
            "Epygi-OrigIpAddr"                      => "Epygi",
            "Epygi-OrigIpPort"                      => "Epygi",
            "Epygi-OutDestRTP_IP"                   => "Epygi",
            "Epygi-OutDestRTP_port"                 => "Epygi",
            "Epygi-OutRTP_Octets"                   => "Epygi",
            "Epygi-OutRTP_Packets"                  => "Epygi",
            "Epygi-OutRTP_PacketSize"               => "Epygi",
            "Epygi-OutRTP_Payload"                  => "Epygi",
            "Epygi-OutSourceRTP_IP"                 => "Epygi",
            "Epygi-OutSourceRTP_port"               => "Epygi",
            "Epygi-ParentCallID"                    => "Epygi",
            "Epygi-PortID"                          => "Epygi",
            "Epygi-RegExpDate"                      => "Epygi",
            "Epygi-TimeslotNumber"                  => "Epygi",
            "Equallogic-Admin-Account-Type"         => "Equallogic",
            "Equallogic-Admin-Email"                => "Equallogic",
            "Equallogic-Admin-Full-Name"            => "Equallogic",
            "Equallogic-Admin-Mobile"               => "Equallogic",
            "Equallogic-Admin-Phone"                => "Equallogic",
            "Equallogic-Admin-Pool-Access"          => "Equallogic",
            "Equallogic-Admin-Repl-Site-Access"     => "Equallogic",
            "Equallogic-EQL-Admin-Privilege"        => "Equallogic",
            "Equallogic-Poll-Interval"              => "Equallogic",
            "Ericsson-ViG-Access-Agent-IP-Address"  => "Ericsson",
            "Ericsson-ViG-Access-Agent-name"        => "Ericsson",
            "Ericsson-ViG-Access-Group-name"        => "Ericsson",
            "Ericsson-ViG-Access-type"              => "Ericsson",
            "Ericsson-ViG-Account-error-reason"     => "Ericsson",
            "Ericsson-ViG-Alive-Indicator"          => "Ericsson",
            "Ericsson-ViG-Allowed-bandwidth"        => "Ericsson",
            "Ericsson-ViG-Auth-DataRequest"         => "Ericsson",
            "Ericsson-ViG-Authentication-type"      => "Ericsson",
            "Ericsson-ViG-Balance"                  => "Ericsson",
            "Ericsson-ViG-Business-Agreement-Name"  => "Ericsson",
            "Ericsson-ViG-Call-Role"                => "Ericsson",
            "Ericsson-ViG-Called-ID"                => "Ericsson",
            "Ericsson-ViG-Called-Usr-Group-ID"      => "Ericsson",
            "Ericsson-ViG-Called-Usr-Sub-Group-ID"  => "Ericsson",
            "Ericsson-ViG-Calling-e164-number"      => "Ericsson",
            "Ericsson-ViG-Calling-Email-address"    => "Ericsson",
            "Ericsson-ViG-Calling-H323Id"           => "Ericsson",
            "Ericsson-ViG-Calling-ID"               => "Ericsson",
            "Ericsson-ViG-Calling-User-Group-ID"    => "Ericsson",
            "Ericsson-ViG-Calling-Usr-Sub-Group-ID" => "Ericsson",
            "Ericsson-ViG-Charging-Case"            => "Ericsson",
            "Ericsson-ViG-Codec"                    => "Ericsson",
            "Ericsson-ViG-CPN-digits"               => "Ericsson",
            "Ericsson-ViG-CPN-NP"                   => "Ericsson",
            "Ericsson-ViG-CPN-PI"                   => "Ericsson",
            "Ericsson-ViG-CPN-SI"                   => "Ericsson",
            "Ericsson-ViG-CPN-TON"                  => "Ericsson",
            "Ericsson-ViG-Currency"                 => "Ericsson",
            "Ericsson-ViG-Currency-Quote"           => "Ericsson",
            "Ericsson-ViG-Data-media-rec-backward"  => "Ericsson",
            "Ericsson-ViG-Data-media-rec-forward"   => "Ericsson",
            "Ericsson-ViG-Dialled-e164-number"      => "Ericsson",
            "Ericsson-ViG-Dialled-Email-address"    => "Ericsson",
            "Ericsson-ViG-Dialled-H323Id"           => "Ericsson",
            "Ericsson-ViG-Dialled-num-digits"       => "Ericsson",
            "Ericsson-ViG-Dialled-num-NP"           => "Ericsson",
            "Ericsson-ViG-Dialled-num-TON"          => "Ericsson",
            "Ericsson-ViG-Digest-Attributes"        => "Ericsson",
            "Ericsson-ViG-Digest-Response"          => "Ericsson",
            "Ericsson-ViG-Emergency-Call-Indicator" => "Ericsson",
            "Ericsson-ViG-Endpoint-Type"            => "Ericsson",
            "Ericsson-ViG-Fax-media-rec-backward"   => "Ericsson",
            "Ericsson-ViG-Fax-media-rec-forward"    => "Ericsson",
            "Ericsson-ViG-Global-unique-call-ID"    => "Ericsson",
            "Ericsson-ViG-Global-unique-service-ID" => "Ericsson",
            "Ericsson-ViG-Interim-interval"         => "Ericsson",
            "Ericsson-ViG-Internal-Rel-reason-orig" => "Ericsson",
            "Ericsson-ViG-Internal-Rel-reason-val"  => "Ericsson",
            "Ericsson-ViG-IPT-Time-Stamp"           => "Ericsson",
            "Ericsson-ViG-Layer-identity"           => "Ericsson",
            "Ericsson-ViG-Major-protocol-version"   => "Ericsson",
            "Ericsson-ViG-Media-channel-count"      => "Ericsson",
            "Ericsson-ViG-Minor-protocol-version"   => "Ericsson",
            "Ericsson-ViG-Proxy-IP-Address"         => "Ericsson",
            "Ericsson-ViG-QoS-Class"                => "Ericsson",
            "Ericsson-ViG-Re-selection-counter"     => "Ericsson",
            "Ericsson-ViG-Redirecting-num-digits"   => "Ericsson",
            "Ericsson-ViG-Redirecting-num-NP"       => "Ericsson",
            "Ericsson-ViG-Redirecting-num-PI"       => "Ericsson",
            "Ericsson-ViG-Redirecting-num-RFD"      => "Ericsson",
            "Ericsson-ViG-Redirecting-num-TON"      => "Ericsson",
            "Ericsson-ViG-Rel-cause-class"          => "Ericsson",
            "Ericsson-ViG-Rel-cause-coding-std"     => "Ericsson",
            "Ericsson-ViG-Rel-cause-location"       => "Ericsson",
            "Ericsson-ViG-Rel-cause-value"          => "Ericsson",
            "Ericsson-ViG-Rel-reason"               => "Ericsson",
            "Ericsson-ViG-Remote-SK-UA-IP-Address"  => "Ericsson",
            "Ericsson-ViG-Requested-bandwidth"      => "Ericsson",
            "Ericsson-ViG-Routed-e164-number"       => "Ericsson",
            "Ericsson-ViG-Routed-Email-address"     => "Ericsson",
            "Ericsson-ViG-Routed-H323Id"            => "Ericsson",
            "Ericsson-ViG-Routing-num-digits"       => "Ericsson",
            "Ericsson-ViG-Routing-num-NP"           => "Ericsson",
            "Ericsson-ViG-Routing-num-TON"          => "Ericsson",
            "Ericsson-ViG-Routing-tariff"           => "Ericsson",
            "Ericsson-ViG-SA-IP-address"            => "Ericsson",
            "Ericsson-ViG-Sequence-Number"          => "Ericsson",
            "Ericsson-ViG-Service-Description"      => "Ericsson",
            "Ericsson-ViG-Service-Duration"         => "Ericsson",
            "Ericsson-ViG-Service-Exe-Rslt-Desc"    => "Ericsson",
            "Ericsson-ViG-Service-Execution-Result" => "Ericsson",
            "Ericsson-ViG-Service-ID"               => "Ericsson",
            "Ericsson-ViG-Service-Name"             => "Ericsson",
            "Ericsson-ViG-Service-Specific-Info"    => "Ericsson",
            "Ericsson-ViG-Session-ringing-duration" => "Ericsson",
            "Ericsson-ViG-Session-routing-duration" => "Ericsson",
            "Ericsson-ViG-Site"                     => "Ericsson",
            "Ericsson-ViG-SiteKeeper-name"          => "Ericsson",
            "Ericsson-ViG-SK-IP-address"            => "Ericsson",
            "Ericsson-ViG-Terminal-Type"            => "Ericsson",
            "Ericsson-ViG-Test-Call-Indicator"      => "Ericsson",
            "Ericsson-ViG-Time-stamp-DST"           => "Ericsson",
            "Ericsson-ViG-Time-stamp-TZ"            => "Ericsson",
            "Ericsson-ViG-Time-stamp-UTC"           => "Ericsson",
            "Ericsson-ViG-Translated-ID"            => "Ericsson",
            "Ericsson-ViG-Trusted-access"           => "Ericsson",
            "Ericsson-ViG-TTL-Absolute"             => "Ericsson",
            "Ericsson-ViG-TTL-relative"             => "Ericsson",
            "Ericsson-ViG-TTL-Start-Event"          => "Ericsson",
            "Ericsson-ViG-UA-IP-address"            => "Ericsson",
            "Ericsson-ViG-User-agent-group-name"    => "Ericsson",
            "Ericsson-ViG-User-agent-name"          => "Ericsson",
            "Ericsson-ViG-User-ID"                  => "Ericsson",
            "Ericsson-ViG-User-name"                => "Ericsson",
            "Ericsson-ViG-User-Name-Info"           => "Ericsson",
            "Ericsson-ViG-Video-media-rec-backward" => "Ericsson",
            "Ericsson-ViG-Video-media-rec-forward"  => "Ericsson",
            "Ericsson-ViG-Voice-media-rec-backward" => "Ericsson",
            "Ericsson-ViG-Voice-media-rec-forward"  => "Ericsson",
            "ERX-Acc-Aggr-Cir-Id-Asc"               => "ERX",
            "ERX-Acc-Aggr-Cir-Id-Bin"               => "ERX",
            "ERX-Acc-Loop-Cir-Id"                   => "ERX",
            "ERX-Acc-Loop-Encap"                    => "ERX",
            "ERX-Acc-Loop-Remote-Id"                => "ERX",
            "ERX-Acct-Request-Reason"               => "ERX",
            "ERX-Act-Data-Rate-Dn"                  => "ERX",
            "ERX-Act-Data-Rate-Up"                  => "ERX",
            "ERX-Act-Interlv-Delay-Dn"              => "ERX",
            "ERX-Act-Interlv-Delay-Up"              => "ERX",
            "ERX-Action-Reason"                     => "ERX",
            "ERX-Address-Pool-Name"                 => "ERX",
            "ERX-Adv-Pcef-Profile-Name"             => "ERX",
            "ERX-Adv-Pcef-Rule-Name"                => "ERX",
            "ERX-Alternate-Cli-Access-Level"        => "ERX",
            "ERX-Alternate-Cli-Vrouter-Name"        => "ERX",
            "ERX-APN-Name"                          => "ERX",
            "ERX-Atm-MBS"                           => "ERX",
            "ERX-Atm-PCR"                           => "ERX",
            "ERX-Atm-SCR"                           => "ERX",
            "ERX-Atm-Service-Category"              => "ERX",
            "ERX-Att-Data-Rate-Dn"                  => "ERX",
            "ERX-Att-Data-Rate-Up"                  => "ERX",
            "ERX-Attainable-Expected-Throughput-Downstream"  => "ERX",
            "ERX-Attainable-Expected-Throughput-Upstream"    => "ERX",
            "ERX-Attainable-Gamma-Data-Rate-Downstream"      => "ERX",
            "ERX-Attainable-Gamma-Data-Rate-Upstream"        => "ERX",
            "ERX-Backup-Address-Pool"                        => "ERX",
            "ERX-Bearer-Type"                                => "ERX",
            "ERX-Bulk-CoA-Identifier"                        => "ERX",
            "ERX-Bulk-CoA-Transaction-Id"                    => "ERX",
            "ERX-Cli-Allow-All-VR-Access"                    => "ERX",
            "ERX-Cli-Initial-Access-Level"                   => "ERX",
            "ERX-Client-Profile-Name"                        => "ERX",
            "ERX-Core-Facing-Interface"                      => "ERX",
            "ERX-CoS-Scheduler-Pmt-Type"                     => "ERX",
            "ERX-CoS-Shaping-Pmt-Type"                       => "ERX",
            "ERX-Cos-Shaping-Rate"                           => "ERX",
            "ERX-DF-Bit"                                     => "ERX",
            "ERX-DHCP-First-Relay-IPv4-Address"              => "ERX",
            "ERX-DHCP-First-Relay-IPv6-Address"              => "ERX",
            "ERX-Dhcp-Gi-Address"                            => "ERX",
            "ERX-DHCP-Guided-Relay-Server"                   => "ERX",
            "ERX-DHCP-Header"                                => "ERX",
            "ERX-Dhcp-Mac-Addr"                              => "ERX",
            "ERX-Dhcp-Option-82"                             => "ERX",
            "ERX-Dhcp-Options"                               => "ERX",
            "ERX-DHCPv6-Guided-Relay-Server"                 => "ERX",
            "ERX-DHCPv6-Header"                              => "ERX",
            "ERX-DHCPv6-Options"                             => "ERX",
            "ERX-Dial-Out-Number"                            => "ERX",
            "ERX-DownStream-Calc-Rate"                       => "ERX",
            "ERX-DSL-Line-State"                             => "ERX",
            "ERX-DSL-Type"                                   => "ERX",
            "ERX-Egress-Policy-Name"                         => "ERX",
            "ERX-Egress-Statistics"                          => "ERX",
            "ERX-Expected-Throughput-Downstream"             => "ERX",
            "ERX-Expected-Throughput-Upstream"               => "ERX",
            "ERX-Framed-Ip-Route-Tag"                        => "ERX",
            "ERX-Gamma-Data-Rate-Downstream"                 => "ERX",
            "ERX-Gamma-Data-Rate-Upstream"                   => "ERX",
            "ERX-Hybrid-Access-DSL-Downstream-Speed"         => "ERX",
            "ERX-Hybrid-Access-LTE-Downstream-Speed"         => "ERX",
            "ERX-ICR-Partition-Id"                           => "ERX",
            "ERX-IGMP-Access-Name"                           => "ERX",
            "ERX-IGMP-Access-Src-Name"                       => "ERX",
            "ERX-Igmp-Enable"                                => "ERX",
            "ERX-IGMP-Explicit-Tracking"                     => "ERX",
            "ERX-IGMP-Immediate-Leave"                       => "ERX",
            "ERX-IGMP-Max-Resp-Time"                         => "ERX",
            "ERX-IGMP-No-Tracking-V2-Grps"                   => "ERX",
            "ERX-IGMP-OIF-Map-Name"                          => "ERX",
            "ERX-IGMP-Query-Interval"                        => "ERX",
            "ERX-IGMP-Version"                               => "ERX",
            "ERX-Ingress-Policy-Name"                        => "ERX",
            "ERX-Ingress-Statistics"                         => "ERX",
            "ERX-Inner-Tag-Protocol-Id"                      => "ERX",
            "ERX-Inner-Vlan-Map-Id"                          => "ERX",
            "ERX-Input-Gigapkts"                             => "ERX",
            "ERX-Input-Interface-Filter"                     => "ERX",
            "ERX-Interface-Desc"                             => "ERX",
            "ERX-Interface-Set-Targeting-Weight"             => "ERX",
            "ERX-Interface-Targeting-Weight"                 => "ERX",
            "ERX-IP-Block-Multicast"                         => "ERX",
            "ERX-IP-Mcast-Adm-Bw-Limit"                      => "ERX",
            "ERX-IPv4-Input-Service-Filter"                  => "ERX",
            "ERX-IPv4-Input-Service-Set"                     => "ERX",
            "ERX-IPv4-Output-Service-Filter"                 => "ERX",
            "ERX-IPv4-Output-Service-Set"                    => "ERX",
            "ERX-IPv6-Acct-Input-Gigawords"                  => "ERX",
            "ERX-IPv6-Acct-Input-Octets"                     => "ERX",
            "ERX-IPv6-Acct-Input-Packets"                    => "ERX",
            "ERX-IPv6-Acct-Output-Gigawords"                 => "ERX",
            "ERX-IPv6-Acct-Output-Octets"                    => "ERX",
            "ERX-IPv6-Acct-Output-Packets"                   => "ERX",
            "ERX-IPv6-Delegated-Pool-Name"                   => "ERX",
            "ERX-IPv6-Egress-Policy-Name"                    => "ERX",
            "ERX-IPv6-Ingress-Policy-Name"                   => "ERX",
            "ERX-IPv6-Input-Service-Filter"                  => "ERX",
            "ERX-IPv6-Input-Service-Set"                     => "ERX",
            "ERX-IpV6-Local-Interface"                       => "ERX",
            "ERX-IPv6-Mcast-Adm-Bw-Limit"                    => "ERX",
            "ERX-IPv6-NdRa-Pool-Name"                        => "ERX",
            "ERX-IPv6-NdRa-Prefix"                           => "ERX",
            "ERX-IPv6-Output-Service-Filter"                 => "ERX",
            "ERX-IPv6-Output-Service-Set"                    => "ERX",
            "ERX-Ipv6-Primary-Dns"                           => "ERX",
            "ERX-Ipv6-Secondary-Dns"                         => "ERX",
            "ERX-IpV6-Virtual-Router"                        => "ERX",
            "ERX-L2c-Down-Stream-Data"                       => "ERX",
            "ERX-L2c-Up-Stream-Data"                         => "ERX",
            "ERX-L2tp-Recv-Window-Size"                      => "ERX",
            "ERX-L2TP-Resynch-Method"                        => "ERX",
            "ERX-LI-Action"                                  => "ERX",
            "ERX-Local-Loopback-Interface"                   => "ERX",
            "ERX-Max-Clients-Per-Interface"                  => "ERX",
            "ERX-Max-Data-Rate-Dn"                           => "ERX",
            "ERX-Max-Data-Rate-Up"                           => "ERX",
            "ERX-Max-Interlv-Delay-Dn"                       => "ERX",
            "ERX-Max-Interlv-Delay-Up"                       => "ERX",
            "ERX-Maximum-BPS"                                => "ERX",
            "ERX-Med-Dev-Handle"                             => "ERX",
            "ERX-Med-Ip-Address"                             => "ERX",
            "ERX-Med-Port-Number"                            => "ERX",
            "ERX-Min-Data-Rate-Dn"                           => "ERX",
            "ERX-Min-Data-Rate-Up"                           => "ERX",
            "ERX-Min-LP-Data-Rate-Dn"                        => "ERX",
            "ERX-Min-LP-Data-Rate-Up"                        => "ERX",
            "ERX-Minimum-BPS"                                => "ERX",
            "ERX-MLD-Access-Name"                            => "ERX",
            "ERX-MLD-Access-Src-Name"                        => "ERX",
            "ERX-MLD-Explicit-Tracking"                      => "ERX",
            "ERX-MLD-Immediate-Leave"                        => "ERX",
            "ERX-MLD-Max-Resp-Time"                          => "ERX",
            "ERX-MLD-No-Tracking-V1-Grps"                    => "ERX",
            "ERX-MLD-OIF-Map-Name"                           => "ERX",
            "ERX-MLD-Query-Interval"                         => "ERX",
            "ERX-MLD-Version"                                => "ERX",
            "ERX-MLPPP-Bundle-Name"                          => "ERX",
            "ERX-Mobile-IP-Access-Control"                   => "ERX",
            "ERX-Mobile-IP-Algorithm"                        => "ERX",
            "ERX-Mobile-IP-Key"                              => "ERX",
            "ERX-Mobile-IP-Lifetime"                         => "ERX",
            "ERX-Mobile-IP-Replay"                           => "ERX",
            "ERX-Mobile-IP-SPI"                              => "ERX",
            "ERX-ONT-ONU-Assured-Data-Rate-Upstream"         => "ERX",
            "ERX-ONT-ONU-Average-Data-Rate-Downstream"       => "ERX",
            "ERX-ONT-ONU-Maximum-Data-Rate-Upstream"         => "ERX",
            "ERX-ONT-ONU-Peak-Data-Rate-Downstream"          => "ERX",
            "ERX-Output-Gigapkts"                            => "ERX",
            "ERX-Output-Interface-Filter"                    => "ERX",
            "ERX-Pim-Enable"                                 => "ERX",
            "ERX-PON-Access-Type"                            => "ERX",
            "ERX-PON-Tree-Maximum-Data-Rate-Downstream"      => "ERX",
            "ERX-PON-Tree-Maximum-Data-Rate-Upstream"        => "ERX",
            "ERX-PPP-Auth-Protocol"                          => "ERX",
            "ERX-PPP-Monitor-Ingress-Only"                   => "ERX",
            "ERX-PPP-Password"                               => "ERX",
            "ERX-PPP-Username"                               => "ERX",
            "ERX-Pppoe-Description"                          => "ERX",
            "ERX-Pppoe-Max-Sessions"                         => "ERX",
            "ERX-PppoE-Padn"                                 => "ERX",
            "ERX-Pppoe-Url"                                  => "ERX",
            "ERX-Primary-Dns"                                => "ERX",
            "ERX-Primary-Wins"                               => "ERX",
            "ERX-Qos-Parameters"                             => "ERX",
            "ERX-Qos-Profile-Interface-Type"                 => "ERX",
            "ERX-Qos-Profile-Name"                           => "ERX",
            "ERX-Qos-Set-Name"                               => "ERX",
            "ERX-Radius-Client-Address"                      => "ERX",
            "ERX-Re-Authentication-Catalyst"                 => "ERX",
            "ERX-Redirect-GW-Address"                        => "ERX",
            "ERX-Redirect-VR-Name"                           => "ERX",
            "ERX-Routing-Services"                           => "ERX",
            "ERX-Rx-Connect-Speed"                           => "ERX",
            "ERX-Sa-Validate"                                => "ERX",
            "ERX-Secondary-Dns"                              => "ERX",
            "ERX-Secondary-Wins"                             => "ERX",
            "ERX-Service-Acct-Interval"                      => "ERX",
            "ERX-Service-Activate"                           => "ERX",
            "ERX-Service-Activate-Type"                      => "ERX",
            "ERX-Service-Bundle"                             => "ERX",
            "ERX-Service-Deactivate"                         => "ERX",
            "ERX-Service-Description"                        => "ERX",
            "ERX-Service-Session"                            => "ERX",
            "ERX-Service-Statistics"                         => "ERX",
            "ERX-Service-Timeout"                            => "ERX",
            "ERX-Service-Volume"                             => "ERX",
            "ERX-Service-Volume-Gigawords"                   => "ERX",
            "ERX-Tunnel-Group"                               => "ERX",
            "ERX-Tunnel-Interface-Id"                        => "ERX",
            "ERX-Tunnel-Maximum-Sessions"                    => "ERX",
            "ERX-Tunnel-Nas-Port-Method"                     => "ERX",
            "ERX-Tunnel-Password"                            => "ERX",
            "ERX-Tunnel-Switch-Profile"                      => "ERX",
            "ERX-Tunnel-Tos"                                 => "ERX",
            "ERX-Tunnel-Tx-Speed-Method"                     => "ERX",
            "ERX-Tunnel-Virtual-Router"                      => "ERX",
            "ERX-Tx-Connect-Speed"                           => "ERX",
            "ERX-Update-Service"                             => "ERX",
            "ERX-UpStream-Calc-Rate"                         => "ERX",
            "ERX-Virtual-Router-Name"                        => "ERX",
            "ERX-Vlan-Map-Id"                                => "ERX",
            "Extreme-Auth-Source"                            => "Aerohive",
            "Extreme-AVPair"                                 => "Aerohive",
            "Extreme-CLI-Authorization"                      => "Extreme",
            "Extreme-Client-Monitor-Problem"                 => "Aerohive",
            "Extreme-Client-Monitor-Session"                 => "Aerohive",
            "Extreme-Data-Usage-Limit"                       => "Aerohive",
            "Extreme-Daylight-Saving-Offset"                 => "Aerohive",
            "Extreme-IDM-Message"                            => "Aerohive",
            "Extreme-IDM-Redirect-URL"                       => "Aerohive",
            "Extreme-Libsip-Action"                          => "Aerohive",
            "Extreme-Libsip-Additional-Message"              => "Aerohive",
            "Extreme-Libsip-Patron-Info"                     => "Aerohive",
            "Extreme-MGT-MAC-Address"                        => "Aerohive",
            "Extreme-Netlogin-Extended-Vlan"                 => "Extreme",
            "Extreme-Netlogin-Only"                          => "Extreme",
            "Extreme-Netlogin-Url"                           => "Extreme",
            "Extreme-Netlogin-Url-Desc"                      => "Extreme",
            "Extreme-Netlogin-Vlan"                          => "Extreme",
            "Extreme-Netlogin-Vlan-Tag"                      => "Extreme",
            "Extreme-NT-Identity"                            => "Aerohive",
            "Extreme-PPSK-PMK"                               => "Aerohive",
            "Extreme-PPSK-Request"                           => "Aerohive",
            "Extreme-Radius-Code"                            => "Aerohive",
            "Extreme-Security-Profile"                       => "Extreme",
            "Extreme-Shell-Command"                          => "Extreme",
            "Extreme-Time-Zone-Offset"                       => "Aerohive",
            "Extreme-User-Language"                          => "Aerohive",
            "Extreme-User-Location"                          => "Extreme",
            "Extreme-User-Profile-Attribute"                 => "Aerohive",
            "Extreme-User-Vlan"                              => "Aerohive",
            "Extreme-VM-IP-Addr"                             => "Extreme",
            "Extreme-VM-Name"                                => "Extreme",
            "Extreme-VM-VLAN-ID"                             => "Extreme",
            "Extreme-VM-VPP-Name"                            => "Extreme",
            "Extreme-VM-VR-Name"                             => "Extreme",
            "F5-LTM-Audit-Msg"                               => "F5",
            "F5-LTM-User-Console"                            => "F5",
            "F5-LTM-User-Context-1"                          => "F5",
            "F5-LTM-User-Context-2"                          => "F5",
            "F5-LTM-User-Info-1"                             => "F5",
            "F5-LTM-User-Info-2"                             => "F5",
            "F5-LTM-User-Partition"                          => "F5",
            "F5-LTM-User-Role"                               => "F5",
            "F5-LTM-User-Role-Universal"                     => "F5",
            "F5-LTM-User-Shell"                              => "F5",
            "Fabric-Attach-Client-Id"                        => "Nortel",
            "Fabric-Attach-Client-PSK"                       => "Nortel",
            "Fabric-Attach-Client-Trust"                     => "Nortel",
            "Fabric-Attach-Client-Trusted-Binding"           => "Nortel",
            "Fabric-Attach-Client-Type"                      => "Nortel",
            "Fabric-Attach-Service-Request"                  => "Nortel",
            "Fabric-Attach-Switch-Mode"                      => "Nortel",
            "Fabric-Attach-VLAN-Create"                      => "Nortel",
            "Fabric-Attach-VLAN-ISID"                        => "Nortel",
            "Fabric-Attach-VLAN-PVID"                        => "Nortel",
            "fdXtended-Bandwidth-Down"                       => "fdXtended",
            "fdXtended-Bandwidth-Up"                         => "fdXtended",
            "fdXtended-BytesDown"                            => "fdXtended",
            "fdXtended-BytesUp"                              => "fdXtended",
            "fdXtended-ContentFilter"                        => "fdXtended",
            "fdXtended-Expiration"                           => "fdXtended",
            "fdXtended-NetworkPolicy"                        => "fdXtended",
            "fdXtended-One2onenat-IP"                        => "fdXtended",
            "fdXtended-PostAuthURL"                          => "fdXtended",
            "fdXtended-SessionTimeout"                       => "fdXtended",
            "fdXtended-Wan-Interface"                        => "fdXtended",
            "Flow-FAC-Profile"                               => "Ericsson-AB",
            "Flow-IP-Profile"                                => "Ericsson-AB",
            "Force10-AVPair"                                 => "Force10",
            "Fortinet-Access-Profile"                        => "Fortinet",
            "Fortinet-AP-Name"                               => "Fortinet",
            "Fortinet-AppCtrl-Category-Allow"                => "Fortinet",
            "Fortinet-AppCtrl-Category-Block"                => "Fortinet",
            "Fortinet-AppCtrl-Risk-Allow"                    => "Fortinet",
            "Fortinet-AppCtrl-Risk-Block"                    => "Fortinet",
            "Fortinet-Client-IP-Address"                     => "Fortinet",
            "Fortinet-Client-IPv6-Address"                   => "Fortinet",
            "Fortinet-FAC-Auth-Status"                       => "Fortinet",
            "Fortinet-FAC-Challenge-Code"                    => "Fortinet",
            "Fortinet-FAC-Token-ID"                          => "Fortinet",
            "Fortinet-FDD-Access-Profile"                    => "Fortinet",
            "Fortinet-FDD-Allow-API-Access"                  => "Fortinet",
            "Fortinet-FDD-Is-SPP-Admin"                      => "Fortinet",
            "Fortinet-FDD-Is-System-Admin"                   => "Fortinet",
            "Fortinet-FDD-SPP-Name"                          => "Fortinet",
            "Fortinet-FDD-SPP-Policy-Group"                  => "Fortinet",
            "Fortinet-FDD-Trusted-Hosts"                     => "Fortinet",
            "Fortinet-FortiWAN-AVPair"                       => "Fortinet",
            "Fortinet-Fpc-User-Role"                         => "Fortinet",
            "Fortinet-Group-Name"                            => "Fortinet",
            "Fortinet-Host-Port-AVPair"                      => "Fortinet",
            "Fortinet-Interface-Name"                        => "Fortinet",
            "Fortinet-SSID"                                  => "Fortinet",
            "Fortinet-Tenant-Identification"                 => "Fortinet",
            "Fortinet-Vdom-Name"                             => "Fortinet",
            "Fortinet-Webfilter-Category-Allow"              => "Fortinet",
            "Fortinet-Webfilter-Category-Block"              => "Fortinet",
            "Fortinet-Webfilter-Category-Monitor"            => "Fortinet",
            "Fortinet-WirelessController-Assoc-Time"         => "Fortinet",
            "Fortinet-WirelessController-Device-MAC"         => "Fortinet",
            "Fortinet-WirelessController-WTP-ID"             => "Fortinet",
            "Forward-Policy"                                 => "Ericsson-AB",
            "Foundry-802.1x-Valid-Lookup"                    => "Foundry",
            "Foundry-Access-List"                            => "Foundry",
            "Foundry-COA-Command"                            => "Foundry",
            "Foundry-Command-Exception-Flag"                 => "Foundry",
            "Foundry-Command-String"                         => "Foundry",
            "Foundry-INM-Privilege"                          => "Foundry",
            "Foundry-INM-Role-Aor-List"                      => "Foundry",
            "Foundry-MAC-Authent-needs-802.1x"               => "Foundry",
            "Foundry-MAC-Based-Vlan-QoS"                     => "Foundry",
            "Foundry-Privilege-Level"                        => "Foundry",
            "Foundry-SI-Context-Role"                        => "Foundry",
            "Foundry-SI-Role-Template"                       => "Foundry",
            "Foundry-Voice-Phone-Config"                     => "Foundry",
            "FreeRADIUS-802.1X-Anonce"                       => "FreeRADIUS",
            "FreeRADIUS-802.1X-EAPoL-Key-Msg"                => "FreeRADIUS",
            "FreeRADIUS-Acct-Session-Start-Time"             => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-Crypto-Binding"             => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-EAP-Payload"                => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-Error"                      => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-Intermediate-Result"        => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-NAK"                        => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC"                        => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-A-ID"                   => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-A-ID-Info"              => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Acknowledge"            => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-I-ID"                   => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Info-A-ID"              => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Info-A-ID-Info"         => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Info-I-ID"              => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Info-PAC-Lifetime"      => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Info-PAC-Type"          => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Info-TLV"               => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Key"                    => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Lifetime"               => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Opaque-I-ID"            => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Opaque-PAC-Key"         => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Opaque-PAC-Lifetime"    => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Opaque-PAC-Type"        => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Opaque-TLV"             => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PAC-Type"                   => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-PKCS"                       => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-Request-Action"             => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-Result"                     => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-TLV"                        => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-Trusted-Root"               => "FreeRADIUS",
            "FreeRADIUS-EAP-FAST-Vendor-Specific"            => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-Authority-ID"               => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-Basic-Password-Auth-Req"    => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-Basic-Password-Auth-Resp"   => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-Channel-Binding"            => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-Crypto-Binding"             => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-EAP-Payload"                => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-Error"                      => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-Intermediate-Result"        => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-NAK"                        => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC"                        => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC-A-ID"                   => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC-A-ID-Info"              => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC-Acknowledgement"        => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC-I-ID"                   => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC-Info-A-ID"              => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC-Info-A-ID-Info"         => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC-Info-I-ID"              => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC-Info-PAC-Lifetime"      => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC-Info-PAC-Type"          => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC-Info-TLV"               => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC-Key"                    => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC-Lifetime"               => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC-Opaque"                 => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PAC-Type"                   => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PKCS10"                     => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-PKCS7"                      => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-Request-Action"             => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-Result"                     => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-TLV"                        => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-Trusted-Server-Root"        => "FreeRADIUS",
            "FreeRADIUS-EAP-TEAP-Vendor-Specific"            => "FreeRADIUS",
            "FreeRADIUS-EAP-TRAP-PAC-Type"                   => "FreeRADIUS",
            "FreeRADIUS-Proxied-To"                          => "FreeRADIUS",
            "FreeRADIUS-Queue-Len-Acct"                      => "FreeRADIUS",
            "FreeRADIUS-Queue-Len-Auth"                      => "FreeRADIUS",
            "FreeRADIUS-Queue-Len-Detail"                    => "FreeRADIUS",
            "FreeRADIUS-Queue-Len-Internal"                  => "FreeRADIUS",
            "FreeRADIUS-Queue-Len-Proxy"                     => "FreeRADIUS",
            "FreeRADIUS-Queue-PPS-In"                        => "FreeRADIUS",
            "FreeRADIUS-Queue-PPS-Out"                       => "FreeRADIUS",
            "FreeRADIUS-Queue-Use-Percentage"                => "FreeRADIUS",
            "FreeRADIUS-Server-EMA-USEC-Window-1"            => "FreeRADIUS",
            "FreeRADIUS-Server-EMA-USEC-Window-10"           => "FreeRADIUS",
            "FreeRADIUS-Server-EMA-Window"                   => "FreeRADIUS",
            "FreeRADIUS-Statistics-Type"                     => "FreeRADIUS",
            "FreeRADIUS-Stats-Client-IP-Address"             => "FreeRADIUS",
            "FreeRADIUS-Stats-Client-IPv6-Address"           => "FreeRADIUS",
            "FreeRADIUS-Stats-Client-Netmask"                => "FreeRADIUS",
            "FreeRADIUS-Stats-Client-Number"                 => "FreeRADIUS",
            "FreeRADIUS-Stats-Error"                         => "FreeRADIUS",
            "FreeRADIUS-Stats-HUP-Time"                      => "FreeRADIUS",
            "FreeRADIUS-Stats-Last-Packet-Recv"              => "FreeRADIUS",
            "FreeRADIUS-Stats-Last-Packet-Sent"              => "FreeRADIUS",
            "FreeRADIUS-Stats-Server-IP-Address"             => "FreeRADIUS",
            "FreeRADIUS-Stats-Server-IPv6-Address"           => "FreeRADIUS",
            "FreeRADIUS-Stats-Server-Outstanding-Requests"   => "FreeRADIUS",
            "FreeRADIUS-Stats-Server-Port"                   => "FreeRADIUS",
            "FreeRADIUS-Stats-Server-Src-IP-Address"         => "FreeRADIUS",
            "FreeRADIUS-Stats-Server-Src-IPv6-Address"       => "FreeRADIUS",
            "FreeRADIUS-Stats-Server-State"                  => "FreeRADIUS",
            "FreeRADIUS-Stats-Server-Time-Of-Death"          => "FreeRADIUS",
            "FreeRADIUS-Stats-Server-Time-Of-Life"           => "FreeRADIUS",
            "FreeRADIUS-Stats-Start-Time"                    => "FreeRADIUS",
            "FreeRADIUS-Stats-Threads-Active"                => "FreeRADIUS",
            "FreeRADIUS-Stats-Threads-Max"                   => "FreeRADIUS",
            "FreeRADIUS-Stats-Threads-Total"                 => "FreeRADIUS",
            "FreeRADIUS-Total-Access-Accepts"                => "FreeRADIUS",
            "FreeRADIUS-Total-Access-Challenges"             => "FreeRADIUS",
            "FreeRADIUS-Total-Access-Rejects"                => "FreeRADIUS",
            "FreeRADIUS-Total-Access-Requests"               => "FreeRADIUS",
            "FreeRADIUS-Total-Accounting-Requests"           => "FreeRADIUS",
            "FreeRADIUS-Total-Accounting-Responses"          => "FreeRADIUS",
            "FreeRADIUS-Total-Acct-Conflicts"                => "FreeRADIUS",
            "FreeRADIUS-Total-Acct-Dropped-Requests"         => "FreeRADIUS",
            "FreeRADIUS-Total-Acct-Duplicate-Requests"       => "FreeRADIUS",
            "FreeRADIUS-Total-Acct-Invalid-Requests"         => "FreeRADIUS",
            "FreeRADIUS-Total-Acct-Malformed-Requests"       => "FreeRADIUS",
            "FreeRADIUS-Total-Acct-Unknown-Types"            => "FreeRADIUS",
            "FreeRADIUS-Total-Auth-Conflicts"                => "FreeRADIUS",
            "FreeRADIUS-Total-Auth-Dropped-Requests"         => "FreeRADIUS",
            "FreeRADIUS-Total-Auth-Duplicate-Requests"       => "FreeRADIUS",
            "FreeRADIUS-Total-Auth-Invalid-Requests"         => "FreeRADIUS",
            "FreeRADIUS-Total-Auth-Malformed-Requests"       => "FreeRADIUS",
            "FreeRADIUS-Total-Auth-Responses"                => "FreeRADIUS",
            "FreeRADIUS-Total-Auth-Unknown-Types"            => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Access-Accepts"          => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Access-Challenges"       => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Access-Rejects"          => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Access-Requests"         => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Accounting-Requests"     => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Accounting-Responses"    => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Acct-Dropped-Requests"   => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Acct-Duplicate-Requests" => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Acct-Invalid-Requests"   => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Acct-Malformed-Requests" => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Acct-Unknown-Types"      => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Auth-Dropped-Requests"   => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Auth-Duplicate-Requests" => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Auth-Invalid-Requests"   => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Auth-Malformed-Requests" => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Auth-Responses"          => "FreeRADIUS",
            "FreeRADIUS-Total-Proxy-Auth-Unknown-Types"      => "FreeRADIUS",
            "Freeswitch-AMAFlags"                            => "Freeswitch",
            "Freeswitch-Ani"                                 => "Freeswitch",
            "Freeswitch-Aniii"                               => "Freeswitch",
            "Freeswitch-AVPair"                              => "Freeswitch",
            "Freeswitch-Billusec"                            => "Freeswitch",
            "Freeswitch-Callanswerdate"                      => "Freeswitch",
            "Freeswitch-Callenddate"                         => "Freeswitch",
            "Freeswitch-Callstartdate"                       => "Freeswitch",
            "Freeswitch-Calltransferdate"                    => "Freeswitch",
            "Freeswitch-CLID"                                => "Freeswitch",
            "Freeswitch-Context"                             => "Freeswitch",
            "Freeswitch-Dialplan"                            => "Freeswitch",
            "Freeswitch-Disposition"                         => "Freeswitch",
            "Freeswitch-Dst"                                 => "Freeswitch",
            "Freeswitch-Dst-Channel"                         => "Freeswitch",
            "Freeswitch-Hangupcause"                         => "Freeswitch",
            "Freeswitch-Lastapp"                             => "Freeswitch",
            "Freeswitch-Lastdata"                            => "Freeswitch",
            "Freeswitch-RDNIS"                               => "Freeswitch",
            "Freeswitch-Signalbond"                          => "Freeswitch",
            "Freeswitch-Source"                              => "Freeswitch",
            "Freeswitch-Src"                                 => "Freeswitch",
            "Freeswitch-Src-Channel"                         => "Freeswitch",
            "Gandalf-Around-The-Corner"                      => "Gandalf",
            "Gandalf-Authentication-String"                  => "Gandalf",
            "Gandalf-Calling-Line-ID-1"                      => "Gandalf",
            "Gandalf-Calling-Line-ID-2"                      => "Gandalf",
            "Gandalf-Channel-Group-Name-1"                   => "Gandalf",
            "Gandalf-Channel-Group-Name-2"                   => "Gandalf",
            "Gandalf-Compression-Status"                     => "Gandalf",
            "Gandalf-Dial-Prefix-Name-1"                     => "Gandalf",
            "Gandalf-Dial-Prefix-Name-2"                     => "Gandalf",
            "Gandalf-Fwd-Broadcast-In"                       => "Gandalf",
            "Gandalf-Fwd-Broadcast-Out"                      => "Gandalf",
            "Gandalf-Fwd-Multicast-In"                       => "Gandalf",
            "Gandalf-Fwd-Multicast-Out"                      => "Gandalf",
            "Gandalf-Fwd-Unicast-In"                         => "Gandalf",
            "Gandalf-Fwd-Unicast-Out"                        => "Gandalf",
            "Gandalf-Hunt-Group"                             => "Gandalf",
            "Gandalf-IPX-Spoofing-State"                     => "Gandalf",
            "Gandalf-IPX-Watchdog-Spoof"                     => "Gandalf",
            "Gandalf-Min-Outgoing-Bearer"                    => "Gandalf",
            "Gandalf-Modem-Mode"                             => "Gandalf",
            "Gandalf-Modem-Required-1"                       => "Gandalf",
            "Gandalf-Modem-Required-2"                       => "Gandalf",
            "Gandalf-Operational-Modes"                      => "Gandalf",
            "Gandalf-Phone-Number-1"                         => "Gandalf",
            "Gandalf-Phone-Number-2"                         => "Gandalf",
            "Gandalf-PPP-Authentication"                     => "Gandalf",
            "Gandalf-PPP-NCP-Type"                           => "Gandalf",
            "Gandalf-Remote-LAN-Name"                        => "Gandalf",
            "Gandalf-SAP-Group-Name-1"                       => "Gandalf",
            "Gandalf-SAP-Group-Name-2"                       => "Gandalf",
            "Gandalf-SAP-Group-Name-3"                       => "Gandalf",
            "Gandalf-SAP-Group-Name-4"                       => "Gandalf",
            "Gandalf-SAP-Group-Name-5"                       => "Gandalf",
            "Garderos-Location-Name"                         => "Garderos",
            "Garderos-MSISDN"                                => "Garderos",
            "Garderos-Proxy"                                 => "Garderos",
            "Garderos-Service-Name"                          => "Garderos",
            "gw-final-xlated-cdn"                            => "Cisco",
            "gw-final-xlated-cgn"                            => "Cisco",
            "gw-rxd-cdn"                                     => "Cisco",
            "gw-rxd-cgn"                                     => "Cisco",
            "h323-billing-model"                             => "Cisco",
            "h323-call-origin"                               => "Cisco",
            "h323-call-type"                                 => "Cisco",
            "h323-conf-id"                                   => "Cisco",
            "h323-connect-time"                              => "Cisco",
            "h323-credit-amount"                             => "Cisco",
            "h323-credit-time"                               => "Cisco",
            "h323-currency"                                  => "Cisco",
            "h323-disconnect-cause"                          => "Cisco",
            "h323-disconnect-time"                           => "Cisco",
            "h323-gw-id"                                     => "Cisco",
            "h323-incoming-conf-id"                          => "Cisco",
            "h323-preferred-lang"                            => "Cisco",
            "h323-prompt-id"                                 => "Cisco",
            "h323-redirect-ip-address"                       => "Cisco",
            "h323-redirect-number"                           => "Cisco",
            "h323-remote-address"                            => "Cisco",
            "h323-return-code"                               => "Cisco",
            "h323-setup-time"                                => "Cisco",
            "h323-time-and-day"                              => "Cisco",
            "h323-voice-quality"                             => "Cisco",
            "H3C-Accounting-Level"                           => "H3C",
            "H3C-Acct-IPv6-Input-Gigawords"                  => "H3C",
            "H3C-Acct-IPv6-Input-Octets"                     => "H3C",
            "H3C-Acct-IPv6-Input-Packets"                    => "H3C",
            "H3C-Acct-IPv6-Output-Gigawords"                 => "H3C",
            "H3C-Acct-IPv6-Output-Octets"                    => "H3C",
            "H3C-Acct-IPv6-Output-Packets"                   => "H3C",
            "H3C-ANCP-Profile"                               => "H3C",
            "H3C-Auth-Detail-Result"                         => "H3C",
            "H3C-Authentication-Type"                        => "H3C",
            "H3C-Av-Pair"                                    => "H3C",
            "H3C-Backup-NAS-IP"                              => "H3C",
            "H3C-Client-Primary-DNS"                         => "H3C",
            "H3C-Client-Secondary-DNS"                       => "H3C",
            "H3C-Command"                                    => "H3C",
            "H3C-Connect_Id"                                 => "H3C",
            "H3C-Control-Identifier"                         => "H3C",
            "H3C-Down-Priority"                              => "H3C",
            "H3C-Exec-Privilege"                             => "H3C",
            "H3C-Ftp-Directory"                              => "H3C",
            "H3C-IGMP-Access-Limit"                          => "H3C",
            "H3C-Input-Average-Rate"                         => "H3C",
            "H3C-Input-Basic-Rate"                           => "H3C",
            "H3C-Input-Committed-Burst-Size"                 => "H3C",
            "H3C-Input-Interval-Gigawords"                   => "H3C",
            "H3C-Input-Interval-Octets"                      => "H3C",
            "H3C-Input-Interval-Packets"                     => "H3C",
            "H3C-Input-Peak-Rate"                            => "H3C",
            "H3C-Ip-Host-Addr"                               => "H3C",
            "H3C-IPv4-Multicast-Receive-Group"               => "H3C",
            "H3C-IPv6-Multicast-Receive-Group"               => "H3C",
            "H3C-ISP-ID"                                     => "H3C",
            "H3C-Ita-Policy"                                 => "H3C",
            "H3C-L2TP-Local-Name"                            => "H3C",
            "H3C-Longitude-Latitude"                         => "H3C",
            "H3C-MLD-Access-Limit"                           => "H3C",
            "H3C-NAS-Port-Name"                              => "H3C",
            "H3C-NAS-Startup-Timestamp"                      => "H3C",
            "H3C-NAT-End-Port"                               => "H3C",
            "H3C-NAT-IP-Address"                             => "H3C",
            "H3C-NAT-Start-Port"                             => "H3C",
            "H3C-Output-Average-Rate"                        => "H3C",
            "H3C-Output-Basic-Rate"                          => "H3C",
            "H3C-Output-Committed-Burst-Size"                => "H3C",
            "H3C-Output-Interval-Gigawords"                  => "H3C",
            "H3C-Output-Interval-Octets"                     => "H3C",
            "H3C-Output-Interval-Packets"                    => "H3C",
            "H3C-Output-Peak-Rate"                           => "H3C",
            "H3C-Portal-URL"                                 => "H3C",
            "H3C-Product-ID"                                 => "H3C",
            "H3C-Remanent-Volume"                            => "H3C",
            "H3C-Result-Code"                                => "H3C",
            "H3C-Security-Level"                             => "H3C",
            "H3C-Subscriber-ID"                              => "H3C",
            "H3C-Subscriber-Profile"                         => "H3C",
            "H3C-Up-Priority"                                => "H3C",
            "H3C-User-Group"                                 => "H3C",
            "H3C-User-HeartBeat"                             => "H3C",
            "H3C-User-Notify"                                => "H3C",
            "H3C-User-Role"                                  => "H3C",
            "H3C-VPN-Instance"                               => "H3C",
            "H3C-WEB-URL"                                    => "H3C",
            "Hillstone-User-Admin-Privilege"                 => "Hillstone",
            "Hillstone-User-Login-Type"                      => "Hillstone",
            "Hillstone-User-Mobile-Number"                   => "Hillstone",
            "Hillstone-User-Mobile-Operator"                 => "Hillstone",
            "Hillstone-User-Policy-dst-ip-begin"             => "Hillstone",
            "Hillstone-User-Policy-dst-ip-end"               => "Hillstone",
            "Hillstone-User-Role-Bame"                       => "Hillstone",
            "Hillstone-User-Type"                            => "Hillstone",
            "Hillstone-User-vsys-id"                         => "Hillstone",
            "Hillstone-VPN-DHCP-Gateway"                     => "Hillstone",
            "Hillstone-VPN-DHCP-Mask"                        => "Hillstone",
            "Hillstone-VPN-DHCP-Pool"                        => "Hillstone",
            "Hillstone-VPN-DNS"                              => "Hillstone",
            "Hillstone-VPN-SNAT"                             => "Hillstone",
            "Hillstone-VPN-Split-Route"                      => "Hillstone",
            "Hillstone-VPN-Tunnel-IP"                        => "Hillstone",
            "Hillstone-VPN-WINS"                             => "Hillstone",
            "HP-Access-Profile"                              => "HP",
            "HP-Bandwidth-Max-Egress"                        => "HP",
            "HP-Bandwidth-Max-Ingress"                       => "HP",
            "HP-Bonjour-Inbound-Profile"                     => "HP",
            "HP-Bonjour-Outbound-Profile"                    => "HP",
            "HP-Capability-Advert"                           => "HP",
            "HP-Captive-Portal-URL"                          => "HP",
            "HP-Command-Exception"                           => "HP",
            "HP-Command-String"                              => "HP",
            "HP-Cos"                                         => "HP",
            "HP-CPPM-Role"                                   => "HP",
            "HP-CPPM-Secondary-Role"                         => "HP",
            "HP-Egress-VLAN-Name"                            => "HP",
            "HP-Egress-VLANID"                               => "HP",
            "HP-Ip-Filter-Raw"                               => "HP",
            "HP-Management-Protocol"                         => "HP",
            "HP-Nas-Filter-Rule"                             => "HP",
            "HP-Nas-Rules-IPv6"                              => "HP",
            "HP-Port-Auth-Mode-Dot1x"                        => "HP",
            "HP-Port-Bounce-Host"                            => "HP",
            "HP-Port-Client-Limit-Dot1x"                     => "HP",
            "HP-Port-Client-Limit-MA"                        => "HP",
            "HP-Port-Client-Limit-WA"                        => "HP",
            "HP-Port-MA-Port-Mode"                           => "HP",
            "HP-Port-Priority-Regeneration-Table"            => "HP",
            "HP-Privilege-Level"                             => "HP",
            "HP-URI-Access"                                  => "HP",
            "HP-URI-Exception"                               => "HP",
            "HP-URI-Json-String"                             => "HP",
            "HP-URI-String"                                  => "HP",
            "HP-User-Role"                                   => "HP",
            "HP-VC-groups"                                   => "HP",
            "HS20-AP-Version"                                => "WiFi-Alliance",
            "HS20-Deauthentication-Request"                  => "WiFi-Alliance",
            "HS20-Mobile-Device-Version"                     => "WiFi-Alliance",
            "HS20-Roaming-Consortium"                        => "WiFi-Alliance",
            "HS20-Session-Information-URL"                   => "WiFi-Alliance",
            "HS20-Subscription-Remediation-Needed"           => "WiFi-Alliance",
            "HTTP-Redirect-Profile-Name"                     => "Ericsson-AB",
            "HTTP-Redirect-URL"                              => "Ericsson-AB",
            "Huawei-Access-Num"                              => "Huawei",
            "Huawei-Access-Service"                          => "Huawei",
            "Huawei-Account-Info"                            => "Huawei",
            "Huawei-Accounting-Level"                        => "Huawei",
            "Huawei-Acct-Connection-Time"                    => "Huawei",
            "Huawei-Acct-IPv6-Input-Gigawords"               => "Huawei",
            "Huawei-Acct-IPv6-Input-Octets"                  => "Huawei",
            "Huawei-Acct-IPv6-Input-Packets"                 => "Huawei",
            "Huawei-Acct-IPv6-Output-Gigawords"              => "Huawei",
            "Huawei-Acct-IPv6-Output-Octets"                 => "Huawei",
            "Huawei-Acct-IPv6-Output-Packets"                => "Huawei",
            "Huawei-Acct-Packet-Type"                        => "Huawei",
            "Huawei-Acct-Terminate-Subcause"                 => "Huawei",
            "Huawei-Acct-Update-Address"                     => "Huawei",
            "Huawei-ACS-Url"                                 => "Huawei",
            "Huawei-ANCP-Profile"                            => "Huawei",
            "Huawei-Application-Scene"                       => "Huawei",
            "Huawei-Application-Type"                        => "Huawei",
            "Huawei-Auth-Type"                               => "Huawei",
            "Huawei-AVpair"                                  => "Huawei",
            "Huawei-Call-Reference"                          => "Huawei",
            "Huawei-Codec-Type"                              => "Huawei",
            "Huawei-Command"                                 => "Huawei",
            "Huawei-Command-Mode"                            => "Huawei",
            "Huawei-Connect-ID"                              => "Huawei",
            "Huawei-Control-Identifier"                      => "Huawei",
            "Huawei-Data-Filter"                             => "Huawei",
            "Huawei-Delegated-IPv6-Prefix-Pool"              => "Huawei",
            "Huawei-Destnation-IP-Addr"                      => "Huawei",
            "Huawei-Destnation-Volume"                       => "Huawei",
            "Huawei-DHCP-Option"                             => "Huawei",
            "Huawei-DHCP-Server-IP"                          => "Huawei",
            "Huawei-DHCPv4-Option121"                        => "Huawei",
            "Huawei-DHCPv4-Option43"                         => "Huawei",
            "Huawei-DHCPv6-Option37"                         => "Huawei",
            "Huawei-DHCPv6-Option38"                         => "Huawei",
            "Huawei-DNS-Server-IPv6-address"                 => "Huawei",
            "Huawei-Domain-Name"                             => "Huawei",
            "Huawei-Down-Priority"                           => "Huawei",
            "Huawei-Down-QOS-Profile-Name"                   => "Huawei",
            "Huawei-DPI-Policy-Name"                         => "Huawei",
            "Huawei-DPSK-Info"                               => "Huawei",
            "Huawei-DS-Lite-Tunnel-Name"                     => "Huawei",
            "Huawei-Dst-GK-ipaddr"                           => "Huawei",
            "Huawei-Dst-GW-ipaddr"                           => "Huawei",
            "Huawei-Error-Reason"                            => "Huawei",
            "Huawei-Exec-Privilege"                          => "Huawei",
            "Huawei-Ext-Specific"                            => "Huawei",
            "Huawei-Flow-Id"                                 => "Huawei",
            "Huawei-Flow-Info"                               => "Huawei",
            "Huawei-Framed-IPv6-Address"                     => "Huawei",
            "Huawei-Framed-Pool"                             => "Huawei",
            "Huawei-Framed-Pool-Group"                       => "Huawei",
            "Huawei-FTP-Directory"                           => "Huawei",
            "Huawei-Gateway-Address"                         => "Huawei",
            "Huawei-GGSN-Vendor"                             => "Huawei",
            "Huawei-GGSN-Version"                            => "Huawei",
            "Huawei-HTTP-Redirect-URL"                       => "Huawei",
            "Huawei-IGMP-Enable"                             => "Huawei",
            "Huawei-In-Kb-After-T-Switch"                    => "Huawei",
            "Huawei-In-Kb-Before-T-Switch"                   => "Huawei",
            "Huawei-In-Pkt-After-T-Switch"                   => "Huawei",
            "Huawei-In-Pkt-Before-T-Switch"                  => "Huawei",
            "Huawei-Indication-Flag"                         => "Huawei",
            "Huawei-Input-Average-Rate"                      => "Huawei",
            "Huawei-Input-Burst-Size"                        => "Huawei",
            "Huawei-Input-Peak-Burst-Size"                   => "Huawei",
            "Huawei-Input-Peak-Rate"                         => "Huawei",
            "Huawei-IP-Address"                              => "Huawei",
            "Huawei-IPHost-Addr"                             => "Huawei",
            "Huawei-IPv6-Address-Lease"                      => "Huawei",
            "Huawei-IPv6-Policy-Route"                       => "Huawei",
            "Huawei-IPv6-Prefix-Lease"                       => "Huawei",
            "Huawei-ISP-ID"                                  => "Huawei",
            "Huawei-L2TP-Terminate-Cause"                    => "Huawei",
            "Huawei-Layer4-Session-Limit"                    => "Huawei",
            "Huawei-Lease-Time"                              => "Huawei",
            "Huawei-LI-ID"                                   => "Huawei",
            "Huawei-LI-Md-Address"                           => "Huawei",
            "Huawei-LI-Md-Port"                              => "Huawei",
            "Huawei-LI-Md-VpnInstance"                       => "Huawei",
            "Huawei-Loopback-Address"                        => "Huawei",
            "Huawei-Max-List-Num"                            => "Huawei",
            "Huawei-Max-Users-Per-Logic-Port"                => "Huawei",
            "Huawei-MNG-IPv6"                                => "Huawei",
            "Huawei-MS-Maximum-MAC-Study-Number"             => "Huawei",
            "Huawei-Multi-Account-Mode"                      => "Huawei",
            "Huawei-Multicast-Profile"                       => "Huawei",
            "Huawei-Multicast-Receive-Group"                 => "Huawei",
            "Huawei-Multicast-Source-Group"                  => "Huawei",
            "Huawei-NAT-End-Port"                            => "Huawei",
            "Huawei-NAT-Policy-Name"                         => "Huawei",
            "Huawei-NAT-Port-Forwarding"                     => "Huawei",
            "Huawei-NAT-Port-Range-Update"                   => "Huawei",
            "Huawei-NAT-Public-Address"                      => "Huawei",
            "Huawei-NAT-Start-Port"                          => "Huawei",
            "Huawei-New-User-Name"                           => "Huawei",
            "Huawei-ONLY-Account-Type"                       => "Huawei",
            "Huawei-Org-GK-ipaddr"                           => "Huawei",
            "Huawei-Org-GW-ipaddr"                           => "Huawei",
            "Huawei-Original_NAS-IP_Address"                 => "Huawei",
            "Huawei-Out-Kb-After-T-Switch"                   => "Huawei",
            "Huawei-Out-Kb-Before-T-Switch"                  => "Huawei",
            "Huawei-Out-Pkt-After-T-Switch"                  => "Huawei",
            "Huawei-Out-Pkt-Before-T-Switch"                 => "Huawei",
            "Huawei-Output-Average-Rate"                     => "Huawei",
            "Huawei-Output-Burst-Size"                       => "Huawei",
            "Huawei-Output-Peak-Burst-Size"                  => "Huawei",
            "Huawei-Output-Peak-Rate"                        => "Huawei",
            "Huawei-PCP-Server-Name"                         => "Huawei",
            "Huawei-Policy-Name"                             => "Huawei",
            "huawei-Policy-Route"                            => "Huawei",
            "Huawei-Port-Mirror"                             => "Huawei",
            "Huawei-Portal-Mode"                             => "Huawei",
            "Huawei-PortalURL"                               => "Huawei",
            "Huawei-PPP-NCP-Type"                            => "Huawei",
            "Huawei-Primary-DNS"                             => "Huawei",
            "Huawei-Primary-WINS"                            => "Huawei",
            "Huawei-Priority"                                => "Huawei",
            "Huawei-Product-ID"                              => "Huawei",
            "Huawei-Provision-Code"                          => "Huawei",
            "Huawei-PSTN-Port"                               => "Huawei",
            "Huawei-Public-IP-Addr-State"                    => "Huawei",
            "Huawei-Qos-Profile-Name"                        => "Huawei",
            "Huawei-QoS-Profile-Type"                        => "Huawei",
            "Huawei-Queue-Profile"                           => "Huawei",
            "Huawei-Rebinding-Time"                          => "Huawei",
            "Huawei-Reduced-CIR"                             => "Huawei",
            "Huawei-Reduced-PIR"                             => "Huawei",
            "Huawei-Remain-Monney"                           => "Huawei",
            "Huawei-Remain-Time"                             => "Huawei",
            "Huawei-Remanent-Volume"                         => "Huawei",
            "Huawei-Renewal-Time"                            => "Huawei",
            "Huawei-Result-Code"                             => "Huawei",
            "Huawei-Secondary-DNS"                           => "Huawei",
            "Huawei-Secondary-WINS"                          => "Huawei",
            "Huawei-Service-Chg-Cmd"                         => "Huawei",
            "Huawei-Service-Info"                            => "Huawei",
            "Huawei-SIP-Server"                              => "Huawei",
            "Huawei-Startup-Stamp"                           => "Huawei",
            "Huawei-Subnet-Mask"                             => "Huawei",
            "Huawei-Tariff-Switch-Interval"                  => "Huawei",
            "Huawei-Transfer-Num"                            => "Huawei",
            "Huawei-Transfer-Station-Id"                     => "Huawei",
            "Huawei-Tunnel-Group-Name"                       => "Huawei",
            "Huawei-Tunnel-Session-Limit"                    => "Huawei",
            "Huawei-Tunnel-VPN-Instance"                     => "Huawei",
            "Huawei-Up-Priority"                             => "Huawei",
            "Huawei-User-Class"                              => "Huawei",
            "Huawei-User-Date"                               => "Huawei",
            "Huawei-User-Mac"                                => "Huawei",
            "Huawei-User-Multicast-Type"                     => "Huawei",
            "Huawei-User-Password"                           => "Huawei",
            "Huawei-User-Priority"                           => "Huawei",
            "Huawei-Version"                                 => "Huawei",
            "Huawei-Voip-Service-Type"                       => "Huawei",
            "Huawei-VPN-Instance"                            => "Huawei",
            "Huawei-VSI-Name"                                => "Huawei",
            "Huawei-VT-Name"                                 => "Huawei",
            "Huawei-Web-URL"                                 => "Huawei",
            "Huawei-Zone-Name"                               => "Huawei",
            "Idle-Timeout-Threshold"                         => "Ericsson-AB",
            "IGMP-Service-Profile-Name"                      => "Ericsson-AB",
            "incoming-req-uri"                               => "Cisco",
            "Infinera-ENM-User-Category"                     => "Infinera",
            "Infinera-User-Category"                         => "Infinera",
            "Infoblox-Group-Info"                            => "Infoblox",
            "Infoblox-Product-Name"                          => "Infoblox",
            "Infoblox-variable-1"                            => "Infoblox",
            "Infoblox-variable-2"                            => "Infoblox",
            "Infoblox-variable-3"                            => "Infoblox",
            "Infoblox-variable-4"                            => "Infoblox",
            "Infoblox-variable-5"                            => "Infoblox",
            "Infoblox-Version"                               => "Infoblox",
            "Infoblox-windows-group"                         => "Infoblox",
            "Infonet-Account-Number"                         => "infonet",
            "Infonet-Config"                                 => "infonet",
            "Infonet-LoginHost-Dest"                         => "infonet",
            "Infonet-MCS-Country"                            => "infonet",
            "Infonet-MCS-Off-Peak"                           => "infonet",
            "Infonet-MCS-Overflow"                           => "infonet",
            "Infonet-MCS-Port"                               => "infonet",
            "Infonet-MCS-Port-Count"                         => "infonet",
            "Infonet-MCS-Region"                             => "infonet",
            "Infonet-NAS-Location"                           => "infonet",
            "Infonet-Pool-Request"                           => "infonet",
            "Infonet-Proxy"                                  => "infonet",
            "Infonet-Random-IP-Pool"                         => "infonet",
            "Infonet-Realm-Type"                             => "infonet",
            "Infonet-Surcharge-Type"                         => "infonet",
            "Infonet-Tunnel-Decision-IP"                     => "infonet",
            "Infonet-Type"                                   => "infonet",
            "Initial-Modulation-Type"                        => "USR",
            "Ip-Address-Pool-Name"                           => "Ericsson-AB",
            "Ip-Host-Addr"                                   => "Ericsson-AB",
            "IP-Interface-Name"                              => "Ericsson-AB",
            "IP-TOS-Field"                                   => "Ericsson-AB",
            "IPU-IKE-Auth"                                   => "ipUnplugged",
            "IPU-IKE-Cmd"                                    => "ipUnplugged",
            "IPU-IKE-Conf-Name"                              => "ipUnplugged",
            "IPU-IKE-Local-Addr"                             => "ipUnplugged",
            "IPU-IKE-Remote-Addr"                            => "ipUnplugged",
            "IPU-MIP-Alg-Mode"                               => "ipUnplugged",
            "IPU-MIP-Alg-Type"                               => "ipUnplugged",
            "IPU-MIP-Key"                                    => "ipUnplugged",
            "IPU-MIP-Replay-Prot"                            => "ipUnplugged",
            "IPU-MIP-Spi"                                    => "ipUnplugged",
            "IPv4-Address-Release-Control"                   => "Ericsson-AB",
            "Issanni-Interface-Name"                         => "Issanni",
            "Issanni-IP-Pool-Name"                           => "Issanni",
            "Issanni-NAT-Support"                            => "Issanni",
            "Issanni-NAT-Type"                               => "Issanni",
            "Issanni-PPPoE-MOTM"                             => "Issanni",
            "Issanni-PPPoE-URL"                              => "Issanni",
            "Issanni-Pri-DNS"                                => "Issanni",
            "Issanni-Pri-NBNS"                               => "Issanni",
            "Issanni-QOS-Class"                              => "Issanni",
            "Issanni-Routing-Context"                        => "Issanni",
            "Issanni-Sec-DNS"                                => "Issanni",
            "Issanni-Sec-NBNS"                               => "Issanni",
            "Issanni-Service"                                => "Issanni",
            "Issanni-SoftFlow-Template"                      => "Issanni",
            "Issanni-Traffic-Class"                          => "Issanni",
            "Issanni-Tunnel-Name"                            => "Issanni",
            "Issanni-Tunnel-Type"                            => "Issanni",
            "ITK-Acct-Serv-IP"                               => "ITK",
            "ITK-Acct-Serv-Prot"                             => "ITK",
            "ITK-Auth-Req-Type"                              => "ITK",
            "ITK-Auth-Serv-IP"                               => "ITK",
            "ITK-Auth-Serv-Prot"                             => "ITK",
            "ITK-Banner"                                     => "ITK",
            "ITK-Channel-Binding"                            => "ITK",
            "ITK-DDI"                                        => "ITK",
            "ITK-Dest-No"                                    => "ITK",
            "ITK-Dialout-Type"                               => "ITK",
            "ITK-Filter-Rule"                                => "ITK",
            "ITK-Ftp-Auth-IP"                                => "ITK",
            "ITK-IP-Pool"                                    => "ITK",
            "ITK-ISDN-Prot"                                  => "ITK",
            "ITK-Modem-Init-String"                          => "ITK",
            "ITK-Modem-Pool-Id"                              => "ITK",
            "ITK-NAS-Name"                                   => "ITK",
            "ITK-Password-Prompt"                            => "ITK",
            "ITK-PPP-Auth-Type"                              => "ITK",
            "ITK-PPP-Client-Server-Mode"                     => "ITK",
            "ITK-PPP-Compression-Prot"                       => "ITK",
            "ITK-Prompt"                                     => "ITK",
            "ITK-Provider-Id"                                => "ITK",
            "ITK-Start-Delay"                                => "ITK",
            "ITK-Tunnel-IP"                                  => "ITK",
            "ITK-Tunnel-Prot"                                => "ITK",
            "ITK-Usergroup"                                  => "ITK",
            "ITK-Username"                                   => "ITK",
            "ITK-Username-Prompt"                            => "ITK",
            "ITK-Users-Default-Entry"                        => "ITK",
            "ITK-Users-Default-Pw"                           => "ITK",
            "ITK-Welcome-Message"                            => "ITK",
            "IWF-Session"                                    => "ADSL-Forum",
            "Juniper-Allow-Commands"                         => "Juniper",
            "Juniper-Allow-Configuration"                    => "Juniper",
            "Juniper-AV-Pair"                                => "Juniper",
            "Juniper-cell-overhead"                          => "Juniper",
            "Juniper-Configuration-Change"                   => "Juniper",
            "Juniper-CoS-Parameter"                          => "Juniper",
            "Juniper-CoS-Traffic-Control-Profile"            => "Juniper",
            "Juniper-CTP-Group"                              => "Juniper",
            "Juniper-CTPView-APP-Group"                      => "Juniper",
            "Juniper-CTPView-OS-Group"                       => "Juniper",
            "Juniper-CWA-Redirect"                           => "Juniper",
            "Juniper-Deny-Commands"                          => "Juniper",
            "Juniper-Deny-Configuration"                     => "Juniper",
            "Juniper-DHCPv4-Options"                         => "Juniper",
            "Juniper-DHCPv4-Packet-Header"                   => "Juniper",
            "Juniper-DHCPv6-Options"                         => "Juniper",
            "Juniper-DHCPv6-Packet-Header"                   => "Juniper",
            "Juniper-encapsulation-overhead"                 => "Juniper",
            "Juniper-Firewall-filter-name"                   => "Juniper",
            "Juniper-Interactive-Command"                    => "Juniper",
            "Juniper-Interface-id"                           => "Juniper",
            "Juniper-Ip-Pool-Name"                           => "Juniper",
            "Juniper-Junosspace-Profile"                     => "Juniper",
            "Juniper-Junosspace-Profiles"                    => "Juniper",
            "Juniper-Keep-Alive"                             => "Juniper",
            "Juniper-Local-Group-Name"                       => "Juniper",
            "Juniper-Local-Interface"                        => "Juniper",
            "Juniper-Local-User-Name"                        => "Juniper",
            "Juniper-Policer-Parameter"                      => "Juniper",
            "Juniper-Primary-Dns"                            => "Juniper",
            "Juniper-Primary-Wins"                           => "Juniper",
            "Juniper-rx-connect-speed"                       => "Juniper",
            "Juniper-Secondary-Dns"                          => "Juniper",
            "Juniper-Secondary-Wins"                         => "Juniper",
            "Juniper-Switching-Filter"                       => "Juniper",
            "Juniper-tx-connect-speed"                       => "Juniper",
            "Juniper-User-Permissions"                       => "Juniper",
            "Juniper-VoIP-Vlan"                              => "Juniper",
            "KarlNet-TurboCell-Name"                         => "KarlNet",
            "KarlNet-TurboCell-OpMode"                       => "KarlNet",
            "KarlNet-TurboCell-OpState"                      => "KarlNet",
            "KarlNet-TurboCell-TxRate"                       => "KarlNet",
            "Kineto-Billing-Rate-Indicator"                  => "Kineto",
            "Kineto-Hand-In-Control-Flag"                    => "Kineto",
            "Kineto-Hand-Out-Control-Flag"                   => "Kineto",
            "Kineto-Location-Key"                            => "Kineto",
            "Kineto-Service-Area-Code"                       => "Kineto",
            "Kineto-UMA-3G-Cell-Identity"                    => "Kineto",
            "Kineto-UMA-AP-Location"                         => "Kineto",
            "Kineto-UMA-AP-Radio-Identity"                   => "Kineto",
            "Kineto-UMA-AP-Service-Name"                     => "Kineto",
            "Kineto-UMA-Cell-Identity"                       => "Kineto",
            "Kineto-UMA-Classmark"                           => "Kineto",
            "Kineto-UMA-Coverage-Indicator"                  => "Kineto",
            "Kineto-UMA-Discovery-Reject-Cause"              => "Kineto",
            "Kineto-UMA-Geographical-Location"               => "Kineto",
            "Kineto-UMA-Location-Area-Identification"        => "Kineto",
            "Kineto-UMA-Location-Blacklist-Indicator"        => "Kineto",
            "Kineto-UMA-Location-Status"                     => "Kineto",
            "Kineto-UMA-MS-Radio-Identity"                   => "Kineto",
            "Kineto-UMA-Redirection-Counter"                 => "Kineto",
            "Kineto-UMA-Register-Reject-Cause"               => "Kineto",
            "Kineto-UMA-Registration-Indicators"             => "Kineto",
            "Kineto-UMA-Release-Indicator"                   => "Kineto",
            "Kineto-UMA-Required-UMA-Services"               => "Kineto",
            "Kineto-UMA-Routing-Area-Code"                   => "Kineto",
            "Kineto-UMA-RRC-State"                           => "Kineto",
            "Kineto-UMA-Service-Zone-Information"            => "Kineto",
            "Kineto-UMA-Serving-UNC-Table-Indicator"         => "Kineto",
            "Kineto-UMA-SGW-FQDN"                            => "Kineto",
            "Kineto-UMA-SGW-IP-Address"                      => "Kineto",
            "Kineto-UMA-UMA-PLMN-List"                       => "Kineto",
            "Kineto-UMA-UNC-FQDN"                            => "Kineto",
            "Kineto-UMA-UNC-IP-Address"                      => "Kineto",
            "Kineto-UMA-Utran-Cell-Identity"                 => "Kineto",
            "Kineto-UP-Client-Remote-Address"                => "Kineto",
            "Kineto-URR-Transaction-Type"                    => "Kineto",
            "KW-HNB-CELL-ACCESS-MODE"                        => "Kineto",
            "KW-HNB-CELL-ID"                                 => "Kineto",
            "KW-HNB-CSG-ID"                                  => "Kineto",
            "KW-HNB-IDENTITY"                                => "Kineto",
            "KW-HNB-LAC"                                     => "Kineto",
            "KW-HNB-LOC-INFO-ALTITUDE-Direction"             => "Kineto",
            "KW-HNB-LOC-INFO-GEO-COORDINATES"                => "Kineto",
            "KW-HNB-LOC-INFO-GERAN-CELL-ID"                  => "Kineto",
            "KW-HNB-LOC-INFO-IP-ADDRESS"                     => "Kineto",
            "KW-HNB-LOC-INFO-MACRO-COVERAGE-IND"             => "Kineto",
            "KW-HNB-LOC-INFO-UTRAN-CELL-ID"                  => "Kineto",
            "KW-HNB-LOCATION-AREA-IND"                       => "Kineto",
            "KW-HNB-LOCATION-BLACKLIST-IND"                  => "Kineto",
            "KW-HNB-PLMN-ID"                                 => "Kineto",
            "KW-HNB-RAC"                                     => "Kineto",
            "KW-HNB-REMOTE-ADDRESS"                          => "Kineto",
            "KW-HNB-SAC"                                     => "Kineto",
            "KW-IUH-BILLING-RATE-INDICATOR"                  => "Kineto",
            "KW-IUH-MESSAGE-TYPE"                            => "Kineto",
            "KW-REGISTRATION-REJECT-CAUSE"                   => "Kineto",
            "KW-UE-Capabilities"                             => "Kineto",
            "KW-UE-MEMBERSHIP-STATUS"                        => "Kineto",
            "LAC-Port"                                       => "Ericsson-AB",
            "LAC-Port-Type"                                  => "Ericsson-AB",
            "LAC-Real-Port"                                  => "Ericsson-AB",
            "LAC-Real-Port-Type"                             => "Ericsson-AB",
            "Lantronix-User-Attributes"                      => "Lantronix",
            "LCS-Access-Rights"                              => "Lancom",
            "LCS-Account-End"                                => "Lancom",
            "LCS-Advertisement-Interval"                     => "Lancom",
            "LCS-Advertisement-URL"                          => "Lancom",
            "LCS-Comment"                                    => "Lancom",
            "LCS-DNS-Server-IPv4-Address"                    => "Lancom",
            "LCS-Function-Rights"                            => "Lancom",
            "LCS-IKEv2-DNS-Domain"                           => "Lancom",
            "LCS-IKEv2-IPv4-Route"                           => "Lancom",
            "LCS-IKEv2-IPv6-Route"                           => "Lancom",
            "LCS-IKEv2-Local-Password"                       => "Lancom",
            "LCS-IKEv2-Remote-Password"                      => "Lancom",
            "LCS-Load-Balancer"                              => "Lancom",
            "LCS-Mac-Address"                                => "Lancom",
            "LCS-Orig-NAS-Identifier"                        => "Lancom",
            "LCS-Orig-NAS-IP-Address"                        => "Lancom",
            "LCS-Orig-NAS-IPv6-Address"                      => "Lancom",
            "LCS-PbSpotUserName"                             => "Lancom",
            "LCS-Redirection-URL"                            => "Lancom",
            "LCS-Routing-Tag"                                => "Lancom",
            "LCS-RxRateLimit"                                => "Lancom",
            "LCS-Traffic-Limit"                              => "Lancom",
            "LCS-Traffic-Limit-Gigawords"                    => "Lancom",
            "LCS-TxRateLimit"                                => "Lancom",
            "LCS-VPN-IPv4-Rule"                              => "Lancom",
            "LCS-VPN-IPv6-Rule"                              => "Lancom",
            "LCS-WPA-Passphrase"                             => "Lancom",
            "LE-Admin-Group"                                 => "Livingston",
            "LE-Advice-of-Charge"                            => "Livingston",
            "LE-Connect-Detail"                              => "Livingston",
            "LE-IP-Gateway"                                  => "Livingston",
            "LE-IP-Pool"                                     => "Livingston",
            "LE-IPSec-Active-Profile"                        => "Livingston",
            "LE-IPSec-Deny-Action"                           => "Livingston",
            "LE-IPSec-Log-Options"                           => "Livingston",
            "LE-IPSec-Outsource-Profile"                     => "Livingston",
            "LE-IPSec-Passive-Profile"                       => "Livingston",
            "LE-Modem-Info"                                  => "Livingston",
            "LE-Multicast-Client"                            => "Livingston",
            "LE-NAT-Inmap"                                   => "Livingston",
            "LE-NAT-Log-Options"                             => "Livingston",
            "LE-NAT-Other-Session-Timeout"                   => "Livingston",
            "LE-NAT-Outmap"                                  => "Livingston",
            "LE-NAT-Outsource-Inmap"                         => "Livingston",
            "LE-NAT-Outsource-Outmap"                        => "Livingston",
            "LE-NAT-Sess-Dir-Fail-Action"                    => "Livingston",
            "LE-NAT-TCP-Session-Timeout"                     => "Livingston",
            "LE-Terminate-Detail"                            => "Livingston",
            "LI-Action"                                      => "Ericsson-AB",
            "LI-Id"                                          => "Ericsson-AB",
            "LI-Md-Address"                                  => "Ericsson-AB",
            "LI-Md-Port"                                     => "Ericsson-AB",
            "LI-Profile"                                     => "Ericsson-AB",
            "Local-Seq-Number"                         => "VerizonWireless",
            "Local-Web-Acct-Duration"                  => "Local-Web",
            "Local-Web-Acct-Interim-Rx-Bytes"          => "Local-Web",
            "Local-Web-Acct-Interim-Rx-Gigawords"      => "Local-Web",
            "Local-Web-Acct-Interim-Rx-Mgmt"           => "Local-Web",
            "Local-Web-Acct-Interim-Tx-Bytes"          => "Local-Web",
            "Local-Web-Acct-Interim-Tx-Gigawords"      => "Local-Web",
            "Local-Web-Acct-Interim-Tx-Mgmt"           => "Local-Web",
            "Local-Web-Acct-Rx-Mgmt"                   => "Local-Web",
            "Local-Web-Acct-Time"                      => "Local-Web",
            "Local-Web-Acct-Tx-Mgmt"                   => "Local-Web",
            "Local-Web-Border-Router"                  => "Local-Web",
            "Local-Web-Client-Ip"                      => "Local-Web",
            "Local-Web-Reauth-Counter"                 => "Local-Web",
            "Local-Web-Rx-Limit"                       => "Local-Web",
            "Local-Web-Tx-Limit"                       => "Local-Web",
            "Lucent-Absolute-Time"                     => "Lucent",
            "Lucent-Access-Intercept-LEA"              => "Lucent",
            "Lucent-Access-Intercept-Log"              => "Lucent",
            "Lucent-Add-Seconds"                       => "Lucent",
            "Lucent-Appletalk-Peer-Mode"               => "Lucent",
            "Lucent-Appletalk-Route"                   => "Lucent",
            "Lucent-Ara-PW"                            => "Lucent",
            "Lucent-Assign-IP-Client"                  => "Lucent",
            "Lucent-Assign-IP-Global-Pool"             => "Lucent",
            "Lucent-Assign-IP-Pool"                    => "Lucent",
            "Lucent-Assign-IP-Server"                  => "Lucent",
            "Lucent-AT-Answer-String"                  => "Lucent",
            "Lucent-ATM-Circuit-Name"                  => "Lucent",
            "Lucent-ATM-Connect-Group"                 => "Lucent",
            "Lucent-ATM-Connect-Vci"                   => "Lucent",
            "Lucent-ATM-Connect-Vpi"                   => "Lucent",
            "Lucent-ATM-Direct"                        => "Lucent",
            "Lucent-ATM-Direct-Profile"                => "Lucent",
            "Lucent-ATM-Fault-Management"              => "Lucent",
            "Lucent-ATM-Group"                         => "Lucent",
            "Lucent-ATM-Loopback-Cell-Loss"            => "Lucent",
            "Lucent-ATM-Vci"                           => "Lucent",
            "Lucent-ATM-Vpi"                           => "Lucent",
            "Lucent-Auth-Delay"                        => "Lucent",
            "Lucent-Auth-Type"                         => "Lucent",
            "Lucent-Authen-Alias"                      => "Lucent",
            "Lucent-Backup"                            => "Lucent",
            "Lucent-BACP-Enable"                       => "Lucent",
            "Lucent-Base-Channel-Count"                => "Lucent",
            "Lucent-Bi-Directional-Auth"               => "Lucent",
            "Lucent-Billing-Number"                    => "Lucent",
            "Lucent-BIR-Bridge-Group"                  => "Lucent",
            "Lucent-BIR-Enable"                        => "Lucent",
            "Lucent-BIR-Proxy"                         => "Lucent",
            "Lucent-Bridge"                            => "Lucent",
            "Lucent-Bridge-Address"                    => "Lucent",
            "Lucent-Bridge-Non-PPPoE"                  => "Lucent",
            "Lucent-Cache-Refresh"                     => "Lucent",
            "Lucent-Cache-Time"                        => "Lucent",
            "Lucent-Call-Attempt-Limit"                => "Lucent",
            "Lucent-Call-Block-Duration"               => "Lucent",
            "Lucent-Call-By-Call"                      => "Lucent",
            "Lucent-Call-Direction"                    => "Lucent",
            "Lucent-Call-Filter"                       => "Lucent",
            "Lucent-Call-Type"                         => "Lucent",
            "Lucent-Callback"                          => "Lucent",
            "Lucent-Callback-Delay"                    => "Lucent",
            "Lucent-Calling-Id-Numbering-Plan"         => "Lucent",
            "Lucent-Calling-Id-Presentation"           => "Lucent",
            "Lucent-Calling-Id-Screening"              => "Lucent",
            "Lucent-Calling-Id-Type-Of-Number"         => "Lucent",
            "Lucent-Calling-Subaddress"                => "Lucent",
            "Lucent-CBCP-Delay"                        => "Lucent",
            "Lucent-CBCP-Enable"                       => "Lucent",
            "Lucent-CBCP-Mode"                         => "Lucent",
            "Lucent-CBCP-Trunk-Group"                  => "Lucent",
            "Lucent-CIR-Timer"                         => "Lucent",
            "Lucent-Ckt-Type"                          => "Lucent",
            "Lucent-Client-Assign-DNS"                 => "Lucent",
            "Lucent-Client-Assign-WINS"                => "Lucent",
            "Lucent-Client-Gateway"                    => "Lucent",
            "Lucent-Client-Primary-DNS"                => "Lucent",
            "Lucent-Client-Primary-WINS"               => "Lucent",
            "Lucent-Client-Secondary-DNS"              => "Lucent",
            "Lucent-Client-Secondary-WINS"             => "Lucent",
            "Lucent-Compression-Protocol"              => "Lucent",
            "Lucent-Configured-Rate-Dn-Max"            => "Lucent",
            "Lucent-Configured-Rate-Dn-Min"            => "Lucent",
            "Lucent-Configured-Rate-Up-Max"            => "Lucent",
            "Lucent-Configured-Rate-Up-Min"            => "Lucent",
            "Lucent-Connect-Progress"                  => "Lucent",
            "Lucent-Connection-Time"                   => "Lucent",
            "Lucent-Cumulative-Hold-Time"              => "Lucent",
            "Lucent-Current-Line-Quality"              => "Lucent",
            "Lucent-Current-Recv-Level"                => "Lucent",
            "Lucent-Current-SNR"                       => "Lucent",
            "Lucent-Current-Xmit-Level"                => "Lucent",
            "Lucent-Data-Filter"                       => "Lucent",
            "Lucent-Data-Rate"                         => "Lucent",
            "Lucent-Data-Svc"                          => "Lucent",
            "Lucent-DBA-Monitor"                       => "Lucent",
            "Lucent-Dec-Channel-Count"                 => "Lucent",
            "Lucent-Destination-NAS-Port"              => "Lucent",
            "Lucent-DHCP-Maximum-Leases"               => "Lucent",
            "Lucent-DHCP-Pool-Number"                  => "Lucent",
            "Lucent-DHCP-Reply"                        => "Lucent",
            "Lucent-Dial-Number"                       => "Lucent",
            "Lucent-Dialed-Number"                     => "Lucent",
            "Lucent-Dialout-Allowed"                   => "Lucent",
            "Lucent-Disconnect-Cause"                  => "Lucent",
            "Lucent-Dropped-Octets"                    => "Lucent",
            "Lucent-Dropped-Packets"                   => "Lucent",
            "Lucent-Ds3-CCVs"                          => "Lucent",
            "Lucent-Ds3-CESs"                          => "Lucent",
            "Lucent-Ds3-CSESs"                         => "Lucent",
            "Lucent-Ds3-F-Bit-Err"                     => "Lucent",
            "Lucent-Ds3-LCVs"                          => "Lucent",
            "Lucent-Ds3-LESs"                          => "Lucent",
            "Lucent-Ds3-P-Bit-Err"                     => "Lucent",
            "Lucent-Ds3-PCVs"                          => "Lucent",
            "Lucent-Ds3-PESs"                          => "Lucent",
            "Lucent-Ds3-PSESs"                         => "Lucent",
            "Lucent-Ds3-SEFs"                          => "Lucent",
            "Lucent-Ds3-UASs"                          => "Lucent",
            "Lucent-Dsl-Atuc-Chan-Corrected-Blks"      => "Lucent",
            "Lucent-Dsl-Atuc-Chan-Recd-Blks"           => "Lucent",
            "Lucent-Dsl-Atuc-Chan-Uncorrect-Blks"      => "Lucent",
            "Lucent-Dsl-Atuc-Chan-Xmit-Blks"           => "Lucent",
            "Lucent-Dsl-Atuc-Curr-Atn-Dn"              => "Lucent",
            "Lucent-Dsl-Atuc-Curr-Atn-Up"              => "Lucent",
            "Lucent-Dsl-Atuc-Curr-Attainable-Rate-Dn"  => "Lucent",
            "Lucent-Dsl-Atuc-Curr-Attainable-Rate-Up"  => "Lucent",
            "Lucent-Dsl-Atuc-Curr-Output-Pwr-Dn"       => "Lucent",
            "Lucent-Dsl-Atuc-Curr-Output-Pwr-Up"       => "Lucent",
            "Lucent-Dsl-Atuc-Curr-Snr-Mgn-D"           => "Lucent",
            "Lucent-Dsl-Atuc-Curr-Snr-Mgn-Up"          => "Lucent",
            "Lucent-Dsl-Atuc-Perf-ESs"                 => "Lucent",
            "Lucent-Dsl-Atuc-Perf-Inits"               => "Lucent",
            "Lucent-Dsl-Atuc-Perf-Lofs"                => "Lucent",
            "Lucent-Dsl-Atuc-Perf-Lols"                => "Lucent",
            "Lucent-Dsl-Atuc-Perf-Loss"                => "Lucent",
            "Lucent-Dsl-Atuc-Perf-Lprs"                => "Lucent",
            "Lucent-Dsl-Atuc-PS-Failed-Fast-Retrains"  => "Lucent",
            "Lucent-Dsl-Atuc-PS-Fast-Retrains"         => "Lucent",
            "Lucent-Dsl-CIR-Recv-Limit"                => "Lucent",
            "Lucent-Dsl-CIR-Xmit-Limit"                => "Lucent",
            "Lucent-Dsl-Code-Violations"               => "Lucent",
            "Lucent-Dsl-Curr-Dn-Rate"                  => "Lucent",
            "Lucent-Dsl-Curr-Up-Rate"                  => "Lucent",
            "Lucent-Dsl-Downstream-Limit"              => "Lucent",
            "Lucent-Dsl-If-Index"                      => "Lucent",
            "Lucent-Dsl-Oper-Status"                   => "Lucent",
            "Lucent-Dsl-Physical-Channel"              => "Lucent",
            "Lucent-Dsl-Physical-Line"                 => "Lucent",
            "Lucent-Dsl-Physical-Slot"                 => "Lucent",
            "Lucent-Dsl-Rate-Mode"                     => "Lucent",
            "Lucent-Dsl-Rate-Type"                     => "Lucent",
            "Lucent-Dsl-Related-If-Index"              => "Lucent",
            "Lucent-Dsl-Related-Port"                  => "Lucent",
            "Lucent-Dsl-Related-Slot"                  => "Lucent",
            "Lucent-Dsl-Sparing-Role"                  => "Lucent",
            "Lucent-Dsl-Upstream-Limit"                => "Lucent",
            "Lucent-Egress-Enabled"                    => "Lucent",
            "Lucent-Endpoint-Disc"                     => "Lucent",
            "Lucent-Error-Correction-Protocol"         => "Lucent",
            "Lucent-Event-Type"                        => "Lucent",
            "Lucent-Expect-Callback"                   => "Lucent",
            "Lucent-FCP-Parameter"                     => "Lucent",
            "Lucent-Filter"                            => "Lucent",
            "Lucent-Filter-Required"                   => "Lucent",
            "Lucent-First-Dest"                        => "Lucent",
            "Lucent-First-Level-User"                  => "Lucent",
            "Lucent-Force-56"                          => "Lucent",
            "Lucent-FR-08-Mode"                        => "Lucent",
            "Lucent-FR-Circuit-Name"                   => "Lucent",
            "Lucent-FR-DCE-N392"                       => "Lucent",
            "Lucent-FR-DCE-N393"                       => "Lucent",
            "Lucent-FR-Direct"                         => "Lucent",
            "Lucent-FR-Direct-DLCI"                    => "Lucent",
            "Lucent-FR-Direct-Profile"                 => "Lucent",
            "Lucent-FR-DLCI"                           => "Lucent",
            "Lucent-FR-DTE-N392"                       => "Lucent",
            "Lucent-FR-DTE-N393"                       => "Lucent",
            "Lucent-FR-Link-Mgt"                       => "Lucent",
            "Lucent-FR-Link-Status-DLCI"               => "Lucent",
            "Lucent-FR-LinkUp"                         => "Lucent",
            "Lucent-FR-N391"                           => "Lucent",
            "Lucent-FR-Nailed-Grp"                     => "Lucent",
            "Lucent-FR-Profile-Name"                   => "Lucent",
            "Lucent-FR-SVC-Addr"                       => "Lucent",
            "Lucent-FR-T391"                           => "Lucent",
            "Lucent-FR-T392"                           => "Lucent",
            "Lucent-FR-Type"                           => "Lucent",
            "Lucent-Fr05-Enabled"                      => "Lucent",
            "Lucent-Fr05-Traffic-Shaper"               => "Lucent",
            "Lucent-Fr05-Vci"                          => "Lucent",
            "Lucent-Fr05-Vpi"                          => "Lucent",
            "Lucent-FT1-Caller"                        => "Lucent",
            "Lucent-Global-Call-Id"                    => "Lucent",
            "Lucent-Group"                             => "Lucent",
            "Lucent-H323-Conference-Id"                => "Lucent",
            "Lucent-H323-Destination-NAS-ID"           => "Lucent",
            "Lucent-H323-Dialed-Time"                  => "Lucent",
            "Lucent-H323-Gatekeeper"                   => "Lucent",
            "Lucent-Handle-IPX"                        => "Lucent",
            "Lucent-History-Weigh-Type"                => "Lucent",
            "Lucent-Home-Agent-IP-Addr"                => "Lucent",
            "Lucent-Home-Agent-Password"               => "Lucent",
            "Lucent-Home-Agent-UDP-Port"               => "Lucent",
            "Lucent-Home-Network-Name"                 => "Lucent",
            "Lucent-Host-Info"                         => "Lucent",
            "Lucent-Http-Redirect-Port"                => "Lucent",
            "Lucent-Http-Redirect-URL"                 => "Lucent",
            "Lucent-Idle-Limit"                        => "Lucent",
            "Lucent-IF-Netmask"                        => "Lucent",
            "Lucent-Inc-Channel-Count"                 => "Lucent",
            "Lucent-Inter-Arrival-Jitter"              => "Lucent",
            "Lucent-IP-Direct"                         => "Lucent",
            "Lucent-IP-DSCP"                           => "Lucent",
            "Lucent-IP-OUTGOING-DSCP"                  => "Lucent",
            "Lucent-IP-OUTGOING-TOS"                   => "Lucent",
            "Lucent-IP-OUTGOING-TOS-Precedence"        => "Lucent",
            "Lucent-IP-Pool-Chaining"                  => "Lucent",
            "Lucent-IP-Pool-Definition"                => "Lucent",
            "Lucent-IP-Source-If"                      => "Lucent",
            "Lucent-IP-TOS"                            => "Lucent",
            "Lucent-IP-TOS-Apply-To"                   => "Lucent",
            "Lucent-IP-TOS-Precedence"                 => "Lucent",
            "Lucent-IPSEC-Profile"                     => "Lucent",
            "Lucent-IPX-Alias"                         => "Lucent",
            "Lucent-IPX-Header-Compression"            => "Lucent",
            "Lucent-IPX-Node-Addr"                     => "Lucent",
            "Lucent-IPX-Peer-Mode"                     => "Lucent",
            "Lucent-IPX-Route"                         => "Lucent",
            "Lucent-L2TP-DCI-Direction"                => "Lucent",
            "Lucent-L2TP-DCI-Disconnect-Code"          => "Lucent",
            "Lucent-L2TP-DCI-Message"                  => "Lucent",
            "Lucent-L2TP-DCI-Protocol-Number"          => "Lucent",
            "Lucent-L2TP-Disconnect-Scenario"          => "Lucent",
            "Lucent-L2TP-Peer-Connect-Progress"        => "Lucent",
            "Lucent-L2TP-Peer-Disconnect-Cause"        => "Lucent",
            "Lucent-L2TP-Q931-Advisory-Message"        => "Lucent",
            "Lucent-L2TP-Q931-Cause-Code"              => "Lucent",
            "Lucent-L2TP-Q931-Cause-Message"           => "Lucent",
            "Lucent-L2TP-RC-Error-Code"                => "Lucent",
            "Lucent-L2TP-RC-Error-Message"             => "Lucent",
            "Lucent-L2TP-RC-Result-Code"               => "Lucent",
            "Lucent-LCP-Keepalive-Missed-Limit"        => "Lucent",
            "Lucent-LCP-Keepalive-Period"              => "Lucent",
            "Lucent-Line-Type"                         => "Lucent",
            "Lucent-Link-Compression"                  => "Lucent",
            "Lucent-Local-Retrain-Requested"           => "Lucent",
            "Lucent-Max-Recv-Rate"                     => "Lucent",
            "Lucent-Max-RTP-Delay"                     => "Lucent",
            "Lucent-Max-Shared-Users"                  => "Lucent",
            "Lucent-Max-SNR"                           => "Lucent",
            "Lucent-Max-Xmit-Rate"                     => "Lucent",
            "Lucent-Maximum-Call-Duration"             => "Lucent",
            "Lucent-Maximum-Channels"                  => "Lucent",
            "Lucent-Maximum-Time"                      => "Lucent",
            "Lucent-Menu-Item"                         => "Lucent",
            "Lucent-Menu-Selector"                     => "Lucent",
            "Lucent-Metric"                            => "Lucent",
            "Lucent-Min-Recv-Rate"                     => "Lucent",
            "Lucent-Min-SNR"                           => "Lucent",
            "Lucent-Min-Xmit-Rate"                     => "Lucent",
            "Lucent-Minimum-Channels"                  => "Lucent",
            "Lucent-Modem-Disconnect-Reason"           => "Lucent",
            "Lucent-Modem-Modulation"                  => "Lucent",
            "Lucent-Modem-PortNo"                      => "Lucent",
            "Lucent-Modem-ShelfNo"                     => "Lucent",
            "Lucent-Modem-SlotNo"                      => "Lucent",
            "Lucent-Modulation"                        => "Lucent",
            "Lucent-MOH-Timeout"                       => "Lucent",
            "Lucent-MPP-Idle-Percent"                  => "Lucent",
            "Lucent-MTU"                               => "Lucent",
            "Lucent-Multi-Packet-Separator"            => "Lucent",
            "Lucent-Multicast-Client"                  => "Lucent",
            "Lucent-Multicast-Filter-Active"           => "Lucent",
            "Lucent-Multicast-Filter-Address"          => "Lucent",
            "Lucent-Multicast-GLeave-Delay"            => "Lucent",
            "Lucent-Multicast-Max-Groups"              => "Lucent",
            "Lucent-Multicast-Rate-Limit"              => "Lucent",
            "Lucent-Multicast-Service-Active"          => "Lucent",
            "Lucent-Multicast-Service-Filter-Type"     => "Lucent",
            "Lucent-Multicast-Service-Name"            => "Lucent",
            "Lucent-Multicast-Service-Profile-Name"    => "Lucent",
            "Lucent-Multicast-Service-Snmp-Trap"       => "Lucent",
            "Lucent-Multilink-ID"                      => "Lucent",
            "Lucent-NAS-Port-Format"                   => "Lucent",
            "Lucent-Netware-timeout"                   => "Lucent",
            "Lucent-No-High-Prio-Pkt-Duratio"          => "Lucent",
            "Lucent-Num-In-Multilink"                  => "Lucent",
            "Lucent-Num-Moh-Sessions"                  => "Lucent",
            "Lucent-Number-Sessions"                   => "Lucent",
            "Lucent-Numbering-Plan-ID"                 => "Lucent",
            "Lucent-Owner-IP-Addr"                     => "Lucent",
            "Lucent-Packet-Classification"             => "Lucent",
            "Lucent-Port-Redir-Portnum"                => "Lucent",
            "Lucent-Port-Redir-Protocol"               => "Lucent",
            "Lucent-Port-Redir-Server"                 => "Lucent",
            "Lucent-PPP-Address"                       => "Lucent",
            "Lucent-PPP-Async-Map"                     => "Lucent",
            "Lucent-PPP-Circuit"                       => "Lucent",
            "Lucent-PPP-Circuit-Name"                  => "Lucent",
            "Lucent-PPP-VJ-1172"                       => "Lucent",
            "Lucent-PPP-VJ-Slot-Comp"                  => "Lucent",
            "Lucent-PPPoE-Enable"                      => "Lucent",
            "Lucent-Pre-Input-Octets"                  => "Lucent",
            "Lucent-Pre-Input-Packets"                 => "Lucent",
            "Lucent-Pre-Output-Octets"                 => "Lucent",
            "Lucent-Pre-Output-Packets"                => "Lucent",
            "Lucent-Preempt-Limit"                     => "Lucent",
            "Lucent-PreSession-Time"                   => "Lucent",
            "Lucent-PRI-Number-Type"                   => "Lucent",
            "Lucent-Primary-Home-Agent"                => "Lucent",
            "Lucent-Priority-For-PPP"                  => "Lucent",
            "Lucent-Private-Route"                     => "Lucent",
            "Lucent-Private-Route-Required"            => "Lucent",
            "Lucent-Private-Route-Table-ID"            => "Lucent",
            "Lucent-PW-Lifetime"                       => "Lucent",
            "Lucent-PW-Warntime"                       => "Lucent",
            "Lucent-QOS-Downstream"                    => "Lucent",
            "Lucent-QOS-Upstream"                      => "Lucent",
            "Lucent-QuickConnect-Attempted"            => "Lucent",
            "Lucent-Receive-Secret"                    => "Lucent",
            "Lucent-Recv-Name"                         => "Lucent",
            "Lucent-Recv-Symbol-Rate"                  => "Lucent",
            "Lucent-Redirect-Number"                   => "Lucent",
            "Lucent-Remote-Addr"                       => "Lucent",
            "Lucent-Remote-FW"                         => "Lucent",
            "Lucent-Remote-Retrain-Requested"          => "Lucent",
            "Lucent-Remove-Seconds"                    => "Lucent",
            "Lucent-Require-Auth"                      => "Lucent",
            "Lucent-Retrain-Reason"                    => "Lucent",
            "Lucent-Reverse-Path-Check"                => "Lucent",
            "Lucent-Route-Appletalk"                   => "Lucent",
            "Lucent-Route-IP"                          => "Lucent",
            "Lucent-Route-IPX"                         => "Lucent",
            "Lucent-Route-Preference"                  => "Lucent",
            "Lucent-Rtp-Local-Bytes-Sent"              => "Lucent",
            "Lucent-Rtp-Local-Delay-Maximum"           => "Lucent",
            "Lucent-Rtp-Local-Delay-Mean"              => "Lucent",
            "Lucent-Rtp-Local-Delay-Minimum"           => "Lucent",
            "Lucent-Rtp-Local-Delay-Variance"          => "Lucent",
            "Lucent-Rtp-Local-Jitter-Maximum"          => "Lucent",
            "Lucent-Rtp-Local-Jitter-Mean"             => "Lucent",
            "Lucent-Rtp-Local-Jitter-Minimum"          => "Lucent",
            "Lucent-Rtp-Local-Jitter-Variance"         => "Lucent",
            "Lucent-Rtp-Local-Number-Of-Samples"       => "Lucent",
            "Lucent-Rtp-Local-Packets-Late"            => "Lucent",
            "Lucent-Rtp-Local-Packets-Lost"            => "Lucent",
            "Lucent-Rtp-Local-Packets-Sent"            => "Lucent",
            "Lucent-Rtp-Local-Silence-Percent"         => "Lucent",
            "Lucent-RTP-Port-Range"                    => "Lucent",
            "Lucent-Rtp-Remote-Bytes-Sent"             => "Lucent",
            "Lucent-Rtp-Remote-Delay-Maximum"          => "Lucent",
            "Lucent-Rtp-Remote-Delay-Mean"             => "Lucent",
            "Lucent-Rtp-Remote-Delay-Minimum"          => "Lucent",
            "Lucent-Rtp-Remote-Delay-Variance"         => "Lucent",
            "Lucent-Rtp-Remote-Jitter-Maximum"         => "Lucent",
            "Lucent-Rtp-Remote-Jitter-Mean"            => "Lucent",
            "Lucent-Rtp-Remote-Jitter-Minimum"         => "Lucent",
            "Lucent-Rtp-Remote-Jitter-Variance"        => "Lucent",
            "Lucent-Rtp-Remote-Number-Of-Samples"      => "Lucent",
            "Lucent-Rtp-Remote-Packets-Late"           => "Lucent",
            "Lucent-Rtp-Remote-Packets-Lost"           => "Lucent",
            "Lucent-Rtp-Remote-Packets-Sent"           => "Lucent",
            "Lucent-Rtp-Remote-Silence-Percent"        => "Lucent",
            "Lucent-Secondary-Home-Agent"              => "Lucent",
            "Lucent-Seconds-Of-History"                => "Lucent",
            "Lucent-Send-Auth"                         => "Lucent",
            "Lucent-Send-Passwd"                       => "Lucent",
            "Lucent-Send-Secret"                       => "Lucent",
            "Lucent-Service-Type"                      => "Lucent",
            "Lucent-Session-Svr-Key"                   => "Lucent",
            "Lucent-Session-Type"                      => "Lucent",
            "Lucent-Shared-Profile-Enable"             => "Lucent",
            "Lucent-Sonet-Line-CVs-Far"                => "Lucent",
            "Lucent-Sonet-Line-CVs-Near"               => "Lucent",
            "Lucent-Sonet-Line-ESs-Far"                => "Lucent",
            "Lucent-Sonet-Line-ESs-Near"               => "Lucent",
            "Lucent-Sonet-Line-SESs-Far"               => "Lucent",
            "Lucent-Sonet-Line-SESs-Near"              => "Lucent",
            "Lucent-Sonet-Line-USs-Far"                => "Lucent",
            "Lucent-Sonet-Line-USs-Near"               => "Lucent",
            "Lucent-Sonet-Path-CVs-Far"                => "Lucent",
            "Lucent-Sonet-Path-CVs-Near"               => "Lucent",
            "Lucent-Sonet-Path-ESs-Far"                => "Lucent",
            "Lucent-Sonet-Path-ESs-Near"               => "Lucent",
            "Lucent-Sonet-Path-SESs-Far"               => "Lucent",
            "Lucent-Sonet-Path-SESs-Near"              => "Lucent",
            "Lucent-Sonet-Path-USs-Far"                => "Lucent",
            "Lucent-Sonet-Path-USs-Near"               => "Lucent",
            "Lucent-Sonet-Section-CVs"                 => "Lucent",
            "Lucent-Sonet-Section-ESs"                 => "Lucent",
            "Lucent-Sonet-Section-SEFSs"               => "Lucent",
            "Lucent-Sonet-Section-SESs"                => "Lucent",
            "Lucent-Source-Auth"                       => "Lucent",
            "Lucent-Source-IP-Check"                   => "Lucent",
            "Lucent-SVC-Enabled"                       => "Lucent",
            "Lucent-Target-Util"                       => "Lucent",
            "Lucent-Telnet-Profile"                    => "Lucent",
            "Lucent-TermSrv-Login-Prompt"              => "Lucent",
            "Lucent-Third-Prompt"                      => "Lucent",
            "Lucent-Token-Expiry"                      => "Lucent",
            "Lucent-Token-Idle"                        => "Lucent",
            "Lucent-Token-Immediate"                   => "Lucent",
            "Lucent-TOS-Copying"                       => "Lucent",
            "Lucent-Traffic-Shaper"                    => "Lucent",
            "Lucent-Transit-Number"                    => "Lucent",
            "Lucent-TS-Idle-Limit"                     => "Lucent",
            "Lucent-TS-Idle-Mode"                      => "Lucent",
            "Lucent-Tunnel-Auth-Type"                  => "Lucent",
            "Lucent-Tunnel-Auth-Type2"                 => "Lucent",
            "Lucent-Tunnel-DSCP"                       => "Lucent",
            "Lucent-Tunnel-TOS"                        => "Lucent",
            "Lucent-Tunnel-TOS-Copy"                   => "Lucent",
            "Lucent-Tunnel-TOS-Filter"                 => "Lucent",
            "Lucent-Tunnel-TOS-Precedence"             => "Lucent",
            "Lucent-Tunnel-VRouter-Name"               => "Lucent",
            "Lucent-Tunneling-Protocol"                => "Lucent",
            "Lucent-User-Acct-Base"                    => "Lucent",
            "Lucent-User-Acct-Expiration"              => "Lucent",
            "Lucent-User-Acct-Host"                    => "Lucent",
            "Lucent-User-Acct-Key"                     => "Lucent",
            "Lucent-User-Acct-Port"                    => "Lucent",
            "Lucent-User-Acct-Time"                    => "Lucent",
            "Lucent-User-Acct-Type"                    => "Lucent",
            "Lucent-User-Login-Level"                  => "Lucent",
            "Lucent-User-Priority"                     => "Lucent",
            "Lucent-UU-Info"                           => "Lucent",
            "Lucent-VRouter-Name"                      => "Lucent",
            "Lucent-X25-Cug"                           => "Lucent",
            "Lucent-X25-Nui"                           => "Lucent",
            "Lucent-X25-Nui-Password-Prompt"           => "Lucent",
            "Lucent-X25-Nui-Prompt"                    => "Lucent",
            "Lucent-X25-Pad-Alias-1"                   => "Lucent",
            "Lucent-X25-Pad-Alias-2"                   => "Lucent",
            "Lucent-X25-Pad-Alias-3"                   => "Lucent",
            "Lucent-X25-Pad-Banner"                    => "Lucent",
            "Lucent-X25-Pad-Prompt"                    => "Lucent",
            "Lucent-X25-Pad-X3-Parameters"             => "Lucent",
            "Lucent-X25-Pad-X3-Profile"                => "Lucent",
            "Lucent-X25-Profile-Name"                  => "Lucent",
            "Lucent-X25-Reverse-Charging"              => "Lucent",
            "Lucent-X25-Rpoa"                          => "Lucent",
            "Lucent-X25-X121-Address"                  => "Lucent",
            "Lucent-X25-X121-Source-Address"           => "Lucent",
            "Lucent-Xmit-Rate"                         => "Lucent",
            "Lucent-Xmit-Symbol-Rate"                  => "Lucent",
            "Mac-Addr"                                 => "Ericsson-AB",
            "Manzara-ECP-Session-Key"                  => "Manzara",
            "Manzara-Full-Login-String"                => "Manzara",
            "Manzara-Map-Error"                        => "Manzara",
            "Manzara-Map-Key"                          => "Manzara",
            "Manzara-Map-Name"                         => "Manzara",
            "Manzara-Map-Value"                        => "Manzara",
            "Manzara-PPP-Addr-String"                  => "Manzara",
            "Manzara-Service-Type"                     => "Manzara",
            "Manzara-Tariff-Type"                      => "Manzara",
            "Manzara-Tariff-Units"                     => "Manzara",
            "Manzara-User-GID"                         => "Manzara",
            "Manzara-User-Home"                        => "Manzara",
            "Manzara-User-Shell"                       => "Manzara",
            "Manzara-User-UID"                         => "Manzara",
            "Maximum-Data-Rate-Downstream"             => "ADSL-Forum",
            "Maximum-Data-Rate-Upstream"               => "ADSL-Forum",
            "Maximum-Interleaving-Delay-Downstream"    => "ADSL-Forum",
            "Maximum-Interleaving-Delay-Upstream"      => "ADSL-Forum",
            "MBG-Management-Privilege-Level"           => "Meinberg",
            "Mcast-MaxGroups"                          => "Ericsson-AB",
            "Mcast-Receive"                            => "Ericsson-AB",
            "Mcast-Send"                               => "Ericsson-AB",
            "Medium-Type"                              => "Ericsson-AB",
            "Mellanox-Local-User-Name"                 => "Mellanox",
            "Meraki-Ap-Name"                           => "Meraki",
            "Meraki-Ap-Tags"                           => "Meraki",
            "Meraki-Device-Name"                       => "Meraki",
            "Meraki-Network-Name"                      => "Meraki",
            "Merit-Proxy-Action"                       => "Merit",
            "Merit-User-Id"                            => "Merit",
            "Merit-User-Realm"                         => "Merit",
            "Meru-Access-Point-Id"                     => "Meru",
            "Meru-Access-Point-Name"                   => "Meru",
            "method"                                   => "Cisco",
            "Microsemi-Fallback-User-Group"            => "Microsemi",
            "Microsemi-Network-Element-Group"          => "Microsemi",
            "Microsemi-User-Email"                     => "Microsemi",
            "Microsemi-User-Full-Name"                 => "Microsemi",
            "Microsemi-User-Group"                     => "Microsemi",
            "Microsemi-User-Initials"                  => "Microsemi",
            "Microsemi-User-Name"                      => "Microsemi",
            "Mikrotik-Address-List"                    => "Mikrotik",
            "Mikrotik-Advertise-Interval"              => "Mikrotik",
            "Mikrotik-Advertise-URL"                   => "Mikrotik",
            "Mikrotik-Delegated-IPv6-Pool"             => "Mikrotik",
            "Mikrotik-DHCP-Option-Param-STR1"          => "Mikrotik",
            "Mikrotik-DHCP-Option-Param-STR2"          => "Mikrotik",
            "Mikrotik-DHCP-Option-ParamSTR2"           => "Mikrotik",
            "Mikrotik-DHCP-Option-Set"                 => "Mikrotik",
            "Mikrotik-Group"                           => "Mikrotik",
            "Mikrotik-Host-IP"                         => "Mikrotik",
            "Mikrotik-Mark-Id"                         => "Mikrotik",
            "Mikrotik-Rate-Limit"                      => "Mikrotik",
            "Mikrotik-Realm"                           => "Mikrotik",
            "Mikrotik-Recv-Limit"                      => "Mikrotik",
            "Mikrotik-Recv-Limit-Gigawords"            => "Mikrotik",
            "Mikrotik-Switching-Filter"                => "Mikrotik",
            "Mikrotik-Total-Limit"                     => "Mikrotik",
            "Mikrotik-Total-Limit-Gigawords"           => "Mikrotik",
            "Mikrotik-Wireless-Comment"                => "Mikrotik",
            "Mikrotik-Wireless-Enc-Algo"               => "Mikrotik",
            "Mikrotik-Wireless-Enc-Key"                => "Mikrotik",
            "Mikrotik-Wireless-Forward"                => "Mikrotik",
            "Mikrotik-Wireless-Maxsignal"              => "Mikrotik",
            "Mikrotik-Wireless-Minsignal"              => "Mikrotik",
            "Mikrotik-Wireless-MPKey"                  => "Mikrotik",
            "Mikrotik-Wireless-PSK"                    => "Mikrotik",
            "Mikrotik-Wireless-Skip-Dot1x"             => "Mikrotik",
            "Mikrotik-Wireless-VLANID"                 => "Mikrotik",
            "Mikrotik-Wireless-VLANID-Type"            => "Mikrotik",
            "Mikrotik-Wireless-VLANIDtype"             => "Mikrotik",
            "Mikrotik-Xmit-Limit"                      => "Mikrotik",
            "Mikrotik-Xmit-Limit-Gigawords"            => "Mikrotik",
            "Mimosa-CloudManagement-Parameter"         => "Mimosa",
            "Mimosa-Device-Configuration-Parameter"    => "Mimosa",
            "Mimosa-DeviceName-Parameter"              => "Mimosa",
            "Mimosa-DNS1-Parameter"                    => "Mimosa",
            "Mimosa-DNS2-Parameter"                    => "Mimosa",
            "Mimosa-EnableHTTPS-Parameter"             => "Mimosa",
            "Mimosa-EnableSNMP-Parameter"              => "Mimosa",
            "Mimosa-EnableSyslog-Parameter"            => "Mimosa",
            "Mimosa-EthernetPortSpeed-Parameter"       => "Mimosa",
            "Mimosa-FirmwareLocation-Parameter"        => "Mimosa",
            "Mimosa-FirmwareVersion-Parameter"         => "Mimosa",
            "Mimosa-HTTPPort-Parameter"                => "Mimosa",
            "Mimosa-HTTPSPort-Parameter"               => "Mimosa",
            "Mimosa-ManagementIPAddress-Parameter"     => "Mimosa",
            "Mimosa-ManagementIPAddressMode-Parameter" => "Mimosa",
            "Mimosa-ManagementIPGateway-Parameter"     => "Mimosa",
            "Mimosa-ManagementIPNetmask-Parameter"     => "Mimosa",
            "Mimosa-ManagementPassword-Parameter"      => "Mimosa",
            "Mimosa-ManagementVlan-Parameter"          => "Mimosa",
            "Mimosa-ManagementVlanStatus-Parameter"    => "Mimosa",
            "Mimosa-NTPServerAddress-Parameter"        => "Mimosa",
            "Mimosa-SNMPCommunityString-Parameter"     => "Mimosa",
            "Mimosa-SNMPTrapServer-Parameter"          => "Mimosa",
            "Mimosa-SyslogPort-Parameter"              => "Mimosa",
            "Mimosa-SyslogProtocol-Parameter"          => "Mimosa",
            "Mimosa-SyslogServerAddress-Parameter"     => "Mimosa",
            "Mimosa-TrafficShapingCommitted-Parameter" => "Mimosa",
            "Mimosa-TrafficShapingPeak-Parameter"      => "Mimosa",
            "Mimosa-WirelessProtocol-Parameter"        => "Mimosa",
            "Minimum-Data-Rate-Downstream"             => "ADSL-Forum",
            "Minimum-Data-Rate-Downstream-Low-Power"   => "ADSL-Forum",
            "Minimum-Data-Rate-Upstream"               => "ADSL-Forum",
            "Minimum-Data-Rate-Upstream-Low-Power"     => "ADSL-Forum",
            "Moonshot-Host-TargetedId"                 => "UKERNA",
            "Moonshot-MSTID-GSS-Acceptor"              => "UKERNA",
            "Moonshot-MSTID-Namespace"                 => "UKERNA",
            "Moonshot-MSTID-TargetedId"                => "UKERNA",
            "Moonshot-OTP-Secret"                      => "UKERNA",
            "Moonshot-Realm-TargetedId"                => "UKERNA",
            "Moonshot-TR-COI-TargetedId"               => "UKERNA",
            "Motorola-Accounting-Message"              => "Motorola",
            "Motorola-Canopy-BCASTMIR"                 => "Motorola",
            "Motorola-Canopy-DLBL"                     => "Motorola",
            "Motorola-Canopy-DLBR"                     => "Motorola",
            "Motorola-Canopy-HPDLCIR"                  => "Motorola",
            "Motorola-Canopy-HPENABLE"                 => "Motorola",
            "Motorola-Canopy-HPULCIR"                  => "Motorola",
            "Motorola-Canopy-LPDLCIR"                  => "Motorola",
            "Motorola-Canopy-LPULCIR"                  => "Motorola",
            "Motorola-Canopy-ULBL"                     => "Motorola",
            "Motorola-Canopy-ULBR"                     => "Motorola",
            "Motorola-Canopy-UserLevel"                => "Motorola",
            "Motorola-Canopy-VLAGETO"                  => "Motorola",
            "Motorola-Canopy-VLFRAMES"                 => "Motorola",
            "Motorola-Canopy-VLIDSET"                  => "Motorola",
            "Motorola-Canopy-VLIGVID"                  => "Motorola",
            "Motorola-Canopy-VLLEARNEN"                => "Motorola",
            "Motorola-Canopy-VLMGVID"                  => "Motorola",
            "Motorola-Canopy-VLSMMGPASS"               => "Motorola",
            "Motorola-WiMAX-Convergence-Sublayer"      => "Motorola",
            "Motorola-WiMAX-DNS-Server-IP-Address"     => "Motorola",
            "Motorola-WiMAX-EMS-Address"               => "Motorola",
            "Motorola-WiMAX-HO-SVC-CLASS"              => "Motorola",
            "Motorola-WiMAX-Home-BTS"                  => "Motorola",
            "Motorola-WiMAX-Maximum-Commit-Bandwidth"  => "Motorola",
            "Motorola-WiMAX-Maximum-Total-Bandwidth"   => "Motorola",
            "Motorola-WiMAX-MIP-KEY"                   => "Motorola",
            "Motorola-WiMAX-MIP-MN-HOME-ADDRESS"       => "Motorola",
            "Motorola-WiMAX-MIP-SPI"                   => "Motorola",
            "Motorola-WiMAX-MN-HA"                     => "Motorola",
            "Motorola-WiMAX-Network-Domain-Name"       => "Motorola",
            "Motorola-WiMAX-NTP-Server"                => "Motorola",
            "Motorola-WiMAX-Provisioning-Server"       => "Motorola",
            "Motorola-WiMAX-Service-Flows"             => "Motorola",
            "Motorola-WiMAX-User-NAI"                  => "Motorola",
            "Motorola-WiMAX-VLAN-ID"                   => "Motorola",
            "MS-Acct-Auth-Type"                        => "Microsoft",
            "MS-Acct-EAP-Type"                         => "Microsoft",
            "MS-AFW-Protection-Level"                  => "Microsoft",
            "MS-AFW-Zone"                              => "Microsoft",
            "MS-ARAP-PW-Change-Reason"                 => "Microsoft",
            "MS-BAP-Usage"                             => "Microsoft",
            "MS-CHAP-Challenge"                        => "Microsoft",
            "MS-CHAP-CPW-1"                            => "Microsoft",
            "MS-CHAP-CPW-2"                            => "Microsoft",
            "MS-CHAP-Domain"                           => "Microsoft",
            "MS-CHAP-Error"                            => "Microsoft",
            "MS-CHAP-LM-Enc-PW"                        => "Microsoft",
            "MS-CHAP-MPPE-Keys"                        => "Microsoft",
            "MS-CHAP-NT-Enc-PW"                        => "Microsoft",
            "MS-CHAP-Response"                         => "Microsoft",
            "MS-CHAP2-CPW"                             => "Microsoft",
            "MS-CHAP2-Response"                        => "Microsoft",
            "MS-CHAP2-Success"                         => "Microsoft",
            "MS-Extended-Quarantine-State"             => "Microsoft",
            "MS-Filter"                                => "Microsoft",
            "MS-HCAP-Location-Group-Name"              => "Microsoft",
            "MS-HCAP-User-Groups"                      => "Microsoft",
            "MS-HCAP-User-Name"                        => "Microsoft",
            "MS-Identity-Type"                         => "Microsoft",
            "MS-IPv4-Remediation-Servers"              => "Microsoft",
            "MS-IPv6-Filter"                           => "Microsoft",
            "MS-IPv6-Remediation-Servers"              => "Microsoft",
            "MS-Link-Drop-Time-Limit"                  => "Microsoft",
            "MS-Link-Utilization-Threshold"            => "Microsoft",
            "MS-Machine-Name"                          => "Microsoft",
            "MS-MPPE-Encryption-Policy"                => "Microsoft",
            "MS-MPPE-Encryption-Type"                  => "Microsoft",
            "MS-MPPE-Encryption-Types"                 => "Microsoft",
            "MS-MPPE-Recv-Key"                         => "Microsoft",
            "MS-MPPE-Send-Key"                         => "Microsoft",
            "MS-Network-Access-Server-Type"            => "Microsoft",
            "MS-New-ARAP-Password"                     => "Microsoft",
            "MS-Old-ARAP-Password"                     => "Microsoft",
            "MS-Primary-DNS-Server"                    => "Microsoft",
            "MS-Primary-NBNS-Server"                   => "Microsoft",
            "MS-Quarantine-Grace-Time"                 => "Microsoft",
            "MS-Quarantine-IPFilter"                   => "Microsoft",
            "MS-Quarantine-Session-Timeout"            => "Microsoft",
            "MS-Quarantine-SOH"                        => "Microsoft",
            "MS-Quarantine-State"                      => "Microsoft",
            "MS-Quarantine-User-Class"                 => "Microsoft",
            "MS-RAS-Client-Name"                       => "Microsoft",
            "MS-RAS-Client-Version"                    => "Microsoft",
            "MS-RAS-Correlation"                       => "Microsoft",
            "MS-RAS-Vendor"                            => "Microsoft",
            "MS-RAS-Version"                           => "Microsoft",
            "MS-RNAP-Not-Quarantine-Capable"           => "Microsoft",
            "MS-Secondary-DNS-Server"                  => "Microsoft",
            "MS-Secondary-NBNS-Server"                 => "Microsoft",
            "MS-Service-Class"                         => "Microsoft",
            "MS-TSG-Device-Redirection"                => "Microsoft",
            "MS-User-IPv4-Address"                     => "Microsoft",
            "MS-User-IPv6-Address"                     => "Microsoft",
            "MS-User-Security-Identity"                => "Microsoft",
            "NAS-Real-Port"                            => "Ericsson-AB",
            "NAT-Policy-Name"                          => "Ericsson-AB",
            "Navini-AVPair"                            => "Navini",
            "NET-Abort-Cause"                          => "NET",
            "NET-Alert-Time"                           => "NET",
            "NET-Bwd-Flow-In-Dst-Addr"                 => "NET",
            "NET-Bwd-Flow-In-Dst-Port"                 => "NET",
            "NET-Bwd-Flow-In-Realm"                    => "NET",
            "NET-Bwd-Flow-In-Src-Addr"                 => "NET",
            "NET-Bwd-Flow-In-Src-Port"                 => "NET",
            "NET-Bwd-Flow-Out-Dst-Addr"                => "NET",
            "NET-Bwd-Flow-Out-Dst-Port"                => "NET",
            "NET-Bwd-Flow-Out-Realm"                   => "NET",
            "NET-Bwd-Flow-Out-Src-Addr"                => "NET",
            "NET-Bwd-Flow-Out-Src-Port"                => "NET",
            "NET-Bwd-Octets"                           => "NET",
            "NET-Bwd-Packets"                          => "NET",
            "NET-Bwd-RTCP-Avg-Jitter"                  => "NET",
            "NET-Bwd-RTCP-MaxJitter"                   => "NET",
            "NET-Bwd-RTCP-Packets-Lost"                => "NET",
            "NET-Bwd-RTP-Avg-Jitter"                   => "NET",
            "NET-Bwd-RTP-Avg-Latency"                  => "NET",
            "NET-Bwd-RTP-MaxJitter"                    => "NET",
            "NET-Bwd-RTP-MaxLatency"                   => "NET",
            "NET-Bwd-RTP-Packets-Lost"                 => "NET",
            "NET-Call-Duration"                        => "NET",
            "NET-Call-Number-Type"                     => "NET",
            "NET-Call-Origin"                          => "NET",
            "NET-Call-Plan"                            => "NET",
            "NET-Call-Priority"                        => "NET",
            "NET-Call-Type"                            => "NET",
            "NET-Called-Name"                          => "NET",
            "NET-Called-Number"                        => "NET",
            "NET-Calling-Name"                         => "NET",
            "NET-Calling-Number"                       => "NET",
            "NET-Connect-Time"                         => "NET",
            "NET-Disconnect-Cause"                     => "NET",
            "NET-Disconnect-Initiator"                 => "NET",
            "NET-Disconnect-Time"                      => "NET",
            "NET-Egress-Channel-Id"                    => "NET",
            "NET-Egress-Channel-Number"                => "NET",
            "NET-Egress-Final-Routing-Num"             => "NET",
            "NET-Egress-Local-Addr"                    => "NET",
            "NET-Egress-Net-Interface-Id"              => "NET",
            "NET-Egress-Remote-Addr"                   => "NET",
            "NET-Egress-Signaling-Group"               => "NET",
            "NET-Egress-Signaling-Port-Num"            => "NET",
            "NET-Firmware-Version"                     => "NET",
            "NET-Fwd-Flow-In-Dst-Addr"                 => "NET",
            "NET-Fwd-Flow-In-Dst-Port"                 => "NET",
            "NET-Fwd-Flow-In-Realm"                    => "NET",
            "NET-Fwd-Flow-In-Src-Addr"                 => "NET",
            "NET-Fwd-Flow-In-Src-Port"                 => "NET",
            "NET-Fwd-Flow-Media-Type"                  => "NET",
            "NET-Fwd-Flow-Out-Dst-Addr"                => "NET",
            "NET-Fwd-Flow-Out-Dst-Port"                => "NET",
            "NET-Fwd-Flow-Out-Realm"                   => "NET",
            "NET-Fwd-Flow-Out-Src-Addr"                => "NET",
            "NET-Fwd-Flow-Out-Src-Port"                => "NET",
            "NET-Fwd-Flow-PTime"                       => "NET",
            "NET-Fwd-Octets"                           => "NET",
            "NET-Fwd-Packets"                          => "NET",
            "NET-Fwd-RTCP-Avg-Jitter"                  => "NET",
            "NET-Fwd-RTCP-MaxJitter"                   => "NET",
            "NET-Fwd-RTCP-Packets-Lost"                => "NET",
            "NET-Fwd-RTP-Avg-Jitter"                   => "NET",
            "NET-Fwd-RTP-Avg-Latency"                  => "NET",
            "NET-Fwd-RTP-MaxJitter"                    => "NET",
            "NET-Fwd-RTP-MaxLatency"                   => "NET",
            "NET-Fwd-RTP-Packets-Lost"                 => "NET",
            "NET-Gw-Id"                                => "NET",
            "NET-Inbound-Seize-Time"                   => "NET",
            "NET-Ingress-Channel-Id"                   => "NET",
            "NET-Ingress-Channel-Number"               => "NET",
            "NET-Ingress-Local-Addr"                   => "NET",
            "NET-Ingress-Net-Interface-Id"             => "NET",
            "NET-Ingress-Remote-Addr"                  => "NET",
            "NET-Ingress-Signaling-Group"              => "NET",
            "NET-Ingress-Signaling-Port-Num"           => "NET",
            "NET-Local-Time-Zone"                      => "NET",
            "NET-Log-Time"                             => "NET",
            "NET-Namespace"                            => "NET",
            "NET-Original-Called-Number"               => "NET",
            "NET-Original-Called-Plan"                 => "NET",
            "NET-Original-Called-Type"                 => "NET",
            "NET-Outbound-Seize-Time"                  => "NET",
            "NET-P-Asserted-ID"                        => "NET",
            "NET-P-Preferred-ID"                       => "NET",
            "NET-Post-Dial-Delay"                      => "NET",
            "NET-Precedence"                           => "NET",
            "NET-Presentation"                         => "NET",
            "NET-Primary-Routing-Number"               => "NET",
            "NET-Redirect-Ip-Address"                  => "NET",
            "NET-Redirect-Number"                      => "NET",
            "NET-Refer-Call-Transfer-Id"               => "NET",
            "NET-Replaced-Header"                      => "NET",
            "NET-Routing-Table-Number"                 => "NET",
            "NET-Screening"                            => "NET",
            "NET-Session-Egress-CallId"                => "NET",
            "NET-Session-Egress-Realm"                 => "NET",
            "NET-Session-Forked-Call-Id"               => "NET",
            "NET-Session-Generic-Id"                   => "NET",
            "NET-Session-Ingress-CallId"               => "NET",
            "NET-Session-Ingress-Realm"                => "NET",
            "NET-Setup-Time"                           => "NET",
            "NET-SIP-Diversion"                        => "NET",
            "NET-Time-And-Day"                         => "NET",
            "NET-Transfer-Capability"                  => "NET",
            "NET-Transfer-Mode"                        => "NET",
            "NET-Transfer-Rate"                        => "NET",
            "NET-Transport-Type"                       => "NET",
            "NET-User-Rate"                            => "NET",
            "NetBorder-AMAFlags"                       => "NetBorder",
            "NetBorder-Ani"                            => "NetBorder",
            "NetBorder-Aniii"                          => "NetBorder",
            "NetBorder-AVPair"                         => "NetBorder",
            "NetBorder-Billusec"                       => "NetBorder",
            "NetBorder-Callanswerdate"                 => "NetBorder",
            "NetBorder-Callenddate"                    => "NetBorder",
            "NetBorder-Callstartdate"                  => "NetBorder",
            "NetBorder-Calltransferdate"               => "NetBorder",
            "NetBorder-CLID"                           => "NetBorder",
            "NetBorder-Context"                        => "NetBorder",
            "NetBorder-Dialplan"                       => "NetBorder",
            "NetBorder-Disposition"                    => "NetBorder",
            "NetBorder-Dst"                            => "NetBorder",
            "NetBorder-Dst-Channel"                    => "NetBorder",
            "NetBorder-Hangupcause"                    => "NetBorder",
            "NetBorder-Lastapp"                        => "NetBorder",
            "NetBorder-Lastdata"                       => "NetBorder",
            "NetBorder-RDNIS"                          => "NetBorder",
            "NetBorder-Signalbond"                     => "NetBorder",
            "NetBorder-Source"                         => "NetBorder",
            "NetBorder-Src"                            => "NetBorder",
            "NetBorder-Src-Channel"                    => "NetBorder",
            "NetElastic-Acct-IPv6-Input-Gigawords"     => "NetElastic",
            "NetElastic-Acct-IPv6-Input-Octets"        => "NetElastic",
            "NetElastic-Acct-IPv6-Input-Packets"       => "NetElastic",
            "NetElastic-Acct-IPv6-Output-Gigawords"    => "NetElastic",
            "NetElastic-Acct-IPv6-Output-Octets"       => "NetElastic",
            "NetElastic-Acct-IPv6-Output-Packets"      => "NetElastic",
            "NetElastic-Data-Filter"                   => "NetElastic",
            "NetElastic-Domain-Name"                   => "NetElastic",
            "NetElastic-Framed-IPv6-Address"           => "NetElastic",
            "NetElastic-HTTP-Redirect-URL"             => "NetElastic",
            "NetElastic-Input-Average-Rate"            => "NetElastic",
            "NetElastic-Input-Burst-Size"              => "NetElastic",
            "NetElastic-Input-Peak-Burst-Size"         => "NetElastic",
            "NetElastic-Input-Peak-Rate"               => "NetElastic",
            "NetElastic-ISP-ID"                        => "NetElastic",
            "NetElastic-Lease-Time"                    => "NetElastic",
            "NetElastic-NAT-End-Port"                  => "NetElastic",
            "NetElastic-NAT-Public-Address"            => "NetElastic",
            "NetElastic-NAT-Start-Port"                => "NetElastic",
            "NetElastic-Output-Average-Rate"           => "NetElastic",
            "NetElastic-Output-Burst-Size"             => "NetElastic",
            "NetElastic-Output-Peak-Burst-Size"        => "NetElastic",
            "NetElastic-Output-Peak-Rate"              => "NetElastic",
            "NetElastic-Policy-Name"                   => "NetElastic",
            "NetElastic-Portal-Mode"                   => "NetElastic",
            "NetElastic-PortalURL"                     => "NetElastic",
            "NetElastic-Primary-DNS"                   => "NetElastic",
            "NetElastic-Qos-Profile-Name"              => "NetElastic",
            "NetElastic-Remanent-Volume"               => "NetElastic",
            "NetElastic-Remanent-Volume-Type"          => "NetElastic",
            "NetElastic-Secondary-DNS"                 => "NetElastic",
            "NetElastic-Tariff-Input-Gigawords"        => "NetElastic",
            "NetElastic-Tariff-Input-Octets"           => "NetElastic",
            "NetElastic-Tariff-Output-Gigawords"       => "NetElastic",
            "NetElastic-Tariff-Output-Octets"          => "NetElastic",
            "NetElastic-User-Mac"                      => "NetElastic",
            "NetElastic-Web-COA"                       => "NetElastic",
            "NetSensory-Privilege"                     => "NetworkPhysics",
            "Nexans-Port-Default-VLAN-ID"              => "Nexans",
            "Nexans-Port-Voice-VLAN-ID"                => "Nexans",
            "next-hop-dn"                              => "Cisco",
            "next-hop-ip"                              => "Cisco",
            "Nile-AVPair"                              => "Nile",
            "Nile-Netseg"                              => "Nile",
            "Nile-Redirect-URL"                        => "Nile",
            "NN-Data-Rate"                             => "Bristol",
            "NN-Data-Rate-Ceiling"                     => "Bristol",
            "NN-Homenode"                              => "Bristol",
            "NN-Homeservice"                           => "Bristol",
            "NN-Homeservice-Name"                      => "Bristol",
            "Nokia-AVPair"                             => "Nokia",
            "Nokia-OCS-ID1"                            => "Nokia",
            "Nokia-OCS-ID2"                            => "Nokia",
            "Nokia-Requested-APN"                      => "Nokia",
            "Nokia-Service-Charging-Type"              => "Nokia",
            "Nokia-Service-Encrypted-Password"         => "Nokia",
            "Nokia-Service-Id"                         => "Nokia",
            "Nokia-Service-Name"                       => "Nokia",
            "Nokia-Service-Password"                   => "Nokia",
            "Nokia-Service-Primary-Indicator"          => "Nokia",
            "Nokia-Service-Username"                   => "Nokia",
            "Nokia-Session-Access-Method"              => "Nokia",
            "Nokia-Session-Charging-Type"              => "Nokia",
            "Nokia-TREC-Index"                         => "Nokia",
            "Nokia-User-Profile"                       => "Nokia",
            "Nomadix-Bw-Down"                          => "Nomadix",
            "Nomadix-Bw-Up"                            => "Nomadix",
            "Nomadix-Centralized-Mgmt"                 => "Nomadix",
            "Nomadix-Config-URL"                       => "Nomadix",
            "Nomadix-EndofSession"                     => "Nomadix",
            "Nomadix-Expiration"                       => "Nomadix",
            "Nomadix-Goodbye-URL"                      => "Nomadix",
            "Nomadix-Group-Bw-Max-Down"                => "Nomadix",
            "Nomadix-Group-Bw-Max-Up"                  => "Nomadix",
            "Nomadix-Group-Policy-Id"                  => "Nomadix",
            "Nomadix-IP-Upsell"                        => "Nomadix",
            "Nomadix-Logoff-URL"                       => "Nomadix",
            "Nomadix-MaxBytesDown"                     => "Nomadix",
            "Nomadix-MaxBytesUp"                       => "Nomadix",
            "Nomadix-Net-VLAN"                         => "Nomadix",
            "Nomadix-Qos-Policy"                       => "Nomadix",
            "Nomadix-SMTP-Redirect"                    => "Nomadix",
            "Nomadix-Subnet"                           => "Nomadix",
            "Nomadix-URL-Redirection"                  => "Nomadix",
            "Nortel-Privilege-Level"                   => "Nortel",
            "Nortel-User-Role"                         => "Nortel",
            "NS-Admin-Privilege"                       => "Netscreen",
            "NS-NSM-User-Domain-Name"                  => "Netscreen",
            "NS-NSM-User-Role-Mapping"                 => "Netscreen",
            "NS-Primary-DNS"                           => "Netscreen",
            "NS-Primary-WINS"                          => "Netscreen",
            "NS-Secondary-DNS"                         => "Netscreen",
            "NS-Secondary-WINS"                        => "Netscreen",
            "NS-User-Group"                            => "Netscreen",
            "NS-VSYS-Name"                             => "Netscreen",
            "OpenWiFi-AP-MAC-Address"                  => "OpenWiFi",
            "OS-Version"                               => "Ericsson-AB",
            "outgoing-req-uri"                         => "Cisco",
            "Packeteer-AVPair"                         => "Packeteer",
            "Packeteer-PC-AVPair"                      => "Packeteer",
            "PacketFence-Authorization-Status"         => "Inverse",
            "PacketFence-AutoReg"                      => "Inverse",
            "PacketFence-Computer-Name"                => "Inverse",
            "PacketFence-Connection-Type"              => "Inverse",
            "PacketFence-ConnectorID"                  => "Inverse",
            "PacketFence-Domain"                       => "Inverse",
            "PacketFence-Eap-Type"                     => "Inverse",
            "PacketFence-Handled"                      => "Inverse",
            "PacketFence-IfIndex"                      => "Inverse",
            "PacketFence-IsPhone"                      => "Inverse",
            "PacketFence-KeyBalanced"                  => "Inverse",
            "PacketFence-Mac"                          => "Inverse",
            "PacketFence-NasName"                      => "Inverse",
            "PacketFence-NTCacheHash"                  => "Inverse",
            "PacketFence-NTLM-Auth-Host"               => "Inverse",
            "PacketFence-NTLM-Auth-Port"               => "Inverse",
            "PacketFence-NTLMv2-Only"                  => "Inverse",
            "PacketFence-Outer-User"                   => "Inverse",
            "PacketFence-Profile"                      => "Inverse",
            "PacketFence-Proxied-From"                 => "Inverse",
            "PacketFence-Proxied-To"                   => "Inverse",
            "PacketFence-Radius-Ip"                    => "Inverse",
            "PacketFence-reply-insert"                 => "Inverse",
            "PacketFence-Request-Time"                 => "Inverse",
            "PacketFence-Role"                         => "Inverse",
            "PacketFence-RPC-Pass"                     => "Inverse",
            "PacketFence-RPC-Port"                     => "Inverse",
            "PacketFence-RPC-Proto"                    => "Inverse",
            "PacketFence-RPC-Server"                   => "Inverse",
            "PacketFence-RPC-User"                     => "Inverse",
            "PacketFence-ShortName"                    => "Inverse",
            "PacketFence-Source"                       => "Inverse",
            "PacketFence-SSID"                         => "Inverse",
            "PacketFence-Status"                       => "Inverse",
            "PacketFence-Switch-Id"                    => "Inverse",
            "PacketFence-Switch-Ip-Address"            => "Inverse",
            "PacketFence-Switch-Mac"                   => "Inverse",
            "PacketFence-UserDN"                       => "Inverse",
            "PacketFence-UserName"                     => "Inverse",
            "PacketFence-UserNameAttribute"            => "Inverse",
            "PacketFence-UserPassword"                 => "Inverse",
            "PaloAlto-Admin-Access-Domain"             => "PaloAlto",
            "PaloAlto-Admin-Role"                      => "PaloAlto",
            "PaloAlto-Client-Hostname"                 => "PaloAlto",
            "PaloAlto-Client-OS"                       => "PaloAlto",
            "PaloAlto-Client-Source-IP"                => "PaloAlto",
            "PaloAlto-GlobalProtect-Client-Version"    => "PaloAlto",
            "PaloAlto-Panorama-Admin-Access-Domain"    => "PaloAlto",
            "PaloAlto-Panorama-Admin-Role"             => "PaloAlto",
            "PaloAlto-User-Domain"                     => "PaloAlto",
            "PaloAlto-User-Group"                      => "PaloAlto",
            "Passport-Access-Priority"                 => "Bay-Networks",
            "Passport-Allowed-Access"                  => "Nortel",
            "Passport-AllowedOut-Access"               => "Nortel",
            "Passport-Command-Impact"                  => "Nortel",
            "Passport-Command-Scope"                   => "Nortel",
            "Passport-Customer-Identifier"             => "Nortel",
            "Passport-Login-Directory"                 => "Nortel",
            "Passport-Role"                            => "Nortel",
            "Passport-Timeout-Protocol"                => "Nortel",
            "Patton-Called-Codec"                      => "Patton",
            "Patton-Called-IP-Address"                 => "Patton",
            "Patton-Called-Local-Udp-Port"             => "Patton",
            "Patton-Called-MOS"                        => "Patton",
            "Patton-Called-Name"                       => "Patton",
            "Patton-Called-Numbering-Plan"             => "Patton",
            "Patton-Called-Qos"                        => "Patton",
            "Patton-Called-Remote-Ip"                  => "Patton",
            "Patton-Called-Remote-Udp-Port"            => "Patton",
            "Patton-Called-Round-Trip-Time"            => "Patton",
            "Patton-Called-Rx-Jitter"                  => "Patton",
            "Patton-Called-Rx-Lost-Packets"            => "Patton",
            "Patton-Called-Rx-Octets"                  => "Patton",
            "Patton-Called-Rx-Packets"                 => "Patton",
            "Patton-Called-Station-Id"                 => "Patton",
            "Patton-Called-Tx-Jitter"                  => "Patton",
            "Patton-Called-Tx-Lost-Packets"            => "Patton",
            "Patton-Called-Tx-Octets"                  => "Patton",
            "Patton-Called-Tx-Packets"                 => "Patton",
            "Patton-Called-Type-Of-Number"             => "Patton",
            "Patton-Called-Unique-Id"                  => "Patton",
            "Patton-Calling-Codec"                     => "Patton",
            "Patton-Calling-IP-Address"                => "Patton",
            "Patton-Calling-Local-Udp-Port"            => "Patton",
            "Patton-Calling-Lost-Rx-Packets"           => "Patton",
            "Patton-Calling-Lost-Tx-Packets"           => "Patton",
            "Patton-Calling-MOS"                       => "Patton",
            "Patton-Calling-Name"                      => "Patton",
            "Patton-Calling-Numbering-Plan"            => "Patton",
            "Patton-Calling-Presentation-Indicator"    => "Patton",
            "Patton-Calling-Qos"                       => "Patton",
            "Patton-Calling-Remote-Ip"                 => "Patton",
            "Patton-Calling-Remote-Udp-Port"           => "Patton",
            "Patton-Calling-Round-Trip-Time"           => "Patton",
            "Patton-Calling-Rx-Jitter"                 => "Patton",
            "Patton-Calling-Rx-Octets"                 => "Patton",
            "Patton-Calling-Rx-Packets"                => "Patton",
            "Patton-Calling-Screening-Indicator"       => "Patton",
            "Patton-Calling-Station-Id"                => "Patton",
            "Patton-Calling-Tx-Jitter"                 => "Patton",
            "Patton-Calling-Tx-Octets"                 => "Patton",
            "Patton-Calling-Tx-Packets"                => "Patton",
            "Patton-Calling-Type-Of-Number"            => "Patton",
            "Patton-Calling-Unique-Id"                 => "Patton",
            "Patton-Connect-Time"                      => "Patton",
            "Patton-Disconnect-Cause"                  => "Patton",
            "Patton-Disconnect-Reason"                 => "Patton",
            "Patton-Disconnect-Source"                 => "Patton",
            "Patton-Disconnect-Time"                   => "Patton",
            "Patton-Group"                             => "Patton",
            "Patton-Protocol"                          => "Patton",
            "Patton-Setup-Time"                        => "Patton",
            "Patton-Web-Privilege-Level"               => "Patton",
            "Perle-Clustered-Port-Access"              => "Perle",
            "Perle-Line-Access-Port-1"                 => "Perle",
            "Perle-Line-Access-Port-10"                => "Perle",
            "Perle-Line-Access-Port-11"                => "Perle",
            "Perle-Line-Access-Port-12"                => "Perle",
            "Perle-Line-Access-Port-13"                => "Perle",
            "Perle-Line-Access-Port-14"                => "Perle",
            "Perle-Line-Access-Port-15"                => "Perle",
            "Perle-Line-Access-Port-16"                => "Perle",
            "Perle-Line-Access-Port-17"                => "Perle",
            "Perle-Line-Access-Port-18"                => "Perle",
            "Perle-Line-Access-Port-19"                => "Perle",
            "Perle-Line-Access-Port-2"                 => "Perle",
            "Perle-Line-Access-Port-20"                => "Perle",
            "Perle-Line-Access-Port-21"                => "Perle",
            "Perle-Line-Access-Port-22"                => "Perle",
            "Perle-Line-Access-Port-23"                => "Perle",
            "Perle-Line-Access-Port-24"                => "Perle",
            "Perle-Line-Access-Port-25"                => "Perle",
            "Perle-Line-Access-Port-26"                => "Perle",
            "Perle-Line-Access-Port-27"                => "Perle",
            "Perle-Line-Access-Port-28"                => "Perle",
            "Perle-Line-Access-Port-29"                => "Perle",
            "Perle-Line-Access-Port-3"                 => "Perle",
            "Perle-Line-Access-Port-30"                => "Perle",
            "Perle-Line-Access-Port-31"                => "Perle",
            "Perle-Line-Access-Port-32"                => "Perle",
            "Perle-Line-Access-Port-33"                => "Perle",
            "Perle-Line-Access-Port-34"                => "Perle",
            "Perle-Line-Access-Port-35"                => "Perle",
            "Perle-Line-Access-Port-36"                => "Perle",
            "Perle-Line-Access-Port-37"                => "Perle",
            "Perle-Line-Access-Port-38"                => "Perle",
            "Perle-Line-Access-Port-39"                => "Perle",
            "Perle-Line-Access-Port-4"                 => "Perle",
            "Perle-Line-Access-Port-40"                => "Perle",
            "Perle-Line-Access-Port-41"                => "Perle",
            "Perle-Line-Access-Port-42"                => "Perle",
            "Perle-Line-Access-Port-43"                => "Perle",
            "Perle-Line-Access-Port-44"                => "Perle",
            "Perle-Line-Access-Port-45"                => "Perle",
            "Perle-Line-Access-Port-46"                => "Perle",
            "Perle-Line-Access-Port-47"                => "Perle",
            "Perle-Line-Access-Port-48"                => "Perle",
            "Perle-Line-Access-Port-49"                => "Perle",
            "Perle-Line-Access-Port-5"                 => "Perle",
            "Perle-Line-Access-Port-6"                 => "Perle",
            "Perle-Line-Access-Port-7"                 => "Perle",
            "Perle-Line-Access-Port-8"                 => "Perle",
            "Perle-Line-Access-Port-9"                 => "Perle",
            "Perle-User-Level"                         => "Perle",
            "pfSense-Bandwidth-Max-Down"               => "pfSense",
            "pfSense-Bandwidth-Max-Up"                 => "pfSense",
            "pfSense-Max-Total-Octets"                 => "pfSense",
            "Pica8-AVPair"                             => "Pica8",
            "Pica8-IP-Downloadable-ACL-Name"           => "Pica8",
            "Pica8-IP-Downloadable-ACL-Rule"           => "Pica8",
            "Pica8-Redirect-URL"                       => "Pica8",
            "Platform-Type"                            => "Ericsson-AB",
            "Police-Burst"                             => "Ericsson-AB",
            "Police-Excess-Burst"                      => "Ericsson-AB",
            "Police-Rate"                              => "Ericsson-AB",
            "PPP-Compression"                          => "Ericsson-AB",
            "PPPoE-IP-Route-Add"                       => "Ericsson-AB",
            "PPPOE-MOTM"                               => "Ericsson-AB",
            "PPPOE-URL"                                => "Ericsson-AB",
            "prev-hop-ip"                              => "Cisco",
            "prev-hop-via"                             => "Cisco",
            "Propel-Accelerate"                        => "Propel",
            "Propel-Client-IP-Address"                 => "Propel",
            "Propel-Client-NAS-IP-Address"             => "Propel",
            "Propel-Client-Source-ID"                  => "Propel",
            "Propel-Content-Filter-ID"                 => "Propel",
            "Propel-Dialed-Digits"                     => "Propel",
            "Prosoft-ATM-Interface"                    => "Prosoft",
            "Prosoft-ATM-VCI"                          => "Prosoft",
            "Prosoft-ATM-VPI"                          => "Prosoft",
            "Prosoft-Auth-Role"                        => "Prosoft",
            "Prosoft-Authentication-Reason"            => "Prosoft",
            "Prosoft-Default-Gateway"                  => "Prosoft",
            "Prosoft-Home-Agent-Address"               => "Prosoft",
            "Prosoft-MAC-Address"                      => "Prosoft",
            "Prosoft-NPM-Identifier"                   => "Prosoft",
            "Prosoft-NPM-IP"                           => "Prosoft",
            "Prosoft-Primary-DNS"                      => "Prosoft",
            "Prosoft-RSC-Identifier"                   => "Prosoft",
            "Prosoft-Secondary-DNS"                    => "Prosoft",
            "Prosoft-Sector-ID"                        => "Prosoft",
            "Prosoft-Security-Key"                     => "Prosoft",
            "Prosoft-Security-Parameter-Index"         => "Prosoft",
            "Proxim_E1_Access_VLAN_ID"                 => "Proxim",
            "Proxim_E1_Access_VLAN_Pri"                => "Proxim",
            "Proxim_E1_Allow_Untag"                    => "Proxim",
            "Proxim_E1_Port_VLAN_ID"                   => "Proxim",
            "Proxim_E1_Port_VLAN_Pri"                  => "Proxim",
            "Proxim_E1_SU_Allow_Untag_Mgmt"            => "Proxim",
            "Proxim_E1_TrunkID_01"                     => "Proxim",
            "Proxim_E1_TrunkID_02"                     => "Proxim",
            "Proxim_E1_TrunkID_03"                     => "Proxim",
            "Proxim_E1_TrunkID_04"                     => "Proxim",
            "Proxim_E1_TrunkID_05"                     => "Proxim",
            "Proxim_E1_TrunkID_06"                     => "Proxim",
            "Proxim_E1_TrunkID_07"                     => "Proxim",
            "Proxim_E1_TrunkID_08"                     => "Proxim",
            "Proxim_E1_TrunkID_09"                     => "Proxim",
            "Proxim_E1_TrunkID_10"                     => "Proxim",
            "Proxim_E1_TrunkID_11"                     => "Proxim",
            "Proxim_E1_TrunkID_12"                     => "Proxim",
            "Proxim_E1_TrunkID_13"                     => "Proxim",
            "Proxim_E1_TrunkID_14"                     => "Proxim",
            "Proxim_E1_TrunkID_15"                     => "Proxim",
            "Proxim_E1_TrunkID_16"                     => "Proxim",
            "Proxim_E1_VLAN_MODE"                      => "Proxim",
            "Proxim_E2_Access_VLAN_ID"                 => "Proxim",
            "Proxim_E2_Access_VLAN_Pri"                => "Proxim",
            "Proxim_E2_Allow_Untag"                    => "Proxim",
            "Proxim_E2_Port_VLAN_ID"                   => "Proxim",
            "Proxim_E2_Port_VLAN_Pri"                  => "Proxim",
            "Proxim_E2_SU_Allow_Untag_Mgmt"            => "Proxim",
            "Proxim_E2_TrunkID_01"                     => "Proxim",
            "Proxim_E2_TrunkID_02"                     => "Proxim",
            "Proxim_E2_TrunkID_03"                     => "Proxim",
            "Proxim_E2_TrunkID_04"                     => "Proxim",
            "Proxim_E2_TrunkID_05"                     => "Proxim",
            "Proxim_E2_TrunkID_06"                     => "Proxim",
            "Proxim_E2_TrunkID_07"                     => "Proxim",
            "Proxim_E2_TrunkID_08"                     => "Proxim",
            "Proxim_E2_TrunkID_09"                     => "Proxim",
            "Proxim_E2_TrunkID_10"                     => "Proxim",
            "Proxim_E2_TrunkID_11"                     => "Proxim",
            "Proxim_E2_TrunkID_12"                     => "Proxim",
            "Proxim_E2_TrunkID_13"                     => "Proxim",
            "Proxim_E2_TrunkID_14"                     => "Proxim",
            "Proxim_E2_TrunkID_15"                     => "Proxim",
            "Proxim_E2_TrunkID_16"                     => "Proxim",
            "Proxim_E2_VLAN_MODE"                      => "Proxim",
            "Proxim_Mgmt_VLAN_ID"                      => "Proxim",
            "Proxim_Mgmt_VLAN_Pri"                     => "Proxim",
            "Proxim_QinQ_Status"                       => "Proxim",
            "Proxim_QoS_Class_Index"                   => "Proxim",
            "Proxim_QoS_Class_SU_Status"               => "Proxim",
            "Proxim_Service_VLAN_ID"                   => "Proxim",
            "Proxim_Service_VLAN_Pri"                  => "Proxim",
            "Proxim_Service_VLAN_TPID"                 => "Proxim",
            "Proxim_SU_VLAN_NAME"                      => "Proxim",
            "Proxim_SU_VLAN_Table_Status"              => "Proxim",
            "Purewave-Client-Profile"                  => "Purewave",
            "Purewave-CS-Type"                         => "Purewave",
            "Purewave-IP-Address"                      => "Purewave",
            "Purewave-IP-Netmask"                      => "Purewave",
            "Purewave-Max-Downlink-Rate"               => "Purewave",
            "Purewave-Max-Uplink-Rate"                 => "Purewave",
            "Purewave-Service-Enable"                  => "Purewave",
            "PVC-Circuit-Padding"                      => "Ericsson-AB",
            "PVC-Encapsulation-Type"                   => "Ericsson-AB",
            "PVC-Profile-Name"                         => "Ericsson-AB",
            "Qos-Metering-Profile-Name"                => "Ericsson-AB",
            "Qos-Policing-Profile-Name"                => "Ericsson-AB",
            "Qos-Policy-Queuing"                       => "Ericsson-AB",
            "Qos-Profile-Overhead"                     => "Ericsson-AB",
            "Qos-Rate"                                 => "Ericsson-AB",
            "QOS-Rate-Inbound"                         => "Ericsson-AB",
            "QOS-Rate-Outbound"                        => "Ericsson-AB",
            "QOS-Reference"                            => "Ericsson-AB",
            "Quiconnect-AVPair"                        => "Quiconnect",
            "Quiconnect-HSP-Information"               => "Quiconnect",
            "Quiconnect-VNP-Information"               => "Quiconnect",
            "Quintum-AVPair"                           => "Quintum",
            "Quintum-h323-billing-model"               => "Quintum",
            "Quintum-h323-call-origin"                 => "Quintum",
            "Quintum-h323-call-type"                   => "Quintum",
            "Quintum-h323-conf-id"                     => "Quintum",
            "Quintum-h323-connect-time"                => "Quintum",
            "Quintum-h323-credit-amount"               => "Quintum",
            "Quintum-h323-credit-time"                 => "Quintum",
            "Quintum-h323-currency-type"               => "Quintum",
            "Quintum-h323-disconnect-cause"            => "Quintum",
            "Quintum-h323-disconnect-time"             => "Quintum",
            "Quintum-h323-gw-id"                       => "Quintum",
            "Quintum-h323-incoming-conf-id"            => "Quintum",
            "Quintum-h323-preferred-lang"              => "Quintum",
            "Quintum-h323-prompt-id"                   => "Quintum",
            "Quintum-h323-redirect-ip-address"         => "Quintum",
            "Quintum-h323-redirect-number"             => "Quintum",
            "Quintum-h323-remote-address"              => "Quintum",
            "Quintum-h323-return-code"                 => "Quintum",
            "Quintum-h323-setup-time"                  => "Quintum",
            "Quintum-h323-time-and-day"                => "Quintum",
            "Quintum-h323-voice-quality"               => "Quintum",
            "Quintum-NAS-Port"                         => "Quintum",
            "Quintum-Trunkid-In"                       => "Quintum",
            "Quintum-Trunkid-Out"                      => "Quintum",
            "Radius-Throttle-Watermark"                => "Ericsson-AB",
            "Rate-Limit-Burst"                         => "Ericsson-AB",
            "Rate-Limit-Excess-Burst"                  => "Ericsson-AB",
            "Rate-Limit-Rate"                          => "Ericsson-AB",
            "RB-IPV6-DNS"                              => "Ericsson-AB",
            "RB-IPv6-Option"                           => "Ericsson-AB",
            "RB-NPM-Service-Id"                        => "Ericsson-AB",
            "RCNTEC-RPCM-Group"                        => "RCNTEC",
            "RCNTEC-RPCM-Session-Expire"               => "RCNTEC",
            "Reauth"                                   => "Ericsson-AB",
            "Reauth-More"                              => "Ericsson-AB",
            "Reauth-Service-Name"                      => "Ericsson-AB",
            "Reauth-Session-Id"                        => "Ericsson-AB",
            "Redback-Reason"                           => "Ericsson-AB",
            "RedCreek-Tunneled-DNS-Server"             => "RedCreek",
            "RedCreek-Tunneled-DomainName"             => "RedCreek",
            "RedCreek-Tunneled-Gateway"                => "RedCreek",
            "RedCreek-Tunneled-HostName"               => "RedCreek",
            "RedCreek-Tunneled-IP-Addr"                => "RedCreek",
            "RedCreek-Tunneled-IP-Netmask"             => "RedCreek",
            "RedCreek-Tunneled-Search-List"            => "RedCreek",
            "RedCreek-Tunneled-WINS-Server1"           => "RedCreek",
            "RedCreek-Tunneled-WINS-Server2"           => "RedCreek",
            "release-source"                           => "Cisco",
            "remote-media-address"                     => "Cisco",
            "Remote-Port"                              => "Ericsson-AB",
            "Riverbed-Local-User"                      => "Riverbed",
            "Riverstone-Command"                       => "Riverstone",
            "Riverstone-SNMP-Config-Change"            => "Riverstone",
            "Riverstone-System-Event"                  => "Riverstone",
            "Riverstone-User-Level"                    => "Riverstone",
            "Route-Tag"                                => "Ericsson-AB",
            "RP-Downstream-Speed-Limit"                => "Roaring-Penguin",
            "RP-HURL"                                  => "Roaring-Penguin",
            "RP-Max-Sessions-Per-User"                 => "Roaring-Penguin",
            "RP-MOTM"                                  => "Roaring-Penguin",
            "RP-Upstream-Speed-Limit"                  => "Roaring-Penguin",
            "Ruckus-AAA-Id"                            => "Ruckus",
            "Ruckus-AAA-IP"                            => "Ruckus",
            "Ruckus-Accept-Enhancement-Reason"         => "Ruckus",
            "Ruckus-Accounting-Status"                 => "Ruckus",
            "Ruckus-Acct-Ctrs_Input-Octets"            => "Ruckus",
            "Ruckus-Acct-Ctrs_Input-Packets"           => "Ruckus",
            "Ruckus-Acct-Ctrs_Output-Octets"           => "Ruckus",
            "Ruckus-Acct-Ctrs_Output-Packets"          => "Ruckus",
            "Ruckus-Acct-Ctrs_TC-Name"                 => "Ruckus",
            "Ruckus-AP-Roamed"                         => "Ruckus",
            "Ruckus-APN-NI"                            => "Ruckus",
            "Ruckus-APN-OI"                            => "Ruckus",
            "Ruckus-APN-Resolution-Req"                => "Ruckus",
            "Ruckus-Area-Code"                         => "Ruckus",
            "Ruckus-Auth-Server-Id"                    => "Ruckus",
            "Ruckus-Auth-Type"                         => "Ruckus",
            "Ruckus-Brand-Code"                        => "Ruckus",
            "Ruckus-BSSID"                             => "Ruckus",
            "Ruckus-CDR-TYPE"                          => "Ruckus",
            "Ruckus-Cell-Identifier"                   => "Ruckus",
            "Ruckus-Charging-Charac"                   => "Ruckus",
            "Ruckus-ChCh-Selection-Mode"               => "Ruckus",
            "Ruckus-Client-Device-Type"                => "Ruckus",
            "Ruckus-Client-Host-Name"                  => "Ruckus",
            "Ruckus-Client-Local-IP"                   => "Ruckus",
            "Ruckus-Client-Os-Class"                   => "Ruckus",
            "Ruckus-Client-Os-Type"                    => "Ruckus",
            "Ruckus-Cluster-Name"                      => "Ruckus",
            "Ruckus-CP-Token"                          => "Ruckus",
            "Ruckus-Domain-Name"                       => "Ruckus",
            "Ruckus-DPSK"                              => "Ruckus",
            "Ruckus-DPSK-AKM-Suite"                    => "Ruckus",
            "Ruckus-DPSK-Anonce"                       => "Ruckus",
            "Ruckus-DPSK-Cipher"                       => "Ruckus",
            "Ruckus-DPSK-EAPOL-Key-Frame"              => "Ruckus",
            "Ruckus-DPSK-Params"                       => "Ruckus",
            "Ruckus-Dynamic-Address-Flag"              => "Ruckus",
            "Ruckus-Eth-Profile-Id"                    => "Ruckus",
            "Ruckus-FlexAuth-AVP"                      => "Ruckus",
            "Ruckus-Gn-User-Name"                      => "Ruckus",
            "Ruckus-Grace-Period"                      => "Ruckus",
            "Ruckus-IMSI"                              => "Ruckus",
            "Ruckus-Location"                          => "Ruckus",
            "Ruckus-Max-DL-UL-Quota"                   => "Ruckus",
            "Ruckus-MSISDN"                            => "Ruckus",
            "Ruckus-NAS-Type"                          => "Ruckus",
            "Ruckus-Nat-Pool-Name"                     => "Ruckus",
            "Ruckus-PDP-Type"                          => "Ruckus",
            "Ruckus-Policy-Name"                       => "Ruckus",
            "Ruckus-QoS"                               => "Ruckus",
            "Ruckus-Read-Preference"                   => "Ruckus",
            "Ruckus-SCG-CBlade-IP"                     => "Ruckus",
            "Ruckus-SCG-DBlade-IP"                     => "Ruckus",
            "Ruckus-SCI-Resource-Group"                => "Ruckus",
            "Ruckus-SCI-Role"                          => "Ruckus",
            "Ruckus-Selection-Mode"                    => "Ruckus",
            "Ruckus-Session-Type"                      => "Ruckus",
            "Ruckus-SGSN-IP"                           => "Ruckus",
            "Ruckus-SGSN-Number"                       => "Ruckus",
            "Ruckus-SSID"                              => "Ruckus",
            "Ruckus-Sta-Expiration"                    => "Ruckus",
            "Ruckus-Sta-Inner-Id"                      => "Ruckus",
            "Ruckus-Sta-RSSI"                          => "Ruckus",
            "Ruckus-Sta-SVlan-Id"                      => "Ruckus",
            "Ruckus-Sta-UUID"                          => "Ruckus",
            "Ruckus-Start-Time"                        => "Ruckus",
            "Ruckus-Status"                            => "Ruckus",
            "Ruckus-TC-Acct-Ctrs"                      => "Ruckus",
            "Ruckus-TC-Attr-Ids-With-Quota"            => "Ruckus",
            "Ruckus-TC-Name-Quota"                     => "Ruckus",
            "Ruckus-TC-Quota"                          => "Ruckus",
            "Ruckus-Traffic-Class-Attribute-Ids"       => "Ruckus",
            "Ruckus-Triplets"                          => "Ruckus",
            "Ruckus-User-Groups"                       => "Ruckus",
            "Ruckus-Utp-Id"                            => "Ruckus",
            "Ruckus-VLAN-ID"                           => "Ruckus",
            "Ruckus-Vlan-Name"                         => "Ruckus",
            "Ruckus-Vlan-Pool"                         => "Ruckus",
            "Ruckus-Wispr-Redirect-Policy"             => "Ruckus",
            "Ruckus-Wlan-Id"                           => "Ruckus",
            "Ruckus-Wlan-Name"                         => "Ruckus",
            "Ruckus-WSG-User"                          => "Ruckus",
            "Ruckus-Zone-Id"                           => "Ruckus",
            "Ruckus-Zone-Name"                         => "Ruckus",
            "RuggedCom-Privilege-level"                => "RuggedCom",
            "SAML-AAA-Assertion"                       => "UKERNA",
            "SBC-Adjacency"                            => "Ericsson-AB",
            "Sdx-Service-Name"                         => "ERX",
            "Sdx-Session-Volume-Quota"                 => "ERX",
            "Sdx-Tunnel-Disconnect-Cause-Info"         => "ERX",
            "Security-Service"                         => "Ericsson-AB",
            "Service-Action"                           => "Ericsson-AB",
            "Service-Data-Container"                   => "VerizonWireless",
            "Service-Data-Container-Bin"               => "VerizonWireless",
            "Service-Error-Cause"                      => "Ericsson-AB",
            "Service-Name"                             => "Ericsson-AB",
            "Service-Parameter"                        => "Ericsson-AB",
            "Session-Error-Code"                       => "Ericsson-AB",
            "Session-Error-Msg"                        => "Ericsson-AB",
            "session-protocol"                         => "Cisco",
            "Session-Traffic-Limit"                    => "Ericsson-AB",
            "SG-Accounting"                            => "SG",
            "SG-Acl-Data-Quota"                        => "SG",
            "SG-Acl-Data-Quota-Used"                   => "SG",
            "SG-Acl-Down-Mean-Rate"                    => "SG",
            "SG-Acl-Eds-Action"                        => "SG",
            "SG-Acl-Idle-Ignore"                       => "SG",
            "SG-Acl-Next-Hop"                          => "SG",
            "SG-Acl-Packet-Quota"                      => "SG",
            "SG-Acl-Packet-Quota-Used"                 => "SG",
            "SG-Acl-Priority"                          => "SG",
            "SG-Acl-Tcp-Nat-Redirect"                  => "SG",
            "SG-Acl-Up-Mean-Rate"                      => "SG",
            "SG-Action"                                => "SG",
            "SG-Advertise-Protocol"                    => "SG",
            "SG-Auth-Source"                           => "SG",
            "SG-Auth-Type"                             => "SG",
            "SG-Auto-Service-Name"                     => "SG",
            "SG-Burst-Size"                            => "SG",
            "SG-Class"                                 => "SG",
            "SG-Cos"                                   => "SG",
            "SG-Data-Quota"                            => "SG",
            "SG-Data-Quota-Used"                       => "SG",
            "SG-Dhcp-Server"                           => "SG",
            "SG-Discover-Action"                       => "SG",
            "SG-Down-Mean-Rate"                        => "SG",
            "SG-Eds-Cookie"                            => "SG",
            "SG-Eds-Enc-Key"                           => "SG",
            "SG-Filter-Redirect-Gw"                    => "SG",
            "SG-Fixed-Ip-Address"                      => "SG",
            "SG-Forward-Addr"                          => "SG",
            "SG-Ip-Address"                            => "SG",
            "SG-Ip-Primary"                            => "SG",
            "SG-Ip-Secondary"                          => "SG",
            "SG-Ip-Tunnel"                             => "SG",
            "SG-L2tp-Tunnel-Password"                  => "SG",
            "SG-Lease-Time"                            => "SG",
            "SG-Mac-Address"                           => "SG",
            "SG-Max-Allowed-Nodes"                     => "SG",
            "SG-Max-Allowed-Sessions"                  => "SG",
            "SG-Nativeip"                              => "SG",
            "SG-Next-Hop"                              => "SG",
            "SG-Next-Service-Name"                     => "SG",
            "SG-Nip-Pipe-Next-Hop"                     => "SG",
            "SG-Node-Acct-Username"                    => "SG",
            "SG-Node-Default-Service"                  => "SG",
            "SG-Node-Dynamic-Service"                  => "SG",
            "SG-Node-Fixed-Ip-Address"                 => "SG",
            "SG-Node-Group"                            => "SG",
            "SG-Opt82-Relay-Remote-Id"                 => "SG",
            "SG-Orig-Name"                             => "SG",
            "SG-Original-Url-Prefix"                   => "SG",
            "SG-Parent-User-Name"                      => "SG",
            "SG-Personal-Site"                         => "SG",
            "SG-Protocol-Type"                         => "SG",
            "SG-Release-Action"                        => "SG",
            "SG-Remote-Filter-Redirect-Gw"             => "SG",
            "SG-Roaming"                               => "SG",
            "SG-Service-Acl-Quota-Ignore"              => "SG",
            "SG-Service-Acl-Quota-Indication"          => "SG",
            "SG-Service-Cache"                         => "SG",
            "SG-Service-Name"                          => "SG",
            "SG-Service-Quota-Ignore"                  => "SG",
            "SG-Service-Timeout"                       => "SG",
            "SG-SSC-Host"                              => "SG",
            "SG-Tunnel-Assignment-Id"                  => "SG",
            "SG-Tunnel-Client-Ip-Address"              => "SG",
            "SG-Tunnel-Id"                             => "SG",
            "SG-Up-Mean-Rate"                          => "SG",
            "SG-User-Group"                            => "SG",
            "SG-Wimax-Acl-ARQ-Enable"                  => "SG",
            "SG-Wimax-Acl-Maximum-Latency"             => "SG",
            "SG-Wimax-Acl-Maximum-Traffic-Burst"       => "SG",
            "SG-Wimax-Acl-Min-Reserved-Traffic-Rate"   => "SG",
            "SG-Wimax-Acl-Schedule-Type"               => "SG",
            "SG-Wimax-Acl-Sdu-Size"                    => "SG",
            "SG-Wimax-Acl-Tolerated-Jitter"            => "SG",
            "SG-Wimax-Acl-Unsolicited-Grant-Int"       => "SG",
            "SG-Wimax-Acl-Unsolicited-Polling-Int"     => "SG",
            "SG-Wimax-Bsid-Next-Hop"                   => "SG",
            "SG-Wimax-DM-Action-Code"                  => "SG",
            "SG-Wimax-Mobility-Features-Supported"     => "SG",
            "SG-Wimax-MSK-Lifetime"                    => "SG",
            "SG-Wimax-Node-Disconnect"                 => "SG",
            "SG-Wimax-Reduced-Resources"               => "SG",
            "SG-Wimax-Service-Flow-Down"               => "SG",
            "SG-Wimax-Service-Flow-Modification"       => "SG",
            "Shaping-Profile-Name"                     => "Ericsson-AB",
            "Shasta-Service-Profile"                   => "Shasta",
            "Shasta-User-Privilege"                    => "Shasta",
            "Shasta-VPN-Name"                          => "Shasta",
            "Shiva-Acct-Serv-Switch"                   => "Shiva",
            "Shiva-Bak-Key"                            => "Shiva",
            "Shiva-Bandwidth-Trap"                     => "Shiva",
            "Shiva-Break-Key"                          => "Shiva",
            "Shiva-Call-Durn-Trap"                     => "Shiva",
            "Shiva-Called-Number"                      => "Shiva",
            "Shiva-Calling-Number"                     => "Shiva",
            "Shiva-Circuit-Type"                       => "Shiva",
            "Shiva-Compression"                        => "Shiva",
            "Shiva-Compression-Type"                   => "Shiva",
            "Shiva-Connect-Reason"                     => "Shiva",
            "Shiva-Customer-Id"                        => "Shiva",
            "Shiva-Default-Host"                       => "Shiva",
            "Shiva-DHCP-Leasetime"                     => "Shiva",
            "Shiva-Dial-Timeout"                       => "Shiva",
            "Shiva-Dialback-Delay"                     => "Shiva",
            "Shiva-Disconnect-Reason"                  => "Shiva",
            "Shiva-Event-Flags"                        => "Shiva",
            "Shiva-Function"                           => "Shiva",
            "Shiva-Fwd-Key"                            => "Shiva",
            "Shiva-LAT-Groups"                         => "Shiva",
            "Shiva-LAT-Port"                           => "Shiva",
            "Shiva-Link-Protocol"                      => "Shiva",
            "Shiva-Link-Speed"                         => "Shiva",
            "Shiva-Links-In-Bundle"                    => "Shiva",
            "Shiva-Max-VCs"                            => "Shiva",
            "Shiva-Menu-Name"                          => "Shiva",
            "Shiva-Minimum-Call"                       => "Shiva",
            "Shiva-Network-Protocols"                  => "Shiva",
            "Shiva-RTC-Timestamp"                      => "Shiva",
            "Shiva-Session-Id"                         => "Shiva",
            "Shiva-Termtype"                           => "Shiva",
            "Shiva-Type-Of-Service"                    => "Shiva",
            "Shiva-User-Attributes"                    => "Shiva",
            "Shiva-User-Flags"                         => "Shiva",
            "SID-Auth"                                 => "BT",
            "Siemens-AP-Name"                          => "Siemens",
            "Siemens-AP-Serial"                        => "Siemens",
            "Siemens-BSS-MAC"                          => "Siemens",
            "Siemens-Egress-RC-Name"                   => "Siemens",
            "Siemens-Ingress-RC-Name"                  => "Siemens",
            "Siemens-Policy-Name"                      => "Siemens",
            "Siemens-SSID"                             => "Siemens",
            "Siemens-Topology-Name"                    => "Siemens",
            "Siemens-URL-Redirection"                  => "Siemens",
            "Siemens-VNS-Name"                         => "Siemens",
            "sip-conf-id"                              => "Cisco",
            "Sip-From"                                 => "Columbia-University",
            "sip-hdr"                                  => "Cisco",
            "Sip-Method"                               => "Columbia-University",
            "Sip-To"                                   => "Columbia-University",
            "Sip-Translated-Request-URI"               => "Columbia-University",
            "Sky-Wifi-AP-ID"                           => "BSkyB",
            "Sky-Wifi-Billing-Class"                   => "BSkyB",
            "Sky-Wifi-Credentials"                     => "BSkyB",
            "Sky-Wifi-Filter-Profile"                  => "BSkyB",
            "Sky-Wifi-Protocol-Restriction"            => "BSkyB",
            "Sky-Wifi-Provider-ID"                     => "BSkyB",
            "Sky-Wifi-Replicated-Packet"               => "BSkyB",
            "Sky-Wifi-Service-ID"                      => "BSkyB",
            "Slipstream-Auth"                          => "Slipstream",
            "SN-Access-link-IP-Frag"                   => "Starent",
            "SN-Acct-Input-Giga-Dropped"               => "Starent",
            "SN-Acct-Input-Octets-Dropped"             => "Starent",
            "SN-Acct-Input-Packets-Dropped"            => "Starent",
            "SN-Acct-Output-Giga-Dropped"              => "Starent",
            "SN-Acct-Output-Octets-Dropped"            => "Starent",
            "SN-Acct-Output-Packets-Dropped"           => "Starent",
            "SN-Acs-Credit-Control-Group"              => "Starent",
            "SN-Admin-Expiry"                          => "Starent",
            "SN-Admin-Permission"                      => "Starent",
            "SN-ANID"                                  => "Starent",
            "SN-Assigned-VLAN-ID"                      => "Starent",
            "SN-Authorised-Qos"                        => "Starent",
            "SN-Bandwidth-Policy"                      => "Starent",
            "SN-Call-Id"                               => "Starent",
            "SN-Cause-Code"                            => "Starent",
            "SN-Cause-For-Rec-Closing"                 => "Starent",
            "SN-CBB-Policy"                            => "Starent",
            "SN-CF-Call-International"                 => "Starent",
            "SN-CF-Call-Local"                         => "Starent",
            "SN-CF-Call-LongDistance"                  => "Starent",
            "SN-CF-Call-Premium"                       => "Starent",
            "SN-CF-Call-RoamingInternatnl"             => "Starent",
            "SN-CF-Call-Transfer"                      => "Starent",
            "SN-CF-Call-Waiting"                       => "Starent",
            "SN-CF-CId-Display"                        => "Starent",
            "SN-CF-CId-Display-Blocked"                => "Starent",
            "SN-CF-Follow-Me"                          => "Starent",
            "SN-CF-Forward-Busy-Line"                  => "Starent",
            "SN-CF-Forward-No-Answer"                  => "Starent",
            "SN-CF-Forward-Not-Regd"                   => "Starent",
            "SN-CF-Forward-Unconditional"              => "Starent",
            "SN-CFPolicy-ID"                           => "Starent",
            "SN-Change-Condition"                      => "Starent",
            "SN-Charging-VPN-Name"                     => "Starent",
            "SN-Chrg-Char-Selection-Mode"              => "Starent",
            "SN-Congestion-Mgmt-Policy"                => "Starent",
            "SN-Content-Disposition"                   => "Starent",
            "SN-Content-Length"                        => "Starent",
            "SN-Content-Type"                          => "Starent",
            "SN-CR-International-Cid"                  => "Starent",
            "SN-CR-LongDistance-Cid"                   => "Starent",
            "SN-CSCF-App-Server-Info"                  => "Starent",
            "SN-CSCF-Rf-SDP-Media-Components"          => "Starent",
            "SN-Cscf-Subscriber-Ip-Address"            => "Starent",
            "SN-Data-Tunnel-Ignore-DF-Bit"             => "Starent",
            "SN-DHCP-Lease-Expiry-Policy"              => "Starent",
            "SN-DHCP-Options"                          => "Starent",
            "SN-Direction"                             => "Starent",
            "SN-Disconnect-Reason"                     => "Starent",
            "SN-DNS-Proxy-Intercept-List"              => "Starent",
            "SN-DNS-Proxy-Use-Subscr-Addr"             => "Starent",
            "SN-Dynamic-Addr-Alloc-Ind-Flag"           => "Starent",
            "SN-Ecs-Data-Volume"                       => "Starent",
            "SN-Enable-QoS-Renegotiation"              => "Starent",
            "SN-Event"                                 => "Starent",
            "SN-Ext-Inline-Srvr-Context"               => "Starent",
            "SN-Ext-Inline-Srvr-Down-Addr"             => "Starent",
            "SN-Ext-Inline-Srvr-Down-VLAN"             => "Starent",
            "SN-Ext-Inline-Srvr-Preference"            => "Starent",
            "SN-Ext-Inline-Srvr-Up-Addr"               => "Starent",
            "SN-Ext-Inline-Srvr-Up-VLAN"               => "Starent",
            "SN-Fast-Reauth-Username"                  => "Starent",
            "SN-Firewall-Enabled"                      => "Starent",
            "SN-Firewall-Policy"                       => "Starent",
            "SN-FMC-Location"                          => "Starent",
            "SN-GGSN-Address"                          => "Starent",
            "SN-GGSN-MIP-Required"                     => "Starent",
            "SN-Gratuitous-ARP-Aggressive"             => "Starent",
            "SN-GTP-Version"                           => "Starent",
            "SN-HA-Send-DNS-ADDRESS"                   => "Starent",
            "SN-Handoff-Indicator"                     => "Starent",
            "SN-Home-Behavior"                         => "Starent",
            "SN-Home-Profile"                          => "Starent",
            "SN-Home-Sub-Use-GGSN"                     => "Starent",
            "SN-IMS-AM-Address"                        => "Starent",
            "SN-IMS-AM-Domain-Name"                    => "Starent",
            "SN-IMS-Charging-Identifier"               => "Starent",
            "SN-IMSI"                                  => "Starent",
            "SN-Internal-SM-Index"                     => "Starent",
            "SN-IP-Alloc-Method"                       => "Starent",
            "SN-IP-Filter-In"                          => "Starent",
            "SN-IP-Filter-Out"                         => "Starent",
            "SN-IP-Header-Compression"                 => "Starent",
            "SN-IP-Hide-Service-Address"               => "Starent",
            "SN-IP-In-ACL"                             => "Starent",
            "SN-IP-In-Plcy-Grp"                        => "Starent",
            "SN-IP-Out-ACL"                            => "Starent",
            "SN-IP-Out-Plcy-Grp"                       => "Starent",
            "SN-IP-Pool-Name"                          => "Starent",
            "SN-IP-Source-Validation"                  => "Starent",
            "SN-IP-Source-Violate-No-Acct"             => "Starent",
            "SN-IP-Src-Validation-Drop-Limit"          => "Starent",
            "SN-IPv6-Alloc-Method"                     => "Starent",
            "SN-IPv6-DNS-Proxy"                        => "Starent",
            "SN-IPv6-Egress-Filtering"                 => "Starent",
            "SN-IPv6-Min-Link-MTU"                     => "Starent",
            "SN-IPv6-num-rtr-advt"                     => "Starent",
            "SN-IPv6-Primary-DNS"                      => "Starent",
            "SN-IPv6-rtr-advt-interval"                => "Starent",
            "SN-IPv6-Sec-Pool"                         => "Starent",
            "SN-IPv6-Sec-Prefix"                       => "Starent",
            "SN-IPv6-Secondary-DNS"                    => "Starent",
            "SN-Is-Unregistered-Subscriber"            => "Starent",
            "SN-ISC-Template-Name"                     => "Starent",
            "SN-L3-to-L2-Tun-Addr-Policy"              => "Starent",
            "SN-Local-IP-Address"                      => "Starent",
            "SN-Long-Duration-Action"                  => "Starent",
            "SN-Long-Duration-Notification"            => "Starent",
            "SN-Long-Duration-Timeout"                 => "Starent",
            "SN-Max-Sec-Contexts-Per-Subs"             => "Starent",
            "SN-Mediation-Acct-Rsp-Action"             => "Starent",
            "SN-Mediation-Enabled"                     => "Starent",
            "SN-Mediation-No-Interims"                 => "Starent",
            "SN-Mediation-VPN-Name"                    => "Starent",
            "SN-Min-Compress-Size"                     => "Starent",
            "SN-MIP-AAA-Assign-Addr"                   => "Starent",
            "SN-MIP-ANCID"                             => "Starent",
            "SN-MIP-Dual-Anchor"                       => "Starent",
            "SN-MIP-HA-Assignment-Table"               => "Starent",
            "SN-MIP-Match-AAA-Assign-Addr"             => "Starent",
            "SN-MIP-Reg-Lifetime-Realm"                => "Starent",
            "SN-MIP-Send-Ancid"                        => "Starent",
            "SN-MIP-Send-Correlation-Info"             => "Starent",
            "SN-MIP-Send-Imsi"                         => "Starent",
            "SN-MIP-Send-Term-Verification"            => "Starent",
            "SN-MN-HA-Hash-Algorithm"                  => "Starent",
            "SN-MN-HA-Timestamp-Tolerance"             => "Starent",
            "SN-Mode"                                  => "Starent",
            "SN-MS-ISDN"                               => "Starent",
            "SN-NAI-Construction-Domain"               => "Starent",
            "SN-NAT-IP-Address"                        => "Starent",
            "SN-Node-Functionality"                    => "Starent",
            "SN-NPU-Qos-Priority"                      => "Starent",
            "SN-Ntk-Initiated-Ctx-Ind-Flag"            => "Starent",
            "SN-Ntk-Session-Disconnect-Flag"           => "Starent",
            "SN-Nw-Reachability-Server-Name"           => "Starent",
            "SN-Originating-IOI"                       => "Starent",
            "SN-Overload-Disc-Connect-Time"            => "Starent",
            "SN-Overload-Disconnect"                   => "Starent",
            "SN-PDG-TTG-Required"                      => "Starent",
            "SN-PDIF-MIP-Release-TIA"                  => "Starent",
            "SN-PDIF-MIP-Required"                     => "Starent",
            "SN-PDIF-MIP-Simple-IP-Fallback"           => "Starent",
            "SN-PDSN-Correlation-Id"                   => "Starent",
            "SN-PDSN-Handoff-Req-IP-Addr"              => "Starent",
            "SN-PDSN-NAS-Id"                           => "Starent",
            "SN-PDSN-NAS-IP-Address"                   => "Starent",
            "SN-Permit-User-Mcast-PDUs"                => "Starent",
            "SN-PPP-Accept-Peer-v6Ifid"                => "Starent",
            "SN-PPP-Always-On-Vse"                     => "Starent",
            "SN-PPP-Data-Compression"                  => "Starent",
            "SN-PPP-Data-Compression-Mode"             => "Starent",
            "SN-PPP-Keepalive"                         => "Starent",
            "SN-PPP-NW-Layer-IPv4"                     => "Starent",
            "SN-PPP-NW-Layer-IPv6"                     => "Starent",
            "SN-PPP-Outbound-Password"                 => "Starent",
            "SN-PPP-Outbound-Username"                 => "Starent",
            "SN-PPP-Progress-Code"                     => "Starent",
            "SN-PPP-Reneg-Disc"                        => "Starent",
            "SN-Prepaid"                               => "Starent",
            "SN-Prepaid-Compressed-Count"              => "Starent",
            "SN-Prepaid-Final-Duration-Alg"            => "Starent",
            "SN-Prepaid-Inbound-Octets"                => "Starent",
            "SN-Prepaid-Outbound-Octets"               => "Starent",
            "SN-Prepaid-Preference"                    => "Starent",
            "SN-Prepaid-Timeout"                       => "Starent",
            "SN-Prepaid-Total-Octets"                  => "Starent",
            "SN-Prepaid-Watermark"                     => "Starent",
            "SN-Primary-DCCA-Peer"                     => "Starent",
            "SN-Primary-DNS-Server"                    => "Starent",
            "SN-Primary-NBNS-Server"                   => "Starent",
            "SN-Proxy-MIP"                             => "Starent",
            "SN-Proxy-MIPV6"                           => "Starent",
            "SN-Pseudonym-Username"                    => "Starent",
            "SN-QoS-Background-Class"                  => "Starent",
            "SN-QoS-Class-Background-PHB"              => "Starent",
            "SN-QoS-Class-Conversational-PHB"          => "Starent",
            "SN-QoS-Class-Interactive-1-PHB"           => "Starent",
            "SN-QoS-Class-Interactive-2-PHB"           => "Starent",
            "SN-QoS-Class-Interactive-3-PHB"           => "Starent",
            "SN-QoS-Class-Streaming-PHB"               => "Starent",
            "SN-QoS-Conversation-Class"                => "Starent",
            "SN-QOS-HLR-Profile"                       => "Starent",
            "SN-QoS-Interactive1-Class"                => "Starent",
            "SN-QoS-Interactive2-Class"                => "Starent",
            "SN-QoS-Interactive3-Class"                => "Starent",
            "SN-QoS-Negotiated"                        => "Starent",
            "SN-QoS-Renegotiation-Timeout"             => "Starent",
            "SN-QoS-Streaming-Class"                   => "Starent",
            "SN-QoS-Tp-Dnlk"                           => "Starent",
            "SN-QoS-Tp-Uplk"                           => "Starent",
            "SN-QoS-Traffic-Policy"                    => "Starent",
            "SN-Rad-APN-Name"                          => "Starent",
            "SN-Radius-Returned-Username"              => "Starent",
            "SN-Re-CHAP-Interval"                      => "Starent",
            "SN-Roaming-Behavior"                      => "Starent",
            "SN-Roaming-Profile"                       => "Starent",
            "SN-Roaming-Sub-Use-GGSN"                  => "Starent",
            "SN-ROHC-Flow-Marking-Mode"                => "Starent",
            "SN-ROHC-Profile-Name"                     => "Starent",
            "SN-Role-Of-Node"                          => "Starent",
            "SN-Routing-Area-Id"                       => "Starent",
            "SN-Rulebase"                              => "Starent",
            "SN-SDP-Session-Description"               => "Starent",
            "SN-Sec-IP-Pool-Name"                      => "Starent",
            "SN-Secondary-DCCA-Peer"                   => "Starent",
            "SN-Secondary-DNS-Server"                  => "Starent",
            "SN-Secondary-NBNS-Server"                 => "Starent",
            "SN-Service-Address"                       => "Starent",
            "SN-Service-Type"                          => "Starent",
            "SN-Session-Id"                            => "Starent",
            "SN-Simultaneous-SIP-MIP"                  => "Starent",
            "SN-SIP-Method"                            => "Starent",
            "SN-SIP-Request-Time-Stamp"                => "Starent",
            "SN-SIP-Response-Time-Stamp"               => "Starent",
            "SN-Software-Version"                      => "Starent",
            "SN-Subs-Acc-Flow-Traffic-Valid"           => "Starent",
            "SN-Subs-IMSA-Service-Name"                => "Starent",
            "SN-Subs-VJ-Slotid-Cmp-Neg-Mode"           => "Starent",
            "SN-Subscriber-Accounting"                 => "Starent",
            "SN-Subscriber-Acct-Interim"               => "Starent",
            "SN-Subscriber-Acct-Mode"                  => "Starent",
            "SN-Subscriber-Acct-Rsp-Action"            => "Starent",
            "SN-Subscriber-Acct-Start"                 => "Starent",
            "SN-Subscriber-Acct-Stop"                  => "Starent",
            "SN-Subscriber-Class"                      => "Starent",
            "SN-Subscriber-IP-Hdr-Neg-Mode"            => "Starent",
            "SN-Subscriber-IP-TOS-Copy"                => "Starent",
            "SN-Subscriber-Nexthop-Address"            => "Starent",
            "SN-Subscriber-No-Interims"                => "Starent",
            "SN-Subscriber-Permission"                 => "Starent",
            "SN-Subscriber-Template-Name"              => "Starent",
            "SN-Terminating-IOI"                       => "Starent",
            "SN-Tp-Dnlk-Burst-Size"                    => "Starent",
            "SN-Tp-Dnlk-Committed-Data-Rate"           => "Starent",
            "SN-Tp-Dnlk-Exceed-Action"                 => "Starent",
            "SN-Tp-Dnlk-Peak-Data-Rate"                => "Starent",
            "SN-Tp-Dnlk-Violate-Action"                => "Starent",
            "SN-Tp-Uplk-Burst-Size"                    => "Starent",
            "SN-Tp-Uplk-Committed-Data-Rate"           => "Starent",
            "SN-Tp-Uplk-Exceed-Action"                 => "Starent",
            "SN-Tp-Uplk-Peak-Data-Rate"                => "Starent",
            "SN-Tp-Uplk-Violate-Action"                => "Starent",
            "SN-Traffic-Group"                         => "Starent",
            "SN-TrafficSelector-Class"                 => "Starent",
            "SN-Transparent-Data"                      => "Starent",
            "SN-Tun-Addr-Policy"                       => "Starent",
            "SN-Tunnel-Gn"                             => "Starent",
            "SN-Tunnel-ISAKMP-Crypto-Map"              => "Starent",
            "SN-Tunnel-ISAKMP-Secret"                  => "Starent",
            "SN-Tunnel-Load-Balancing"                 => "Starent",
            "SN-Tunnel-Password"                       => "Starent",
            "SN-Unclassify-List-Name"                  => "Starent",
            "SN-User-Privilege"                        => "Starent",
            "SN-Virtual-APN-Name"                      => "Starent",
            "SN-Visiting-Behavior"                     => "Starent",
            "SN-Visiting-Profile"                      => "Starent",
            "SN-Visiting-Sub-Use-GGSN"                 => "Starent",
            "SN-Voice-Push-List-Name"                  => "Starent",
            "SN-VPN-ID"                                => "Starent",
            "SN-VPN-Name"                              => "Starent",
            "SN-WiMAX-Auth-Only"                       => "Starent",
            "SN-WLAN-AP-Identifier"                    => "Starent",
            "SN-WLAN-UE-Identifier"                    => "Starent",
            "SN-WSG-MIP-Release-TIA"                   => "Starent",
            "SN-WSG-MIP-Required"                      => "Starent",
            "SN-WSG-MIP-Simple-IP-Fallback"            => "Starent",
            "SNA-Input-Gigawords"                      => "Starent",
            "SNA-Output-Gigawords"                     => "Starent",
            "SNA-PPP-Bad-Addr"                         => "Starent",
            "SNA-PPP-Bad-Ctrl"                         => "Starent",
            "SNA-PPP-Bad-FCS"                          => "Starent",
            "SNA-PPP-Ctrl-Input-Octets"                => "Starent",
            "SNA-PPP-Ctrl-Input-Packets"               => "Starent",
            "SNA-PPP-Ctrl-Output-Octets"               => "Starent",
            "SNA-PPP-Ctrl-Output-Packets"              => "Starent",
            "SNA-PPP-Discards-Input"                   => "Starent",
            "SNA-PPP-Discards-Output"                  => "Starent",
            "SNA-PPP-Echo-Req-Input"                   => "Starent",
            "SNA-PPP-Echo-Req-Output"                  => "Starent",
            "SNA-PPP-Echo-Rsp-Input"                   => "Starent",
            "SNA-PPP-Echo-Rsp-Output"                  => "Starent",
            "SNA-PPP-Errors-Input"                     => "Starent",
            "SNA-PPP-Errors-Output"                    => "Starent",
            "SNA-PPP-Framed-Input-Octets"              => "Starent",
            "SNA-PPP-Framed-Output-Octets"             => "Starent",
            "SNA-PPP-Packet-Too-Long"                  => "Starent",
            "SNA-PPP-Unfr-Data-In-Gig"                 => "Starent",
            "SNA-PPP-Unfr-data-In-Oct"                 => "Starent",
            "SNA-PPP-Unfr-Data-Out-Gig"                => "Starent",
            "SNA-PPP-Unfr-data-Out-Oct"                => "Starent",
            "SNA-RP-Reg-Reply-Sent-Acc-Dereg"          => "Starent",
            "SNA-RP-Reg-Reply-Sent-Acc-Reg"            => "Starent",
            "SNA-RP-Reg-Reply-Sent-Bad-Req"            => "Starent",
            "SNA-RP-Reg-Reply-Sent-Denied"             => "Starent",
            "SNA-RP-Reg-Reply-Sent-Mis-ID"             => "Starent",
            "SNA-RP-Reg-Reply-Sent-Send-Err"           => "Starent",
            "SNA-RP-Reg-Reply-Sent-Total"              => "Starent",
            "SNA-RP-Reg-Upd-Re-Sent"                   => "Starent",
            "SNA-RP-Reg-Upd-Send-Err"                  => "Starent",
            "SNA-RP-Reg-Upd-Sent"                      => "Starent",
            "SNA-RPRAK-Rcvd-Acc-Ack"                   => "Starent",
            "SNA-RPRAK-Rcvd-Mis-ID"                    => "Starent",
            "SNA-RPRAK-Rcvd-Msg-Auth-Fail"             => "Starent",
            "SNA-RPRAK-Rcvd-Total"                     => "Starent",
            "SNA-RPRRQ-Rcvd-Acc-Dereg"                 => "Starent",
            "SNA-RPRRQ-Rcvd-Acc-Reg"                   => "Starent",
            "SNA-RPRRQ-Rcvd-Badly-Formed"              => "Starent",
            "SNA-RPRRQ-Rcvd-Mis-ID"                    => "Starent",
            "SNA-RPRRQ-Rcvd-Msg-Auth-Fail"             => "Starent",
            "SNA-RPRRQ-Rcvd-T-Bit-Not-Set"             => "Starent",
            "SNA-RPRRQ-Rcvd-Total"                     => "Starent",
            "SNA-RPRRQ-Rcvd-VID-Unsupported"           => "Starent",
            "SofaWare-Admin"                           => "SofaWare",
            "SofaWare-Hotspot"                         => "SofaWare",
            "SofaWare-UFP"                             => "SofaWare",
            "SofaWare-VPN"                             => "SofaWare",
            "SoftBank-BB-Unit-HW-Revision"             => "SoftBank",
            "SoftBank-BB-Unit-MAC"                     => "SoftBank",
            "SoftBank-BB-Unit-Manufacturer"            => "SoftBank",
            "SoftBank-BB-Unit-Model"                   => "SoftBank",
            "SoftBank-DNS-IPv6-Primary"                => "SoftBank",
            "SoftBank-DNS-IPv6-Secondary"              => "SoftBank",
            "SoftBank-IPv4-Tunnel-Endpoint"            => "SoftBank",
            "SoftBank-IPv4-Tunnel-Local-Address"       => "SoftBank",
            "SoftBank-RouteInfo-Server"                => "SoftBank",
            "SoftBank-SNTP-Server"                     => "SoftBank",
            "SoftBank-Syslog-Server"                   => "SoftBank",
            "SoftBank-TFTP-Config-File"                => "SoftBank",
            "SoftBank-TFTP-Config-Server"              => "SoftBank",
            "SonicWall-User-Group"                     => "SonicWall",
            "SonicWall-User-Privilege"                 => "SonicWall",
            "Source-Validation"                        => "Ericsson-AB",
            "SS3-Firewall-User-Privilege"              => "SonicWall",
            "SSS-Proxy-Id"                             => "SmartShareSystems",
            "SSS-Proxy-Identifier"                     => "SmartShareSystems",
            "SSS-Proxy-Location"                       => "SmartShareSystems",
            "ST-Acct-VC-Connection-Id"                 => "SpringTide",
            "ST-IPSec-Client-Firewall"                 => "SpringTide",
            "ST-IPSec-Client-Subnet"                   => "SpringTide",
            "ST-IPSec-Pfs-Group"                       => "SpringTide",
            "ST-Physical-Port"                         => "SpringTide",
            "ST-Physical-Slot"                         => "SpringTide",
            "ST-Policy-Name"                           => "SpringTide",
            "ST-Primary-DNS-Server"                    => "SpringTide",
            "ST-Primary-NBNS-Server"                   => "SpringTide",
            "ST-Realm-Name"                            => "SpringTide",
            "ST-Secondary-DNS-Server"                  => "SpringTide",
            "ST-Secondary-NBNS-Server"                 => "SpringTide",
            "ST-Service-Domain"                        => "SpringTide",
            "ST-Service-Name"                          => "SpringTide",
            "ST-Virtual-Circuit-ID"                    => "SpringTide",
            "ST-Virtual-Path-ID"                       => "SpringTide",
            "subscriber"                               => "Cisco",
            "Subscriber-Profile-Name"                  => "Ericsson-AB",
            "Suggested-Rule-Space"           => "Ericsson-Packet-Core-Networks",
            "Suggested-Secondary-Rule-Space" => "Ericsson-Packet-Core-Networks",
            "Surfnet-AVPair"                 => "Surfnet",
            "Surfnet-Service-Identifier"     => "Surfnet",
            "Surfnet-Service-Provider"       => "Surfnet",
            "Symbol-Admin-Role"              => "Symbol",
            "Symbol-Allowed-ESSID"           => "Symbol",
            "Symbol-Allowed-Radio"           => "Symbol",
            "Symbol-Current-ESSID"           => "Symbol",
            "Symbol-Downlink-Limit"          => "Symbol",
            "Symbol-Expiry-Date-Time"        => "Symbol",
            "Symbol-Login-Source"            => "Symbol",
            "Symbol-Posture-Status"          => "Symbol",
            "Symbol-QoS-Profile"             => "Symbol",
            "Symbol-Start-Date-Time"         => "Symbol",
            "Symbol-Uplink-Limit"            => "Symbol",
            "Symbol-User-Group"              => "Symbol",
            "Symbol-WLAN-Index"              => "Symbol",
            "T-Systems-Nova-Bandwidth-Max-Down"       => "T-Systems-Nova",
            "T-Systems-Nova-Bandwidth-Max-Up"         => "T-Systems-Nova",
            "T-Systems-Nova-Bandwidth-Min-Down"       => "T-Systems-Nova",
            "T-Systems-Nova-Bandwidth-Min-Up"         => "T-Systems-Nova",
            "T-Systems-Nova-Billing-Class-Of-Service" => "T-Systems-Nova",
            "T-Systems-Nova-Location-ID"              => "T-Systems-Nova",
            "T-Systems-Nova-Location-Name"            => "T-Systems-Nova",
            "T-Systems-Nova-Logoff-URL"               => "T-Systems-Nova",
            "T-Systems-Nova-Price-Of-Service"         => "T-Systems-Nova",
            "T-Systems-Nova-Redirection-URL"          => "T-Systems-Nova",
            "T-Systems-Nova-Service-Name"             => "T-Systems-Nova",
            "T-Systems-Nova-Session-Terminate-EoD"    => "T-Systems-Nova",
            "T-Systems-Nova-Session-Terminate-Time"   => "T-Systems-Nova",
            "T-Systems-Nova-UnknownAVP"               => "T-Systems-Nova",
            "T-Systems-Nova-Visiting-Provider-Code"   => "T-Systems-Nova",
            "Telebit-Accounting-Info"                 => "Telebit",
            "Telebit-Activate-Command"                => "Telebit",
            "Telebit-Login-Command"                   => "Telebit",
            "Telebit-Login-Option"                    => "Telebit",
            "Telebit-Port-Name"                       => "Telebit",
            "Telkom-Access-Type"                      => "Telkom",
            "Telkom-Degrade-Token"                    => "Telkom",
            "Telkom-Service-Type"                     => "Telkom",
            "Telrad-C-VLAN-ID"                        => "Telrad",
            "Telrad-C-VLAN-ID-Retag"                  => "Telrad",
            "Telrad-Item-Identity"                    => "Telrad",
            "Telrad-Reference-QOS-Profile-Name"       => "Telrad",
            "Telrad-Reference-VPWS-PDN-Name"          => "Telrad",
            "Telrad-S-VLAN-ID"                        => "Telrad",
            "Telrad-TSDF-Parameters"                  => "Telrad",
            "Telrad-TSDF-Table"                       => "Telrad",
            "Time-First-Usage"                        => "VerizonWireless",
            "Time-Last-Usage"                         => "VerizonWireless",
            "Timetra-Access"             => "Alcatel-Lucent-Service-Router",
            "Timetra-Action"             => "Alcatel-Lucent-Service-Router",
            "Timetra-Cmd"                => "Alcatel-Lucent-Service-Router",
            "Timetra-Default-Action"     => "Alcatel-Lucent-Service-Router",
            "Timetra-Exec-File"          => "Alcatel-Lucent-Service-Router",
            "Timetra-Home-Directory"     => "Alcatel-Lucent-Service-Router",
            "Timetra-Profile"            => "Alcatel-Lucent-Service-Router",
            "Timetra-Restrict-To-Home"   => "Alcatel-Lucent-Service-Router",
            "TP-Access-Class-Id"         => "Travelping",
            "TP-Access-Group"            => "Travelping",
            "TP-Access-Rule"             => "Travelping",
            "TP-Auth-Reply"              => "Travelping",
            "TP-CAPWAP-Boot-Version"     => "Travelping",
            "TP-CAPWAP-GPS-Altitude"     => "Travelping",
            "TP-CAPWAP-GPS-Hdop"         => "Travelping",
            "TP-CAPWAP-GPS-Latitude"     => "Travelping",
            "TP-CAPWAP-GPS-Longitude"    => "Travelping",
            "TP-CAPWAP-GPS-Timestamp"    => "Travelping",
            "TP-CAPWAP-Hardware-Version" => "Travelping",
            "TP-CAPWAP-Max-WIFI-Clients" => "Travelping",
            "TP-CAPWAP-Other-Software-Version"             => "Travelping",
            "TP-CAPWAP-POWER-SAVE-BUSY-TIMEOUT"            => "Travelping",
            "TP-CAPWAP-POWER-SAVE-IDLE-TIMEOUT"            => "Travelping",
            "TP-CAPWAP-Radio-Id"                           => "Travelping",
            "TP-CAPWAP-Session-Id"                         => "Travelping",
            "TP-CAPWAP-Software-Version"                   => "Travelping",
            "TP-CAPWAP-SSID"                               => "Travelping",
            "TP-CAPWAP-Timestamp"                          => "Travelping",
            "TP-CAPWAP-Walled-Garden"                      => "Travelping",
            "TP-CAPWAP-WTP-Version"                        => "Travelping",
            "TP-CAPWAP-WWAN-Cell-Id"                       => "Travelping",
            "TP-CAPWAP-WWAN-CREG"                          => "Travelping",
            "TP-CAPWAP-WWAN-Id"                            => "Travelping",
            "TP-CAPWAP-WWAN-LAC"                           => "Travelping",
            "TP-CAPWAP-WWAN-Latency"                       => "Travelping",
            "TP-CAPWAP-WWAN-MCC"                           => "Travelping",
            "TP-CAPWAP-WWAN-MNC"                           => "Travelping",
            "TP-CAPWAP-WWAN-RAT"                           => "Travelping",
            "TP-CAPWAP-WWAN-RSSi"                          => "Travelping",
            "TP-DHCP-Client-Id"                            => "Travelping",
            "TP-DHCP-Parameter-Request-List"               => "Travelping",
            "TP-DHCP-Request-Option-List"                  => "Travelping",
            "TP-DHCP-Vendor-Class-Id"                      => "Travelping",
            "TP-ENC-IV"                                    => "Travelping",
            "TP-Exit-Access-Class-Id"                      => "Travelping",
            "TP-Firmware-Variant"                          => "Travelping",
            "TP-Firmware-Version"                          => "Travelping",
            "TP-Gateway-Config"                            => "Travelping",
            "TP-Gateway-Version"                           => "Travelping",
            "TP-Host-Name"                                 => "Travelping",
            "TP-Keep-Alive-Timeout"                        => "Travelping",
            "TP-Location-Id"                               => "Travelping",
            "TP-Max-Input-Octets"                          => "Travelping",
            "TP-Max-Output-Octets"                         => "Travelping",
            "TP-Max-Total-Octets"                          => "Travelping",
            "TP-Monitor-Id"                                => "Travelping",
            "TP-Monitor-Session-Id"                        => "Travelping",
            "TP-NAT-IP-Address"                            => "Travelping",
            "TP-NAT-Pool-Id"                               => "Travelping",
            "TP-NAT-Port-End"                              => "Travelping",
            "TP-NAT-Port-Start"                            => "Travelping",
            "TP-Password"                                  => "Travelping",
            "TP-Related-Session-Id"                        => "Travelping",
            "TP-TLS-Auth-Type"                             => "Travelping",
            "TP-TLS-Pre-Shared-Key"                        => "Travelping",
            "TP-User-Agent"                                => "Travelping",
            "TP-Zone-Id"                                   => "Travelping",
            "TPLink-Authentication-FindKey"                => "TPLink",
            "TPLink-Authentication-FoundKey"               => "TPLink",
            "TPLink-Omada"                                 => "TPLink",
            "TPLink-Portal-Access-Status"                  => "TPLink",
            "TPLink-Recv-limit"                            => "TPLink",
            "TPLink-Redirect-Url"                          => "TPLink",
            "TPLink-Site"                                  => "TPLink",
            "TPLink-User-Command"                          => "TPLink",
            "TPLink-Xmit-limit"                            => "TPLink",
            "Trapeze-Audit"                                => "Trapeze",
            "Trapeze-CoA-Username"                         => "Trapeze",
            "Trapeze-Encryption-Type"                      => "Trapeze",
            "Trapeze-End-Date"                             => "Trapeze",
            "Trapeze-Mobility-Profile"                     => "Trapeze",
            "Trapeze-QoS-Profile"                          => "Trapeze",
            "Trapeze-Simultaneous-Logins"                  => "Trapeze",
            "Trapeze-SSID"                                 => "Trapeze",
            "Trapeze-Start-Date"                           => "Trapeze",
            "Trapeze-Time-Of-Day"                          => "Trapeze",
            "Trapeze-URL"                                  => "Trapeze",
            "Trapeze-User-Group-Name"                      => "Trapeze",
            "Trapeze-VLAN-Name"                            => "Trapeze",
            "TrippLite-Authorization"                      => "TrippLite",
            "TrippLite-Message"                            => "TrippLite",
            "TrippLite-Outlet-Realms"                      => "TrippLite",
            "TrippLite-User-Role"                          => "TrippLite",
            "Tropos-Average-RSSI"                          => "Tropos",
            "Tropos-Capability-Info"                       => "Tropos",
            "Tropos-Cell-Location"                         => "Tropos",
            "Tropos-Cell-Name"                             => "Tropos",
            "Tropos-Channel"                               => "Tropos",
            "Tropos-Class-Mult"                            => "Tropos",
            "Tropos-Input-Cap"                             => "Tropos",
            "Tropos-Latitude"                              => "Tropos",
            "Tropos-Layer2-Input-Drops"                    => "Tropos",
            "Tropos-Layer2-Input-Frames"                   => "Tropos",
            "Tropos-Layer2-Input-Octets"                   => "Tropos",
            "Tropos-Layer2-Output-Frames"                  => "Tropos",
            "Tropos-Layer2-Output-Octets"                  => "Tropos",
            "Tropos-Longitude"                             => "Tropos",
            "Tropos-Noise-Floor"                           => "Tropos",
            "Tropos-Noise-Upper-Bound"                     => "Tropos",
            "Tropos-Output-Cap"                            => "Tropos",
            "Tropos-Rates-Received"                        => "Tropos",
            "Tropos-Rates-Sent"                            => "Tropos",
            "Tropos-Release"                               => "Tropos",
            "Tropos-Retries-Sent"                          => "Tropos",
            "Tropos-Retry-Bits"                            => "Tropos",
            "Tropos-Routed-Time"                           => "Tropos",
            "Tropos-Routless-Since"                        => "Tropos",
            "Tropos-Secondary-IP"                          => "Tropos",
            "Tropos-Serial-Number"                         => "Tropos",
            "Tropos-Terminate-Cause"                       => "Tropos",
            "Tropos-Unicast-Cipher"                        => "Tropos",
            "Trust-Router-APC"                             => "UKERNA",
            "Trust-Router-COI"                             => "UKERNA",
            "TTY-Level-Max"                                => "Ericsson-AB",
            "TTY-Level-Start"                              => "Ericsson-AB",
            "Tunnel-Algorithm"                             => "Ericsson-AB",
            "Tunnel-Checksum"                              => "Ericsson-AB",
            "Tunnel-Client-Int-Addr"                       => "Ericsson-AB",
            "Tunnel-Client-Rhost"                          => "Ericsson-AB",
            "Tunnel-Client-VPN"                            => "Ericsson-AB",
            "Tunnel-Cmd-Timeout"                           => "Ericsson-AB",
            "Tunnel-Context"                               => "Ericsson-AB",
            "Tunnel-Deadtime"                              => "Ericsson-AB",
            "Tunnel-DNIS"                                  => "Ericsson-AB",
            "Tunnel-Domain"                                => "Ericsson-AB",
            "Tunnel-Flow-Control"                          => "Ericsson-AB",
            "Tunnel-Function"                              => "Ericsson-AB",
            "Tunnel-Group"                                 => "Ericsson-AB",
            "Tunnel-Hello-Timer"                           => "Ericsson-AB",
            "Tunnel-L2F-Second-Password"                   => "Ericsson-AB",
            "Tunnel-Local-Name"                            => "Ericsson-AB",
            "Tunnel-Max-Sessions"                          => "Ericsson-AB",
            "Tunnel-Max-Tunnels"                           => "Ericsson-AB",
            "Tunnel-Police-Burst"                          => "Ericsson-AB",
            "Tunnel-Police-Excess-Burst"                   => "Ericsson-AB",
            "Tunnel-Police-Rate"                           => "Ericsson-AB",
            "Tunnel-Profile"                               => "Ericsson-AB",
            "Tunnel-Rate-Limit-Burst"                      => "Ericsson-AB",
            "Tunnel-Rate-Limit-Excess-Burst"               => "Ericsson-AB",
            "Tunnel-Rate-Limit-Rate"                       => "Ericsson-AB",
            "Tunnel-Remote-Name"                           => "Ericsson-AB",
            "Tunnel-Retransmit"                            => "Ericsson-AB",
            "Tunnel-Server-Int-Addr"                       => "Ericsson-AB",
            "Tunnel-Server-Rhost"                          => "Ericsson-AB",
            "Tunnel-Server-VPN"                            => "Ericsson-AB",
            "Tunnel-Session-Auth"                          => "Ericsson-AB",
            "Tunnel-Session-Auth-Ctx"                      => "Ericsson-AB",
            "Tunnel-Session-Auth-Service-Grp"              => "Ericsson-AB",
            "Tunnel-Static"                                => "Ericsson-AB",
            "Tunnel-Window"                                => "Ericsson-AB",
            "UE-Info-Type"                                 => "VerizonWireless",
            "UE-Info-Value"                                => "VerizonWireless",
            "UKERNA-GSS-Acceptor-Host-Name"                => "UKERNA",
            "UKERNA-GSS-Acceptor-Realm-Name"               => "UKERNA",
            "UKERNA-GSS-Acceptor-Service-Name"             => "UKERNA",
            "UKERNA-GSS-Acceptor-Service-Specific"         => "UKERNA",
            "Unix-FTP-GID"                                 => "Unix",
            "Unix-FTP-Group-Ids"                           => "Unix",
            "Unix-FTP-Group-Names"                         => "Unix",
            "Unix-FTP-Home"                                => "Unix",
            "Unix-FTP-Shell"                               => "Unix",
            "Unix-FTP-UID"                                 => "Unix",
            "UserLogon-Acct-TerminateCause"                => "NTUA",
            "UserLogon-DriveNames"                         => "NTUA",
            "UserLogon-Expiration"                         => "NTUA",
            "UserLogon-Gid"                                => "NTUA",
            "UserLogon-GroupNames"                         => "NTUA",
            "UserLogon-HomeDir"                            => "NTUA",
            "UserLogon-LogoffTask"                         => "NTUA",
            "UserLogon-LogonTask"                          => "NTUA",
            "UserLogon-QuotaBytes"                         => "NTUA",
            "UserLogon-QuotaFiles"                         => "NTUA",
            "UserLogon-Restriction"                        => "NTUA",
            "UserLogon-Shell"                              => "NTUA",
            "UserLogon-Type"                               => "NTUA",
            "UserLogon-Uid"                                => "NTUA",
            "UserLogon-UserDescription"                    => "NTUA",
            "UserLogon-UserDomain"                         => "NTUA",
            "UserLogon-UserFullName"                       => "NTUA",
            "UserLogon-UserProfile"                        => "NTUA",
            "USR-ACCM-Type"                                => "USR",
            "USR-Acct-Reason-Code"                         => "USR",
            "USR-Actual-Voltage"                           => "USR",
            "USR-Agent"                                    => "USR",
            "USR-Appletalk"                                => "USR",
            "USR-Appletalk-Network-Range"                  => "USR",
            "USR-AT-Call-Input-Filter"                     => "USR",
            "USR-AT-Call-Output-Filter"                    => "USR",
            "USR-AT-Input-Filter"                          => "USR",
            "USR-AT-Output-Filter"                         => "USR",
            "USR-AT-RTMP-Input-Filter"                     => "USR",
            "USR-AT-RTMP-Output-Filter"                    => "USR",
            "USR-AT-Zip-Input-Filter"                      => "USR",
            "USR-AT-Zip-Output-Filter"                     => "USR",
            "USR-Auth-Mode"                                => "USR",
            "USR-Auth-Next-Server-Address"                 => "USR",
            "USR-Back-Channel-Data-Rate"                   => "USR",
            "USR-Bearer-Capabilities"                      => "USR",
            "USR-Block-Error-Count-Limit"                  => "USR",
            "USR-Blocks-Received"                          => "USR",
            "USR-Blocks-Resent"                            => "USR",
            "USR-Blocks-Sent"                              => "USR",
            "USR-Bridging"                                 => "USR",
            "USR-Bytes-RX-Remain"                          => "USR",
            "USR-Bytes-TX-Remain"                          => "USR",
            "USR-Call-Arrival-in-GMT"                      => "USR",
            "USR-Call-Arrival-Time"                        => "USR",
            "USR-Call-Connect-in-GMT"                      => "USR",
            "USR-Call-Connecting-Time"                     => "USR",
            "USR-Call-End-Date-Time"                       => "USR",
            "USR-Call-End-Time"                            => "USR",
            "USR-Call-Error-Code"                          => "USR",
            "USR-Call-Event-Code"                          => "USR",
            "USR-Call-Reference-Number"                    => "USR",
            "USR-Call-Start-Date-Time"                     => "USR",
            "USR-Call-Terminate-in-GMT"                    => "USR",
            "USR-Call-Type"                                => "USR",
            "USR-Callback-Type"                            => "USR",
            "USR-Called-Party-Number"                      => "USR",
            "USR-Calling-Party-Number"                     => "USR",
            "USR-Card-Type"                                => "USR",
            "USR-CCP-Algorithm"                            => "USR",
            "USR-CDMA-Call-Reference-Number"               => "USR",
            "USR-CDMA-PktData-Network-ID"                  => "USR",
            "USR-Channel"                                  => "USR",
            "USR-Channel-Connected-To"                     => "USR",
            "USR-Channel-Decrement"                        => "USR",
            "USR-Channel-Expansion"                        => "USR",
            "USR-Characters-Received"                      => "USR",
            "USR-Characters-Sent"                          => "USR",
            "USR-Chassis-Call-Channel"                     => "USR",
            "USR-Chassis-Call-Slot"                        => "USR",
            "USR-Chassis-Call-Span"                        => "USR",
            "USR-Chassis-Slot"                             => "USR",
            "USR-Chassis-Temp-Threshold"                   => "USR",
            "USR-Chassis-Temperature"                      => "USR",
            "USR-Chat-Script-Name"                         => "USR",
            "USR-Compression-Algorithm"                    => "USR",
            "USR-Compression-Reset-Mode"                   => "USR",
            "USR-Compression-Type"                         => "USR",
            "USR-Connect-Speed"                            => "USR",
            "USR-Connect-Term-Reason"                      => "USR",
            "USR-Connect-Time"                             => "USR",
            "USR-Connect-Time-Limit"                       => "USR",
            "USR-CUSR-hat-Script-Rules"                    => "USR",
            "USR-Default-DTE-Data-Rate"                    => "USR",
            "USR-Device-Connected-To"                      => "USR",
            "USR-Disconnect-Cause-Indicator"               => "USR",
            "USR-DNIS-ReAuthentication"                    => "USR",
            "USR-DS0"                                      => "USR",
            "USR-DS0s"                                     => "USR",
            "USR-DTE-Data-Idle-Timout"                     => "USR",
            "USR-DTE-Ring-No-Answer-Limit"                 => "USR",
            "USR-DTR-False-Timeout"                        => "USR",
            "USR-DTR-True-Timeout"                         => "USR",
            "USR-Dvmrp-Advertised-Metric"                  => "USR",
            "USR-Dvmrp-Initial-Flooding"                   => "USR",
            "USR-Dvmrp-Input-Filter"                       => "USR",
            "USR-Dvmrp-Non-Pruners"                        => "USR",
            "USR-Dvmrp-Output-Filter"                      => "USR",
            "USR-Dvmrp-Prune-Lifetime"                     => "USR",
            "USR-Dvmrp-Retransmit-Prunes"                  => "USR",
            "USR-Dvmrp-Route-Transit"                      => "USR",
            "USR-End-Time"                                 => "USR",
            "USR-Equalization-Type"                        => "USR",
            "USR-ESN"                                      => "USR",
            "USR-ET-Bridge-Call-Output-Filte"              => "USR",
            "USR-ET-Bridge-Input-Filter"                   => "USR",
            "USR-ET-Bridge-Output-Filter"                  => "USR",
            "USR-Event-Date-Time"                          => "USR",
            "USR-Event-Id"                                 => "USR",
            "USR-Expansion-Algorithm"                      => "USR",
            "USR-Expected-Voltage"                         => "USR",
            "USR-Failure-to-Connect-Reason"                => "USR",
            "USR-Fallback-Enabled"                         => "USR",
            "USR-Fallback-Limit"                           => "USR",
            "USR-Filter-Zones"                             => "USR",
            "USR-Final-Rx-Link-Data-Rate"                  => "USR",
            "USR-Final-Tx-Link-Data-Rate"                  => "USR",
            "USR-FQ-Default-Priority"                      => "USR",
            "USR-Framed-IPX-Route"                         => "USR",
            "USR-Framed_IP_Address_Pool_Name"              => "USR",
            "USR-Gateway-IP-Address"                       => "USR",
            "USR-HARC-Disconnect-Code"                     => "USR",
            "USR-Host-Type"                                => "USR",
            "USR-IDS0-Call-Type"                           => "USR",
            "USR-IGMP-Maximum-Response-Time"               => "USR",
            "USR-IGMP-Query-Interval"                      => "USR",
            "USR-IGMP-Robustness"                          => "USR",
            "USR-IGMP-Routing"                             => "USR",
            "USR-IGMP-Version"                             => "USR",
            "USR-IMSI"                                     => "USR",
            "USR-Init-Reg-Server-Addr"                     => "USR",
            "USR-Initial-Rx-Link-Data-Rate"                => "USR",
            "USR-Initial-Tx-Link-Data-Rate"                => "USR",
            "USR-Interface-Index"                          => "USR",
            "USR-IP"                                       => "USR",
            "USR-IP-Call-Input-Filter"                     => "USR",
            "USR-IP-Call-Output-Filter"                    => "USR",
            "USR-IP-Default-Route-Option"                  => "USR",
            "USR-IP-RIP-Input-Filter"                      => "USR",
            "USR-IP-RIP-Output-Filter"                     => "USR",
            "USR-IP-RIP-Policies"                          => "USR",
            "USR-IP-RIP-Simple-Auth-Password"              => "USR",
            "USR-IP-SAA-Filter"                            => "USR",
            "USR-IPP-Enable"                               => "USR",
            "USR-IPX"                                      => "USR",
            "USR-IPX-Call-Input-Filter"                    => "USR",
            "USR-IPX-Call-Output-Filter"                   => "USR",
            "USR-IPX-RIP-Input-Filter"                     => "USR",
            "USR-IPX-RIP-Output-Filter"                    => "USR",
            "USR-IPX-Routing"                              => "USR",
            "USR-IPX-WAN"                                  => "USR",
            "USR-IWF-Call-Identifier"                      => "USR",
            "USR-IWF-IP-Address"                           => "USR",
            "USR-Keep-Alive-Interval"                      => "USR",
            "USR-Keypress-Timeout"                         => "USR",
            "USR-Last-Callers-Number-ANI"                  => "USR",
            "USR-Last-Number-Dialed-In-DNIS"               => "USR",
            "USR-Last-Number-Dialed-Out"                   => "USR",
            "USR-Line-Reversals"                           => "USR",
            "USR-Local-Framed-IP-Addr"                     => "USR",
            "USR-Local-IP-Address"                         => "USR",
            "USR-Log-Filter-Packets"                       => "USR",
            "USR-Max-Channels"                             => "USR",
            "USR-Mbi_Ct_BChannel_Used"                     => "USR",
            "USR-Mbi_Ct_PRI_Card_Slot"                     => "USR",
            "USR-Mbi_Ct_PRI_Card_Span_Line"                => "USR",
            "USR-Mbi_Ct_TDM_Time_Slot"                     => "USR",
            "USR-MIC"                                      => "USR",
            "USR-Min-Compression-Size"                     => "USR",
            "USR-MIP-NAI"                                  => "USR",
            "USR-MLPPP-Fragmentation-Threshld"             => "USR",
            "USR-Mobile-Accounting-Type"                   => "USR",
            "USR-Mobile-IP-Address"                        => "USR",
            "USR-Mobile-NumBytes-Rxed"                     => "USR",
            "USR-Mobile-NumBytes-Txed"                     => "USR",
            "USR-Mobile-Service-Option"                    => "USR",
            "USR-Mobile-Session-ID"                        => "USR",
            "USR-MobileIP-Home-Agent-Address"              => "USR",
            "USR-Modem-Group"                              => "USR",
            "USR-Modem-Setup-Time"                         => "USR",
            "USR-Modem-Training-Time"                      => "USR",
            "USR-Modulation-Type"                          => "USR",
            "USR-MP-EDO"                                   => "USR",
            "USR-MP-EDO-HIPER"                             => "USR",
            "USR-MP-MRRU"                                  => "USR",
            "USR-MPIP-Tunnel-Originator"                   => "USR",
            "USR-Multicast-Forwarding"                     => "USR",
            "USR-Multicast-Proxy"                          => "USR",
            "USR-Multicast-Receive"                        => "USR",
            "USR-Nailed-B-Channel-Indicator"               => "USR",
            "USR-NAS-Type"                                 => "USR",
            "USR-NFAS-ID"                                  => "USR",
            "USR-Num-Fax-Pages-Processed"                  => "USR",
            "USR-Number-of-Blers"                          => "USR",
            "USR-Number-Of-Characters-Lost"                => "USR",
            "USR-Number-of-Fallbacks"                      => "USR",
            "USR-Number-of-Link-NAKs"                      => "USR",
            "USR-Number-of-Link-Timeouts"                  => "USR",
            "USR-Number-of-Rings-Limit"                    => "USR",
            "USR-Number-of-Upshifts"                       => "USR",
            "USR-Orig-NAS-Type"                            => "USR",
            "USR-Originate-Answer-Mode"                    => "USR",
            "USR-OSPF-Addressless-Index"                   => "USR",
            "USR-Packet-Bus-Session"                       => "USR",
            "USR-Physical-State"                           => "USR",
            "USR-Policy-Access"                            => "USR",
            "USR-Policy-Configuration"                     => "USR",
            "USR-Policy-Filename"                          => "USR",
            "USR-Policy-Type"                              => "USR",
            "USR-Port-Tap"                                 => "USR",
            "USR-Port-Tap-Address"                         => "USR",
            "USR-Port-Tap-Facility"                        => "USR",
            "USR-Port-Tap-Format"                          => "USR",
            "USR-Port-Tap-Output"                          => "USR",
            "USR-Port-Tap-Priority"                        => "USR",
            "USR-Power-Supply-Number"                      => "USR",
            "USR-PQ-Default-Priority"                      => "USR",
            "USR-PQ-Parameters"                            => "USR",
            "USR-Pre-Paid-Enabled"                         => "USR",
            "USR-Pre-Shared-MN-Key"                        => "USR",
            "USR-Primary_DNS_Server"                       => "USR",
            "USR-Primary_NBNS_Server"                      => "USR",
            "USR-PW_Cutoff"                                => "USR",
            "USR-PW_Framed_Routing_V2"                     => "USR",
            "USR-PW_Index"                                 => "USR",
            "USR-PW_Packet"                                => "USR",
            "USR-PW_Tunnel_Authentication"                 => "USR",
            "USR-PW_USR_IFilter_IP"                        => "USR",
            "USR-PW_USR_IFilter_IPX"                       => "USR",
            "USR-PW_USR_OFilter_IP"                        => "USR",
            "USR-PW_USR_OFilter_IPX"                       => "USR",
            "USR-PW_USR_OFilter_SAP"                       => "USR",
            "USR-PW_VPN_Gateway"                           => "USR",
            "USR-PW_VPN_ID"                                => "USR",
            "USR-PW_VPN_Name"                              => "USR",
            "USR-PW_VPN_Neighbor"                          => "USR",
            "USR-Q931-Call-Reference-Value"                => "USR",
            "USR-QNC1-Service-Destination"                 => "USR",
            "USR-QoS-Queuing-Mehtod"                       => "USR",
            "USR-Rad-Dvmrp-Metric"                         => "USR",
            "USR-Rad-IP-Pool-Definition"                   => "USR",
            "USR-Rad-Location-Type"                        => "USR",
            "USR-Rad-Multicast-Routing-Bound"              => "USR",
            "USR-Rad-Multicast-Routing-Proto"              => "USR",
            "USR-Rad-Multicast-Routing-RtLim"              => "USR",
            "USR-Rad-Multicast-Routing-Ttl"                => "USR",
            "USR-Rad-NMC-Blocks_RX"                        => "USR",
            "USR-Rad-NMC-Call-Progress-Status"             => "USR",
            "USR-Re-Chap-Timeout"                          => "USR",
            "USR-Re-Reg-Server-Addr"                       => "USR",
            "USR-Receive-Acc-Map"                          => "USR",
            "USR-Redirect"                                 => "USR",
            "USR-Reg-Server-Prov-Timeout"                  => "USR",
            "USR-Reply-Script1"                            => "USR",
            "USR-Reply-Script2"                            => "USR",
            "USR-Reply-Script3"                            => "USR",
            "USR-Reply-Script4"                            => "USR",
            "USR-Reply-Script5"                            => "USR",
            "USR-Reply-Script6"                            => "USR",
            "USR-Request-Type"                             => "USR",
            "USR-Retrains-Granted"                         => "USR",
            "USR-Retrains-Requested"                       => "USR",
            "USR-RMMIE-Firmware-Build-Date"                => "USR",
            "USR-RMMIE-Firmware-Version"                   => "USR",
            "USR-RMMIE-Last-Update-Event"                  => "USR",
            "USR-RMMIE-Last-Update-Time"                   => "USR",
            "USR-RMMIE-Manufacturer-ID"                    => "USR",
            "USR-RMMIE-Num-Of-Updates"                     => "USR",
            "USR-RMMIE-Planned-Disconnect"                 => "USR",
            "USR-RMMIE-Product-Code"                       => "USR",
            "USR-RMMIE-PwrLvl-FarEcho-Canc"                => "USR",
            "USR-RMMIE-PwrLvl-NearEcho-Canc"               => "USR",
            "USR-RMMIE-PwrLvl-Noise-Lvl"                   => "USR",
            "USR-RMMIE-PwrLvl-Xmit-Lvl"                    => "USR",
            "USR-RMMIE-Rcv-PwrLvl-3300Hz"                  => "USR",
            "USR-RMMIE-Rcv-PwrLvl-3750Hz"                  => "USR",
            "USR-RMMIE-Rcv-Tot-PwrLvl"                     => "USR",
            "USR-RMMIE-Serial-Number"                      => "USR",
            "USR-RMMIE-Status"                             => "USR",
            "USR-RMMIE-x2-Status"                          => "USR",
            "USR-Routing-Protocol"                         => "USR",
            "USR-SAP-Filter-In"                            => "USR",
            "USR-Secondary_DNS_Server"                     => "USR",
            "USR-Secondary_NBNS_Server"                    => "USR",
            "USR-Security-Login-Limit"                     => "USR",
            "USR-Security-Resp-Limit"                      => "USR",
            "USR-Send-Name"                                => "USR",
            "USR-Send-Password"                            => "USR",
            "USR-Send-Script1"                             => "USR",
            "USR-Send-Script2"                             => "USR",
            "USR-Send-Script3"                             => "USR",
            "USR-Send-Script4"                             => "USR",
            "USR-Send-Script5"                             => "USR",
            "USR-Send-Script6"                             => "USR",
            "USR-Server-Time"                              => "USR",
            "USR-Service-Option"                           => "USR",
            "USR-Session-Time-Remain"                      => "USR",
            "USR-Simplified-MNP-Levels"                    => "USR",
            "USR-Simplified-V42bis-Usage"                  => "USR",
            "USR-Slot-Connected-To"                        => "USR",
            "USR-Special-Xon-Xoff-Flow"                    => "USR",
            "USR-Speed-Of-Connection"                      => "USR",
            "USR-Spoofing"                                 => "USR",
            "USR-Start-Time"                               => "USR",
            "USR-Supports-Tags"                            => "USR",
            "USR-Sync-Async-Mode"                          => "USR",
            "USR-Syslog-Tap"                               => "USR",
            "USR-Telnet-Options"                           => "USR",
            "USR-Terminal-Type"                            => "USR",
            "USR-Traffic-Threshold"                        => "USR",
            "USR-Transmit-Acc-Map"                         => "USR",
            "USR-Tunnel-Auth-Hostname"                     => "USR",
            "USR-Tunnel-Challenge-Outgoing"                => "USR",
            "USR-Tunnel-Security"                          => "USR",
            "USR-Tunnel-Switch-Endpoint"                   => "USR",
            "USR-Tunneled-MLPP"                            => "USR",
            "USR-Unauthenticated-Time"                     => "USR",
            "USR-Unnumbered-Local-IP-Address"              => "USR",
            "USR-User-PPP-AODI-Type"                       => "USR",
            "USR-VLAN-Tag"                                 => "USR",
            "USR-VPN-Encrypter"                            => "USR",
            "USR-VPN-GW-Location-Id"                       => "USR",
            "USR-VTS-Session-Key"                          => "USR",
            "USR-Wallclock-Timestamp"                      => "USR",
            "USR-X25-Acct-Input-Segment-Count"             => "USR",
            "USR-X25-Acct-Output-Segment-Coun"             => "USR",
            "USR-X25-Acct-Segment-Size"                    => "USR",
            "USR-X25-Acct-Termination-Code"                => "USR",
            "USR-X25-SVC-Call-Attributes"                  => "USR",
            "USR-X25-SVC-Logical-Channel-Numb"             => "USR",
            "USR-X25-Trunk-Profile"                        => "USR",
            "UTStarcom-Act-Input-Frames"                   => "UTStarcom",
            "UTStarcom-Act-Input-Octets"                   => "UTStarcom",
            "UTStarcom-Act-Output-Frames"                  => "UTStarcom",
            "UTStarcom-Act-Output-Octets"                  => "UTStarcom",
            "UTStarcom-CLI-Access-Level"                   => "UTStarcom",
            "UTStarcom-CommittedBandwidth"                 => "UTStarcom",
            "UTStarcom-Default-Gateway"                    => "UTStarcom",
            "UTStarcom-DeviceId"                           => "UTStarcom",
            "UTStarcom-Error-Reason"                       => "UTStarcom",
            "UTStarcom-Logical-Port-No"                    => "UTStarcom",
            "UTStarcom-MaxBandwidth"                       => "UTStarcom",
            "UTStarcom-MaxBurstSize"                       => "UTStarcom",
            "UTStarcom-MaxDelay"                           => "UTStarcom",
            "UTStarcom-MaxJitter"                          => "UTStarcom",
            "UTStarcom-Module-Id"                          => "UTStarcom",
            "UTStarcom-ONU-Admin_status"                   => "UTStarcom",
            "UTStarcom-ONU-FW-SC-Upgrade"                  => "UTStarcom",
            "UTStarcom-Onu-MC-Filter-Enable"               => "UTStarcom",
            "UTStarcom-Port-No"                            => "UTStarcom",
            "UTStarcom-PrimaryDNS"                         => "UTStarcom",
            "UTStarcom-Priority"                           => "UTStarcom",
            "UTStarcom-SecondaryDNS"                       => "UTStarcom",
            "UTStarcom-UNI-Auto-Negotiation"               => "UTStarcom",
            "UTStarcom-UNI-Duplex"                         => "UTStarcom",
            "UTStarcom-UNI-MAX-MAC"                        => "UTStarcom",
            "UTStarcom-UNI-Speed"                          => "UTStarcom",
            "UTStarcom-VLAN-ID"                            => "UTStarcom",
            "VasExperts-Acct-Traffic-Class-Input-Octets"   => "VasExperts",
            "VasExperts-Acct-Traffic-Class-Input-Packets"  => "VasExperts",
            "VasExperts-Acct-Traffic-Class-Name"           => "VasExperts",
            "VasExperts-Acct-Traffic-Class-Output-Octets"  => "VasExperts",
            "VasExperts-Acct-Traffic-Class-Output-Packets" => "VasExperts",
            "VasExperts-ARP-SourceIP"                      => "VasExperts",
            "VasExperts-ARP-TargetIP"                      => "VasExperts",
            "VasExperts-BOOTP-File"                        => "VasExperts",
            "VasExperts-BOOTP-SName"                       => "VasExperts",
            "VasExperts-Command-Code"                      => "VasExperts",
            "VasExperts-DHCP-ClassId"                      => "VasExperts",
            "VasExperts-DHCP-ClientId"                     => "VasExperts",
            "VasExperts-DHCP-ClientIP"                     => "VasExperts",
            "VasExperts-DHCP-DNS"                          => "VasExperts",
            "VasExperts-DHCP-Gateway"                      => "VasExperts",
            "VasExperts-DHCP-Hostname"                     => "VasExperts",
            "VasExperts-DHCP-Option"                       => "VasExperts",
            "VasExperts-DHCP-Option-Bin"                   => "VasExperts",
            "VasExperts-DHCP-Option-IP"                    => "VasExperts",
            "VasExperts-DHCP-Option-IPv6"                  => "VasExperts",
            "VasExperts-DHCP-Option-IPv6-Prefix"           => "VasExperts",
            "VasExperts-DHCP-Option-Num"                   => "VasExperts",
            "VasExperts-DHCP-Option-String"                => "VasExperts",
            "VasExperts-DHCP-RelayCircuitId"               => "VasExperts",
            "VasExperts-DHCP-RelayInfo"                    => "VasExperts",
            "VasExperts-DHCP-RelayRemoteId"                => "VasExperts",
            "VasExperts-DHCP-Request"                      => "VasExperts",
            "VasExperts-DHCP6-Option-Bin"                  => "VasExperts",
            "VasExperts-DHCP6-Option-Num"                  => "VasExperts",
            "VasExperts-DHCP6-Option-String"               => "VasExperts",
            "VasExperts-DHCPv6-Delegated"                  => "VasExperts",
            "VasExperts-DHCPv6-RemoteId"                   => "VasExperts",
            "VasExperts-DHCPv6-Request"                    => "VasExperts",
            "VasExperts-DHCPv6-SubsId"                     => "VasExperts",
            "VasExperts-DHCPv6-UserClass"                  => "VasExperts",
            "VasExperts-DHCPv6-VendorClass"                => "VasExperts",
            "VasExperts-Enable-Interconnect"               => "VasExperts",
            "VasExperts-Enable-Service"                    => "VasExperts",
            "VasExperts-Multi-IP-User"                     => "VasExperts",
            "VasExperts-NAT-IP"                            => "VasExperts",
            "VasExperts-OutMAC"                            => "VasExperts",
            "VasExperts-OutVLAN"                           => "VasExperts",
            "VasExperts-Policing-Profile"                  => "VasExperts",
            "VasExperts-Restrict-User"                     => "VasExperts",
            "VasExperts-Service-Profile"                   => "VasExperts",
            "VasExperts-Service-Type"                      => "VasExperts",
            "VasExperts-UserName"                          => "VasExperts",
            "Versanet-Termination-Cause"                   => "Versanet",
            "Vlan-Source-Info"                             => "Ericsson-AB",
            "VNC-PPPoE-CBQ-RX"                           => "ValemountNetworks",
            "VNC-PPPoE-CBQ-RX-Fallback"                  => "ValemountNetworks",
            "VNC-PPPoE-CBQ-TX"                           => "ValemountNetworks",
            "VNC-PPPoE-CBQ-TX-Fallback"                  => "ValemountNetworks",
            "VNC-Splash"                                 => "ValemountNetworks",
            "Waverider-Authentication-Key"               => "Waverider",
            "Waverider-Current-Password"                 => "Waverider",
            "Waverider-Grade-Of-Service"                 => "Waverider",
            "Waverider-Max-Customers"                    => "Waverider",
            "Waverider-New-Password"                     => "Waverider",
            "Waverider-Priority-Enabled"                 => "Waverider",
            "Waverider-Radio-Frequency"                  => "Waverider",
            "Waverider-Rf-Power"                         => "Waverider",
            "Waverider-SNMP-Contact"                     => "Waverider",
            "Waverider-SNMP-Location"                    => "Waverider",
            "Waverider-SNMP-Name"                        => "Waverider",
            "Waverider-SNMP-Read-Community"              => "Waverider",
            "Waverider-SNMP-Trap-Server"                 => "Waverider",
            "Waverider-SNMP-Write-Community"             => "Waverider",
            "WB-Auth-Accum-BW"                           => "Walabi",
            "WB-Auth-BW-Count"                           => "Walabi",
            "WB-Auth-BW-Quota"                           => "Walabi",
            "WB-Auth-BW-Usage"                           => "Walabi",
            "WB-Auth-Download-Limit"                     => "Walabi",
            "WB-Auth-Login-Time"                         => "Walabi",
            "WB-Auth-Logout-Time"                        => "Walabi",
            "WB-Auth-Time-Diff"                          => "Walabi",
            "WB-AUTH-Time-Left"                          => "Walabi",
            "WB-Auth-Upload-Limit"                       => "Walabi",
            "WBA-Custom-SLA"                             => "WISPr",
            "WBA-Data-Clearing-Provider"                 => "WISPr",
            "WBA-Financial-Clearing-Provider"            => "WISPr",
            "WBA-Identity-Provider"                      => "WISPr",
            "WBA-Linear-Volume-Rate"                     => "WISPr",
            "WBA-Offered-Service"                        => "WISPr",
            "Wichorus-Policy-Name"                       => "Wichorus",
            "Wichorus-User-Privilege"                    => "Wichorus",
            "WiMAX-802.1p"                               => "WiMAX",
            "WiMAX-AAA-Session-Id"                       => "WiMAX",
            "WiMAX-Accounting-Capabilities"              => "WiMAX",
            "WiMAX-Acct-Input-Packets-Gigaword"          => "WiMAX",
            "WiMAX-Acct-Output-Packets-Gigaword"         => "WiMAX",
            "WiMAX-Activation-Trigger"                   => "WiMAX",
            "WiMAX-Active-Time-Duration"                 => "WiMAX",
            "WiMAX-AE-Command-Code"                      => "WiMAX",
            "WiMAX-Age-Of-Location-Information"          => "WiMAX",
            "WiMAX-ASN-Ethernet-Service-Capabilities"    => "WiMAX",
            "WiMAX-ASN-IP-Service-Capabilities"          => "WiMAX",
            "WiMAX-Authentication-Info"                  => "WiMAX",
            "WiMAX-Authorized-Anchor-Locations"          => "WiMAX",
            "WiMAX-Authorized-Ethernet-Services"         => "WiMAX",
            "WiMAX-Authorized-IP-Services"               => "WiMAX",
            "WiMAX-Available-In-Client"                  => "WiMAX",
            "WiMAX-Beginning-Of-Session"                 => "WiMAX",
            "WiMAX-Blu-Coa-IPv6"                         => "WiMAX",
            "WiMAX-BS-Id"                                => "WiMAX",
            "WiMAX-BS-Location"                          => "WiMAX",
            "WiMAX-Cancellation-Type"                    => "WiMAX",
            "WiMAX-Capability"                           => "WiMAX",
            "WiMAX-Check-Balance-Result"                 => "WiMAX",
            "WiMAX-Classifer-Direction"                  => "WiMAX",
            "WiMAX-Classifer-Priority"                   => "WiMAX",
            "WiMAX-Classifer-Protocol"                   => "WiMAX",
            "WiMAX-Classifier"                           => "WiMAX",
            "WiMAX-ClassifierID"                         => "WiMAX",
            "WiMAX-Control-Octets-In"                    => "WiMAX",
            "WiMAX-Control-Octets-Out"                   => "WiMAX",
            "WiMAX-Control-Packets-In"                   => "WiMAX",
            "WiMAX-Control-Packets-Out"                  => "WiMAX",
            "WiMAX-Cost-Information-AVP"                 => "WiMAX",
            "WiMAX-Count-Type"                           => "WiMAX",
            "WiMAX-Current-Location-Retrieved"           => "WiMAX",
            "WiMAX-Destination-Assigned"                 => "WiMAX",
            "WiMAX-Destination-Inverted"                 => "WiMAX",
            "WiMAX-Destination-IPAddress"                => "WiMAX",
            "WiMAX-Destination-IPAddressRange"           => "WiMAX",
            "WiMAX-Destination-Port"                     => "WiMAX",
            "WiMAX-Destination-Port-Range"               => "WiMAX",
            "WiMAX-Destination-Specification"            => "WiMAX",
            "WiMAX-Device-Authentication-Indicator"      => "WiMAX",
            "WiMAX-DGW-IPv4-addr"                        => "WiMAX",
            "WiMAX-DHCP-Msg-Server-IP"                   => "WiMAX",
            "WiMAX-DHCP-Option"                          => "WiMAX",
            "WiMAX-DHCP-Option-Container"                => "WiMAX",
            "WiMAX-DHCP-RK"                              => "WiMAX",
            "WiMAX-DHCP-RK-Key-Id"                       => "WiMAX",
            "WiMAX-DHCP-RK-Lifetime"                     => "WiMAX",
            "WiMAX-Direction"                            => "WiMAX",
            "WiMAX-DM-Action-Code"                       => "WiMAX",
            "WiMAX-Downlink-Classifier"                  => "WiMAX",
            "WiMAX-Downlink-Flow-Description"            => "WiMAX",
            "WiMAX-Downlink-Granted-QoS"                 => "WiMAX",
            "WiMAX-Downlink-QOS-Id"                      => "WiMAX",
            "WiMAX-Duration-Quota"                       => "WiMAX",
            "WiMAX-Duration-Threshold"                   => "WiMAX",
            "WiMAX-E-UTRAN-Cell-Global-Identity"         => "WiMAX",
            "WiMAX-E-UTRAN-Vector"                       => "WiMAX",
            "WiMAX-E-UTRAN-Vector-AUTN"                  => "WiMAX",
            "WiMAX-E-UTRAN-Vector-Item-Number"           => "WiMAX",
            "WiMAX-E-UTRAN-Vector-KASME"                 => "WiMAX",
            "WiMAX-E-UTRAN-Vector-RAND"                  => "WiMAX",
            "WiMAX-E-UTRAN-Vector-XRES"                  => "WiMAX",
            "WiMAX-EPS-Location-Information"             => "WiMAX",
            "WiMAX-FA-RK-Key"                            => "WiMAX",
            "WiMAX-FA-RK-SPI"                            => "WiMAX",
            "WiMAX-Flow-Descriptor-v2"                   => "WiMAX",
            "WiMAX-Geodetic-Information"                 => "WiMAX",
            "WiMAX-Geographical-Information"             => "WiMAX",
            "WiMAX-Global-Service-Class-Name"            => "WiMAX",
            "WiMAX-GMT-Timezone-offset"                  => "WiMAX",
            "WiMAX-HA-RK-Key"                            => "WiMAX",
            "WiMAX-HA-RK-Key-Requested"                  => "WiMAX",
            "WiMAX-HA-RK-Lifetime"                       => "WiMAX",
            "WiMAX-HA-RK-SPI"                            => "WiMAX",
            "WiMAX-hDHCP-DHCP-RK"                        => "WiMAX",
            "WiMAX-hDHCP-DHCP-RK-Key-Id"                 => "WiMAX",
            "WiMAX-hDHCP-DHCP-RK-Lifetime"               => "WiMAX",
            "WiMAX-hDHCP-DHCPv4-Address"                 => "WiMAX",
            "WiMAX-hDHCP-DHCPv6-Address"                 => "WiMAX",
            "WiMAX-hDHCP-Server-Parameters"              => "WiMAX",
            "WiMAX-hHA-IP-MIP4"                          => "WiMAX",
            "WiMAX-hHA-IP-MIP6"                          => "WiMAX",
            "WiMAX-hLMA-IPv4-PMIP6"                      => "WiMAX",
            "WiMAX-hLMA-IPv6-PMIP6"                      => "WiMAX",
            "WiMAX-Home-HNP-PMIP6"                       => "WiMAX",
            "WiMAX-Home-Interface-Id-PMIP6"              => "WiMAX",
            "WiMAX-Home-IPv4-HoA-PMIP6"                  => "WiMAX",
            "WiMAX-Hotline-Indicator"                    => "WiMAX",
            "WiMAX-Hotline-Profile-Id"                   => "WiMAX",
            "WiMAX-Hotline-Session-Timer"                => "WiMAX",
            "WiMAX-Hotlining-Capabilities"               => "WiMAX",
            "WiMAX-HTTP-Redirection-Rule"                => "WiMAX",
            "WiMAX-Idle-Mode-Notification-Cap"           => "WiMAX",
            "WiMAX-Idle-Mode-Transition"                 => "WiMAX",
            "WiMAX-IMEI"                                 => "WiMAX",
            "WiMAX-Immediate-Response-Preferred"         => "WiMAX",
            "WiMAX-IP-Redirection-Rule"                  => "WiMAX",
            "WiMAX-IP-Technology"                        => "WiMAX",
            "WiMAX-IP-TOS/DSCP-Range-and-Mask"           => "WiMAX",
            "WiMAX-IPv4-addr"                            => "WiMAX",
            "WiMAX-IPv4-Netmask"                         => "WiMAX",
            "WiMAX-Location"                             => "WiMAX",
            "WiMAX-Maximum-Latency"                      => "WiMAX",
            "WiMAX-Maximum-Sustained-Traffic-Rate"       => "WiMAX",
            "WiMAX-Maximum-Traffic-Burst"                => "WiMAX",
            "WiMAX-Media-Flow-Description-SDP"           => "WiMAX",
            "WiMAX-Media-Flow-Type"                      => "WiMAX",
            "WiMAX-Minimum-Reserved-Traffic-Rate"        => "WiMAX",
            "WiMAX-MIP-Authorization-Status"             => "WiMAX",
            "WiMAX-MN-hHA-MIP4-Key"                      => "WiMAX",
            "WiMAX-MN-hHA-MIP4-SPI"                      => "WiMAX",
            "WiMAX-MN-hHA-MIP6-Key"                      => "WiMAX",
            "WiMAX-MN-hHA-MIP6-SPI"                      => "WiMAX",
            "WiMAX-MN-vHA-MIP4-SPI"                      => "WiMAX",
            "WiMAX-MN-vHA-MIP6-Key"                      => "WiMAX",
            "WiMAX-MN-vHA-MIP6-SPI"                      => "WiMAX",
            "WiMAX-MS-Authenticated"                     => "WiMAX",
            "WiMAX-MSK"                                  => "WiMAX",
            "WiMAX-NAP-Id"                               => "WiMAX",
            "WiMAX-NSP-Id"                               => "WiMAX",
            "WiMAX-Number-Of-Requested-Vectors"          => "WiMAX",
            "WiMAX-Packet-Data-Flow-Id"                  => "WiMAX",
            "WiMAX-Packet-Flow-Descriptor"               => "WiMAX",
            "WiMAX-Packet-Flow-Descriptor-v2"            => "WiMAX",
            "WiMAX-PDFID"                                => "WiMAX",
            "WiMAX-PFDv2-Activation-Trigger"             => "WiMAX",
            "WiMAX-PFDv2-Classifier"                     => "WiMAX",
            "WiMAX-PFDv2-Classifier-Action"              => "WiMAX",
            "WiMAX-PFDv2-Classifier-Dest-Spec"           => "WiMAX",
            "WiMAX-PFDv2-Classifier-Direction"           => "WiMAX",
            "WiMAX-PFDv2-Classifier-Eth-Option"          => "WiMAX",
            "WiMAX-PFDv2-Classifier-Id"                  => "WiMAX",
            "WiMAX-PFDv2-Classifier-IP-ToS-DSCP"         => "WiMAX",
            "WiMAX-PFDv2-Classifier-Priority"            => "WiMAX",
            "WiMAX-PFDv2-Classifier-Protocol"            => "WiMAX",
            "WiMAX-PFDv2-Classifier-Source-Spec"         => "WiMAX",
            "WiMAX-PFDv2-Direction"                      => "WiMAX",
            "WiMAX-PFDv2-Downlink-QoS-Id"                => "WiMAX",
            "WiMAX-PFDv2-Eth-Priority-Range"             => "WiMAX",
            "WiMAX-PFDv2-Eth-Priority-Range-High"        => "WiMAX",
            "WiMAX-PFDv2-Eth-Priority-Range-Low"         => "WiMAX",
            "WiMAX-PFDv2-Eth-Proto-Type"                 => "WiMAX",
            "WiMAX-PFDv2-Eth-Proto-Type-DSAP"            => "WiMAX",
            "WiMAX-PFDv2-Eth-Proto-Type-Ethertype"       => "WiMAX",
            "WiMAX-PFDv2-Eth-VLAN-Id"                    => "WiMAX",
            "WiMAX-PFDv2-Eth-VLAN-Id-C-VID"              => "WiMAX",
            "WiMAX-PFDv2-Eth-VLAN-Id-S-VID"              => "WiMAX",
            "WiMAX-PFDv2-Packet-Data-Flow-Id"            => "WiMAX",
            "WiMAX-PFDv2-Paging-Preference"              => "WiMAX",
            "WiMAX-PFDv2-Service-Data-Flow-Id"           => "WiMAX",
            "WiMAX-PFDv2-Service-Profile-Id"             => "WiMAX",
            "WiMAX-PFDv2-Src-Assigned"                   => "WiMAX",
            "WiMAX-PFDv2-Src-Inverted"                   => "WiMAX",
            "WiMAX-PFDv2-Src-IP-Address-Range"           => "WiMAX",
            "WiMAX-PFDv2-Src-MAC-Address"                => "WiMAX",
            "WiMAX-PFDv2-Src-MAC-Mask"                   => "WiMAX",
            "WiMAX-PFDv2-Src-Port"                       => "WiMAX",
            "WiMAX-PFDv2-Src-Port-Range"                 => "WiMAX",
            "WiMAX-PFDv2-Transport-Type"                 => "WiMAX",
            "WiMAX-PFDv2-Uplink-QoS-Id"                  => "WiMAX",
            "WiMAX-PFDv2-VLAN-Tag-Rule-Id"               => "WiMAX",
            "WiMAX-PMIP-Authenticated-Network-Identity"  => "WiMAX",
            "WiMAX-PMIP6-RK-Key"                         => "WiMAX",
            "WiMAX-PMIP6-RK-SPI"                         => "WiMAX",
            "WiMAX-PMIP6-Service-Info"                   => "WiMAX",
            "WiMAX-Pool-Id"                              => "WiMAX",
            "WiMAX-Pool-Multiplier"                      => "WiMAX",
            "WiMAX-PPAC"                                 => "WiMAX",
            "WiMAX-PPAQ"                                 => "WiMAX",
            "WiMAX-PPAQ-Quota-Identifier"                => "WiMAX",
            "WiMAX-Prepaid-Indicator"                    => "WiMAX",
            "WiMAX-Prepaid-Quota-Identifier"             => "WiMAX",
            "WiMAX-Prepaid-Tariff-Switching"             => "WiMAX",
            "WiMAX-QoS-Descriptor"                       => "WiMAX",
            "WiMAX-QoS-Id"                               => "WiMAX",
            "WiMAX-R3-IF-Descriptor"                     => "WiMAX",
            "WiMAX-R3-IF-ID"                             => "WiMAX",
            "WiMAX-R3-IF-Name"                           => "WiMAX",
            "WiMAX-RAT-Type"                             => "WiMAX",
            "WiMAX-Rating-Group-Id"                      => "WiMAX",
            "WiMAX-Re-synchronization-Info"              => "WiMAX",
            "WiMAX-Reduced-Resources-Code"               => "WiMAX",
            "WiMAX-Ref-R3-IF-Name"                       => "WiMAX",
            "WiMAX-Release"                              => "WiMAX",
            "WiMAX-Requested-Action"                     => "WiMAX",
            "WiMAX-Requested-EUTRAN-Authentication-Info" => "WiMAX",
            "WiMAX-Resource-Quota"                       => "WiMAX",
            "WiMAX-Resource-Threshold"                   => "WiMAX",
            "WiMAX-RRQ-MN-HA-Key"                        => "WiMAX",
            "WiMAX-RRQ-MN-HA-SPI"                        => "WiMAX",
            "WiMAX-Schedule-Type"                        => "WiMAX",
            "WiMAX-SDFID"                                => "WiMAX",
            "WiMAX-SDU-Size"                             => "WiMAX",
            "WiMAX-Service-Class-Name"                   => "WiMAX",
            "WiMAX-Service-Data-Flow-Id"                 => "WiMAX",
            "WiMAX-Service-Id"                           => "WiMAX",
            "WiMAX-Service-Profile-Id"                   => "WiMAX",
            "WiMAX-Service-Selection"                    => "WiMAX",
            "WiMAX-Session-Continue"                     => "WiMAX",
            "WiMAX-Session-Termination-Capability"       => "WiMAX",
            "WiMAX-Software-Version"                     => "WiMAX",
            "WiMAX-Source-Assigned"                      => "WiMAX",
            "WiMAX-Source-Inverted"                      => "WiMAX",
            "WiMAX-Source-IPAddress"                     => "WiMAX",
            "WiMAX-Source-IPAddressRange"                => "WiMAX",
            "WiMAX-Source-Port"                          => "WiMAX",
            "WiMAX-Source-Port-Range"                    => "WiMAX",
            "WiMAX-Source-Specification"                 => "WiMAX",
            "WiMAX-Subscription-Data"                    => "WiMAX",
            "WiMAX-Tariff-Switch-Interval"               => "WiMAX",
            "WiMAX-Terminal-Information"                 => "WiMAX",
            "WiMAX-Termination-Action"                   => "WiMAX",
            "WiMAX-Time-Interval-After"                  => "WiMAX",
            "WiMAX-Tolerated-Jitter"                     => "WiMAX",
            "WiMAX-Tracking-Area-Identity"               => "WiMAX",
            "WiMAX-Traffic-Priority"                     => "WiMAX",
            "WiMAX-Transport-Type"                       => "WiMAX",
            "WiMAX-UE-AMBR-DL"                           => "WiMAX",
            "WiMAX-UE-AMBR-UL"                           => "WiMAX",
            "WiMAX-Unsolicited-Grant-Interval"           => "WiMAX",
            "WiMAX-Unsolicited-Polling-Interval"         => "WiMAX",
            "WiMAX-Update-Reason"                        => "WiMAX",
            "WiMAX-Uplink-Classifier"                    => "WiMAX",
            "WiMAX-Uplink-Flow-Description"              => "WiMAX",
            "WiMAX-Uplink-Granted-QoS"                   => "WiMAX",
            "WiMAX-Uplink-QOS-Id"                        => "WiMAX",
            "WiMAX-VCSN-Ethernet-Service-Capabilities"   => "WiMAX",
            "WiMAX-VCSN-IP-Service-Capabilities"         => "WiMAX",
            "WiMAX-vDHCP-DHCP-RK"                        => "WiMAX",
            "WiMAX-vDHCP-DHCP-RK-Key-Id"                 => "WiMAX",
            "WiMAX-vDHCP-DHCP-RK-Lifetime"               => "WiMAX",
            "WiMAX-vDHCP-DHCPv4-Address"                 => "WiMAX",
            "WiMAX-vDHCP-DHCPv6-Address"                 => "WiMAX",
            "WiMAX-vDHCP-RK"                             => "WiMAX",
            "WiMAX-vDHCP-RK-Key-ID"                      => "WiMAX",
            "WiMAX-vDHCP-RK-Lifetime"                    => "WiMAX",
            "WiMAX-vDHCP-Server-Parameters"              => "WiMAX",
            "WiMAX-vDHCPv4-Server"                       => "WiMAX",
            "WiMAX-vDHCPv6-Server"                       => "WiMAX",
            "WiMAX-vHA-IP-MIP4"                          => "WiMAX",
            "WiMAX-vHA-IP-MIP6"                          => "WiMAX",
            "WiMAX-vHA-MIP4-Key"                         => "WiMAX",
            "WiMAX-vHA-RK-Key"                           => "WiMAX",
            "WiMAX-vHA-RK-Lifetime"                      => "WiMAX",
            "WiMAX-vHA-RK-SPI"                           => "WiMAX",
            "WiMAX-Visited-Framed-Interface-Id"          => "WiMAX",
            "WiMAX-Visited-Framed-IP-Address"            => "WiMAX",
            "WiMAX-Visited-Framed-IPv6-Prefix"           => "WiMAX",
            "WiMAX-Visited-HNP-PMIP6"                    => "WiMAX",
            "WiMAX-Visited-Interface-Id-PMIP6"           => "WiMAX",
            "WiMAX-Visited-IPv4-HoA-PMIP6"               => "WiMAX",
            "WiMAX-Visited-IPv4-HoA-PMIP6-2"             => "WiMAX",
            "WiMAX-Visited-PLMN-ID"                      => "WiMAX",
            "WiMAX-VLAN-ID"                              => "WiMAX",
            "WiMAX-VLAN-Tag-C-S-VLAN-Id-Mapping"         => "WiMAX",
            "WiMAX-VLAN-Tag-C-VLAN-Id"                   => "WiMAX",
            "WiMAX-VLAN-Tag-C-VLAN-Priority"             => "WiMAX",
            "WiMAX-VLAN-Tag-Local-Config-Info"           => "WiMAX",
            "WiMAX-VLAN-Tag-Processing-Descriptor"       => "WiMAX",
            "WiMAX-VLAN-Tag-Rule-Id"                     => "WiMAX",
            "WiMAX-VLAN-Tag-S-VLAN-Id"                   => "WiMAX",
            "WiMAX-VLAN-Tag-VLAN-Id-Assignment"          => "WiMAX",
            "WiMAX-vLMA-IPv4-PMIP6"                      => "WiMAX",
            "WiMAX-vLMA-IPv6-PMIP6"                      => "WiMAX",
            "WiMAX-Volume-Quota"                         => "WiMAX",
            "WiMAX-Volume-Threshold"                     => "WiMAX",
            "WiMAX-Volume-Used-After"                    => "WiMAX",
            "WiMAX-XXX"                                  => "WiMAX",
            "WISPr-Bandwidth-Max-Down"                   => "WISPr",
            "WISPr-Bandwidth-Max-Up"                     => "WISPr",
            "WISPr-Bandwidth-Min-Down"                   => "WISPr",
            "WISPr-Bandwidth-Min-Up"                     => "WISPr",
            "WISPr-Billing-Class-Of-Service"             => "WISPr",
            "WISPr-Location-ID"                          => "WISPr",
            "WISPr-Location-Name"                        => "WISPr",
            "WISPr-Logoff-URL"                           => "WISPr",
            "WISPr-Redirection-URL"                      => "WISPr",
            "WISPr-Session-Terminate-End-Of-Day"         => "WISPr",
            "WISPr-Session-Terminate-Time"               => "WISPr",
            "Xedia-Address-Pool"                         => "Xedia",
            "Xedia-Client-Access-Network"                => "Xedia",
            "Xedia-Client-Firewall-Setting"              => "Xedia",
            "Xedia-DNS-Server"                           => "Xedia",
            "Xedia-NetBios-Server"                       => "Xedia",
            "Xedia-PPP-Echo-Interval"                    => "Xedia",
            "Xedia-Save-Password"                        => "Xedia",
            "Xedia-SSH-Privileges"                       => "Xedia",
            "Xylan-Acce-Priv-F-R1"                       => "Xylan",
            "Xylan-Acce-Priv-F-R2"                       => "Xylan",
            "Xylan-Acce-Priv-F-W1"                       => "Xylan",
            "Xylan-Acce-Priv-F-W2"                       => "Xylan",
            "Xylan-Acce-Priv-G1"                         => "Xylan",
            "Xylan-Acce-Priv-G2"                         => "Xylan",
            "Xylan-Acce-Priv-R1"                         => "Xylan",
            "Xylan-Acce-Priv-R2"                         => "Xylan",
            "Xylan-Acce-Priv-W1"                         => "Xylan",
            "Xylan-Acce-Priv-W2"                         => "Xylan",
            "Xylan-Access-Priv"                          => "Xylan",
            "Xylan-Asa-Access"                           => "Xylan",
            "Xylan-Auth-Group"                           => "Xylan",
            "Xylan-Auth-Group-Protocol"                  => "Xylan",
            "Xylan-Client-IP-Addr"                       => "Xylan",
            "Xylan-Device-Location"                      => "Xylan",
            "Xylan-Device-Name"                          => "Xylan",
            "Xylan-End-User-Profile"                     => "Xylan",
            "Xylan-Group-Desc"                           => "Xylan",
            "Xylan-Home-Agent-Password"                  => "Xylan",
            "Xylan-Home-Network-Name"                    => "Xylan",
            "Xylan-Nms-Description"                      => "Xylan",
            "Xylan-Nms-First-Name"                       => "Xylan",
            "Xylan-Nms-Group"                            => "Xylan",
            "Xylan-Nms-Last-Name"                        => "Xylan",
            "Xylan-Policy-List"                          => "Xylan",
            "Xylan-Port-Desc"                            => "Xylan",
            "Xylan-Primary-Home-Agent"                   => "Xylan",
            "Xylan-Profil-Numb"                          => "Xylan",
            "Xylan-Redirect-Url"                         => "Xylan",
            "Xylan-Secondary-Home-Agent"                 => "Xylan",
            "Xylan-Slot-Port"                            => "Xylan",
            "Xylan-Time-of-Day"                          => "Xylan",
            "Yubikey-Counter"                            => "Yubico",
            "Yubikey-Key"                                => "Yubico",
            "Yubikey-OTP"                                => "Yubico",
            "Yubikey-Private-ID"                         => "Yubico",
            "Yubikey-Public-ID"                          => "Yubico",
            "Yubikey-Random"                             => "Yubico",
            "Yubikey-Timestamp"                          => "Yubico",
            "Zeus-ZXTM-Group"                            => "Zeus",
            "ZTE-Access-Domain"                          => "ZTE",
            "ZTE-Access-Type"                            => "ZTE",
            "ZTE-Client-DNS-Pri"                         => "ZTE",
            "ZTE-Client-DNS-Sec"                         => "ZTE",
            "ZTE-Context-Name"                           => "ZTE",
            "ZTE-IGMP-Service-Profile-Num"               => "ZTE",
            "ZTE-Mcast-MaxGroups"                        => "ZTE",
            "ZTE-Mcast-Receive"                          => "ZTE",
            "ZTE-Mcast-Send"                             => "ZTE",
            "ZTE-PPP-Sservice-Type"                      => "ZTE",
            "ZTE-PPPOE-MOTM"                             => "ZTE",
            "ZTE-PPPOE-URL"                              => "ZTE",
            "ZTE-Priority-Level"                         => "ZTE",
            "ZTE-QoS-Profile-Down"                       => "ZTE",
            "ZTE-QoS-Profile-Down-v6"                    => "ZTE",
            "ZTE-QOS-Profile-Up"                         => "ZTE",
            "ZTE-QoS-Profile-Up-v6"                      => "ZTE",
            "ZTE-QoS-Type"                               => "ZTE",
            "ZTE-Rate-Ctrl-Burst-Down"                   => "ZTE",
            "ZTE-Rate-Ctrl-Burst-Down-v6"                => "ZTE",
            "ZTE-Rate-Ctrl-Burst-Max-Down"               => "ZTE",
            "ZTE-Rate-Ctrl-Burst-Max-Down-v6"            => "ZTE",
            "ZTE-Rate-Ctrl-Burst-Max-Up"                 => "ZTE",
            "ZTE-Rate-Ctrl-Burst-Max-Up-v6"              => "ZTE",
            "ZTE-Rate-Ctrl-Burst-Up"                     => "ZTE",
            "ZTE-Rate-Ctrl-Burst-Up-v6"                  => "ZTE",
            "ZTE-Rate-Ctrl-PBS-Down"                     => "ZTE",
            "ZTE-Rate-Ctrl-PBS-Down-v6"                  => "ZTE",
            "ZTE-Rate-Ctrl-PBS-Up"                       => "ZTE",
            "ZTE-Rate-Ctrl-PBS-Up-v6"                    => "ZTE",
            "ZTE-Rate-Ctrl-PCR"                          => "ZTE",
            "ZTE-Rate-Ctrl-SCR-Down"                     => "ZTE",
            "ZTE-Rate-Ctrl-SCR-Down-v6"                  => "ZTE",
            "ZTE-Rate-Ctrl-SCR-Up"                       => "ZTE",
            "ZTE-Rate-Ctrl-SCR-Up-v6"                    => "ZTE",
            "ZTE-SW-Privilege"                           => "ZTE",
            "ZTE-TCP-Limit-Mode"                         => "ZTE",
            "ZTE-TCP-Limit-Num"                          => "ZTE",
            "ZTE-TCP-Syn-Rate"                           => "ZTE",
            "ZTE-Tunnel-Algorithm"                       => "ZTE",
            "ZTE-Tunnel-Cmd-Timeout"                     => "ZTE",
            "ZTE-Tunnel-Deadtime"                        => "ZTE",
            "ZTE-Tunnel-Max-Sessions"                    => "ZTE",
            "ZTE-Tunnel-Max-Tunnels"                     => "ZTE",
            "ZTE-Tunnel-Retransmit"                      => "ZTE",
            "ZTE-Tunnel-Window"                          => "ZTE",
            "ZTE-VPN-ID"                                 => "ZTE",
            "ZTE_Rate-Bust-DPIR"                         => "ZTE",
            "ZTE_Rate-Bust-UPIR"                         => "ZTE",
            "Zyxel-Callback-Option"                      => "Zyxel",
            "Zyxel-Callback-Phone-Source"                => "Zyxel",
            "Zyxel-Privilege-AVPair"                     => "Zyxel",
        },
        rattr => {
            1    => [ "User-Name",                              "string" ],
            2    => [ "User-Password",                          "string" ],
            3    => [ "CHAP-Password",                          "octets" ],
            4    => [ "NAS-IP-Address",                         "ipaddr" ],
            5    => [ "NAS-Port",                               "integer" ],
            6    => [ "Service-Type",                           "integer" ],
            7    => [ "Framed-Protocol",                        "integer" ],
            8    => [ "Framed-IP-Address",                      "ipaddr" ],
            9    => [ "Framed-IP-Netmask",                      "ipaddr" ],
            10   => [ "Framed-Routing",                         "integer" ],
            11   => [ "Filter-Id",                              "string" ],
            12   => [ "Framed-MTU",                             "integer" ],
            13   => [ "Framed-Compression",                     "integer" ],
            14   => [ "Login-IP-Host",                          "ipaddr" ],
            15   => [ "Login-Service",                          "integer" ],
            16   => [ "Login-TCP-Port",                         "integer" ],
            17   => [ "Old-Password",                           "string" ],
            18   => [ "Reply-Message",                          "string" ],
            19   => [ "Callback-Number",                        "string" ],
            20   => [ "Callback-Id",                            "string" ],
            22   => [ "Framed-Route",                           "string" ],
            23   => [ "Framed-IPX-Network",                     "ipaddr" ],
            24   => [ "State",                                  "octets" ],
            25   => [ "Class",                                  "octets" ],
            26   => [ "Vendor-Specific",                        "vsa" ],
            27   => [ "Session-Timeout",                        "integer" ],
            28   => [ "Idle-Timeout",                           "integer" ],
            29   => [ "Termination-Action",                     "integer" ],
            30   => [ "Called-Station-Id",                      "string" ],
            31   => [ "Calling-Station-Id",                     "string" ],
            32   => [ "NAS-Identifier",                         "string" ],
            33   => [ "Proxy-State",                            "octets" ],
            34   => [ "Login-LAT-Service",                      "string" ],
            35   => [ "Login-LAT-Node",                         "string" ],
            36   => [ "Login-LAT-Group",                        "octets" ],
            37   => [ "Framed-AppleTalk-Link",                  "integer" ],
            38   => [ "Framed-AppleTalk-Network",               "integer" ],
            39   => [ "Framed-AppleTalk-Zone",                  "string" ],
            40   => [ "Acct-Status-Type",                       "integer" ],
            41   => [ "Acct-Delay-Time",                        "integer" ],
            42   => [ "Acct-Input-Octets",                      "integer" ],
            43   => [ "Acct-Output-Octets",                     "integer" ],
            44   => [ "Acct-Session-Id",                        "string" ],
            45   => [ "Acct-Authentic",                         "integer" ],
            46   => [ "Acct-Session-Time",                      "integer" ],
            47   => [ "Acct-Input-Packets",                     "integer" ],
            48   => [ "Acct-Output-Packets",                    "integer" ],
            49   => [ "Acct-Terminate-Cause",                   "integer" ],
            50   => [ "Acct-Multi-Session-Id",                  "string" ],
            51   => [ "Acct-Link-Count",                        "integer" ],
            52   => [ "Acct-Input-Gigawords",                   "integer" ],
            53   => [ "Acct-Output-Gigawords",                  "integer" ],
            55   => [ "Event-Timestamp",                        "date" ],
            56   => [ "Egress-VLANID",                          "integer" ],
            57   => [ "Ingress-Filters",                        "integer" ],
            58   => [ "Egress-VLAN-Name",                       "string" ],
            59   => [ "User-Priority-Table",                    "octets" ],
            60   => [ "CHAP-Challenge",                         "octets" ],
            61   => [ "NAS-Port-Type",                          "integer" ],
            62   => [ "Port-Limit",                             "integer" ],
            63   => [ "Login-LAT-Port",                         "string" ],
            64   => [ "Tunnel-Type",                            "integer" ],
            65   => [ "Tunnel-Medium-Type",                     "integer" ],
            66   => [ "Tunnel-Client-Endpoint",                 "string" ],
            67   => [ "Tunnel-Server-Endpoint",                 "string" ],
            68   => [ "Acct-Tunnel-Connection",                 "string" ],
            69   => [ "Tunnel-Password",                        "string" ],
            70   => [ "ARAP-Password",                          "octets" ],
            71   => [ "ARAP-Features",                          "octets" ],
            72   => [ "ARAP-Zone-Access",                       "integer" ],
            73   => [ "ARAP-Security",                          "integer" ],
            74   => [ "ARAP-Security-Data",                     "string" ],
            75   => [ "Password-Retry",                         "integer" ],
            76   => [ "Prompt",                                 "integer" ],
            77   => [ "Connect-Info",                           "string" ],
            78   => [ "Configuration-Token",                    "string" ],
            79   => [ "EAP-Message",                            "octets" ],
            80   => [ "Message-Authenticator",                  "octets" ],
            81   => [ "Tunnel-Private-Group-Id",                "string" ],
            82   => [ "Tunnel-Assignment-Id",                   "string" ],
            83   => [ "Tunnel-Preference",                      "integer" ],
            84   => [ "ARAP-Challenge-Response",                "octets" ],
            85   => [ "Acct-Interim-Interval",                  "integer" ],
            86   => [ "Acct-Tunnel-Packets-Lost",               "integer" ],
            87   => [ "NAS-Port-Id",                            "string" ],
            88   => [ "Framed-Pool",                            "string" ],
            89   => [ "Chargeable-User-Identity",               "octets" ],
            90   => [ "Tunnel-Client-Auth-Id",                  "string" ],
            91   => [ "Tunnel-Server-Auth-Id",                  "string" ],
            92   => [ "NAS-Filter-Rule",                        "string" ],
            94   => [ "Originating-Line-Info",                  "octets" ],
            95   => [ "NAS-IPv6-Address",                       "ipv6addr" ],
            96   => [ "Framed-Interface-Id",                    "ifid" ],
            97   => [ "Framed-IPv6-Prefix",                     "ipv6prefix" ],
            98   => [ "Login-IPv6-Host",                        "ipv6addr" ],
            99   => [ "Framed-IPv6-Route",                      "string" ],
            100  => [ "Framed-IPv6-Pool",                       "string" ],
            101  => [ "Error-Cause",                            "integer" ],
            102  => [ "EAP-Key-Name",                           "octets" ],
            119  => [ "X-Ascend-FCP-Parameter",                 "string" ],
            120  => [ "X-Ascend-Modem-PortNo",                  "integer" ],
            121  => [ "X-Ascend-Modem-SlotNo",                  "integer" ],
            122  => [ "X-Ascend-Modem-ShelfNo",                 "integer" ],
            123  => [ "Delegated-IPv6-Prefix",                  "ipv6prefix" ],
            124  => [ "MIP6-Feature-Vector",                    "integer64" ],
            125  => [ "MIP6-Home-Link-Prefix",                  "octets" ],
            126  => [ "Operator-Name",                          "string" ],
            127  => [ "Location-Information",                   "octets" ],
            128  => [ "Location-Data",                          "octets" ],
            129  => [ "Basic-Location-Policy-Rules",            "octets" ],
            130  => [ "Extended-Location-Policy-Rules",         "string" ],
            131  => [ "Location-Capable",                       "integer" ],
            132  => [ "Requested-Location-Info",                "integer" ],
            133  => [ "Framed-Management",                      "integer" ],
            134  => [ "Management-Transport-Protection",        "integer" ],
            135  => [ "Management-Policy-Id",                   "string" ],
            136  => [ "Management-Privilege-Level",             "integer" ],
            137  => [ "PKM-SS-Cert",                            "octets" ],
            138  => [ "PKM-CA-Cert",                            "octets" ],
            139  => [ "PKM-Config-Settings",                    "octets" ],
            140  => [ "PKM-Cryptosuite-List",                   "octets" ],
            141  => [ "PKM-SAID",                               "short" ],
            142  => [ "PKM-SA-Descriptor",                      "octets" ],
            143  => [ "PKM-Auth-Key",                           "octets" ],
            144  => [ "DS-Lite-Tunnel-Name",                    "octets" ],
            145  => [ "Mobile-Node-Identifier",                 "octets" ],
            146  => [ "Service-Selection",                      "string" ],
            147  => [ "PMIP6-Home-LMA-IPv6-Address",            "ipv6addr" ],
            148  => [ "PMIP6-Visited-LMA-IPv6-Address",         "ipv6addr" ],
            149  => [ "PMIP6-Home-LMA-IPv4-Address",            "ipaddr" ],
            150  => [ "PMIP6-Visited-LMA-IPv4-Address",         "ipaddr" ],
            151  => [ "PMIP6-Home-HN-Prefix",                   "ipv6prefix" ],
            152  => [ "PMIP6-Visited-HN-Prefix",                "ipv6prefix" ],
            153  => [ "PMIP6-Home-Interface-ID",                "ifid" ],
            154  => [ "PMIP6-Visited-Interface-ID",             "ifid" ],
            155  => [ "PMIP6-Home-IPv4-HoA",                    "ipv4prefix" ],
            156  => [ "PMIP6-Visited-IPv4-HoA",                 "ipv4prefix" ],
            157  => [ "PMIP6-Home-DHCP4-Server-Address",        "ipaddr" ],
            158  => [ "PMIP6-Visited-DHCP4-Server-Address",     "ipaddr" ],
            159  => [ "PMIP6-Home-DHCP6-Server-Address",        "ipv6addr" ],
            160  => [ "PMIP6-Visited-DHCP6-Server-Address",     "ipv6addr" ],
            161  => [ "PMIP6-Home-IPv4-Gateway",                "ipaddr" ],
            162  => [ "PMIP6-Visited-IPv4-Gateway",             "ipaddr" ],
            163  => [ "EAP-Lower-Layer",                        "integer" ],
            164  => [ "GSS-Acceptor-Service-Name",              "string" ],
            165  => [ "GSS-Acceptor-Host-Name",                 "string" ],
            166  => [ "GSS-Acceptor-Service-Specifics",         "string" ],
            167  => [ "GSS-Acceptor-Realm-Name",                "string" ],
            168  => [ "Framed-IPv6-Address",                    "ipv6addr" ],
            169  => [ "DNS-Server-IPv6-Address",                "ipv6addr" ],
            170  => [ "Route-IPv6-Information",                 "ipv6prefix" ],
            171  => [ "Delegated-IPv6-Prefix-Pool",             "string" ],
            172  => [ "Stateful-IPv6-Address-Pool",             "string" ],
            173  => [ "IPv6-6rd-BR-IPv4-Address",               "ipaddr" ],
            174  => [ "Allowed-Called-Station-Id",              "string" ],
            175  => [ "EAP-Peer-Id",                            "octets" ],
            176  => [ "EAP-Server-Id",                          "octets" ],
            177  => [ "Mobility-Domain-Id",                     "integer" ],
            178  => [ "Preauth-Timeout",                        "integer" ],
            179  => [ "Network-Id-Name",                        "octets" ],
            180  => [ "EAPoL-Announcement",                     "octets" ],
            181  => [ "WLAN-HESSID",                            "string" ],
            182  => [ "WLAN-Venue-Info",                        "integer" ],
            183  => [ "WLAN-Venue-Language",                    "octets" ],
            184  => [ "WLAN-Venue-Name",                        "string" ],
            185  => [ "WLAN-Reason-Code",                       "integer" ],
            186  => [ "WLAN-Pairwise-Cipher",                   "integer" ],
            187  => [ "WLAN-Group-Cipher",                      "integer" ],
            188  => [ "WLAN-AKM-Suite",                         "integer" ],
            189  => [ "WLAN-Group-Mgmt-Cipher",                 "integer" ],
            190  => [ "WLAN-RF-Band",                           "integer" ],
            191  => [ "X-Ascend-Pre-Output-Octets",             "integer" ],
            192  => [ "X-Ascend-Pre-Input-Packets",             "integer" ],
            193  => [ "X-Ascend-Pre-Output-Packets",            "integer" ],
            194  => [ "X-Ascend-Maximum-Time",                  "integer" ],
            195  => [ "X-Ascend-Disconnect-Cause",              "integer" ],
            196  => [ "X-Ascend-Connect-Progress",              "integer" ],
            197  => [ "X-Ascend-Data-Rate",                     "integer" ],
            198  => [ "X-Ascend-PreSession-Time",               "integer" ],
            199  => [ "X-Ascend-Token-Idle",                    "integer" ],
            200  => [ "X-Ascend-Token-Immediate",               "integer" ],
            201  => [ "X-Ascend-Require-Auth",                  "integer" ],
            202  => [ "X-Ascend-Number-Sessions",               "string" ],
            203  => [ "X-Ascend-Authen-Alias",                  "string" ],
            204  => [ "X-Ascend-Token-Expiry",                  "integer" ],
            205  => [ "X-Ascend-Menu-Selector",                 "string" ],
            206  => [ "Digest-Response",                        "string" ],
            207  => [ "Digest-Attributes",                      "octets" ],
            208  => [ "X-Ascend-PW-Lifetime",                   "integer" ],
            209  => [ "X-Ascend-IP-Direct",                     "ipaddr" ],
            210  => [ "X-Ascend-PPP-VJ-Slot-Comp",              "integer" ],
            211  => [ "X-Ascend-PPP-VJ-1172",                   "integer" ],
            212  => [ "X-Ascend-PPP-Async-Map",                 "integer" ],
            213  => [ "X-Ascend-Third-Prompt",                  "string" ],
            214  => [ "X-Ascend-Send-Secret",                   "string" ],
            215  => [ "X-Ascend-Receive-Secret",                "string" ],
            216  => [ "X-Ascend-IPX-Peer-Mode",                 "integer" ],
            217  => [ "X-Ascend-IP-Pool-Definition",            "string" ],
            218  => [ "X-Ascend-Assign-IP-Pool",                "integer" ],
            219  => [ "X-Ascend-FR-Direct",                     "integer" ],
            220  => [ "X-Ascend-FR-Direct-Profile",             "string" ],
            221  => [ "X-Ascend-FR-Direct-DLCI",                "integer" ],
            222  => [ "X-Ascend-Handle-IPX",                    "integer" ],
            223  => [ "X-Ascend-Netware-timeout",               "integer" ],
            224  => [ "X-Ascend-IPX-Alias",                     "integer" ],
            225  => [ "X-Ascend-Metric",                        "integer" ],
            226  => [ "X-Ascend-PRI-Number-Type",               "integer" ],
            227  => [ "X-Ascend-Dial-Number",                   "string" ],
            228  => [ "X-Ascend-Route-IP",                      "integer" ],
            229  => [ "X-Ascend-Route-IPX",                     "integer" ],
            230  => [ "X-Ascend-Bridge",                        "integer" ],
            231  => [ "X-Ascend-Send-Auth",                     "integer" ],
            232  => [ "X-Ascend-Send-Passwd",                   "string" ],
            233  => [ "X-Ascend-Link-Compression",              "integer" ],
            234  => [ "X-Ascend-Target-Util",                   "integer" ],
            235  => [ "X-Ascend-Maximum-Channels",              "integer" ],
            236  => [ "X-Ascend-Inc-Channel-Count",             "integer" ],
            237  => [ "X-Ascend-Dec-Channel-Count",             "integer" ],
            238  => [ "X-Ascend-Seconds-Of-History",            "integer" ],
            239  => [ "X-Ascend-History-Weigh-Type",            "integer" ],
            240  => [ "X-Ascend-Add-Seconds",                   "integer" ],
            241  => [ "Operator-NAS-Identifier",                "octets" ],
            242  => [ "X-Ascend-Data-Filter",                   "abinary" ],
            243  => [ "X-Ascend-Call-Filter",                   "abinary" ],
            244  => [ "X-Ascend-Idle-Limit",                    "integer" ],
            245  => [ "X-Ascend-Preempt-Limit",                 "integer" ],
            246  => [ "X-Ascend-Callback",                      "integer" ],
            247  => [ "X-Ascend-Data-Svc",                      "integer" ],
            248  => [ "X-Ascend-Force-56",                      "integer" ],
            249  => [ "X-Ascend-Billing-Number",                "string" ],
            250  => [ "X-Ascend-Call-By-Call",                  "integer" ],
            251  => [ "X-Ascend-Transit-Number",                "string" ],
            252  => [ "X-Ascend-Host-Info",                     "string" ],
            253  => [ "X-Ascend-PPP-Address",                   "ipaddr" ],
            254  => [ "X-Ascend-MPP-Idle-Percent",              "integer" ],
            255  => [ "X-Ascend-Xmit-Rate",                     "integer" ],
            500  => [ "Fall-Through",                           "integer" ],
            501  => [ "Relax-Filter",                           "integer" ],
            502  => [ "Exec-Program",                           "string" ],
            503  => [ "Exec-Program-Wait",                      "string" ],
            1000 => [ "Auth-Type",                              "integer" ],
            1001 => [ "Menu",                                   "string" ],
            1002 => [ "Termination-Menu",                       "string" ],
            1003 => [ "Prefix",                                 "string" ],
            1004 => [ "Suffix",                                 "string" ],
            1005 => [ "Group",                                  "string" ],
            1006 => [ "Crypt-Password",                         "string" ],
            1008 => [ "Add-Prefix",                             "string" ],
            1009 => [ "Add-Suffix",                             "string" ],
            1010 => [ "Expiration",                             "date" ],
            1011 => [ "Autz-Type",                              "integer" ],
            1012 => [ "Acct-Type",                              "integer" ],
            1013 => [ "Session-Type",                           "integer" ],
            1014 => [ "Post-Auth-Type",                         "integer" ],
            1015 => [ "Pre-Proxy-Type",                         "integer" ],
            1016 => [ "Post-Proxy-Type",                        "integer" ],
            1017 => [ "Pre-Acct-Type",                          "integer" ],
            1018 => [ "EAP-Type",                               "integer" ],
            1019 => [ "EAP-TLS-Require-Client-Cert",            "integer" ],
            1020 => [ "EAP-Id",                                 "integer" ],
            1021 => [ "EAP-Code",                               "integer" ],
            1022 => [ "EAP-MD5-Password",                       "string" ],
            1023 => [ "PEAP-Version",                           "integer" ],
            1024 => [ "Client-Shortname",                       "string" ],
            1025 => [ "Load-Balance-Key",                       "string" ],
            1026 => [ "Raw-Attribute",                          "octets" ],
            1027 => [ "TNC-VLAN-Access",                        "string" ],
            1028 => [ "TNC-VLAN-Isolate",                       "string" ],
            1029 => [ "User-Category",                          "string" ],
            1030 => [ "Group-Name",                             "string" ],
            1031 => [ "Huntgroup-Name",                         "string" ],
            1034 => [ "Simultaneous-Use",                       "integer" ],
            1035 => [ "Strip-User-Name",                        "integer" ],
            1040 => [ "Hint",                                   "string" ],
            1041 => [ "Pam-Auth",                               "string" ],
            1042 => [ "Login-Time",                             "string" ],
            1043 => [ "Stripped-User-Name",                     "string" ],
            1044 => [ "Current-Time",                           "string" ],
            1045 => [ "Realm",                                  "string" ],
            1046 => [ "No-Such-Attribute",                      "string" ],
            1047 => [ "Packet-Type",                            "integer" ],
            1048 => [ "Proxy-To-Realm",                         "string" ],
            1049 => [ "Replicate-To-Realm",                     "string" ],
            1050 => [ "Acct-Session-Start-Time",                "date" ],
            1051 => [ "Acct-Unique-Session-Id",                 "string" ],
            1052 => [ "Client-IP-Address",                      "ipaddr" ],
            1053 => [ "LDAP-UserDN",                            "string" ],
            1054 => [ "NS-MTA-MD5-Password",                    "string" ],
            1055 => [ "SQL-User-Name",                          "string" ],
            1057 => [ "LM-Password",                            "octets" ],
            1058 => [ "NT-Password",                            "octets" ],
            1059 => [ "SMB-Account-CTRL",                       "integer" ],
            1061 => [ "SMB-Account-CTRL-TEXT",                  "string" ],
            1062 => [ "User-Profile",                           "string" ],
            1063 => [ "Digest-Realm",                           "string" ],
            1064 => [ "Digest-Nonce",                           "string" ],
            1065 => [ "Digest-Method",                          "string" ],
            1066 => [ "Digest-URI",                             "string" ],
            1067 => [ "Digest-QOP",                             "string" ],
            1068 => [ "Digest-Algorithm",                       "string" ],
            1069 => [ "Digest-Body-Digest",                     "string" ],
            1070 => [ "Digest-CNonce",                          "string" ],
            1071 => [ "Digest-Nonce-Count",                     "string" ],
            1072 => [ "Digest-User-Name",                       "string" ],
            1073 => [ "Pool-Name",                              "string" ],
            1075 => [ "Module-Success-Message",                 "string" ],
            1076 => [ "Module-Failure-Message",                 "string" ],
            1078 => [ "Rewrite-Rule",                           "string" ],
            1080 => [ "Response-Packet-Type",                   "integer" ],
            1081 => [ "Digest-HA1",                             "string" ],
            1082 => [ "MS-CHAP-Use-NTLM-Auth",                  "integer" ],
            1083 => [ "MS-CHAP-User-Name",                      "string" ],
            1084 => [ "Packet-Src-IP-Address",                  "ipaddr" ],
            1085 => [ "Packet-Dst-IP-Address",                  "ipaddr" ],
            1086 => [ "Packet-Src-Port",                        "integer" ],
            1087 => [ "Packet-Dst-Port",                        "integer" ],
            1088 => [ "Packet-Authentication-Vector",           "octets" ],
            1089 => [ "Time-Of-Day",                            "string" ],
            1090 => [ "Request-Processing-Stage",               "string" ],
            1092 => [ "SHA2-Password",                          "octets" ],
            1093 => [ "SHA1-Password",                          "octets" ],
            1094 => [ "SSHA1-Password",                         "octets" ],
            1095 => [ "MD5-Password",                           "octets" ],
            1096 => [ "SMD5-Password",                          "octets" ],
            1097 => [ "Packet-Src-IPv6-Address",                "ipv6addr" ],
            1098 => [ "Packet-Dst-IPv6-Address",                "ipv6addr" ],
            1099 => [ "Virtual-Server",                         "string" ],
            1100 => [ "Cleartext-Password",                     "string" ],
            1101 => [ "Password-With-Header",                   "string" ],
            1102 => [ "Inner-Tunnel-User-Name",                 "string" ],
            1103 => [ "EAP-IKEv2-IDType",                       "integer" ],
            1104 => [ "EAP-IKEv2-ID",                           "string" ],
            1105 => [ "EAP-IKEv2-Secret",                       "string" ],
            1106 => [ "EAP-IKEv2-AuthType",                     "integer" ],
            1107 => [ "Send-CoA-Request",                       "integer" ],
            1108 => [ "Module-Return-Code",                     "integer" ],
            1109 => [ "Packet-Original-Timestamp",              "date" ],
            1110 => [ "SQL-Table-Name",                         "string" ],
            1111 => [ "Home-Server-Pool",                       "string" ],
            1112 => [ "Attribute-Map",                          "string" ],
            1113 => [ "CoA-Packet-Type",                        "string" ],
            1114 => [ "CoA-Packet-DST-IP-Address",              "ipaddr" ],
            1115 => [ "CoA-Packet-DST-Port",                    "integer" ],
            1116 => [ "CoA-Acct-Session-Id",                    "string" ],
            1117 => [ "CoA-Packet-DST-IPv6-Address",            "ipv6addr" ],
            1120 => [ "FreeRADIUS-Client-IP-Address",           "ipaddr" ],
            1121 => [ "FreeRADIUS-Client-IPv6-Address",         "ipv6addr" ],
            1122 => [ "FreeRADIUS-Client-Require-MA",           "integer" ],
            1123 => [ "FreeRADIUS-Client-Secret",               "string" ],
            1124 => [ "FreeRADIUS-Client-Shortname",            "string" ],
            1125 => [ "FreeRADIUS-Client-NAS-Type",             "string" ],
            1126 => [ "FreeRADIUS-Client-Virtual-Server",       "string" ],
            1127 => [ "Allow-Session-Resumption",               "integer" ],
            1128 => [ "EAP-Session-Resumed",                    "integer" ],
            1129 => [ "EAP-MSK",                                "octets" ],
            1130 => [ "EAP-EMSK",                               "octets" ],
            1131 => [ "Recv-CoA-Type",                          "integer" ],
            1132 => [ "Send-CoA-Type",                          "integer" ],
            1133 => [ "MS-CHAP-Password",                       "string" ],
            1134 => [ "Packet-Transmit-Counter",                "integer" ],
            1135 => [ "Cached-Session-Policy",                  "string" ],
            1136 => [ "MS-CHAP-New-Cleartext-Password",         "string" ],
            1137 => [ "MS-CHAP-New-NT-Password",                "octets" ],
            1138 => [ "Stripped-User-Domain",                   "string" ],
            1139 => [ "Called-Station-SSID",                    "string" ],
            1140 => [ "Called-Station-MAC",                     "octets" ],
            1141 => [ "Pre-Shared-Key",                         "string" ],
            1142 => [ "Pairwise-Master-Key",                    "octets" ],
            1143 => [ "PSK-Identity",                           "string" ],
            1145 => [ "OTP-Challenge",                          "string" ],
            1146 => [ "EAP-Session-Id",                         "octets" ],
            1147 => [ "Chbind-Response-Code",                   "integer" ],
            1148 => [ "Acct-Input-Octets64",                    "integer64" ],
            1149 => [ "Acct-Output-Octets64",                   "integer64" ],
            1150 => [ "FreeRADIUS-Client-IP-Prefix",            "ipv4prefix" ],
            1151 => [ "FreeRADIUS-Client-IPv6-Prefix",          "ipv6prefix" ],
            1152 => [ "FreeRADIUS-Response-Delay",              "integer" ],
            1153 => [ "FreeRADIUS-Client-Src-IP-Address",       "ipaddr" ],
            1154 => [ "FreeRADIUS-Client-Src-IPv6-Address",     "ipv6addr" ],
            1155 => [ "FreeRADIUS-Response-Delay-USec",         "integer" ],
            1160 => [ "REST-HTTP-Header",                       "string" ],
            1161 => [ "REST-HTTP-Body",                         "string" ],
            1162 => [ "REST-HTTP-Status-Code",                  "integer" ],
            1170 => [ "Cache-Expires",                          "date" ],
            1171 => [ "Cache-Created",                          "date" ],
            1172 => [ "Cache-TTL",                              "signed" ],
            1173 => [ "Cache-Status-Only",                      "integer" ],
            1174 => [ "Cache-Merge",                            "integer" ],
            1175 => [ "Cache-Entry-Hits",                       "integer" ],
            1176 => [ "Cache-Read-Only",                        "integer" ],
            1177 => [ "SSHA2-224-Password",                     "octets" ],
            1178 => [ "SSHA2-256-Password",                     "octets" ],
            1179 => [ "SSHA2-384-Password",                     "octets" ],
            1180 => [ "SSHA2-512-Password",                     "octets" ],
            1181 => [ "PBKDF2-Password",                        "octets" ],
            1182 => [ "SSHA3-224-Password",                     "octets" ],
            1183 => [ "SSHA3-256-Password",                     "octets" ],
            1184 => [ "SSHA3-384-Password",                     "octets" ],
            1185 => [ "SSHA3-512-Password",                     "octets" ],
            1192 => [ "MS-CHAP-Peer-Challenge",                 "octets" ],
            1193 => [ "Home-Server-Name",                       "string" ],
            1194 => [ "TOTP-Secret",                            "string" ],
            1195 => [ "TOTP-Key",                               "octets" ],
            1196 => [ "TOTP-Password",                          "string" ],
            1197 => [ "Proxy-Tunneled-Request-As-EAP",          "integer" ],
            1198 => [ "Temp-Home-Server-String",                "string" ],
            1199 => [ "TOTP-Time-Offset",                       "signed" ],
            1200 => [ "EAP-Sim-Subtype",                        "integer" ],
            1201 => [ "EAP-Sim-Rand1",                          "octets" ],
            1202 => [ "EAP-Sim-Rand2",                          "octets" ],
            1203 => [ "EAP-Sim-Rand3",                          "octets" ],
            1204 => [ "EAP-Sim-SRES1",                          "octets" ],
            1205 => [ "EAP-Sim-SRES2",                          "octets" ],
            1206 => [ "EAP-Sim-SRES3",                          "octets" ],
            1207 => [ "EAP-Sim-State",                          "integer" ],
            1208 => [ "EAP-Sim-IMSI",                           "string" ],
            1209 => [ "EAP-Sim-HMAC",                           "string" ],
            1210 => [ "EAP-Sim-KEY",                            "octets" ],
            1211 => [ "EAP-Sim-EXTRA",                          "octets" ],
            1212 => [ "EAP-Sim-KC1",                            "octets" ],
            1213 => [ "EAP-Sim-KC2",                            "octets" ],
            1214 => [ "EAP-Sim-KC3",                            "octets" ],
            1215 => [ "EAP-Sim-Ki",                             "octets" ],
            1216 => [ "EAP-Sim-Algo-Version",                   "integer" ],
            1218 => [ "Outer-Realm-Name",                       "string" ],
            1219 => [ "Inner-Realm-Name",                       "string" ],
            1220 => [ "EAP-Pwd-Password-Hash",                  "octets" ],
            1221 => [ "EAP-Pwd-Password-Salt",                  "octets" ],
            1222 => [ "EAP-Pwd-Password-Prep",                  "byte" ],
            1223 => [ "TEAP-Type-Machine",                      "integer" ],
            1224 => [ "TEAP-Type-User",                         "integer" ],
            1280 => [ "EAP-Type-None",                          "octets" ],
            1281 => [ "EAP-Type-Identity",                      "octets" ],
            1282 => [ "EAP-Type-Notification",                  "octets" ],
            1283 => [ "EAP-Type-NAK",                           "octets" ],
            1284 => [ "EAP-Type-MD5-Challenge",                 "octets" ],
            1285 => [ "EAP-Type-One-Time-Password",             "octets" ],
            1286 => [ "EAP-Type-Generic-Token-Card",            "octets" ],
            1289 => [ "EAP-Type-RSA-Public-Key",                "octets" ],
            1290 => [ "EAP-Type-DSS-Unilateral",                "octets" ],
            1291 => [ "EAP-Type-KEA",                           "octets" ],
            1292 => [ "EAP-Type-KEA-Validate",                  "octets" ],
            1293 => [ "EAP-Type-EAP-TLS",                       "octets" ],
            1294 => [ "EAP-Type-Defender-Token",                "octets" ],
            1295 => [ "EAP-Type-RSA-SecurID-EAP",               "octets" ],
            1296 => [ "EAP-Type-Arcot-Systems-EAP",             "octets" ],
            1297 => [ "EAP-Type-Cisco-LEAP",                    "octets" ],
            1298 => [ "EAP-Type-SIM",                           "octets" ],
            1299 => [ "EAP-Type-SRP-SHA1",                      "octets" ],
            1301 => [ "EAP-Type-EAP-TTLS",                      "octets" ],
            1302 => [ "EAP-Type-Remote-Access-Service",         "octets" ],
            1303 => [ "EAP-Type-AKA",                           "octets" ],
            1304 => [ "EAP-Type-EAP-3Com-Wireless",             "octets" ],
            1305 => [ "EAP-Type-PEAP",                          "octets" ],
            1306 => [ "EAP-Type-MS-CHAP-V2",                    "octets" ],
            1307 => [ "EAP-Type-MAKE",                          "octets" ],
            1308 => [ "EAP-Type-CRYPTOCard",                    "octets" ],
            1309 => [ "EAP-Type-Cisco-MS-CHAPv2",               "octets" ],
            1310 => [ "EAP-Type-DynamID",                       "octets" ],
            1311 => [ "EAP-Type-Rob-EAP",                       "octets" ],
            1312 => [ "EAP-Type-SecurID-EAP",                   "octets" ],
            1313 => [ "EAP-Type-MS-Authentication-TLV",         "octets" ],
            1314 => [ "EAP-Type-SentriNET",                     "octets" ],
            1315 => [ "EAP-Type-EAP-Actiontec-Wireless",        "octets" ],
            1316 => [ "EAP-Type-Cogent-Biomentric-EAP",         "octets" ],
            1317 => [ "EAP-Type-AirFortress-EAP",               "octets" ],
            1318 => [ "EAP-Type-EAP-HTTP-Digest",               "octets" ],
            1319 => [ "EAP-Type-SecuriSuite-EAP",               "octets" ],
            1320 => [ "EAP-Type-DeviceConnect-EAP",             "octets" ],
            1321 => [ "EAP-Type-EAP-SPEKE",                     "octets" ],
            1322 => [ "EAP-Type-EAP-MOBAC",                     "octets" ],
            1323 => [ "EAP-Type-EAP-FAST",                      "octets" ],
            1324 => [ "EAP-Type-Zonelabs",                      "octets" ],
            1325 => [ "EAP-Type-EAP-Link",                      "octets" ],
            1326 => [ "EAP-Type-EAP-PAX",                       "octets" ],
            1327 => [ "EAP-Type-EAP-PSK",                       "octets" ],
            1328 => [ "EAP-Type-EAP-SAKE",                      "octets" ],
            1329 => [ "EAP-Type-EAP-IKEv2",                     "octets" ],
            1330 => [ "EAP-Type-EAP-AKA2",                      "octets" ],
            1331 => [ "EAP-Type-EAP-GPSK",                      "octets" ],
            1332 => [ "EAP-Type-EAP-PWD",                       "octets" ],
            1333 => [ "EAP-Type-EAP-EVEv1",                     "octets" ],
            1334 => [ "EAP-Type-EAP-PT-EAP",                    "octets" ],
            1335 => [ "EAP-Type-EAP-TEAP",                      "octets" ],
            1536 => [ "EAP_Sim-Base",                           "octets" ],
            1537 => [ "EAP-Sim-RAND",                           "octets" ],
            1542 => [ "EAP-Sim-PADDING",                        "octets" ],
            1543 => [ "EAP-Sim-NONCE_MT",                       "octets" ],
            1546 => [ "EAP-Sim-PERMANENT_ID_REQ",               "octets" ],
            1547 => [ "EAP-Sim-MAC",                            "octets" ],
            1548 => [ "EAP-Sim-NOTIFICATION",                   "octets" ],
            1549 => [ "EAP-Sim-ANY_ID_REQ",                     "octets" ],
            1550 => [ "EAP-Sim-IDENTITY",                       "octets" ],
            1551 => [ "EAP-Sim-VERSION_LIST",                   "octets" ],
            1552 => [ "EAP-Sim-SELECTED_VERSION",               "octets" ],
            1553 => [ "EAP-Sim-FULLAUTH_ID_REQ",                "octets" ],
            1555 => [ "EAP-Sim-COUNTER",                        "octets" ],
            1556 => [ "EAP-Sim-COUNTER_TOO_SMALL",              "octets" ],
            1557 => [ "EAP-Sim-NONCE_S",                        "octets" ],
            1665 => [ "EAP-Sim-IV",                             "octets" ],
            1666 => [ "EAP-Sim-ENCR_DATA",                      "octets" ],
            1668 => [ "EAP-Sim-NEXT_PSEUDONUM",                 "octets" ],
            1669 => [ "EAP-Sim-NEXT_REAUTH_ID",                 "octets" ],
            1670 => [ "EAP-Sim-CHECKCODE",                      "octets" ],
            1800 => [ "Tmp-String-0",                           "string" ],
            1801 => [ "Tmp-String-1",                           "string" ],
            1802 => [ "Tmp-String-2",                           "string" ],
            1803 => [ "Tmp-String-3",                           "string" ],
            1804 => [ "Tmp-String-4",                           "string" ],
            1805 => [ "Tmp-String-5",                           "string" ],
            1806 => [ "Tmp-String-6",                           "string" ],
            1807 => [ "Tmp-String-7",                           "string" ],
            1808 => [ "Tmp-String-8",                           "string" ],
            1809 => [ "Tmp-String-9",                           "string" ],
            1810 => [ "Tmp-Integer-0",                          "integer" ],
            1811 => [ "Tmp-Integer-1",                          "integer" ],
            1812 => [ "Tmp-Integer-2",                          "integer" ],
            1813 => [ "Tmp-Integer-3",                          "integer" ],
            1814 => [ "Tmp-Integer-4",                          "integer" ],
            1815 => [ "Tmp-Integer-5",                          "integer" ],
            1816 => [ "Tmp-Integer-6",                          "integer" ],
            1817 => [ "Tmp-Integer-7",                          "integer" ],
            1818 => [ "Tmp-Integer-8",                          "integer" ],
            1819 => [ "Tmp-Integer-9",                          "integer" ],
            1820 => [ "Tmp-IP-Address-0",                       "ipaddr" ],
            1821 => [ "Tmp-IP-Address-1",                       "ipaddr" ],
            1822 => [ "Tmp-IP-Address-2",                       "ipaddr" ],
            1823 => [ "Tmp-IP-Address-3",                       "ipaddr" ],
            1824 => [ "Tmp-IP-Address-4",                       "ipaddr" ],
            1825 => [ "Tmp-IP-Address-5",                       "ipaddr" ],
            1826 => [ "Tmp-IP-Address-6",                       "ipaddr" ],
            1827 => [ "Tmp-IP-Address-7",                       "ipaddr" ],
            1828 => [ "Tmp-IP-Address-8",                       "ipaddr" ],
            1829 => [ "Tmp-IP-Address-9",                       "ipaddr" ],
            1830 => [ "Tmp-Octets-0",                           "octets" ],
            1831 => [ "Tmp-Octets-1",                           "octets" ],
            1832 => [ "Tmp-Octets-2",                           "octets" ],
            1833 => [ "Tmp-Octets-3",                           "octets" ],
            1834 => [ "Tmp-Octets-4",                           "octets" ],
            1835 => [ "Tmp-Octets-5",                           "octets" ],
            1836 => [ "Tmp-Octets-6",                           "octets" ],
            1837 => [ "Tmp-Octets-7",                           "octets" ],
            1838 => [ "Tmp-Octets-8",                           "octets" ],
            1839 => [ "Tmp-Octets-9",                           "octets" ],
            1840 => [ "Tmp-Date-0",                             "date" ],
            1841 => [ "Tmp-Date-1",                             "date" ],
            1842 => [ "Tmp-Date-2",                             "date" ],
            1843 => [ "Tmp-Date-3",                             "date" ],
            1844 => [ "Tmp-Date-4",                             "date" ],
            1845 => [ "Tmp-Date-5",                             "date" ],
            1846 => [ "Tmp-Date-6",                             "date" ],
            1847 => [ "Tmp-Date-7",                             "date" ],
            1848 => [ "Tmp-Date-8",                             "date" ],
            1849 => [ "Tmp-Date-9",                             "date" ],
            1851 => [ "Tmp-Cast-String",                        "string" ],
            1852 => [ "Tmp-Cast-Integer",                       "integer" ],
            1853 => [ "Tmp-Cast-Ipaddr",                        "ipaddr" ],
            1854 => [ "Tmp-Cast-Date",                          "date" ],
            1855 => [ "Tmp-Cast-Abinary",                       "abinary" ],
            1856 => [ "Tmp-Cast-Octets",                        "octets" ],
            1857 => [ "Tmp-Cast-Ifid",                          "ifid" ],
            1858 => [ "Tmp-Cast-IPv6Addr",                      "ipv6addr" ],
            1859 => [ "Tmp-Cast-IPv6Prefix",                    "ipv6prefix" ],
            1860 => [ "Tmp-Cast-Byte",                          "byte" ],
            1861 => [ "Tmp-Cast-Short",                         "short" ],
            1862 => [ "Tmp-Cast-Ethernet",                      "ether" ],
            1863 => [ "Tmp-Cast-Signed",                        "signed" ],
            1869 => [ "Tmp-Cast-Integer64",                     "integer64" ],
            1870 => [ "Tmp-Cast-IPv4Prefix",                    "ipv4prefix" ],
            1871 => [ "Tmp-Integer64-0",                        "integer64" ],
            1872 => [ "Tmp-Integer64-1",                        "integer64" ],
            1873 => [ "Tmp-Integer64-2",                        "integer64" ],
            1874 => [ "Tmp-Integer64-3",                        "integer64" ],
            1875 => [ "Tmp-Integer64-4",                        "integer64" ],
            1876 => [ "Tmp-Integer64-5",                        "integer64" ],
            1877 => [ "Tmp-Integer64-6",                        "integer64" ],
            1878 => [ "Tmp-Integer64-7",                        "integer64" ],
            1879 => [ "Tmp-Integer64-8",                        "integer64" ],
            1880 => [ "Tmp-Integer64-9",                        "integer64" ],
            1900 => [ "WiMAX-MN-NAI",                           "string" ],
            1901 => [ "WiMAX-SIM-Ki",                           "octets" ],
            1902 => [ "WiMAX-SIM-OPc",                          "octets" ],
            1903 => [ "WiMAX-SIM-AMF",                          "octets" ],
            1904 => [ "WiMAX-SIM-SQN",                          "octets" ],
            1905 => [ "WiMAX-SIM-RAND",                         "octets" ],
            1910 => [ "TLS-Cert-Serial",                        "string" ],
            1911 => [ "TLS-Cert-Expiration",                    "string" ],
            1912 => [ "TLS-Cert-Issuer",                        "string" ],
            1913 => [ "TLS-Cert-Subject",                       "string" ],
            1914 => [ "TLS-Cert-Common-Name",                   "string" ],
            1915 => [ "TLS-Cert-Subject-Alt-Name-Email",        "string" ],
            1916 => [ "TLS-Cert-Subject-Alt-Name-Dns",          "string" ],
            1917 => [ "TLS-Cert-Subject-Alt-Name-Upn",          "string" ],
            1918 => [ "TLS-Cert-Valid-Since",                   "string" ],
            1919 => [ "TLS-Session-Information",                "string" ],
            1920 => [ "TLS-Client-Cert-Serial",                 "string" ],
            1921 => [ "TLS-Client-Cert-Expiration",             "string" ],
            1922 => [ "TLS-Client-Cert-Issuer",                 "string" ],
            1923 => [ "TLS-Client-Cert-Subject",                "string" ],
            1924 => [ "TLS-Client-Cert-Common-Name",            "string" ],
            1925 => [ "TLS-Client-Cert-Filename",               "string" ],
            1926 => [ "TLS-Client-Cert-Subject-Alt-Name-Email", "string" ],
            1927 => [ "TLS-Client-Cert-X509v3-Extended-Key-Usage", "string" ],
            1928 =>
              [ "TLS-Client-Cert-X509v3-Subject-Key-Identifier", "string" ],
            1929 =>
              [ "TLS-Client-Cert-X509v3-Authority-Key-Identifier", "string" ],
            1930 => [ "TLS-Client-Cert-X509v3-Basic-Constraints", "string" ],
            1931 => [ "TLS-Client-Cert-Subject-Alt-Name-Dns",     "string" ],
            1932 => [ "TLS-Client-Cert-Subject-Alt-Name-Upn",     "string" ],
            1933 => [ "TLS-PSK-Identity",                         "string" ],
            1934 => [ "TLS-Cert-Subject-Alt-Name-Uri",            "string" ],
            1935 => [ "TLS-Client-Cert-Subject-Alt-Name-Uri",     "string" ],
            1936 =>
              [ "TLS-Client-Cert-X509v3-Extended-Key-Usage-OID", "string" ],
            1937 => [ "TLS-Client-Cert-Valid-Since", "string" ],
            1938 => [ "TLS-Cache-Method",            "integer" ],
            1939 => [ "TLS-Client-Cert-X509v3-Certificate-Policies", "string" ],
            1940 => [ "TLS-Session-ID",                              "octets" ],
            1942 => [ "TLS-Session-Data",                            "octets" ],
            1943 => [ "TLS-OCSP-Cert-Valid",               "integer" ],
            1946 => [ "TLS-Cache-Filename",                "string" ],
            1947 => [ "TLS-Session-Version",               "string" ],
            1948 => [ "TLS-Session-Cipher-Suite",          "string" ],
            1949 => [ "TLS-Session-Cert-File",             "string" ],
            1950 => [ "TLS-Session-Cert-Private-Key-File", "string" ],
            1951 => [ "TLS-Server-Name-Indication",        "string" ],
            2100 => [ "SoH-MS-Machine-OS-vendor",          "integer" ],
            2101 => [ "SoH-MS-Machine-OS-version",         "integer" ],
            2102 => [ "SoH-MS-Machine-OS-release",         "integer" ],
            2103 => [ "SoH-MS-Machine-OS-build",           "integer" ],
            2104 => [ "SoH-MS-Machine-SP-version",         "integer" ],
            2105 => [ "SoH-MS-Machine-SP-release",         "integer" ],
            2106 => [ "SoH-MS-Machine-Processor",          "integer" ],
            2107 => [ "SoH-MS-Machine-Name",               "string" ],
            2108 => [ "SoH-MS-Correlation-Id",             "octets" ],
            2109 => [ "SoH-MS-Machine-Role",               "integer" ],
            2119 => [ "SoH-Supported",                     "integer" ],
            2120 => [ "SoH-MS-Windows-Health-Status",      "string" ],
            2129 => [ "SoH-MS-Health-Other",               "string" ],
            2200 => [ "Radclient-Test-Name",               "string" ],
            3000 => [ "OAuth2-Password-Last-Modified",     "date" ],
            3001 => [ "OAuth2-Group",                      "string" ],
            3003 => [ "AD-Samaccountname",                 "string" ],
        },
        rval => {
            6 => {
                1         => "Login-User",
                2         => "Framed-User",
                3         => "Callback-Login-User",
                4         => "Callback-Framed-User",
                5         => "Outbound-User",
                6         => "Administrative-User",
                7         => "NAS-Prompt-User",
                8         => "Authenticate-Only",
                9         => "Callback-NAS-Prompt",
                10        => "Call-Check",
                11        => "Callback-Administrative",
                12        => "Sip-session",
                13        => "Fax",
                14        => "Modem-Relay",
                15        => "IAPP-Register",
                16        => "IAPP-AP-Check",
                17        => "Authorize-Only",
                18        => "Framed-Management",
                103809025 => "Annex-Authorize-Only",
                103809026 => "Annex-Framed-Tunnel",
            },
            7 => {
                1        => "PPP",
                2        => "SLIP",
                3        => "ARAP",
                4        => "Gandalf-SLML",
                5        => "Xylogics-IPX-SLIP",
                6        => "X.75-Synchronous",
                7        => "GPRS-PDP-Context",
                9        => "PPTP",
                17825794 => "Bintec-X25",
                17825795 => "Bintec-X25-PPP",
                17825796 => "Bintec-IP-LAPB",
                17825798 => "Bintec-IP-HDLC",
                17825799 => "Bintec-MPR-LAPB",
                17825800 => "Bintec-MPR-HDLC",
                17825801 => "Bintec-FRAME-RELAY",
                17825802 => "Bintec-X31-BCHAN",
                17825803 => "Bintec-X75-PPP",
                17825804 => "Bintec-X75BTX-PPP",
                17825805 => "Bintec-X25-NOSIG",
                17825806 => "Bintec-X25-PPP-OPT",
            },
            10 => {
                "0" => "None",
                "1" => "Broadcast",
                "2" => "Listen",
                "3" => "Broadcast-Listen",
            },
            13 => {
                "0" => "None",
                "1" => "Van-Jacobson-TCP-IP",
                "2" => "IPX-Header-Compression",
                "3" => "Stac-LZS",
            },
            15 => {
                "0" => "Telnet",
                "1" => "Rlogin",
                "2" => "TCP-Clear",
                "3" => "PortMaster",
                "4" => "LAT",
                "5" => "X25-PAD",
                "6" => "X25-T3POS",
                "8" => "TCP-Clear-Quiet",
            },
            16 => { 23 => "Telnet", 513 => "Rlogin", 514 => "Rsh" },
            29 => {
                "0" => "Default",
                "1" => "RADIUS-Request",
                "2" => "Manage-Resources"
            },
            40 => {
                1         => "Start",
                2         => "Stop",
                3         => "Interim-Update",
                4         => "Modem-Start",
                5         => "Modem-Stop",
                6         => "Cancel",
                7         => "Accounting-On",
                8         => "Accounting-Off",
                9         => "Tunnel-Start",
                10        => "Tunnel-Stop",
                11        => "Tunnel-Reject",
                12        => "Tunnel-Link-Start",
                13        => "Tunnel-Link-Stop",
                14        => "Tunnel-Link-Reject",
                15        => "Failed",
                18        => "Subsystem-On",
                19        => "Subsystem-Off",
                217       => "WB-Login",
                218       => "WB-Logout",
                219       => "WB-WRitelog",
                103809025 => "Annex-User-Reject",
                103809026 => "Annex-Call-Reject",
                103809027 => "Annex-IPCP-Start",
                103809028 => "Annex-IPXCP-Start",
                103809029 => "Annex-ATCP-Start",
                103809030 => "Annex-Accounting-Restart",
                103809031 => "Annex-Accounting-Shutoff",
                103809032 => "Annex-Tunnel-Start",
                103809033 => "Annex-Tunnel-Stop",
                103809034 => "Annex-Tunnel-Reject",
                103809035 => "Annex-Tunnel-Link-Start",
                103809036 => "Annex-Tunnel-Link-Stop",
                103809037 => "Annex-MP-Start",
                103809038 => "Annex-MP-Stop",
                103809039 => "Annex-Line-Seizure",
                103809040 => "Annex-Rlogin-Start",
                103809041 => "Annex-Rlogin-Stop",
            },
            45 =>
              { 1 => "RADIUS", 2 => "Local", 3 => "Remote", 4 => "Diameter" },
            49 => {
                1  => "User-Request",
                2  => "Lost-Carrier",
                3  => "Lost-Service",
                4  => "Idle-Timeout",
                5  => "Session-Timeout",
                6  => "Admin-Reset",
                7  => "Admin-Reboot",
                8  => "Port-Error",
                9  => "NAS-Error",
                10 => "NAS-Request",
                11 => "NAS-Reboot",
                12 => "Port-Unneeded",
                13 => "Port-Preempted",
                14 => "Port-Suspended",
                15 => "Service-Unavailable",
                16 => "Callback",
                17 => "User-Error",
                18 => "Host-Request",
                19 => "Supplicant-Restart",
                20 => "Reauthentication-Failure",
                21 => "Port-Reinit",
                22 => "Port-Disabled",
            },
            57 => { 1 => "Enabled", 2 => "Disabled" },
            61 => {
                "0"  => "Async",
                "1"  => "Sync",
                "2"  => "ISDN",
                "3"  => "ISDN-V120",
                "4"  => "ISDN-V110",
                "5"  => "Virtual",
                "6"  => "PIAFS",
                "7"  => "HDLC-Clear-Channel",
                "8"  => "X.25",
                "9"  => "X.75",
                "10" => "G.3-Fax",
                "11" => "SDSL",
                "12" => "ADSL-CAP",
                "13" => "ADSL-DMT",
                "14" => "IDSL",
                "15" => "Ethernet",
                "16" => "xDSL",
                "17" => "Cable",
                "18" => "Wireless-Other",
                "19" => "Wireless-802.11",
                "20" => "Token-Ring",
                "21" => "FDDI",
                "22" => "Wireless-CDMA2000",
                "23" => "Wireless-UMTS",
                "24" => "Wireless-1X-EV",
                "25" => "IAPP",
                "26" => "FTTP",
                "27" => "Wireless-802.16",
                "28" => "Wireless-802.20",
                "29" => "Wireless-802.22",
                "30" => "PPPoA",
                "31" => "PPPoEoA",
                "32" => "PPPoEoE",
                "33" => "PPPoEoVLAN",
                "34" => "PPPoEoQinQ",
                "35" => "xPON",
                "36" => "Wireless-XGP",
            },
            64 => {
                1  => "PPTP",
                2  => "L2F",
                3  => "L2TP",
                4  => "ATMP",
                5  => "VTP",
                6  => "AH",
                7  => "IP",
                8  => "MIN-IP",
                9  => "ESP",
                10 => "GRE",
                11 => "DVS",
                12 => "IP-in-IP",
                13 => "VLAN",
            },
            65 => {
                1  => "IPv4",
                2  => "IPv6",
                3  => "NSAP",
                4  => "HDLC",
                5  => "BBN-1822",
                6  => "IEEE-802",
                7  => "E.163",
                8  => "E.164",
                9  => "F.69",
                10 => "X.121",
                11 => "IPX",
                12 => "Appletalk",
                13 => "DecNet-IV",
                14 => "Banyan-Vines",
                15 => "E.164-NSAP",
            },
            72 => {
                1 => "Default-Zone",
                2 => "Zone-Filter-Inclusive",
                4 => "Zone-Filter-Exclusive",
            },
            76  => { "0" => "No-Echo", "1" => "Echo" },
            101 => {
                201 => "Residual-Context-Removed",
                202 => "Invalid-EAP-Packet",
                401 => "Unsupported-Attribute",
                402 => "Missing-Attribute",
                403 => "NAS-Identification-Mismatch",
                404 => "Invalid-Request",
                405 => "Unsupported-Service",
                406 => "Unsupported-Extension",
                407 => "Invalid-Attribute-Value",
                501 => "Administratively-Prohibited",
                502 => "Proxy-Request-Not-Routable",
                503 => "Session-Context-Not-Found",
                504 => "Session-Context-Not-Removable",
                505 => "Proxy-Processing-Error",
                506 => "Resources-Unavailable",
                507 => "Request-Initiated",
                508 => "Multiple-Session-Selection-Unsupported",
            },
            126 => { "0" => "Temp-Rtes-No",      "1" => "Temp-Rtes-Yes" },
            127 => { "0" => "ATMP-Tunnel",       "1" => "VTP-Tunnel" },
            128 => { "0" => "Shared-Profile-No", "1" => "Shared-Profile-Yes" },
            131 => {
                "0" => "Dialout-Not-Allowed",
                "1" => "Civic-Location",
                "2" => "Geo-Location",
                "4" => "Users-Location",
                "8" => "NAS-Location",
            },
            132 => {
                1  => "Civic-Location",
                2  => "Geo-Location",
                4  => "Users-Location",
                8  => "NAS-Location",
                16 => "Future-Requests",
                32 => "None",
            },
            133 => {
                "0" => "BACP-No",
                "1" => "SNMP",
                "2" => "Web-Based",
                "3" => "Netconf",
                "4" => "FTP",
                "5" => "TFTP",
                "6" => "SFTP",
                "7" => "RCP",
                "8" => "SCP",
            },
            134 => {
                1 => "No-Protection",
                2 => "Integrity-Protection",
                3 => "Integrity-Confidentiality-Protection",
            },
            137 => { "0" => "DNS-Assign-No", "1" => "DNS-Assign-Yes" },
            138 => {
                "0" => "Ascend-User-Acct-None",
                "1" => "Ascend-User-Acct-User",
                "2" => "Ascend-User-Acct-User-Default",
            },
            142 => { "0" => "Base-10",       "1" => "Base-16" },
            147 => { "0" => "DHCP-Reply-No", "1" => "DHCP-Reply-Yes" },
            149 =>
              { "0" => "Expect-Callback-No", "1" => "Expect-Callback-Yes" },
            150 => { 1   => "Ascend-ColdStart", 2   => "Ascend-Session-Event" },
            155 => { "0" => "Multicast-No",     "1" => "Multicast-Yes" },
            157 => {
                "0" => "Ascend-LinkUp-Default",
                "1" => "Ascend-LinkUp-AlwaysUp"
            },
            159 => {
                "0" => "Ascend-FR-DTE",
                "1" => "Ascend-FR-DCE",
                "2" => "Ascend-FR-NNI"
            },
            160 => {
                "0" => "Ascend-FR-No-Link-Mgt",
                "1" => "Ascend-FR-T1-617D",
                "2" => "Ascend-FR-Q-933A",
            },
            163 => {
                1 => "Wired-IEEE-802.1X",
                2 => "IEEE-802.1X-No-Preauth",
                3 => "IEEE-802.1X-Preauth",
                4 => "IEEE-802.16e",
                5 => "IKEv2",
                6 => "PPP",
                7 => "PANA-No-Preauth",
                8 => "GSS-API",
                9 => "PANA-Preauth",
            },
            170 => {
                "0" => "TS-Idle-None",
                "1" => "TS-Idle-Input",
                "2" => "TS-Idle-Input-Output",
            },
            171 => {
                "0" => "DBA-Transmit",
                "1" => "DBA-Transmit-Recv",
                "2" => "DBA-None"
            },
            175 => { "0" => "FT1-No", "1" => "FT1-Yes" },
            177 => {
                "0" => "Switched",
                "1" => "Nailed",
                "2" => "Nailed/Mpp",
                "3" => "Perm/Switched",
                "6" => "AO/DI",
                "7" => "MegaMax",
            },
            195 => {
                "0"   => "No-Reason",
                "1"   => "Not-Applicable",
                "2"   => "Unknown",
                "3"   => "Call-Disconnected",
                "4"   => "CLID-Authentication-Failed",
                "5"   => "CLID-RADIUS-Timeout",
                "10"  => "Modem-No-DCD",
                "11"  => "DCD-Detected-Then-Inactive",
                "12"  => "Modem-Invalid-Result-Codes",
                "20"  => "TermSrv-User-Quit",
                "21"  => "TermSrv-Idle-Timeout",
                "22"  => "TermSrv-Exit-Telnet",
                "23"  => "TermSrv-No-IPaddr",
                "24"  => "TermSrv-Exit-Raw-TCP",
                "25"  => "TermSrv-Exit-Login-Failed",
                "26"  => "TermSrv-Exit-Raw-TCP-Disabled",
                "27"  => "TermSrv-CTRL-C-In-Login",
                "28"  => "TermSrv-Destroyed",
                "29"  => "TermSrv-User-Closed-VCon",
                "30"  => "TermSrv-VCon-Destroyed",
                "31"  => "TermSrv-Exit-Rlogin",
                "32"  => "TermSrv-Bad-Rlogin-Option",
                "33"  => "TermSrv-Not-Enough-Resources",
                "35"  => "MPP-No-NULL-Msg-Timeout",
                "40"  => "PPP-LCP-Timeout",
                "41"  => "PPP-LCP-Negotion-Failed",
                "42"  => "PPP-PAP-Auth-Failed",
                "43"  => "PPP-CHAP-Auth-Failed",
                "44"  => "PPP-Rmt-Auth-Failed",
                "45"  => "PPP-Rcv-Terminate-Req",
                "46"  => "PPP-Rcv-Close-Event",
                "47"  => "PPP-No-NCPs-Open",
                "48"  => "PPP-MP-Bundle-Unknown",
                "49"  => "PPP-LCP-Close-MP-Add-Fail",
                "50"  => "Session-Table-Full",
                "51"  => "Out-Of-Resources",
                "52"  => "Invalid-IP-Address",
                "53"  => "Hostname-Resolution-Failed",
                "54"  => "Bad-Or-Missing-Port-Number",
                "60"  => "Host-Reset",
                "61"  => "Connection-Refused",
                "62"  => "Connection-Timeout",
                "63"  => "Connection-Closed",
                "64"  => "Network-Unreachable",
                "65"  => "Host-Unreachable",
                "66"  => "Network-Unreachable-Admin",
                "67"  => "Host-Unreachable-Admin",
                "68"  => "Port-Unreachable",
                "100" => "Session-Timeout",
                "101" => "Invalid-Incoming-User",
                "102" => "Disconnect-Due-To-Callback",
                "120" => "Proto-Disabled-Or-Unsupported",
                "150" => "Disconnect-Req-By-RADIUS",
                "151" => "Disconnect-Req-By-Local-Admin",
                "160" => "V110-Timeout-Sync-Retry-Exceed",
                "170" => "PPP-Auth-Timeout-Exceeded",
                "180" => "User-Executed-Do-Hangup",
                "185" => "Remote-End-Hung-Up",
                "190" => "Resource-Has-Been-Quiesced",
                "195" => "Max-Call-Duration-Reached",
            },
            196 => {
                "0"  => "No-Progress",
                "10" => "Call-Up",
                "30" => "Modem-Up",
                "31" => "Modem-Awaiting-DCD",
                "32" => "Modem-Awaiting-Codes",
                "40" => "TermSrv-Started",
                "41" => "TermSrv-Raw-TCP-Started",
                "42" => "TermSrv-Telnet-Started",
                "43" => "TermSrv-Raw-TCP-Connected",
                "44" => "TermSrv-Telnet-Connected",
                "45" => "TermSrv-Rlogin-Started",
                "46" => "TermSrv-Rlogin-Connected",
                "50" => "Modem-Outdial-Call-Up",
                "60" => "LAN-Session-Up",
                "61" => "LCP-Opening",
                "62" => "CCP-Opening",
                "63" => "IPNCP-Opening",
                "64" => "BNCP-Opening",
                "65" => "LCP-Opened",
                "66" => "CCP-Opened",
                "67" => "IPNCP-Opened",
                "68" => "BNCP-Opened",
                "69" => "LCP-State-Initial",
                "70" => "LCP-State-Starting",
                "71" => "LCP-State-Closed",
                "72" => "LCP-State-Stopped",
                "73" => "LCP-State-Closing",
                "74" => "LCP-State-Stopping",
                "75" => "LCP-State-Request-Sent",
                "76" => "LCP-State-Ack-Received",
                "77" => "LCP-State-Ack-Sent",
                "80" => "IPXNCP-Opened",
                "81" => "ATNCP-Opened",
                "82" => "BACP-Opening",
                "83" => "BACP-Opened",
                "90" => "V110-Up",
                "91" => "V110-State-Opened",
                "92" => "V110-State-Carrier",
                "93" => "V110-State-Reset",
                "94" => "V110-State-Closed",
            },
            200 => { "0" => "Tok-Imm-No",       "1" => "Tok-Imm-Yes" },
            201 => { "0" => "Not-Require-Auth", "1" => "Require-Auth" },
            207 => { "0" => "Days-Of-Warning" },
            208 => { "0" => "Lifetime-In-Days" },
            210 => { 1   => "VJ-Slot-Comp-No" },
            211 => { 1   => "PPP-VJ-1172" },
            216 => { "0" => "IPX-Peer-Router", "1" => "IPX-Peer-Dialin" },
            219 => { "0" => "FR-Direct-No",    "1" => "FR-Direct-Yes" },
            222 => {
                "0" => "Handle-IPX-None",
                "1" => "Handle-IPX-Client",
                "2" => "Handle-IPX-Server",
            },
            226 => {
                "0" => "Unknown-Number",
                "1" => "Intl-Number",
                "2" => "National-Number",
                "3" => "Net-Specific-Number",
                "4" => "Local-Number",
                "5" => "Abbrev-Number",
            },
            228 => { "0" => "Route-IP-No",  "1" => "Route-IP-Yes" },
            229 => { "0" => "Route-IPX-No", "1" => "Route-IPX-Yes" },
            230 => { "0" => "Bridge-No",    "1" => "Bridge-Yes" },
            231 => {
                "0" => "Send-Auth-None",
                "1" => "Send-Auth-PAP",
                "2" => "Send-Auth-CHAP",
                "3" => "Send-Auth-MS-CHAP",
            },
            233 => {
                "0" => "Link-Comp-None",
                "1" => "Link-Comp-Stac",
                "2" => "Link-Comp-Stac-Draft-9",
                "3" => "Link-Comp-MS-Stac",
            },
            239 => {
                "0" => "History-Constant",
                "1" => "History-Linear",
                "2" => "History-Quadratic",
            },
            241 => {
                "0" => "Reserved",
                "1" => "Allocation",
                "2" => "Deallocation",
                "3" => "More-Data-Request",
            },
            246 => { "0" => "Callback-No", "1" => "Callback-Yes" },
            247 => {
                "0"  => "Switched-Voice-Bearer",
                "1"  => "Nailed-56KR",
                "2"  => "Nailed-64K",
                "3"  => "Switched-64KR",
                "4"  => "Switched-56K",
                "5"  => "Switched-384KR",
                "6"  => "Switched-384K",
                "7"  => "Switched-1536K",
                "8"  => "Switched-1536KR",
                "9"  => "Switched-128K",
                "10" => "Switched-192K",
                "11" => "Switched-256K",
                "12" => "Switched-320K",
                "13" => "Switched-384K-MR",
                "14" => "Switched-448K",
                "15" => "Switched-512K",
                "16" => "Switched-576K",
                "17" => "Switched-640K",
                "18" => "Switched-704K",
                "19" => "Switched-768K",
                "20" => "Switched-832K",
                "21" => "Switched-896K",
                "22" => "Switched-960K",
                "23" => "Switched-1024K",
                "24" => "Switched-1088K",
                "25" => "Switched-1152K",
                "26" => "Switched-1216K",
                "27" => "Switched-1280K",
                "28" => "Switched-1344K",
                "29" => "Switched-1408K",
                "30" => "Switched-1472K",
                "31" => "Switched-1600K",
                "32" => "Switched-1664K",
                "33" => "Switched-1728K",
                "34" => "Switched-1792K",
                "35" => "Switched-1856K",
                "36" => "Switched-1920K",
                "37" => "Switched-inherited",
                "38" => "Switched-restricted-bearer-x30",
                "39" => "Switched-clear-bearer-v110",
                "40" => "Switched-restricted-64-x30",
                "41" => "Switched-clear-56-v110",
                "42" => "Switched-modem",
                "43" => "Switched-atmodem",
                "45" => "Switched-V110-24-56",
                "46" => "Switched-V110-48-56",
                "47" => "Switched-V110-96-56",
                "48" => "Switched-V110-192-56",
                "49" => "Switched-V110-384-56",
                "50" => "Switched-V110-24-56R",
                "51" => "Switched-V110-48-56R",
                "52" => "Switched-V110-96-56R",
                "53" => "Switched-V110-192-56R",
                "54" => "Switched-V110-384-56R",
                "55" => "Switched-V110-24-64",
                "56" => "Switched-V110-48-64",
                "57" => "Switched-V110-96-64",
                "58" => "Switched-V110-192-64",
                "59" => "Switched-V110-384-64",
                "60" => "Switched-V110-24-64R",
                "61" => "Switched-V110-48-64R",
                "62" => "Switched-V110-96-64R",
                "63" => "Switched-V110-192-64R",
                "64" => "Switched-V110-384-64R",
                "68" => "Switched-Pots",
                "69" => "Switched-ATM",
                "70" => "Switched-FR",
            },
            248  => { "0" => "Force-56-No", "1" => "Force-56-Yes" },
            500  => { "0" => "No",          "1" => "Yes" },
            501  => { "0" => "No",          "1" => "Yes" },
            1000 => { 1   => "Local",       4   => "Reject", 254 => "Accept" },
            1011 => { 1   => "Local" },
            1012 => { 1   => "Local" },
            1013 => { 1   => "Local" },
            1014 => {
                1 => "Local",
                2 => "Reject",
                3 => "Challenge",
                4 => "Client-Lost"
            },
            1016 => {
                1 => "Fail",
                2 => "Fail-Authentication",
                3 => "Fail-Accounting",
                4 => "Fail-CoA",
                5 => "Fail-Disconnect",
            },
            1018 => {
                "0"  => "None",
                "1"  => "Identity",
                "2"  => "Notification",
                "3"  => "NAK",
                "4"  => "MD5",
                "5"  => "OTP",
                "6"  => "GTC",
                "9"  => "RSA-Public-Key",
                "10" => "DSS-Unilateral",
                "11" => "KEA",
                "12" => "KEA-Validate",
                "13" => "TLS",
                "14" => "Defender-Token",
                "15" => "RSA-SecurID-EAP",
                "16" => "Arcot-Systems-EAP",
                "17" => "LEAP",
                "18" => "SIM",
                "19" => "SRP-SHA1",
                "21" => "TTLS",
                "22" => "Remote-Access-Service",
                "23" => "AKA",
                "24" => "3Com-Wireless",
                "25" => "PEAP",
                "26" => "MSCHAPv2",
                "27" => "MAKE",
                "28" => "CRYPTOCard",
                "29" => "Cisco-MS-CHAPv2",
                "30" => "DynamID",
                "31" => "Rob-EAP",
                "32" => "SecurID-EAP",
                "33" => "MS-Authentication-TLV",
                "34" => "SentriNET",
                "35" => "Actiontec-Wireless",
                "36" => "Cogent-Biomentric-EAP",
                "37" => "AirFortress-EAP",
                "38" => "TNC",
                "39" => "SecuriSuite-EAP",
                "40" => "DeviceConnect-EAP",
                "41" => "SPEKE",
                "42" => "MOBAC",
                "43" => "FAST",
                "44" => "Zonelabs",
                "45" => "Link",
                "46" => "PAX",
                "47" => "PSK",
                "48" => "SAKE",
                "49" => "IKEv2",
                "50" => "AKA2",
                "51" => "GPSK",
                "52" => "PWD",
                "53" => "EKEv1",
                "54" => "PT-EAP",
                "55" => "TEAP",
            },
            1019 => { "0" => "No", "1" => "Yes" },
            1021 => {
                1 => "Request",
                2 => "Response",
                3 => "Success",
                4 => "Failure"
            },
            1035 => { "0" => "No", "1" => "Yes" },
            1047 => {
                1  => "Access-Request",
                2  => "Access-Accept",
                3  => "Access-Reject",
                4  => "Accounting-Request",
                5  => "Accounting-Response",
                6  => "Accounting-Status",
                7  => "Password-Request",
                8  => "Password-Accept",
                9  => "Password-Reject",
                10 => "Accounting-Message",
                11 => "Access-Challenge",
                12 => "Status-Server",
                13 => "Status-Client",
                21 => "Resource-Free-Request",
                22 => "Resource-Free-Response",
                23 => "Resource-Query-Request",
                24 => "Resource-Query-Response",
                25 => "Alternate-Resource-Reclaim-Request",
                26 => "NAS-Reboot-Request",
                27 => "NAS-Reboot-Response",
                29 => "Next-Passcode",
                30 => "New-Pin",
                31 => "Terminate-Session",
                32 => "Password-Expired",
                33 => "Event-Request",
                34 => "Event-Response",
                40 => "Disconnect-Request",
                41 => "Disconnect-ACK",
                42 => "Disconnect-NAK",
                43 => "CoA-Request",
                44 => "CoA-ACK",
                45 => "CoA-NAK",
                50 => "IP-Address-Allocate",
                51 => "IP-Address-Release",
            },
            1080 => {
                1   => "Access-Request",
                2   => "Access-Accept",
                3   => "Access-Reject",
                4   => "Accounting-Request",
                5   => "Accounting-Response",
                6   => "Accounting-Status",
                7   => "Password-Request",
                8   => "Password-Accept",
                9   => "Password-Reject",
                10  => "Accounting-Message",
                11  => "Access-Challenge",
                12  => "Status-Server",
                13  => "Status-Client",
                40  => "Disconnect-Request",
                41  => "Disconnect-ACK",
                42  => "Disconnect-NAK",
                43  => "CoA-Request",
                44  => "CoA-ACK",
                45  => "CoA-NAK",
                256 => "Do-Not-Respond",
            },
            1082 => { "0" => "No", "1" => "Yes" },
            1103 => {
                1  => "IPV4_ADDR",
                2  => "FQDN",
                3  => "RFC822_ADDR",
                5  => "IPV6_ADDR",
                9  => "DER_ASN1_DN",
                10 => "DER_ASN1_GN",
                11 => "KEY_ID",
            },
            1106 =>
              { "0" => "none", "1" => "secret", "2" => "cert", "3" => "both" },
            1107 => { "0" => "No", "1" => "Yes" },
            1108 => {
                "0" => "reject",
                "1" => "fail",
                "2" => "ok",
                "3" => "handled",
                "4" => "invalid",
                "5" => "userlock",
                "6" => "notfound",
                "7" => "noop",
                "8" => "updated",
            },
            1122 => { "0" => "false",   "1" => "true" },
            1127 => { "0" => "no",      "1" => "yes" },
            1128 => { "0" => "no",      "1" => "yes" },
            1147 => { 2   => "success", 3   => "failure" },
            1173 => { "0" => "no",      "1" => "yes" },
            1174 => { "0" => "no",      "1" => "yes" },
            1176 => { "0" => "no",      "1" => "yes" },
            1197 => { "0" => "No",      "1" => "Yes" },
            1200 => {
                10 => "Start",
                11 => "Challenge",
                12 => "Notification",
                13 => "Re-authentication",
            },
            1223 => {
                "0"  => "None",
                "1"  => "Identity",
                "2"  => "Notification",
                "3"  => "NAK",
                "4"  => "MD5",
                "5"  => "OTP",
                "6"  => "GTC",
                "9"  => "RSA-Public-Key",
                "10" => "DSS-Unilateral",
                "11" => "KEA",
                "12" => "KEA-Validate",
                "13" => "TLS",
                "14" => "Defender-Token",
                "15" => "RSA-SecurID-EAP",
                "16" => "Arcot-Systems-EAP",
                "17" => "LEAP",
                "18" => "SIM",
                "19" => "SRP-SHA1",
                "21" => "TTLS",
                "22" => "Remote-Access-Service",
                "23" => "AKA",
                "24" => "3Com-Wireless",
                "25" => "PEAP",
                "26" => "MSCHAPv2",
                "27" => "MAKE",
                "28" => "CRYPTOCard",
                "29" => "Cisco-MS-CHAPv2",
                "30" => "DynamID",
                "31" => "Rob-EAP",
                "32" => "SecurID-EAP",
                "33" => "MS-Authentication-TLV",
                "34" => "SentriNET",
                "35" => "Actiontec-Wireless",
                "36" => "Cogent-Biomentric-EAP",
                "37" => "AirFortress-EAP",
                "38" => "TNC",
                "39" => "SecuriSuite-EAP",
                "40" => "DeviceConnect-EAP",
                "41" => "SPEKE",
                "42" => "MOBAC",
                "43" => "FAST",
                "44" => "Zonelabs",
                "45" => "Link",
                "46" => "PAX",
                "47" => "PSK",
                "48" => "SAKE",
                "49" => "IKEv2",
                "50" => "AKA2",
                "51" => "GPSK",
                "52" => "PWD",
                "53" => "EKEv1",
                "54" => "PT-EAP",
                "55" => "TEAP",
            },
            1224 => {
                "0"  => "None",
                "1"  => "Identity",
                "2"  => "Notification",
                "3"  => "NAK",
                "4"  => "MD5",
                "5"  => "OTP",
                "6"  => "GTC",
                "9"  => "RSA-Public-Key",
                "10" => "DSS-Unilateral",
                "11" => "KEA",
                "12" => "KEA-Validate",
                "13" => "TLS",
                "14" => "Defender-Token",
                "15" => "RSA-SecurID-EAP",
                "16" => "Arcot-Systems-EAP",
                "17" => "LEAP",
                "18" => "SIM",
                "19" => "SRP-SHA1",
                "21" => "TTLS",
                "22" => "Remote-Access-Service",
                "23" => "AKA",
                "24" => "3Com-Wireless",
                "25" => "PEAP",
                "26" => "MSCHAPv2",
                "27" => "MAKE",
                "28" => "CRYPTOCard",
                "29" => "Cisco-MS-CHAPv2",
                "30" => "DynamID",
                "31" => "Rob-EAP",
                "32" => "SecurID-EAP",
                "33" => "MS-Authentication-TLV",
                "34" => "SentriNET",
                "35" => "Actiontec-Wireless",
                "36" => "Cogent-Biomentric-EAP",
                "37" => "AirFortress-EAP",
                "38" => "TNC",
                "39" => "SecuriSuite-EAP",
                "40" => "DeviceConnect-EAP",
                "41" => "SPEKE",
                "42" => "MOBAC",
                "43" => "FAST",
                "44" => "Zonelabs",
                "45" => "Link",
                "46" => "PAX",
                "47" => "PSK",
                "48" => "SAKE",
                "49" => "IKEv2",
                "50" => "AKA2",
                "51" => "GPSK",
                "52" => "PWD",
                "53" => "EKEv1",
                "54" => "PT-EAP",
                "55" => "TEAP",
            },
            1938 => { 1 => "save", 2 => "load", 3 => "clear", 4 => "refresh" },
            1943 =>
              { "0" => "no", "1" => "yes", "2" => "skipped", "3" => "unknown" },
            2100 => { 311 => "Microsoft" },
            2106 => { "0" => "x86",    "6" => "i64", "9" => "x86_64" },
            2109 => { 1   => "client", 2   => "dc",  3   => "server" },
            2119 => { "0" => "no",     "1" => "yes" },
        },
        rvsattr => {
            4 => {
                10 => [ "Unix-FTP-UID",         "integer" ],
                11 => [ "Unix-FTP-GID",         "integer" ],
                12 => [ "Unix-FTP-Home",        "string" ],
                13 => [ "Unix-FTP-Shell",       "string" ],
                14 => [ "Unix-FTP-Group-Names", "string" ],
                15 => [ "Unix-FTP-Group-Ids",   "string" ],
            },
            5 => {
                1  => [ "Acc-Reason-Code",              "integer" ],
                2  => [ "Acc-Ccp-Option",               "integer" ],
                3  => [ "Acc-Input-Errors",             "integer" ],
                4  => [ "Acc-Output-Errors",            "integer" ],
                5  => [ "Acc-Access-Partition",         "string" ],
                6  => [ "Acc-Customer-Id",              "string" ],
                7  => [ "Acc-Ip-Gateway-Pri",           "ipaddr" ],
                8  => [ "Acc-Ip-Gateway-Sec",           "ipaddr" ],
                9  => [ "Acc-Route-Policy",             "integer" ],
                10 => [ "Acc-ML-MLX-Admin-State",       "integer" ],
                11 => [ "Acc-ML-Call-Threshold",        "integer" ],
                12 => [ "Acc-ML-Clear-Threshold",       "integer" ],
                13 => [ "Acc-ML-Damping-Factor",        "integer" ],
                14 => [ "Acc-Tunnel-Secret",            "string" ],
                15 => [ "Acc-Clearing-Cause",           "integer" ],
                16 => [ "Acc-Clearing-Location",        "integer" ],
                17 => [ "Acc-Service-Profile",          "string" ],
                18 => [ "Acc-Request-Type",             "integer" ],
                19 => [ "Acc-Bridging-Support",         "integer" ],
                20 => [ "Acc-Apsm-Oversubscribed",      "integer" ],
                21 => [ "Acc-Acct-On-Off-Reason",       "integer" ],
                22 => [ "Acc-Tunnel-Port",              "integer" ],
                23 => [ "Acc-Dns-Server-Pri",           "ipaddr" ],
                24 => [ "Acc-Dns-Server-Sec",           "ipaddr" ],
                25 => [ "Acc-Nbns-Server-Pri",          "ipaddr" ],
                26 => [ "Acc-Nbns-Server-Sec",          "ipaddr" ],
                27 => [ "Acc-Dial-Port-Index",          "integer" ],
                28 => [ "Acc-Ip-Compression",           "integer" ],
                29 => [ "Acc-Ipx-Compression",          "integer" ],
                30 => [ "Acc-Connect-Tx-Speed",         "integer" ],
                31 => [ "Acc-Connect-Rx-Speed",         "integer" ],
                32 => [ "Acc-Modem-Modulation-Type",    "string" ],
                33 => [ "Acc-Modem-Error-Protocol",     "string" ],
                34 => [ "Acc-Callback-Delay",           "integer" ],
                35 => [ "Acc-Callback-Num-Valid",       "string" ],
                36 => [ "Acc-Callback-Mode",            "integer" ],
                37 => [ "Acc-Callback-CBCP-Type",       "integer" ],
                38 => [ "Acc-Dialout-Auth-Mode",        "integer" ],
                39 => [ "Acc-Dialout-Auth-Password",    "string" ],
                40 => [ "Acc-Dialout-Auth-Username",    "string" ],
                42 => [ "Acc-Access-Community",         "integer" ],
                43 => [ "Acc-Vpsm-Reject-Cause",        "integer" ],
                44 => [ "Acc-Ace-Token",                "string" ],
                45 => [ "Acc-Ace-Token-Ttl",            "integer" ],
                46 => [ "Acc-Ip-Pool-Name",             "string" ],
                47 => [ "Acc-Igmp-Admin-State",         "integer" ],
                48 => [ "Acc-Igmp-Version",             "integer" ],
                73 => [ "Acc-MN-HA-Secret",             "string" ],
                98 => [ "Acc-Location-Id",              "string" ],
                99 => [ "Acc-Calling-Station-Category", "integer" ],
            },
            9 => {
                1   => [ "Cisco-AVPair",                   "string" ],
                2   => [ "Cisco-NAS-Port",                 "string" ],
                3   => [ "Cisco-Fax-Account-Id-Origin",    "string" ],
                4   => [ "Cisco-Fax-Msg-Id",               "string" ],
                5   => [ "Cisco-Fax-Pages",                "string" ],
                6   => [ "Cisco-Fax-Coverpage-Flag",       "string" ],
                7   => [ "Cisco-Fax-Modem-Time",           "string" ],
                8   => [ "Cisco-Fax-Connect-Speed",        "string" ],
                9   => [ "Cisco-Fax-Recipient-Count",      "string" ],
                10  => [ "Cisco-Fax-Process-Abort-Flag",   "string" ],
                11  => [ "Cisco-Fax-Dsn-Address",          "string" ],
                12  => [ "Cisco-Fax-Dsn-Flag",             "string" ],
                13  => [ "Cisco-Fax-Mdn-Address",          "string" ],
                14  => [ "Cisco-Fax-Mdn-Flag",             "string" ],
                15  => [ "Cisco-Fax-Auth-Status",          "string" ],
                16  => [ "Cisco-Email-Server-Address",     "string" ],
                17  => [ "Cisco-Email-Server-Ack-Flag",    "string" ],
                18  => [ "Cisco-Gateway-Id",               "string" ],
                19  => [ "Cisco-Call-Type",                "string" ],
                20  => [ "Cisco-Port-Used",                "string" ],
                21  => [ "Cisco-Abort-Cause",              "string" ],
                23  => [ "h323-remote-address",            "string" ],
                24  => [ "h323-conf-id",                   "string" ],
                25  => [ "h323-setup-time",                "string" ],
                26  => [ "h323-call-origin",               "string" ],
                27  => [ "h323-call-type",                 "string" ],
                28  => [ "h323-connect-time",              "string" ],
                29  => [ "h323-disconnect-time",           "string" ],
                30  => [ "h323-disconnect-cause",          "string" ],
                31  => [ "h323-voice-quality",             "string" ],
                33  => [ "h323-gw-id",                     "string" ],
                35  => [ "h323-incoming-conf-id",          "string" ],
                37  => [ "Cisco-Policy-Up",                "string" ],
                38  => [ "Cisco-Policy-Down",              "string" ],
                46  => [ "Cisco-Relay-Information-Option", "string" ],
                47  => [ "Cisco-DHCP-User-Class",          "string" ],
                48  => [ "Cisco-DHCP-Vendor-Class",        "string" ],
                50  => [ "Cisco-DHCP-Relay-GiAddr",        "string" ],
                51  => [ "Cisco-Service-Name",             "string" ],
                52  => [ "Cisco-Parent-Session-Id",        "string" ],
                55  => [ "Cisco-Sub-QoS-Pol-In",           "string" ],
                56  => [ "Cisco-Sub-QoS-Pol-Out",          "string" ],
                57  => [ "Cisco-In-ACL",                   "string" ],
                58  => [ "Cisco-Out-ACL",                  "string" ],
                59  => [ "Cisco-Sub-PBR-Policy-In",        "string" ],
                60  => [ "Cisco-Sub-Activate-Service",     "string" ],
                61  => [ "Cisco-IPv6-In-ACL",              "string" ],
                62  => [ "Cisco-IPv6-Out-ACL",             "string" ],
                63  => [ "Cisco-Sub-Deactivate-Service",   "string" ],
                65  => [ "Cisco-DHCP-Subscriber-Id",       "string" ],
                66  => [ "Cisco-DHCPv6-Link-Address",      "string" ],
                100 => [ "sip-conf-id",                    "string" ],
                101 => [ "h323-credit-amount",             "string" ],
                102 => [ "h323-credit-time",               "string" ],
                103 => [ "h323-return-code",               "string" ],
                104 => [ "h323-prompt-id",                 "string" ],
                105 => [ "h323-time-and-day",              "string" ],
                106 => [ "h323-redirect-number",           "string" ],
                107 => [ "h323-preferred-lang",            "string" ],
                108 => [ "h323-redirect-ip-address",       "string" ],
                109 => [ "h323-billing-model",             "string" ],
                110 => [ "h323-currency",                  "string" ],
                111 => [ "subscriber",                     "string" ],
                112 => [ "gw-rxd-cdn",                     "string" ],
                113 => [ "gw-final-xlated-cdn",            "string" ],
                114 => [ "remote-media-address",           "string" ],
                115 => [ "release-source",                 "string" ],
                116 => [ "gw-rxd-cgn",                     "string" ],
                117 => [ "gw-final-xlated-cgn",            "string" ],
                141 => [ "call-id",                        "string" ],
                142 => [ "session-protocol",               "string" ],
                143 => [ "method",                         "string" ],
                144 => [ "prev-hop-via",                   "string" ],
                145 => [ "prev-hop-ip",                    "string" ],
                146 => [ "incoming-req-uri",               "string" ],
                147 => [ "outgoing-req-uri",               "string" ],
                148 => [ "next-hop-ip",                    "string" ],
                149 => [ "next-hop-dn",                    "string" ],
                150 => [ "sip-hdr",                        "string" ],
                151 => [ "dsp-id",                         "string" ],
                187 => [ "Cisco-Multilink-ID",             "integer" ],
                188 => [ "Cisco-Num-In-Multilink",         "integer" ],
                190 => [ "Cisco-Pre-Input-Octets",         "integer" ],
                191 => [ "Cisco-Pre-Output-Octets",        "integer" ],
                192 => [ "Cisco-Pre-Input-Packets",        "integer" ],
                193 => [ "Cisco-Pre-Output-Packets",       "integer" ],
                194 => [ "Cisco-Maximum-Time",             "integer" ],
                195 => [ "Cisco-Disconnect-Cause",         "integer" ],
                197 => [ "Cisco-Data-Rate",                "integer" ],
                198 => [ "Cisco-PreSession-Time",          "integer" ],
                208 => [ "Cisco-PW-Lifetime",              "integer" ],
                209 => [ "Cisco-IP-Direct",                "integer" ],
                210 => [ "Cisco-PPP-VJ-Slot-Comp",         "integer" ],
                212 => [ "Cisco-PPP-Async-Map",            "integer" ],
                217 => [ "Cisco-IP-Pool-Definition",       "string" ],
                218 => [ "Cisco-Assign-IP-Pool",           "integer" ],
                228 => [ "Cisco-Route-IP",                 "integer" ],
                233 => [ "Cisco-Link-Compression",         "integer" ],
                234 => [ "Cisco-Target-Util",              "integer" ],
                235 => [ "Cisco-Maximum-Channels",         "integer" ],
                242 => [ "Cisco-Data-Filter",              "integer" ],
                243 => [ "Cisco-Call-Filter",              "integer" ],
                244 => [ "Cisco-Idle-Limit",               "integer" ],
                249 => [ "Cisco-Subscriber-Password",      "string" ],
                250 => [ "Cisco-Account-Info",             "string" ],
                251 => [ "Cisco-Service-Info",             "string" ],
                252 => [ "Cisco-Command-Code",             "string" ],
                253 => [ "Cisco-Control-Info",             "string" ],
                255 => [ "Cisco-Xmit-Rate",                "integer" ],
            },
            11 => {
                1   => [ "HP-Privilege-Level",          "integer" ],
                2   => [ "HP-Command-String",           "string" ],
                3   => [ "HP-Command-Exception",        "integer" ],
                10  => [ "HP-Port-Client-Limit-Dot1x",  "integer" ],
                11  => [ "HP-Port-Client-Limit-MA",     "integer" ],
                12  => [ "HP-Port-Client-Limit-WA",     "integer" ],
                13  => [ "HP-Port-Auth-Mode-Dot1x",     "integer" ],
                14  => [ "HP-Port-MA-Port-Mode",        "integer" ],
                23  => [ "HP-Port-Bounce-Host",         "integer" ],
                24  => [ "HP-Captive-Portal-URL",       "string" ],
                25  => [ "HP-User-Role",                "string" ],
                26  => [ "HP-Management-Protocol",      "integer" ],
                27  => [ "HP-CPPM-Role",                "string" ],
                28  => [ "HP-CPPM-Secondary-Role",      "string" ],
                40  => [ "HP-Cos",                      "string" ],
                46  => [ "HP-Bandwidth-Max-Ingress",    "integer" ],
                48  => [ "HP-Bandwidth-Max-Egress",     "integer" ],
                61  => [ "HP-Nas-Filter-Rule",          "string" ],
                62  => [ "HP-Access-Profile",           "string" ],
                63  => [ "HP-Nas-Rules-IPv6",           "integer" ],
                64  => [ "HP-Egress-VLANID",            "integer" ],
                65  => [ "HP-Egress-VLAN-Name",         "string" ],
                66  => [ "HP-Bonjour-Inbound-Profile",  "string" ],
                67  => [ "HP-Bonjour-Outbound-Profile", "string" ],
                80  => [ "HP-URI-String",               "string" ],
                81  => [ "HP-URI-Json-String",          "string" ],
                82  => [ "HP-URI-Access",               "string" ],
                83  => [ "HP-URI-Exception",            "integer" ],
                192 => [ "HP-VC-groups",                "string" ],
                255 => [ "HP-Capability-Advert",        "octets" ],
            },
            43 => {
                1   => [ "3Com-User-Access-Level",     "integer" ],
                2   => [ "3Com-VLAN-Name",             "string" ],
                3   => [ "3Com-Mobility-Profile",      "string" ],
                4   => [ "3Com-Encryption-Type",       "string" ],
                5   => [ "3Com-Time-Of-Day",           "string" ],
                6   => [ "3Com-SSID",                  "string" ],
                7   => [ "3Com-End-Date",              "string" ],
                8   => [ "3Com-URL",                   "string" ],
                26  => [ "3Com-Connect_Id",            "integer" ],
                59  => [ "3Com-NAS-Startup-Timestamp", "integer" ],
                60  => [ "3Com-Ip-Host-Addr",          "string" ],
                255 => [ "3Com-Product-ID",            "string" ],
            },
            52 => {
                201 => [ "Cabletron-Protocol-Enable",   "integer" ],
                202 => [ "Cabletron-Protocol-Callable", "integer" ],
            },
            61 => {
                211 => [ "Merit-Proxy-Action", "string" ],
                222 => [ "Merit-User-Id",      "string" ],
                223 => [ "Merit-User-Realm",   "string" ],
            },
            64 => {
                "0"  => [ "Gandalf-Remote-LAN-Name",       "string" ],
                "1"  => [ "Gandalf-Operational-Modes",     "integer" ],
                "2"  => [ "Gandalf-Compression-Status",    "integer" ],
                "3"  => [ "Gandalf-Min-Outgoing-Bearer",   "integer" ],
                "5"  => [ "Gandalf-Authentication-String", "string" ],
                "6"  => [ "Gandalf-PPP-Authentication",    "integer" ],
                "7"  => [ "Gandalf-PPP-NCP-Type",          "integer" ],
                "8"  => [ "Gandalf-Fwd-Multicast-In",      "integer" ],
                "9"  => [ "Gandalf-Fwd-Broadcast-In",      "integer" ],
                "10" => [ "Gandalf-Fwd-Unicast-In",        "integer" ],
                "11" => [ "Gandalf-Fwd-Multicast-Out",     "integer" ],
                "12" => [ "Gandalf-Fwd-Broadcast-Out",     "integer" ],
                "13" => [ "Gandalf-Fwd-Unicast-Out",       "integer" ],
                "14" => [ "Gandalf-Around-The-Corner",     "integer" ],
                "15" => [ "Gandalf-Channel-Group-Name-1",  "string" ],
                "16" => [ "Gandalf-Dial-Prefix-Name-1",    "string" ],
                "17" => [ "Gandalf-Phone-Number-1",        "string" ],
                "18" => [ "Gandalf-Calling-Line-ID-1",     "string" ],
                "19" => [ "Gandalf-Channel-Group-Name-2",  "string" ],
                "20" => [ "Gandalf-Dial-Prefix-Name-2",    "string" ],
                "21" => [ "Gandalf-Phone-Number-2",        "string" ],
                "22" => [ "Gandalf-Calling-Line-ID-2",     "string" ],
                "23" => [ "Gandalf-IPX-Spoofing-State",    "integer" ],
                "24" => [ "Gandalf-IPX-Watchdog-Spoof",    "integer" ],
                "25" => [ "Gandalf-SAP-Group-Name-1",      "string" ],
                "26" => [ "Gandalf-SAP-Group-Name-2",      "string" ],
                "27" => [ "Gandalf-SAP-Group-Name-3",      "string" ],
                "28" => [ "Gandalf-SAP-Group-Name-4",      "string" ],
                "29" => [ "Gandalf-SAP-Group-Name-5",      "string" ],
                "30" => [ "Gandalf-Hunt-Group",            "string" ],
                "31" => [ "Gandalf-Modem-Mode",            "integer" ],
                "32" => [ "Gandalf-Modem-Required-1",      "integer" ],
                "33" => [ "Gandalf-Modem-Required-2",      "integer" ],
            },
            66 => {
                10 => [ "Citrix-UID",         "integer" ],
                11 => [ "Citrix-GID",         "integer" ],
                12 => [ "Citrix-Home",        "string" ],
                13 => [ "Citrix-Shell",       "string" ],
                14 => [ "Citrix-Group-Names", "string" ],
                15 => [ "Citrix-Group-Ids",   "string" ],
                16 => [ "Citrix-User-Groups", "string" ],
            },
            94 => {
                1  => [ "Nokia-AVPair",                     "string" ],
                2  => [ "Nokia-User-Profile",               "string" ],
                3  => [ "Nokia-Service-Name",               "octets" ],
                4  => [ "Nokia-Service-Id",                 "octets" ],
                5  => [ "Nokia-Service-Username",           "octets" ],
                6  => [ "Nokia-Service-Password",           "octets" ],
                7  => [ "Nokia-Service-Primary-Indicator",  "octets" ],
                8  => [ "Nokia-Service-Charging-Type",      "octets" ],
                9  => [ "Nokia-Service-Encrypted-Password", "octets" ],
                10 => [ "Nokia-Session-Access-Method",      "octets" ],
                11 => [ "Nokia-Session-Charging-Type",      "octets" ],
                12 => [ "Nokia-OCS-ID1",                    "integer" ],
                13 => [ "Nokia-OCS-ID2",                    "integer" ],
                14 => [ "Nokia-TREC-Index",                 "integer" ],
                15 => [ "Nokia-Requested-APN",              "string" ],
            },
            117 => {
                1 => [ "Telebit-Login-Command",    "string" ],
                2 => [ "Telebit-Port-Name",        "string" ],
                3 => [ "Telebit-Activate-Command", "string" ],
                4 => [ "Telebit-Accounting-Info",  "string" ],
                5 => [ "Telebit-Login-Option",     "string" ],
            },
            161 => {
                1  => [ "Motorola-Canopy-LPULCIR",                 "integer" ],
                2  => [ "Motorola-Canopy-LPDLCIR",                 "integer" ],
                3  => [ "Motorola-Canopy-HPULCIR",                 "integer" ],
                4  => [ "Motorola-Canopy-HPDLCIR",                 "integer" ],
                5  => [ "Motorola-Canopy-HPENABLE",                "integer" ],
                6  => [ "Motorola-Canopy-ULBR",                    "integer" ],
                7  => [ "Motorola-Canopy-ULBL",                    "integer" ],
                8  => [ "Motorola-Canopy-DLBR",                    "integer" ],
                9  => [ "Motorola-Canopy-DLBL",                    "integer" ],
                10 => [ "Motorola-WiMAX-MIP-MN-HOME-ADDRESS",      "ipaddr" ],
                11 => [ "Motorola-WiMAX-MIP-KEY",                  "string" ],
                12 => [ "Motorola-WiMAX-MIP-SPI",                  "integer" ],
                13 => [ "Motorola-WiMAX-MN-HA",                    "ipaddr" ],
                14 => [ "Motorola-Canopy-VLLEARNEN",               "integer" ],
                15 => [ "Motorola-Canopy-VLFRAMES",                "integer" ],
                16 => [ "Motorola-Canopy-VLIDSET",                 "integer" ],
                20 => [ "Motorola-WiMAX-DNS-Server-IP-Address",    "octets" ],
                21 => [ "Motorola-Canopy-VLIGVID",                 "integer" ],
                22 => [ "Motorola-WiMAX-User-NAI",                 "string" ],
                23 => [ "Motorola-Canopy-VLSMMGPASS",              "integer" ],
                24 => [ "Motorola-Canopy-BCASTMIR",                "integer" ],
                30 => [ "Motorola-WiMAX-Network-Domain-Name",      "string" ],
                31 => [ "Motorola-WiMAX-EMS-Address",              "ipaddr" ],
                32 => [ "Motorola-WiMAX-Provisioning-Server",      "string" ],
                34 => [ "Motorola-WiMAX-NTP-Server",               "octets" ],
                35 => [ "Motorola-WiMAX-HO-SVC-CLASS",             "octets" ],
                50 => [ "Motorola-WiMAX-Home-BTS",                 "octets" ],
                60 => [ "Motorola-WiMAX-Maximum-Total-Bandwidth",  "octets" ],
                61 => [ "Motorola-WiMAX-Maximum-Commit-Bandwidth", "octets" ],
                63 => [ "Motorola-WiMAX-Convergence-Sublayer",     "octets" ],
                64 => [ "Motorola-WiMAX-Service-Flows",            "string" ],
                65 => [ "Motorola-WiMAX-VLAN-ID",                  "octets" ],
                80 => [ "Motorola-Accounting-Message",             "string" ],
            },
            166 => {
                1   => [ "Shiva-User-Attributes",   "string" ],
                30  => [ "Shiva-Compression",       "integer" ],
                31  => [ "Shiva-Dialback-Delay",    "integer" ],
                32  => [ "Shiva-Call-Durn-Trap",    "integer" ],
                33  => [ "Shiva-Bandwidth-Trap",    "integer" ],
                34  => [ "Shiva-Minimum-Call",      "integer" ],
                35  => [ "Shiva-Default-Host",      "string" ],
                36  => [ "Shiva-Menu-Name",         "string" ],
                37  => [ "Shiva-User-Flags",        "string" ],
                38  => [ "Shiva-Termtype",          "string" ],
                39  => [ "Shiva-Break-Key",         "string" ],
                40  => [ "Shiva-Fwd-Key",           "string" ],
                41  => [ "Shiva-Bak-Key",           "string" ],
                42  => [ "Shiva-Dial-Timeout",      "integer" ],
                43  => [ "Shiva-LAT-Port",          "string" ],
                44  => [ "Shiva-Max-VCs",           "integer" ],
                45  => [ "Shiva-DHCP-Leasetime",    "integer" ],
                46  => [ "Shiva-LAT-Groups",        "string" ],
                60  => [ "Shiva-RTC-Timestamp",     "integer" ],
                61  => [ "Shiva-Circuit-Type",      "integer" ],
                90  => [ "Shiva-Called-Number",     "string" ],
                91  => [ "Shiva-Calling-Number",    "string" ],
                92  => [ "Shiva-Customer-Id",       "string" ],
                93  => [ "Shiva-Type-Of-Service",   "integer" ],
                94  => [ "Shiva-Link-Speed",        "integer" ],
                95  => [ "Shiva-Links-In-Bundle",   "integer" ],
                96  => [ "Shiva-Compression-Type",  "integer" ],
                97  => [ "Shiva-Link-Protocol",     "integer" ],
                98  => [ "Shiva-Network-Protocols", "integer" ],
                99  => [ "Shiva-Session-Id",        "integer" ],
                100 => [ "Shiva-Disconnect-Reason", "integer" ],
                101 => [ "Shiva-Acct-Serv-Switch",  "ipaddr" ],
                102 => [ "Shiva-Event-Flags",       "integer" ],
                103 => [ "Shiva-Function",          "integer" ],
                104 => [ "Shiva-Connect-Reason",    "integer" ],
            },
            171 => {
                1  => [ "Dlink-User-Level",                   "integer" ],
                2  => [ "Dlink-Ingress-Bandwidth-Assignment", "integer" ],
                3  => [ "Dlink-Egress-Bandwidth-Assignment",  "integer" ],
                4  => [ "Dlink-1p-Priority",                  "integer" ],
                10 => [ "Dlink-VLAN-Name",                    "string" ],
                11 => [ "Dlink-VLAN-ID",                      "string" ],
                12 => [ "Dlink-ACL-Profile",                  "string" ],
                13 => [ "Dlink-ACL-Rule",                     "string" ],
                14 => [ "Dlink-ACL-Script",                   "string" ],
            },
            177 => {
                11  => [ "NET-Fwd-Flow-In-Realm",          "string" ],
                12  => [ "NET-Fwd-Flow-In-Src-Addr",       "string" ],
                13  => [ "NET-Fwd-Flow-In-Src-Port",       "integer" ],
                14  => [ "NET-Fwd-Flow-In-Dst-Addr",       "string" ],
                15  => [ "NET-Fwd-Flow-In-Dst-Port",       "integer" ],
                16  => [ "NET-Fwd-Flow-Out-Realm",         "string" ],
                17  => [ "NET-Fwd-Flow-Out-Src-Addr",      "string" ],
                18  => [ "NET-Fwd-Flow-Out-Src-Port",      "integer" ],
                19  => [ "NET-Fwd-Flow-Out-Dst-Addr",      "string" ],
                20  => [ "NET-Fwd-Flow-Out-Dst-Port",      "integer" ],
                21  => [ "NET-Bwd-Flow-In-Realm",          "string" ],
                22  => [ "NET-Bwd-Flow-In-Src-Addr",       "string" ],
                23  => [ "NET-Bwd-Flow-In-Src-Port",       "integer" ],
                24  => [ "NET-Bwd-Flow-In-Dst-Addr",       "string" ],
                25  => [ "NET-Bwd-Flow-In-Dst-Port",       "integer" ],
                26  => [ "NET-Bwd-Flow-Out-Realm",         "string" ],
                27  => [ "NET-Bwd-Flow-Out-Src-Addr",      "string" ],
                28  => [ "NET-Bwd-Flow-Out-Src-Port",      "integer" ],
                29  => [ "NET-Bwd-Flow-Out-Dst-Addr",      "string" ],
                30  => [ "NET-Bwd-Flow-Out-Dst-Port",      "integer" ],
                31  => [ "NET-Fwd-Flow-Media-Type",        "string" ],
                32  => [ "NET-Fwd-Flow-PTime",             "integer" ],
                33  => [ "NET-Fwd-Octets",                 "integer" ],
                34  => [ "NET-Fwd-Packets",                "integer" ],
                35  => [ "NET-Fwd-RTCP-Packets-Lost",      "integer" ],
                36  => [ "NET-Fwd-RTCP-Avg-Jitter",        "integer" ],
                37  => [ "NET-Fwd-RTP-Avg-Latency",        "integer" ],
                38  => [ "NET-Fwd-RTCP-MaxJitter",         "integer" ],
                39  => [ "NET-Fwd-RTP-MaxLatency",         "integer" ],
                40  => [ "NET-Fwd-RTP-Packets-Lost",       "integer" ],
                41  => [ "NET-Fwd-RTP-Avg-Jitter",         "integer" ],
                42  => [ "NET-Fwd-RTP-MaxJitter",          "integer" ],
                43  => [ "NET-Bwd-Octets",                 "integer" ],
                44  => [ "NET-Bwd-Packets",                "integer" ],
                45  => [ "NET-Bwd-RTCP-Packets-Lost",      "integer" ],
                46  => [ "NET-Bwd-RTCP-Avg-Jitter",        "integer" ],
                47  => [ "NET-Bwd-RTP-Avg-Latency",        "integer" ],
                48  => [ "NET-Bwd-RTCP-MaxJitter",         "integer" ],
                49  => [ "NET-Bwd-RTP-MaxLatency",         "integer" ],
                50  => [ "NET-Bwd-RTP-Packets-Lost",       "integer" ],
                51  => [ "NET-Bwd-RTP-Avg-Jitter",         "integer" ],
                52  => [ "NET-Bwd-RTP-MaxJitter",          "integer" ],
                60  => [ "NET-Session-Ingress-CallId",     "integer" ],
                61  => [ "NET-Session-Egress-CallId",      "integer" ],
                62  => [ "NET-Session-Generic-Id",         "integer" ],
                63  => [ "NET-Routing-Table-Number",       "integer" ],
                64  => [ "NET-Ingress-Signaling-Group",    "integer" ],
                65  => [ "NET-Egress-Signaling-Group",     "integer" ],
                66  => [ "NET-Primary-Routing-Number",     "string" ],
                67  => [ "NET-Egress-Final-Routing-Num",   "string" ],
                68  => [ "NET-Ingress-Channel-Number",     "integer" ],
                69  => [ "NET-Egress-Channel-Number",      "integer" ],
                70  => [ "NET-Call-Type",                  "integer" ],
                71  => [ "NET-Call-Origin",                "integer" ],
                72  => [ "NET-Calling-Number",             "string" ],
                73  => [ "NET-Called-Number",              "string" ],
                74  => [ "NET-Calling-Name",               "string" ],
                75  => [ "NET-Disconnect-Cause",           "integer" ],
                76  => [ "NET-Abort-Cause",                "integer" ],
                77  => [ "NET-Ingress-Channel-Id",         "string" ],
                78  => [ "NET-Egress-Channel-Id",          "string" ],
                79  => [ "NET-Call-Priority",              "string" ],
                90  => [ "NET-Call-Number-Type",           "string" ],
                91  => [ "NET-Call-Plan",                  "string" ],
                92  => [ "NET-Original-Called-Number",     "string" ],
                93  => [ "NET-Original-Called-Type",       "string" ],
                94  => [ "NET-Original-Called-Plan",       "string" ],
                95  => [ "NET-Called-Name",                "string" ],
                96  => [ "NET-Namespace",                  "string" ],
                97  => [ "NET-Precedence",                 "string" ],
                98  => [ "NET-Presentation",               "string" ],
                99  => [ "NET-Screening",                  "string" ],
                100 => [ "NET-Transfer-Capability",        "string" ],
                101 => [ "NET-Transfer-Mode",              "string" ],
                102 => [ "NET-Transfer-Rate",              "string" ],
                103 => [ "NET-User-Rate",                  "string" ],
                110 => [ "NET-Setup-Time",                 "string" ],
                111 => [ "NET-Alert-Time",                 "string" ],
                112 => [ "NET-Connect-Time",               "string" ],
                113 => [ "NET-Disconnect-Time",            "string" ],
                114 => [ "NET-Inbound-Seize-Time",         "string" ],
                115 => [ "NET-Outbound-Seize-Time",        "string" ],
                116 => [ "NET-Call-Duration",              "integer" ],
                117 => [ "NET-Post-Dial-Delay",            "integer" ],
                118 => [ "NET-Disconnect-Initiator",       "integer" ],
                130 => [ "NET-P-Asserted-ID",              "string" ],
                131 => [ "NET-SIP-Diversion",              "string" ],
                132 => [ "NET-Ingress-Local-Addr",         "string" ],
                133 => [ "NET-Ingress-Remote-Addr",        "string" ],
                134 => [ "NET-Egress-Local-Addr",          "string" ],
                135 => [ "NET-Egress-Remote-Addr",         "string" ],
                136 => [ "NET-Ingress-Net-Interface-Id",   "integer" ],
                137 => [ "NET-Egress-Net-Interface-Id",    "integer" ],
                138 => [ "NET-Refer-Call-Transfer-Id",     "string" ],
                139 => [ "NET-Session-Forked-Call-Id",     "string" ],
                140 => [ "NET-Redirect-Number",            "string" ],
                141 => [ "NET-Redirect-Ip-Address",        "string" ],
                142 => [ "NET-Session-Ingress-Realm",      "string" ],
                143 => [ "NET-Session-Egress-Realm",       "string" ],
                144 => [ "NET-Ingress-Signaling-Port-Num", "integer" ],
                145 => [ "NET-Egress-Signaling-Port-Num",  "integer" ],
                146 => [ "NET-Transport-Type",             "integer" ],
                147 => [ "NET-P-Preferred-ID",             "string" ],
                148 => [ "NET-Replaced-Header",            "string" ],
                160 => [ "NET-Firmware-Version",           "string" ],
                161 => [ "NET-Local-Time-Zone",            "string" ],
                162 => [ "NET-Gw-Id",                      "string" ],
                163 => [ "NET-Time-And-Day",               "string" ],
                164 => [ "NET-Log-Time",                   "string" ],
            },
            193 => {
                3   => [ "Ericsson-ViG-Balance",                  "integer" ],
                4   => [ "Ericsson-ViG-Codec",                    "integer" ],
                5   => [ "Ericsson-ViG-Currency",                 "string" ],
                6   => [ "Ericsson-ViG-Currency-Quote",           "string" ],
                8   => [ "Ericsson-ViG-Endpoint-Type",            "integer" ],
                9   => [ "Ericsson-ViG-Sequence-Number",          "integer" ],
                11  => [ "Ericsson-ViG-Access-Agent-IP-Address",  "ipaddr" ],
                12  => [ "Ericsson-ViG-QoS-Class",                "integer" ],
                14  => [ "Ericsson-ViG-Digest-Response",          "string" ],
                15  => [ "Ericsson-ViG-Digest-Attributes",        "octets" ],
                16  => [ "Ericsson-ViG-Business-Agreement-Name",  "string" ],
                17  => [ "Ericsson-ViG-Call-Role",                "integer" ],
                20  => [ "Ericsson-ViG-Remote-SK-UA-IP-Address",  "ipaddr" ],
                23  => [ "Ericsson-ViG-Site",                     "string" ],
                32  => [ "Ericsson-ViG-TTL-relative",             "integer" ],
                33  => [ "Ericsson-ViG-Account-error-reason",     "integer" ],
                34  => [ "Ericsson-ViG-Layer-identity",           "integer" ],
                35  => [ "Ericsson-ViG-Major-protocol-version",   "integer" ],
                36  => [ "Ericsson-ViG-Minor-protocol-version",   "integer" ],
                37  => [ "Ericsson-ViG-Authentication-type",      "integer" ],
                38  => [ "Ericsson-ViG-Trusted-access",           "integer" ],
                39  => [ "Ericsson-ViG-User-name",                "string" ],
                40  => [ "Ericsson-ViG-Global-unique-call-ID",    "string" ],
                41  => [ "Ericsson-ViG-Global-unique-service-ID", "string" ],
                42  => [ "Ericsson-ViG-Interim-interval",         "integer" ],
                43  => [ "Ericsson-ViG-Alive-Indicator",          "integer" ],
                44  => [ "Ericsson-ViG-TTL-Absolute",             "integer" ],
                45  => [ "Ericsson-ViG-TTL-Start-Event",          "integer" ],
                46  => [ "Ericsson-ViG-SK-IP-address",            "ipaddr" ],
                47  => [ "Ericsson-ViG-UA-IP-address",            "ipaddr" ],
                48  => [ "Ericsson-ViG-SA-IP-address",            "ipaddr" ],
                49  => [ "Ericsson-ViG-Calling-e164-number",      "string" ],
                50  => [ "Ericsson-ViG-Calling-H323Id",           "string" ],
                51  => [ "Ericsson-ViG-Calling-Email-address",    "string" ],
                52  => [ "Ericsson-ViG-Dialled-e164-number",      "string" ],
                53  => [ "Ericsson-ViG-Dialled-H323Id",           "string" ],
                54  => [ "Ericsson-ViG-Dialled-Email-address",    "string" ],
                55  => [ "Ericsson-ViG-Routed-e164-number",       "string" ],
                56  => [ "Ericsson-ViG-Routed-H323Id",            "string" ],
                57  => [ "Ericsson-ViG-Routed-Email-address",     "string" ],
                58  => [ "Ericsson-ViG-SiteKeeper-name",          "string" ],
                59  => [ "Ericsson-ViG-Access-Group-name",        "string" ],
                60  => [ "Ericsson-ViG-Access-Agent-name",        "string" ],
                61  => [ "Ericsson-ViG-User-agent-group-name",    "string" ],
                62  => [ "Ericsson-ViG-User-agent-name",          "string" ],
                63  => [ "Ericsson-ViG-Routing-tariff",           "integer" ],
                64  => [ "Ericsson-ViG-Re-selection-counter",     "integer" ],
                65  => [ "Ericsson-ViG-CPN-digits",               "string" ],
                66  => [ "Ericsson-ViG-CPN-TON",                  "integer" ],
                67  => [ "Ericsson-ViG-CPN-NP",                   "integer" ],
                68  => [ "Ericsson-ViG-CPN-PI",                   "integer" ],
                69  => [ "Ericsson-ViG-CPN-SI",                   "integer" ],
                70  => [ "Ericsson-ViG-Dialled-num-digits",       "string" ],
                71  => [ "Ericsson-ViG-Dialled-num-TON",          "integer" ],
                72  => [ "Ericsson-ViG-Dialled-num-NP",           "integer" ],
                73  => [ "Ericsson-ViG-Routing-num-digits",       "string" ],
                74  => [ "Ericsson-ViG-Routing-num-TON",          "integer" ],
                75  => [ "Ericsson-ViG-Routing-num-NP",           "integer" ],
                76  => [ "Ericsson-ViG-Redirecting-num-digits",   "string" ],
                77  => [ "Ericsson-ViG-Redirecting-num-TON",      "integer" ],
                78  => [ "Ericsson-ViG-Redirecting-num-NP",       "integer" ],
                79  => [ "Ericsson-ViG-Redirecting-num-PI",       "integer" ],
                80  => [ "Ericsson-ViG-Redirecting-num-RFD",      "integer" ],
                81  => [ "Ericsson-ViG-Time-stamp-UTC",           "integer" ],
                82  => [ "Ericsson-ViG-Time-stamp-TZ",            "integer" ],
                83  => [ "Ericsson-ViG-Time-stamp-DST",           "integer" ],
                84  => [ "Ericsson-ViG-Session-routing-duration", "integer" ],
                85  => [ "Ericsson-ViG-Session-ringing-duration", "integer" ],
                86  => [ "Ericsson-ViG-Access-type",              "integer" ],
                87  => [ "Ericsson-ViG-Requested-bandwidth",      "integer" ],
                88  => [ "Ericsson-ViG-Allowed-bandwidth",        "integer" ],
                89  => [ "Ericsson-ViG-Media-channel-count",      "integer" ],
                90  => [ "Ericsson-ViG-Voice-media-rec-forward",  "string" ],
                91  => [ "Ericsson-ViG-Voice-media-rec-backward", "string" ],
                92  => [ "Ericsson-ViG-Video-media-rec-forward",  "string" ],
                93  => [ "Ericsson-ViG-Video-media-rec-backward", "string" ],
                94  => [ "Ericsson-ViG-Fax-media-rec-forward",    "string" ],
                95  => [ "Ericsson-ViG-Fax-media-rec-backward",   "string" ],
                96  => [ "Ericsson-ViG-Data-media-rec-forward",   "string" ],
                97  => [ "Ericsson-ViG-Data-media-rec-backward",  "string" ],
                98  => [ "Ericsson-ViG-Charging-Case",            "integer" ],
                99  => [ "Ericsson-ViG-Rel-cause-coding-std",     "integer" ],
                100 => [ "Ericsson-ViG-Rel-cause-location",       "integer" ],
                101 => [ "Ericsson-ViG-Rel-cause-class",          "integer" ],
                102 => [ "Ericsson-ViG-Rel-cause-value",          "integer" ],
                103 => [ "Ericsson-ViG-Rel-reason",               "integer" ],
                104 => [ "Ericsson-ViG-Internal-Rel-reason-val",  "integer" ],
                105 => [ "Ericsson-ViG-Internal-Rel-reason-orig", "integer" ],
                106 => [ "Ericsson-ViG-Service-ID",               "integer" ],
                107 => [ "Ericsson-ViG-User-ID",                  "string" ],
                108 => [ "Ericsson-ViG-Service-Name",             "string" ],
                109 => [ "Ericsson-ViG-Test-Call-Indicator",      "integer" ],
                110 => [ "Ericsson-ViG-Emergency-Call-Indicator", "integer" ],
                111 => [ "Ericsson-ViG-Calling-ID",               "string" ],
                112 => [ "Ericsson-ViG-Called-ID",                "string" ],
                113 => [ "Ericsson-ViG-Translated-ID",            "string" ],
                114 => [ "Ericsson-ViG-Calling-User-Group-ID",    "string" ],
                115 => [ "Ericsson-ViG-Calling-Usr-Sub-Group-ID", "string" ],
                116 => [ "Ericsson-ViG-Called-Usr-Group-ID",      "string" ],
                117 => [ "Ericsson-ViG-Called-Usr-Sub-Group-ID",  "string" ],
                118 => [ "Ericsson-ViG-Terminal-Type",            "string" ],
                119 => [ "Ericsson-ViG-Service-Duration",         "integer" ],
                120 => [ "Ericsson-ViG-Service-Execution-Result", "integer" ],
                121 => [ "Ericsson-ViG-Service-Exe-Rslt-Desc",    "string" ],
                122 => [ "Ericsson-ViG-Service-Description",      "string" ],
                123 => [ "Ericsson-ViG-Service-Specific-Info",    "string" ],
                124 => [ "Ericsson-ViG-Proxy-IP-Address",         "ipaddr" ],
                125 => [ "Ericsson-ViG-Auth-DataRequest",         "integer" ],
                126 => [ "Ericsson-ViG-IPT-Time-Stamp",           "integer" ],
                127 => [ "Ericsson-ViG-User-Name-Info",           "integer" ],
            },
            244 => { 1 => [ "Lantronix-User-Attributes", "string" ] },
            255 => {},
            266 => {
                1 => [ "Nexans-Port-Default-VLAN-ID", "integer" ],
                2 => [ "Nexans-Port-Voice-VLAN-ID",   "integer" ],
            },
            272 => {
                224 => [ "BinTec-biboPPPTable",        "string" ],
                225 => [ "BinTec-biboDialTable",       "string" ],
                226 => [ "BinTec-ipExtIfTable",        "string" ],
                227 => [ "BinTec-ipRouteTable",        "string" ],
                228 => [ "BinTec-ipExtRtTable",        "string" ],
                229 => [ "BinTec-ipNatPresetTable",    "string" ],
                230 => [ "BinTec-ipxCircTable",        "string" ],
                231 => [ "BinTec-ripCircTable",        "string" ],
                232 => [ "BinTec-sapCircTable",        "string" ],
                233 => [ "BinTec-ipxStaticRouteTable", "string" ],
                234 => [ "BinTec-ipxStaticServTable",  "string" ],
                235 => [ "BinTec-ospfIfTable",         "string" ],
                236 => [ "BinTec-pppExtIfTable",       "string" ],
                237 => [ "BinTec-ipFilterTable",       "string" ],
                238 => [ "BinTec-ipQoSTable",          "string" ],
                239 => [ "BinTec-qosIfTable",          "string" ],
                240 => [ "BinTec-qosPolicyTable",      "string" ],
            },
            307 => {
                2  => [ "LE-Terminate-Detail",          "string" ],
                3  => [ "LE-Advice-of-Charge",          "string" ],
                4  => [ "LE-Connect-Detail",            "string" ],
                6  => [ "LE-IP-Pool",                   "string" ],
                7  => [ "LE-IP-Gateway",                "ipaddr" ],
                8  => [ "LE-Modem-Info",                "string" ],
                9  => [ "LE-IPSec-Log-Options",         "integer" ],
                10 => [ "LE-IPSec-Deny-Action",         "integer" ],
                11 => [ "LE-IPSec-Active-Profile",      "string" ],
                12 => [ "LE-IPSec-Outsource-Profile",   "string" ],
                13 => [ "LE-IPSec-Passive-Profile",     "string" ],
                14 => [ "LE-NAT-TCP-Session-Timeout",   "integer" ],
                15 => [ "LE-NAT-Other-Session-Timeout", "integer" ],
                16 => [ "LE-NAT-Log-Options",           "integer" ],
                17 => [ "LE-NAT-Sess-Dir-Fail-Action",  "integer" ],
                18 => [ "LE-NAT-Inmap",                 "string" ],
                19 => [ "LE-NAT-Outmap",                "string" ],
                20 => [ "LE-NAT-Outsource-Inmap",       "string" ],
                21 => [ "LE-NAT-Outsource-Outmap",      "string" ],
                22 => [ "LE-Admin-Group",               "string" ],
                23 => [ "LE-Multicast-Client",          "integer" ],
            },
            311 => {
                1  => [ "MS-CHAP-Response",               "octets" ],
                2  => [ "MS-CHAP-Error",                  "string" ],
                3  => [ "MS-CHAP-CPW-1",                  "octets" ],
                4  => [ "MS-CHAP-CPW-2",                  "octets" ],
                5  => [ "MS-CHAP-LM-Enc-PW",              "octets" ],
                6  => [ "MS-CHAP-NT-Enc-PW",              "octets" ],
                7  => [ "MS-MPPE-Encryption-Policy",      "integer" ],
                8  => [ "MS-MPPE-Encryption-Types",       "integer" ],
                9  => [ "MS-RAS-Vendor",                  "integer" ],
                10 => [ "MS-CHAP-Domain",                 "string" ],
                11 => [ "MS-CHAP-Challenge",              "octets" ],
                12 => [ "MS-CHAP-MPPE-Keys",              "octets" ],
                13 => [ "MS-BAP-Usage",                   "integer" ],
                14 => [ "MS-Link-Utilization-Threshold",  "integer" ],
                15 => [ "MS-Link-Drop-Time-Limit",        "integer" ],
                16 => [ "MS-MPPE-Send-Key",               "octets" ],
                17 => [ "MS-MPPE-Recv-Key",               "octets" ],
                18 => [ "MS-RAS-Version",                 "string" ],
                19 => [ "MS-Old-ARAP-Password",           "octets" ],
                20 => [ "MS-New-ARAP-Password",           "octets" ],
                21 => [ "MS-ARAP-PW-Change-Reason",       "integer" ],
                22 => [ "MS-Filter",                      "octets" ],
                23 => [ "MS-Acct-Auth-Type",              "integer" ],
                24 => [ "MS-Acct-EAP-Type",               "integer" ],
                25 => [ "MS-CHAP2-Response",              "octets" ],
                26 => [ "MS-CHAP2-Success",               "octets" ],
                27 => [ "MS-CHAP2-CPW",                   "octets" ],
                28 => [ "MS-Primary-DNS-Server",          "ipaddr" ],
                29 => [ "MS-Secondary-DNS-Server",        "ipaddr" ],
                30 => [ "MS-Primary-NBNS-Server",         "ipaddr" ],
                31 => [ "MS-Secondary-NBNS-Server",       "ipaddr" ],
                34 => [ "MS-RAS-Client-Name",             "string" ],
                35 => [ "MS-RAS-Client-Version",          "string" ],
                36 => [ "MS-Quarantine-IPFilter",         "octets" ],
                37 => [ "MS-Quarantine-Session-Timeout",  "integer" ],
                40 => [ "MS-User-Security-Identity",      "string" ],
                41 => [ "MS-Identity-Type",               "integer" ],
                42 => [ "MS-Service-Class",               "string" ],
                44 => [ "MS-Quarantine-User-Class",       "string" ],
                45 => [ "MS-Quarantine-State",            "integer" ],
                46 => [ "MS-Quarantine-Grace-Time",       "integer" ],
                47 => [ "MS-Network-Access-Server-Type",  "integer" ],
                48 => [ "MS-AFW-Zone",                    "integer" ],
                49 => [ "MS-AFW-Protection-Level",        "integer" ],
                50 => [ "MS-Machine-Name",                "string" ],
                51 => [ "MS-IPv6-Filter",                 "octets" ],
                52 => [ "MS-IPv4-Remediation-Servers",    "octets" ],
                53 => [ "MS-IPv6-Remediation-Servers",    "octets" ],
                54 => [ "MS-RNAP-Not-Quarantine-Capable", "integer" ],
                55 => [ "MS-Quarantine-SOH",              "octets" ],
                56 => [ "MS-RAS-Correlation",             "octets" ],
                57 => [ "MS-Extended-Quarantine-State",   "integer" ],
                58 => [ "MS-HCAP-User-Groups",            "string" ],
                59 => [ "MS-HCAP-Location-Group-Name",    "string" ],
                60 => [ "MS-HCAP-User-Name",              "string" ],
                61 => [ "MS-User-IPv4-Address",           "ipaddr" ],
                62 => [ "MS-User-IPv6-Address",           "ipv6addr" ],
                63 => [ "MS-TSG-Device-Redirection",      "integer" ],
            },
            318 => {
                1  => [ "APC-Service-Type",  "integer" ],
                2  => [ "APC-Outlets",       "string" ],
                3  => [ "APC-Perms",         "string" ],
                4  => [ "APC-Username",      "string" ],
                5  => [ "APC-Contact",       "string" ],
                6  => [ "APC-ACCPX-Doors",   "string" ],
                7  => [ "APC-ACCPX-Status",  "string" ],
                8  => [ "APC-ACCPX-Access1", "string" ],
                9  => [ "APC-ACCPX-Access2", "string" ],
                10 => [ "APC-ACCPX-Access3", "string" ],
                11 => [ "APC-ACCPX-Access4", "string" ],
                12 => [ "APC-ACCPX-Access5", "string" ],
                13 => [ "APC-ACCPX-Access6", "string" ],
                14 => [ "APC-ACCPX-Access7", "string" ],
            },
            388 => {
                1   => [ "Symbol-Admin-Role",       "integer" ],
                2   => [ "Symbol-Current-ESSID",    "string" ],
                3   => [ "Symbol-Allowed-ESSID",    "string" ],
                4   => [ "Symbol-WLAN-Index",       "integer" ],
                5   => [ "Symbol-QoS-Profile",      "integer" ],
                6   => [ "Symbol-Allowed-Radio",    "string" ],
                7   => [ "Symbol-Expiry-Date-Time", "string" ],
                8   => [ "Symbol-Start-Date-Time",  "string" ],
                9   => [ "Symbol-Posture-Status",   "string" ],
                10  => [ "Symbol-Downlink-Limit",   "string" ],
                11  => [ "Symbol-Uplink-Limit",     "string" ],
                12  => [ "Symbol-User-Group",       "string" ],
                100 => [ "Symbol-Login-Source",     "integer" ],
            },
            429 => {
                72    => [ "USR-DTE-Data-Idle-Timout",         "integer" ],
                94    => [ "USR-Default-DTE-Data-Rate",        "integer" ],
                102   => [ "USR-Last-Number-Dialed-Out",       "string" ],
                103   => [ "USR-Sync-Async-Mode",              "integer" ],
                104   => [ "USR-Originate-Answer-Mode",        "integer" ],
                105   => [ "USR-Failure-to-Connect-Reason",    "integer" ],
                106   => [ "USR-Initial-Tx-Link-Data-Rate",    "integer" ],
                107   => [ "USR-Final-Tx-Link-Data-Rate",      "integer" ],
                108   => [ "USR-Modulation-Type",              "integer" ],
                111   => [ "USR-Equalization-Type",            "integer" ],
                112   => [ "USR-Fallback-Enabled",             "integer" ],
                113   => [ "USR-Characters-Sent",              "integer" ],
                114   => [ "USR-Characters-Received",          "integer" ],
                117   => [ "USR-Blocks-Sent",                  "integer" ],
                118   => [ "USR-Blocks-Received",              "integer" ],
                119   => [ "USR-Blocks-Resent",                "integer" ],
                120   => [ "USR-Retrains-Requested",           "integer" ],
                121   => [ "USR-Retrains-Granted",             "integer" ],
                122   => [ "USR-Line-Reversals",               "integer" ],
                123   => [ "USR-Number-Of-Characters-Lost",    "integer" ],
                124   => [ "USR-Back-Channel-Data-Rate",       "integer" ],
                125   => [ "USR-Number-of-Blers",              "integer" ],
                126   => [ "USR-Number-of-Link-Timeouts",      "integer" ],
                127   => [ "USR-Number-of-Fallbacks",          "integer" ],
                128   => [ "USR-Number-of-Upshifts",           "integer" ],
                129   => [ "USR-Number-of-Link-NAKs",          "integer" ],
                153   => [ "USR-Simplified-MNP-Levels",        "integer" ],
                155   => [ "USR-Connect-Term-Reason",          "integer" ],
                190   => [ "USR-DTR-False-Timeout",            "integer" ],
                191   => [ "USR-Fallback-Limit",               "integer" ],
                192   => [ "USR-Block-Error-Count-Limit",      "integer" ],
                199   => [ "USR-Simplified-V42bis-Usage",      "integer" ],
                218   => [ "USR-DTR-True-Timeout",             "integer" ],
                232   => [ "USR-Last-Number-Dialed-In-DNIS",   "string" ],
                233   => [ "USR-Last-Callers-Number-ANI",      "string" ],
                387   => [ "USR-CDMA-Call-Reference-Number",   "integer" ],
                388   => [ "USR-Mbi_Ct_PRI_Card_Slot",         "integer" ],
                389   => [ "USR-Mbi_Ct_TDM_Time_Slot",         "integer" ],
                390   => [ "USR-Mbi_Ct_PRI_Card_Span_Line",    "integer" ],
                391   => [ "USR-Mbi_Ct_BChannel_Used",         "integer" ],
                461   => [ "USR-RMMIE-Status",                 "integer" ],
                462   => [ "USR-RMMIE-Num-Of-Updates",         "integer" ],
                479   => [ "USR-RMMIE-Manufacturer-ID",        "integer" ],
                480   => [ "USR-RMMIE-Product-Code",           "string" ],
                481   => [ "USR-RMMIE-Serial-Number",          "string" ],
                482   => [ "USR-RMMIE-Firmware-Version",       "string" ],
                483   => [ "USR-RMMIE-Firmware-Build-Date",    "string" ],
                1012  => [ "USR-IWF-IP-Address",               "ipaddr" ],
                2190  => [ "USR-Mobile-IP-Address",            "ipaddr" ],
                2191  => [ "USR-Calling-Party-Number",         "string" ],
                2192  => [ "USR-Called-Party-Number",          "string" ],
                2193  => [ "USR-Call-Type",                    "integer" ],
                2194  => [ "USR-ESN",                          "string" ],
                2195  => [ "USR-IWF-Call-Identifier",          "integer" ],
                2196  => [ "USR-IMSI",                         "string" ],
                2197  => [ "USR-Service-Option",               "integer" ],
                2198  => [ "USR-Disconnect-Cause-Indicator",   "integer" ],
                2199  => [ "USR-Mobile-NumBytes-Txed",         "integer" ],
                2200  => [ "USR-Mobile-NumBytes-Rxed",         "integer" ],
                2201  => [ "USR-Num-Fax-Pages-Processed",      "integer" ],
                2202  => [ "USR-Compression-Type",             "integer" ],
                2203  => [ "USR-Call-Error-Code",              "integer" ],
                2204  => [ "USR-Modem-Setup-Time",             "integer" ],
                2205  => [ "USR-Call-Connecting-Time",         "integer" ],
                2206  => [ "USR-Connect-Time",                 "integer" ],
                2292  => [ "USR-QNC1-Service-Destination",     "ipaddr" ],
                2304  => [ "USR-RMMIE-Last-Update-Time",       "integer" ],
                2305  => [ "USR-RMMIE-Last-Update-Event",      "integer" ],
                2306  => [ "USR-RMMIE-Rcv-Tot-PwrLvl",         "integer" ],
                2307  => [ "USR-RMMIE-Rcv-PwrLvl-3300Hz",      "integer" ],
                2308  => [ "USR-RMMIE-Rcv-PwrLvl-3750Hz",      "integer" ],
                2309  => [ "USR-RMMIE-PwrLvl-NearEcho-Canc",   "integer" ],
                2310  => [ "USR-RMMIE-PwrLvl-FarEcho-Canc",    "integer" ],
                2311  => [ "USR-RMMIE-PwrLvl-Noise-Lvl",       "integer" ],
                2312  => [ "USR-RMMIE-PwrLvl-Xmit-Lvl",        "integer" ],
                2313  => [ "USR-RMMIE-x2-Status",              "integer" ],
                2314  => [ "USR-RMMIE-Planned-Disconnect",     "integer" ],
                2339  => [ "Initial-Modulation-Type",          "integer" ],
                32768 => [ "CW-Version-Id",                    "integer" ],
                32769 => [ "CW-Account-Id",                    "string" ],
                32770 => [ "CW-Acct-Type",                     "integer" ],
                32771 => [ "CW-Acct-Identification-Code",      "integer" ],
                32772 => [ "CW-Service-Type",                  "integer" ],
                32773 => [ "CW-Rate-Plan-Id",                  "integer" ],
                32774 => [ "CW-Source-Identifier",             "integer" ],
                32775 => [ "CW-Session-Id",                    "string" ],
                32776 => [ "CW-Num-Call-Attempt-Session",      "integer" ],
                32777 => [ "CW-Session-Sequence-Num",          "integer" ],
                32778 => [ "CW-Session-Sequence-End",          "integer" ],
                32779 => [ "CW-Authentication-Fail-Cnt",       "integer" ],
                32780 => [ "CW-Clg-Party-E164-Type",           "integer" ],
                32781 => [ "CW-Clg-Party-E164-Number",         "string" ],
                32782 => [ "CW-Clg-Party-Trans-Protocol",      "integer" ],
                32783 => [ "CW-Clg-Party-Trans-Port",          "integer" ],
                32784 => [ "CW-Clg-Party-Trans-IP",            "ipaddr" ],
                32785 => [ "CW-Clg-Party-Trans-DNS",           "string" ],
                32786 => [ "CW-Cld-Party-E164-Type",           "integer" ],
                32787 => [ "CW-Cld-Party-E164-Number",         "string" ],
                32788 => [ "CW-Cld-Party-Trans-Protocol",      "integer" ],
                32789 => [ "CW-Cld-Party-Trans-Port",          "integer" ],
                32790 => [ "CW-Cld-Party-Trans-IP",            "ipaddr" ],
                32791 => [ "CW-Cld-Party-Trans-DNS",           "string" ],
                32792 => [ "CW-Orig-Line-Identifier",          "integer" ],
                32793 => [ "CW-PSTN-Interface-Number",         "integer" ],
                32794 => [ "CW-Ingr-Gway-E164-Type",           "integer" ],
                32795 => [ "CW-Ingr-Gway-E164-Number",         "string" ],
                32796 => [ "CW-Ingr-Gway-Trans-Protocol",      "integer" ],
                32797 => [ "CW-Ingr-Gway-Trans-Port",          "integer" ],
                32798 => [ "CW-Ingr-Gway-Trans-IP",            "ipaddr" ],
                32799 => [ "CW-Ingr-Gway-Trans-DNS",           "string" ],
                32800 => [ "CW-Egr-Gway-Trans-Protocol",       "integer" ],
                32801 => [ "CW-Egr-Gway-Trans-Port",           "integer" ],
                32802 => [ "CW-Egr-Gway-Trans-IP",             "ipaddr" ],
                32803 => [ "CW-Egr-Gway-Trans-DNS",            "string" ],
                32804 => [ "CW-Ingr-Gtkpr-Trans-Protocol",     "integer" ],
                32805 => [ "CW-Ingr-Gtkpr-Trans-Port",         "integer" ],
                32806 => [ "CW-Ingr-Gtkpr-Trans-IP",           "ipaddr" ],
                32807 => [ "CW-Ingr-Gtkpr-Trans-DNS",          "string" ],
                32808 => [ "CW-Egr-Gtkpr-Trans-Protocol",      "integer" ],
                32809 => [ "CW-Egr-Gtkpr-Trans-Port",          "integer" ],
                32810 => [ "CW-Egr-Gtkpr-Trans-IP",            "ipaddr" ],
                32811 => [ "CW-Egr-Gtkpr-Trans-DNS",           "string" ],
                32812 => [ "CW-Call-Identifier",               "string" ],
                32813 => [ "CW-Call-Type",                     "integer" ],
                32814 => [ "CW-Call-Start-Ingr-GW-Sec",        "string" ],
                32815 => [ "CW-Call-Start-Ingr-GW-Msec",       "integer" ],
                32816 => [ "CW-Call-Start-Time-Ans-Sec",       "string" ],
                32817 => [ "CW-Call-Start-Time-Ans-Msec",      "integer" ],
                32818 => [ "CW-Call-End-Time-Sec",             "string" ],
                32819 => [ "CW-Call-End-Time-Msec",            "integer" ],
                32820 => [ "CW-Call-Durn-Connect-Disc",        "integer" ],
                32821 => [ "CW-Codec-Type",                    "integer" ],
                32822 => [ "CW-Call-Termination-Cause",        "integer" ],
                32823 => [ "CW-Audio-Packets-Sent",            "integer" ],
                32824 => [ "CW-Audio-Packets-Received",        "integer" ],
                32825 => [ "CW-Audio-Packets-Lost",            "integer" ],
                32826 => [ "CW-Audio-Packets-In-Frame",        "integer" ],
                32827 => [ "CW-Audio-Bytes-In-Frame",          "integer" ],
                32828 => [ "CW-Audio-Signal-In-Packet",        "integer" ],
                32829 => [ "CW-Port-Id-For-Call",              "integer" ],
                32830 => [ "CW-Slot-Id-For-Call",              "integer" ],
                32831 => [ "CW-Acct-Balance-Start-Curr",       "integer" ],
                32832 => [ "CW-Acct-Balance-Start-Amt",        "integer" ],
                32833 => [ "CW-Acct-Balance-Start-Dec",        "integer" ],
                32834 => [ "CW-Acct-Balance-Decr-Curr",        "integer" ],
                32835 => [ "CW-LRQ-Token",                     "string" ],
                32836 => [ "CW-ARQ-Token",                     "string" ],
                32837 => [ "CW-Token-Status",                  "integer" ],
                32838 => [ "CW-SS7-Destn-Ptcode-Type",         "integer" ],
                32839 => [ "CW-SS7-Destn-Ptcode-Address",      "integer" ],
                32840 => [ "CW-SS7-Orig-Ptcode-Type",          "integer" ],
                32841 => [ "CW-SS7-Orig-Ptcode-Address",       "integer" ],
                32842 => [ "CW-SS7-CIC",                       "integer" ],
                32843 => [ "CW-MGC-Id",                        "integer" ],
                32844 => [ "CW-MG-Id",                         "integer" ],
                32845 => [ "CW-Signaling-Protocol",            "integer" ],
                32846 => [ "CW-Protocol-Transport",            "integer" ],
                32847 => [ "CW-Local-Sig-Trans-Protocol",      "integer" ],
                32848 => [ "CW-Local-Sig-Trans-Port",          "integer" ],
                32849 => [ "CW-Local-Sig-Trans-IP",            "ipaddr" ],
                32850 => [ "CW-Local-Sig-Trans-DNS",           "string" ],
                32851 => [ "CW-Remote-Sig-Trans-Protocol",     "integer" ],
                32852 => [ "CW-Remote-Sig-Trans-Port",         "integer" ],
                32853 => [ "CW-Remote-Sig-Trans-IP",           "ipaddr" ],
                32854 => [ "CW-Remote-Sig-Trans-DNS",          "string" ],
                32855 => [ "CW-Local-MG-RTP-Protocol",         "integer" ],
                32856 => [ "CW-Local-MG-RTP-Port",             "integer" ],
                32857 => [ "CW-Local-MG-RTP-IP",               "ipaddr" ],
                32858 => [ "CW-Local-MG-RTP-DNS",              "string" ],
                32859 => [ "CW-Remote-MG-RTP-Protocol",        "integer" ],
                32860 => [ "CW-Remote-MG-RTP-Port",            "integer" ],
                32861 => [ "CW-Remote-MG-RTP-IP",              "ipaddr" ],
                32862 => [ "CW-Remote-MG-RTP-DNS",             "string" ],
                32863 => [ "CW-Call-Model",                    "integer" ],
                32864 => [ "CW-Call-Plan-Id",                  "integer" ],
                32865 => [ "CW-Trans-Cld-Party-E164-Type",     "integer" ],
                32866 => [ "CW-Trans-Cld-Party-E164-Num",      "string" ],
                32867 => [ "CW-OSP-Source-Device",             "string" ],
                36864 => [ "USR-PW_USR_IFilter_IP",            "string" ],
                36865 => [ "USR-PW_USR_IFilter_IPX",           "string" ],
                36866 => [ "USR-SAP-Filter-In",                "string" ],
                36867 => [ "USR-PW_USR_OFilter_IP",            "string" ],
                36868 => [ "USR-PW_USR_OFilter_IPX",           "string" ],
                36869 => [ "USR-PW_USR_OFilter_SAP",           "string" ],
                36870 => [ "USR-PW_VPN_ID",                    "string" ],
                36871 => [ "USR-PW_VPN_Name",                  "string" ],
                36872 => [ "USR-PW_VPN_Neighbor",              "ipaddr" ],
                36873 => [ "USR-PW_Framed_Routing_V2",         "string" ],
                36874 => [ "USR-PW_VPN_Gateway",               "string" ],
                36875 => [ "USR-PW_Tunnel_Authentication",     "string" ],
                36876 => [ "USR-PW_Index",                     "string" ],
                36877 => [ "USR-PW_Cutoff",                    "string" ],
                36878 => [ "USR-PW_Packet",                    "string" ],
                36879 => [ "USR-Primary_DNS_Server",           "ipaddr" ],
                36880 => [ "USR-Secondary_DNS_Server",         "ipaddr" ],
                36881 => [ "USR-Primary_NBNS_Server",          "ipaddr" ],
                36882 => [ "USR-Secondary_NBNS_Server",        "ipaddr" ],
                36883 => [ "USR-Syslog-Tap",                   "integer" ],
                36884 => [ "USR-MIC",                          "string" ],
                36887 => [ "USR-Log-Filter-Packets",           "string" ],
                36889 => [ "USR-Chassis-Call-Slot",            "integer" ],
                36890 => [ "USR-Chassis-Call-Span",            "integer" ],
                36891 => [ "USR-Chassis-Call-Channel",         "integer" ],
                36892 => [ "USR-Keypress-Timeout",             "integer" ],
                36893 => [ "USR-Unauthenticated-Time",         "integer" ],
                36894 => [ "USR-VPN-Encrypter",                "integer" ],
                36895 => [ "USR-VPN-GW-Location-Id",           "string" ],
                36896 => [ "USR-Re-Chap-Timeout",              "integer" ],
                36897 => [ "USR-CCP-Algorithm",                "integer" ],
                36898 => [ "USR-ACCM-Type",                    "integer" ],
                36899 => [ "USR-Connect-Speed",                "integer" ],
                36900 => [ "USR-Framed_IP_Address_Pool_Name",  "string" ],
                36901 => [ "USR-MP-EDO",                       "string" ],
                36902 => [ "USR-Local-Framed-IP-Addr",         "ipaddr" ],
                36903 => [ "USR-Framed-IPX-Route",             "ipaddr" ],
                36904 => [ "USR-MPIP-Tunnel-Originator",       "ipaddr" ],
                38912 => [ "USR-Bearer-Capabilities",          "integer" ],
                38913 => [ "USR-Speed-Of-Connection",          "integer" ],
                38914 => [ "USR-Max-Channels",                 "integer" ],
                38915 => [ "USR-Channel-Expansion",            "integer" ],
                38916 => [ "USR-Channel-Decrement",            "integer" ],
                38917 => [ "USR-Expansion-Algorithm",          "integer" ],
                38918 => [ "USR-Compression-Algorithm",        "integer" ],
                38919 => [ "USR-Receive-Acc-Map",              "integer" ],
                38920 => [ "USR-Transmit-Acc-Map",             "integer" ],
                38922 => [ "USR-Compression-Reset-Mode",       "integer" ],
                38923 => [ "USR-Min-Compression-Size",         "integer" ],
                38924 => [ "USR-IP",                           "integer" ],
                38925 => [ "USR-IPX",                          "integer" ],
                38926 => [ "USR-Filter-Zones",                 "integer" ],
                38927 => [ "USR-Appletalk",                    "integer" ],
                38928 => [ "USR-Bridging",                     "integer" ],
                38929 => [ "USR-Spoofing",                     "integer" ],
                38930 => [ "USR-Host-Type",                    "integer" ],
                38931 => [ "USR-Send-Name",                    "string" ],
                38932 => [ "USR-Send-Password",                "string" ],
                38933 => [ "USR-Start-Time",                   "integer" ],
                38934 => [ "USR-End-Time",                     "integer" ],
                38935 => [ "USR-Send-Script1",                 "string" ],
                38936 => [ "USR-Reply-Script1",                "string" ],
                38937 => [ "USR-Send-Script2",                 "string" ],
                38938 => [ "USR-Reply-Script2",                "string" ],
                38939 => [ "USR-Send-Script3",                 "string" ],
                38940 => [ "USR-Reply-Script3",                "string" ],
                38941 => [ "USR-Send-Script4",                 "string" ],
                38942 => [ "USR-Reply-Script4",                "string" ],
                38943 => [ "USR-Send-Script5",                 "string" ],
                38944 => [ "USR-Reply-Script5",                "string" ],
                38945 => [ "USR-Send-Script6",                 "string" ],
                38946 => [ "USR-Reply-Script6",                "string" ],
                38947 => [ "USR-Terminal-Type",                "string" ],
                38948 => [ "USR-Appletalk-Network-Range",      "integer" ],
                38949 => [ "USR-Local-IP-Address",             "string" ],
                38950 => [ "USR-Routing-Protocol",             "integer" ],
                38951 => [ "USR-Modem-Group",                  "integer" ],
                38952 => [ "USR-IPX-Routing",                  "integer" ],
                38953 => [ "USR-IPX-WAN",                      "integer" ],
                38954 => [ "USR-IP-RIP-Policies",              "integer" ],
                38955 => [ "USR-IP-RIP-Simple-Auth-Password",  "string" ],
                38956 => [ "USR-IP-RIP-Input-Filter",          "string" ],
                38957 => [ "USR-IP-Call-Input-Filter",         "string" ],
                38958 => [ "USR-IPX-RIP-Input-Filter",         "string" ],
                38959 => [ "USR-MP-MRRU",                      "integer" ],
                38960 => [ "USR-IPX-Call-Input-Filter",        "string" ],
                38961 => [ "USR-AT-Input-Filter",              "string" ],
                38962 => [ "USR-AT-RTMP-Input-Filter",         "string" ],
                38963 => [ "USR-AT-Zip-Input-Filter",          "string" ],
                38964 => [ "USR-AT-Call-Input-Filter",         "string" ],
                38965 => [ "USR-ET-Bridge-Input-Filter",       "string" ],
                38966 => [ "USR-IP-RIP-Output-Filter",         "string" ],
                38967 => [ "USR-IP-Call-Output-Filter",        "string" ],
                38968 => [ "USR-IPX-RIP-Output-Filter",        "string" ],
                38969 => [ "USR-IPX-Call-Output-Filter",       "string" ],
                38970 => [ "USR-AT-Output-Filter",             "string" ],
                38971 => [ "USR-AT-RTMP-Output-Filter",        "string" ],
                38972 => [ "USR-AT-Zip-Output-Filter",         "string" ],
                38973 => [ "USR-AT-Call-Output-Filter",        "string" ],
                38974 => [ "USR-ET-Bridge-Output-Filter",      "string" ],
                38975 => [ "USR-ET-Bridge-Call-Output-Filte",  "string" ],
                38976 => [ "USR-IP-Default-Route-Option",      "integer" ],
                38977 => [ "USR-MP-EDO-HIPER",                 "string" ],
                38978 => [ "USR-Modem-Training-Time",          "integer" ],
                38979 => [ "USR-Interface-Index",              "integer" ],
                38980 => [ "USR-Tunnel-Security",              "integer" ],
                38981 => [ "USR-Port-Tap",                     "integer" ],
                38982 => [ "USR-Port-Tap-Format",              "integer" ],
                38983 => [ "USR-Port-Tap-Output",              "integer" ],
                38984 => [ "USR-Port-Tap-Facility",            "integer" ],
                38985 => [ "USR-Port-Tap-Priority",            "integer" ],
                38986 => [ "USR-Port-Tap-Address",             "ipaddr" ],
                38987 => [ "USR-MobileIP-Home-Agent-Address",  "ipaddr" ],
                38988 => [ "USR-Tunneled-MLPP",                "integer" ],
                38989 => [ "USR-Multicast-Proxy",              "integer" ],
                38990 => [ "USR-Multicast-Receive",            "integer" ],
                38992 => [ "USR-Multicast-Forwarding",         "integer" ],
                38993 => [ "USR-IGMP-Query-Interval",          "integer" ],
                38994 => [ "USR-IGMP-Maximum-Response-Time",   "integer" ],
                38995 => [ "USR-IGMP-Robustness",              "integer" ],
                38996 => [ "USR-IGMP-Version",                 "integer" ],
                38997 => [ "USR-IGMP-Routing",                 "integer" ],
                38998 => [ "USR-VTS-Session-Key",              "string" ],
                38999 => [ "USR-Orig-NAS-Type",                "string" ],
                39000 => [ "USR-Call-Arrival-Time",            "integer" ],
                39001 => [ "USR-Call-End-Time",                "integer" ],
                39008 => [ "USR-Rad-Multicast-Routing-Ttl",    "integer" ],
                39009 => [ "USR-Rad-Multicast-Routing-RtLim",  "integer" ],
                39010 => [ "USR-Rad-Multicast-Routing-Proto",  "integer" ],
                39011 => [ "USR-Rad-Multicast-Routing-Bound",  "string" ],
                39012 => [ "USR-Rad-Dvmrp-Metric",             "integer" ],
                39013 => [ "USR-Chat-Script-Name",             "string" ],
                39014 => [ "USR-CUSR-hat-Script-Rules",        "string" ],
                39015 => [ "USR-Rad-Location-Type",            "integer" ],
                39016 => [ "USR-Tunnel-Switch-Endpoint",       "string" ],
                39017 => [ "USR-OSPF-Addressless-Index",       "integer" ],
                39018 => [ "USR-Callback-Type",                "integer" ],
                39019 => [ "USR-Tunnel-Auth-Hostname",         "string" ],
                39020 => [ "USR-Acct-Reason-Code",             "integer" ],
                39021 => [ "USR-QoS-Queuing-Mehtod",           "integer" ],
                39022 => [ "USR-PQ-Default-Priority",          "integer" ],
                39024 => [ "USR-IP-SAA-Filter",                "integer" ],
                39025 => [ "USR-FQ-Default-Priority",          "integer" ],
                39026 => [ "USR-IPP-Enable",                   "integer" ],
                39027 => [ "USR-Pre-Shared-MN-Key",            "string" ],
                39028 => [ "USR-MIP-NAI",                      "integer" ],
                39029 => [ "USR-DNIS-ReAuthentication",        "integer" ],
                39030 => [ "USR-Agent",                        "integer" ],
                39031 => [ "USR-PQ-Parameters",                "integer" ],
                39032 => [ "USR-Dvmrp-Prune-Lifetime",         "integer" ],
                39033 => [ "USR-Special-Xon-Xoff-Flow",        "integer" ],
                39034 => [ "USR-Dvmrp-Advertised-Metric",      "integer" ],
                39035 => [ "USR-Dvmrp-Retransmit-Prunes",      "integer" ],
                39036 => [ "USR-Dvmrp-Non-Pruners",            "integer" ],
                39037 => [ "USR-Dvmrp-Route-Transit",          "integer" ],
                39038 => [ "USR-Dvmrp-Input-Filter",           "string" ],
                39040 => [ "USR-Dvmrp-Output-Filter",          "string" ],
                39041 => [ "USR-Policy-Access",                "integer" ],
                39042 => [ "USR-Policy-Configuration",         "integer" ],
                39043 => [ "USR-Policy-Filename",              "string" ],
                39044 => [ "USR-Policy-Type",                  "integer" ],
                39045 => [ "USR-Mobile-Session-ID",            "integer" ],
                39046 => [ "USR-Mobile-Accounting-Type",       "integer" ],
                39047 => [ "USR-Mobile-Service-Option",        "integer" ],
                39048 => [ "USR-Wallclock-Timestamp",          "integer" ],
                39049 => [ "USR-Supports-Tags",                "integer" ],
                39050 => [ "USR-Dvmrp-Initial-Flooding",       "integer" ],
                39051 => [ "USR-HARC-Disconnect-Code",         "integer" ],
                39052 => [ "USR-Telnet-Options",               "integer" ],
                39053 => [ "USR-CDMA-PktData-Network-ID",      "integer" ],
                39054 => [ "USR-Auth-Next-Server-Address",     "ipaddr" ],
                39055 => [ "USR-User-PPP-AODI-Type",           "integer" ],
                39056 => [ "USR-MLPPP-Fragmentation-Threshld", "integer" ],
                39057 => [ "USR-Unnumbered-Local-IP-Address",  "ipaddr" ],
                39058 => [ "USR-Traffic-Threshold",            "integer" ],
                39059 => [ "USR-Keep-Alive-Interval",          "integer" ],
                39060 => [ "USR-Tunnel-Challenge-Outgoing",    "integer" ],
                39061 => [ "USR-X25-Trunk-Profile",            "string" ],
                39062 => [ "USR-X25-Acct-Input-Segment-Count", "integer" ],
                39063 => [ "USR-X25-Acct-Output-Segment-Coun", "integer" ],
                39064 => [ "USR-X25-Acct-Segment-Size",        "integer" ],
                39065 => [ "USR-X25-Acct-Termination-Code",    "integer" ],
                39066 => [ "USR-X25-SVC-Logical-Channel-Numb", "integer" ],
                39067 => [ "USR-Nailed-B-Channel-Indicator",   "integer" ],
                39068 => [ "USR-X25-SVC-Call-Attributes",      "integer" ],
                39069 => [ "USR-Init-Reg-Server-Addr",         "ipaddr" ],
                39070 => [ "USR-Re-Reg-Server-Addr",           "ipaddr" ],
                39071 => [ "USR-Bytes-TX-Remain",              "integer" ],
                39072 => [ "USR-Bytes-RX-Remain",              "integer" ],
                39073 => [ "USR-Session-Time-Remain",          "integer" ],
                39074 => [ "USR-Pre-Paid-Enabled",             "integer" ],
                39075 => [ "USR-Reg-Server-Prov-Timeout",      "integer" ],
                39076 => [ "USR-Redirect",                     "integer" ],
                39077 => [ "USR-VLAN-Tag",                     "integer" ],
                39078 => [ "USR-Rad-IP-Pool-Definition",       "string" ],
                39079 => [ "USR-Rad-NMC-Call-Progress-Status", "integer" ],
                39080 => [ "USR-Rad-NMC-Blocks_RX",            "integer" ],
                48719 => [ "USR-IDS0-Call-Type",               "integer" ],
                48720 => [ "USR-Call-Terminate-in-GMT",        "date" ],
                48721 => [ "USR-Call-Connect-in-GMT",          "date" ],
                48722 => [ "USR-Call-Arrival-in-GMT",          "date" ],
                48733 => [ "USR-Channel-Connected-To",         "integer" ],
                48734 => [ "USR-Slot-Connected-To",            "integer" ],
                48735 => [ "USR-Device-Connected-To",          "integer" ],
                48736 => [ "USR-NFAS-ID",                      "integer" ],
                48737 => [ "USR-Q931-Call-Reference-Value",    "integer" ],
                48738 => [ "USR-Call-Event-Code",              "integer" ],
                48739 => [ "USR-DS0",                          "integer" ],
                48740 => [ "USR-DS0s",                         "string" ],
                48742 => [ "USR-Gateway-IP-Address",           "ipaddr" ],
                48759 => [ "USR-Physical-State",               "integer" ],
                48765 => [ "USR-Call-Reference-Number",        "integer" ],
                48772 => [ "USR-Chassis-Temp-Threshold",       "integer" ],
                48773 => [ "USR-Card-Type",                    "integer" ],
                48862 => [ "USR-Security-Login-Limit",         "integer" ],
                48890 => [ "USR-Security-Resp-Limit",          "integer" ],
                48916 => [ "USR-Packet-Bus-Session",           "integer" ],
                48919 => [ "USR-DTE-Ring-No-Answer-Limit",     "integer" ],
                48940 => [ "USR-Final-Rx-Link-Data-Rate",      "integer" ],
                48941 => [ "USR-Initial-Rx-Link-Data-Rate",    "integer" ],
                48943 => [ "USR-Event-Date-Time",              "date" ],
                48945 => [ "USR-Chassis-Temperature",          "integer" ],
                48946 => [ "USR-Actual-Voltage",               "integer" ],
                48947 => [ "USR-Expected-Voltage",             "integer" ],
                48948 => [ "USR-Power-Supply-Number",          "integer" ],
                48952 => [ "USR-Channel",                      "integer" ],
                48953 => [ "USR-Chassis-Slot",                 "integer" ],
                49086 => [ "USR-Event-Id",                     "integer" ],
                49126 => [ "USR-Number-of-Rings-Limit",        "integer" ],
                49127 => [ "USR-Connect-Time-Limit",           "integer" ],
                49142 => [ "USR-Call-End-Date-Time",           "date" ],
                49143 => [ "USR-Call-Start-Date-Time",         "date" ],
                61440 => [ "USR-Server-Time",                  "date" ],
                61441 => [ "USR-Request-Type",                 "integer" ],
                61442 => [ "USR-NAS-Type",                     "integer" ],
                61443 => [ "USR-Auth-Mode",                    "integer" ],
            },
            529 => {
                2   => [ "Ascend-Max-Shared-Users",        "integer" ],
                7   => [ "Ascend-UU-Info",                 "string" ],
                9   => [ "Ascend-CIR-Timer",               "integer" ],
                10  => [ "Ascend-FR-08-Mode",              "integer" ],
                11  => [ "Ascend-Destination-Nas-Port",    "integer" ],
                12  => [ "Ascend-FR-SVC-Addr",             "string" ],
                13  => [ "Ascend-NAS-Port-Format",         "integer" ],
                14  => [ "Ascend-ATM-Fault-Management",    "integer" ],
                15  => [ "Ascend-ATM-Loopback-Cell-Loss",  "integer" ],
                16  => [ "Ascend-Ckt-Type",                "integer" ],
                17  => [ "Ascend-SVC-Enabled",             "integer" ],
                18  => [ "Ascend-Session-Type",            "integer" ],
                19  => [ "Ascend-H323-Gatekeeper",         "ipaddr" ],
                20  => [ "Ascend-Global-Call-Id",          "string" ],
                21  => [ "Ascend-H323-Conference-Id",      "integer" ],
                22  => [ "Ascend-H323-Fegw-Address",       "ipaddr" ],
                23  => [ "Ascend-H323-Dialed-Time",        "integer" ],
                24  => [ "Ascend-Dialed-Number",           "string" ],
                25  => [ "Ascend-Inter-Arrival-Jitter",    "integer" ],
                26  => [ "Ascend-Dropped-Octets",          "integer" ],
                27  => [ "Ascend-Dropped-Packets",         "integer" ],
                28  => [ "Ascend-Auth-Delay",              "integer" ],
                29  => [ "Ascend-X25-Pad-X3-Profile",      "integer" ],
                30  => [ "Ascend-X25-Pad-X3-Parameters",   "string" ],
                31  => [ "Ascend-Tunnel-VRouter-Name",     "string" ],
                32  => [ "Ascend-X25-Reverse-Charging",    "integer" ],
                33  => [ "Ascend-X25-Nui-Prompt",          "string" ],
                34  => [ "Ascend-X25-Nui-Password-Prompt", "string" ],
                35  => [ "Ascend-X25-Cug",                 "string" ],
                36  => [ "Ascend-X25-Pad-Alias-1",         "string" ],
                37  => [ "Ascend-X25-Pad-Alias-2",         "string" ],
                38  => [ "Ascend-X25-Pad-Alias-3",         "string" ],
                39  => [ "Ascend-X25-X121-Address",        "string" ],
                40  => [ "Ascend-X25-Nui",                 "string" ],
                41  => [ "Ascend-X25-Rpoa",                "string" ],
                42  => [ "Ascend-X25-Pad-Prompt",          "string" ],
                43  => [ "Ascend-X25-Pad-Banner",          "string" ],
                44  => [ "Ascend-X25-Profile-Name",        "string" ],
                45  => [ "Ascend-Recv-Name",               "string" ],
                46  => [ "Ascend-Bi-Directional-Auth",     "integer" ],
                47  => [ "Ascend-MTU",                     "integer" ],
                48  => [ "Ascend-Call-Direction",          "integer" ],
                49  => [ "Ascend-Service-Type",            "integer" ],
                50  => [ "Ascend-Filter-Required",         "integer" ],
                51  => [ "Ascend-Traffic-Shaper",          "integer" ],
                52  => [ "Ascend-Access-Intercept-LEA",    "string" ],
                53  => [ "Ascend-Access-Intercept-Log",    "string" ],
                54  => [ "Ascend-Private-Route-Table-ID",  "string" ],
                55  => [ "Ascend-Private-Route-Required",  "integer" ],
                56  => [ "Ascend-Cache-Refresh",           "integer" ],
                57  => [ "Ascend-Cache-Time",              "integer" ],
                58  => [ "Ascend-Egress-Enabled",          "integer" ],
                59  => [ "Ascend-QOS-Upstream",            "string" ],
                60  => [ "Ascend-QOS-Downstream",          "string" ],
                61  => [ "Ascend-ATM-Connect-Vpi",         "integer" ],
                62  => [ "Ascend-ATM-Connect-Vci",         "integer" ],
                63  => [ "Ascend-ATM-Connect-Group",       "integer" ],
                64  => [ "Ascend-ATM-Group",               "integer" ],
                65  => [ "Ascend-IPX-Header-Compression",  "integer" ],
                66  => [ "Ascend-Calling-Id-Type-Of-Num",  "integer" ],
                67  => [ "Ascend-Calling-Id-Number-Plan",  "integer" ],
                68  => [ "Ascend-Calling-Id-Presentatn",   "integer" ],
                69  => [ "Ascend-Calling-Id-Screening",    "integer" ],
                70  => [ "Ascend-BIR-Enable",              "integer" ],
                71  => [ "Ascend-BIR-Proxy",               "integer" ],
                72  => [ "Ascend-BIR-Bridge-Group",        "integer" ],
                73  => [ "Ascend-IPSEC-Profile",           "string" ],
                74  => [ "Ascend-PPPoE-Enable",            "integer" ],
                75  => [ "Ascend-Bridge-Non-PPPoE",        "integer" ],
                76  => [ "Ascend-ATM-Direct",              "integer" ],
                77  => [ "Ascend-ATM-Direct-Profile",      "string" ],
                78  => [ "Ascend-Client-Primary-WINS",     "ipaddr" ],
                79  => [ "Ascend-Client-Secondary-WINS",   "ipaddr" ],
                80  => [ "Ascend-Client-Assign-WINS",      "integer" ],
                81  => [ "Ascend-Auth-Type",               "integer" ],
                82  => [ "Ascend-Port-Redir-Protocol",     "integer" ],
                83  => [ "Ascend-Port-Redir-Portnum",      "integer" ],
                84  => [ "Ascend-Port-Redir-Server",       "ipaddr" ],
                85  => [ "Ascend-IP-Pool-Chaining",        "integer" ],
                86  => [ "Ascend-Owner-IP-Addr",           "ipaddr" ],
                87  => [ "Ascend-IP-TOS",                  "integer" ],
                88  => [ "Ascend-IP-TOS-Precedence",       "integer" ],
                89  => [ "Ascend-IP-TOS-Apply-To",         "integer" ],
                90  => [ "Ascend-Filter",                  "string" ],
                91  => [ "Ascend-Telnet-Profile",          "string" ],
                92  => [ "Ascend-Dsl-Rate-Type",           "integer" ],
                93  => [ "Ascend-Redirect-Number",         "string" ],
                94  => [ "Ascend-ATM-Vpi",                 "integer" ],
                95  => [ "Ascend-ATM-Vci",                 "integer" ],
                96  => [ "Ascend-Source-IP-Check",         "integer" ],
                97  => [ "Ascend-Dsl-Rate-Mode",           "integer" ],
                98  => [ "Ascend-Dsl-Upstream-Limit",      "integer" ],
                99  => [ "Ascend-Dsl-Downstream-Limit",    "integer" ],
                100 => [ "Ascend-Dsl-CIR-Recv-Limit",      "integer" ],
                101 => [ "Ascend-Dsl-CIR-Xmit-Limit",      "integer" ],
                102 => [ "Ascend-VRouter-Name",            "string" ],
                103 => [ "Ascend-Source-Auth",             "string" ],
                104 => [ "Ascend-Private-Route",           "string" ],
                105 => [ "Ascend-Numbering-Plan-ID",       "integer" ],
                106 => [ "Ascend-FR-Link-Status-DLCI",     "integer" ],
                107 => [ "Ascend-Calling-Subaddress",      "string" ],
                108 => [ "Ascend-Callback-Delay",          "integer" ],
                109 => [ "Ascend-Endpoint-Disc",           "string" ],
                110 => [ "Ascend-Remote-FW",               "string" ],
                111 => [ "Ascend-Multicast-GLeave-Delay",  "integer" ],
                112 => [ "Ascend-CBCP-Enable",             "integer" ],
                113 => [ "Ascend-CBCP-Mode",               "integer" ],
                114 => [ "Ascend-CBCP-Delay",              "integer" ],
                115 => [ "Ascend-CBCP-Trunk-Group",        "integer" ],
                116 => [ "Ascend-Appletalk-Route",         "string" ],
                117 => [ "Ascend-Appletalk-Peer-Mode",     "integer" ],
                118 => [ "Ascend-Route-Appletalk",         "integer" ],
                119 => [ "Ascend-FCP-Parameter",           "string" ],
                120 => [ "Ascend-Modem-PortNo",            "integer" ],
                121 => [ "Ascend-Modem-SlotNo",            "integer" ],
                122 => [ "Ascend-Modem-ShelfNo",           "integer" ],
                123 => [ "Ascend-Call-Attempt-Limit",      "integer" ],
                124 => [ "Ascend-Call-Block-Duration",     "integer" ],
                125 => [ "Ascend-Maximum-Call-Duration",   "integer" ],
                126 => [ "Ascend-Temporary-Rtes",          "integer" ],
                127 => [ "Ascend-Tunneling-Protocol",      "integer" ],
                128 => [ "Ascend-Shared-Profile-Enable",   "integer" ],
                129 => [ "Ascend-Primary-Home-Agent",      "string" ],
                130 => [ "Ascend-Secondary-Home-Agent",    "string" ],
                131 => [ "Ascend-Dialout-Allowed",         "integer" ],
                132 => [ "Ascend-Client-Gateway",          "ipaddr" ],
                133 => [ "Ascend-BACP-Enable",             "integer" ],
                134 => [ "Ascend-DHCP-Maximum-Leases",     "integer" ],
                135 => [ "Ascend-Client-Primary-DNS",      "ipaddr" ],
                136 => [ "Ascend-Client-Secondary-DNS",    "ipaddr" ],
                137 => [ "Ascend-Client-Assign-DNS",       "integer" ],
                138 => [ "Ascend-User-Acct-Type",          "integer" ],
                139 => [ "Ascend-User-Acct-Host",          "ipaddr" ],
                140 => [ "Ascend-User-Acct-Port",          "integer" ],
                141 => [ "Ascend-User-Acct-Key",           "string" ],
                142 => [ "Ascend-User-Acct-Base",          "integer" ],
                143 => [ "Ascend-User-Acct-Time",          "integer" ],
                144 => [ "Ascend-Assign-IP-Client",        "ipaddr" ],
                145 => [ "Ascend-Assign-IP-Server",        "ipaddr" ],
                146 => [ "Ascend-Assign-IP-Global-Pool",   "string" ],
                147 => [ "Ascend-DHCP-Reply",              "integer" ],
                148 => [ "Ascend-DHCP-Pool-Number",        "integer" ],
                149 => [ "Ascend-Expect-Callback",         "integer" ],
                150 => [ "Ascend-Event-Type",              "integer" ],
                151 => [ "Ascend-Session-Svr-Key",         "string" ],
                152 => [ "Ascend-Multicast-Rate-Limit",    "integer" ],
                153 => [ "Ascend-IF-Netmask",              "ipaddr" ],
                154 => [ "Ascend-Remote-Addr",             "ipaddr" ],
                155 => [ "Ascend-Multicast-Client",        "integer" ],
                156 => [ "Ascend-FR-Circuit-Name",         "string" ],
                157 => [ "Ascend-FR-LinkUp",               "integer" ],
                158 => [ "Ascend-FR-Nailed-Grp",           "integer" ],
                159 => [ "Ascend-FR-Type",                 "integer" ],
                160 => [ "Ascend-FR-Link-Mgt",             "integer" ],
                161 => [ "Ascend-FR-N391",                 "integer" ],
                162 => [ "Ascend-FR-DCE-N392",             "integer" ],
                163 => [ "Ascend-FR-DTE-N392",             "integer" ],
                164 => [ "Ascend-FR-DCE-N393",             "integer" ],
                165 => [ "Ascend-FR-DTE-N393",             "integer" ],
                166 => [ "Ascend-FR-T391",                 "integer" ],
                167 => [ "Ascend-FR-T392",                 "integer" ],
                168 => [ "Ascend-Bridge-Address",          "string" ],
                169 => [ "Ascend-TS-Idle-Limit",           "integer" ],
                170 => [ "Ascend-TS-Idle-Mode",            "integer" ],
                171 => [ "Ascend-DBA-Monitor",             "integer" ],
                172 => [ "Ascend-Base-Channel-Count",      "integer" ],
                173 => [ "Ascend-Minimum-Channels",        "integer" ],
                174 => [ "Ascend-IPX-Route",               "string" ],
                175 => [ "Ascend-FT1-Caller",              "integer" ],
                176 => [ "Ascend-Backup",                  "string" ],
                177 => [ "Ascend-Call-Type",               "integer" ],
                178 => [ "Ascend-Group",                   "string" ],
                179 => [ "Ascend-FR-DLCI",                 "integer" ],
                180 => [ "Ascend-FR-Profile-Name",         "string" ],
                181 => [ "Ascend-Ara-PW",                  "string" ],
                182 => [ "Ascend-IPX-Node-Addr",           "string" ],
                183 => [ "Ascend-Home-Agent-IP-Addr",      "ipaddr" ],
                184 => [ "Ascend-Home-Agent-Password",     "string" ],
                185 => [ "Ascend-Home-Network-Name",       "string" ],
                186 => [ "Ascend-Home-Agent-UDP-Port",     "integer" ],
                187 => [ "Ascend-Multilink-ID",            "integer" ],
                188 => [ "Ascend-Num-In-Multilink",        "integer" ],
                189 => [ "Ascend-First-Dest",              "ipaddr" ],
                190 => [ "Ascend-Pre-Input-Octets",        "integer" ],
                191 => [ "Ascend-Pre-Output-Octets",       "integer" ],
                192 => [ "Ascend-Pre-Input-Packets",       "integer" ],
                193 => [ "Ascend-Pre-Output-Packets",      "integer" ],
                194 => [ "Ascend-Maximum-Time",            "integer" ],
                195 => [ "Ascend-Disconnect-Cause",        "integer" ],
                196 => [ "Ascend-Connect-Progress",        "integer" ],
                197 => [ "Ascend-Data-Rate",               "integer" ],
                198 => [ "Ascend-PreSession-Time",         "integer" ],
                199 => [ "Ascend-Token-Idle",              "integer" ],
                200 => [ "Ascend-Token-Immediate",         "integer" ],
                201 => [ "Ascend-Require-Auth",            "integer" ],
                202 => [ "Ascend-Number-Sessions",         "string" ],
                203 => [ "Ascend-Authen-Alias",            "string" ],
                204 => [ "Ascend-Token-Expiry",            "integer" ],
                205 => [ "Ascend-Menu-Selector",           "string" ],
                206 => [ "Ascend-Menu-Item",               "string" ],
                207 => [ "Ascend-PW-Warntime",             "integer" ],
                208 => [ "Ascend-PW-Lifetime",             "integer" ],
                209 => [ "Ascend-IP-Direct",               "ipaddr" ],
                210 => [ "Ascend-PPP-VJ-Slot-Comp",        "integer" ],
                211 => [ "Ascend-PPP-VJ-1172",             "integer" ],
                212 => [ "Ascend-PPP-Async-Map",           "integer" ],
                213 => [ "Ascend-Third-Prompt",            "string" ],
                214 => [ "Ascend-Send-Secret",             "string" ],
                215 => [ "Ascend-Receive-Secret",          "string" ],
                216 => [ "Ascend-IPX-Peer-Mode",           "integer" ],
                217 => [ "Ascend-IP-Pool-Definition",      "string" ],
                218 => [ "Ascend-Assign-IP-Pool",          "integer" ],
                219 => [ "Ascend-FR-Direct",               "integer" ],
                220 => [ "Ascend-FR-Direct-Profile",       "string" ],
                221 => [ "Ascend-FR-Direct-DLCI",          "integer" ],
                222 => [ "Ascend-Handle-IPX",              "integer" ],
                223 => [ "Ascend-Netware-timeout",         "integer" ],
                224 => [ "Ascend-IPX-Alias",               "integer" ],
                225 => [ "Ascend-Metric",                  "integer" ],
                226 => [ "Ascend-PRI-Number-Type",         "integer" ],
                227 => [ "Ascend-Dial-Number",             "string" ],
                228 => [ "Ascend-Route-IP",                "integer" ],
                229 => [ "Ascend-Route-IPX",               "integer" ],
                230 => [ "Ascend-Bridge",                  "integer" ],
                231 => [ "Ascend-Send-Auth",               "integer" ],
                232 => [ "Ascend-Send-Passwd",             "string" ],
                233 => [ "Ascend-Link-Compression",        "integer" ],
                234 => [ "Ascend-Target-Util",             "integer" ],
                235 => [ "Ascend-Maximum-Channels",        "integer" ],
                236 => [ "Ascend-Inc-Channel-Count",       "integer" ],
                237 => [ "Ascend-Dec-Channel-Count",       "integer" ],
                238 => [ "Ascend-Seconds-Of-History",      "integer" ],
                239 => [ "Ascend-History-Weigh-Type",      "integer" ],
                240 => [ "Ascend-Add-Seconds",             "integer" ],
                241 => [ "Ascend-Remove-Seconds",          "integer" ],
                242 => [ "Ascend-Data-Filter",             "abinary" ],
                243 => [ "Ascend-Call-Filter",             "abinary" ],
                244 => [ "Ascend-Idle-Limit",              "integer" ],
                245 => [ "Ascend-Preempt-Limit",           "integer" ],
                246 => [ "Ascend-Callback",                "integer" ],
                247 => [ "Ascend-Data-Svc",                "integer" ],
                248 => [ "Ascend-Force-56",                "integer" ],
                249 => [ "Ascend-Billing-Number",          "string" ],
                250 => [ "Ascend-Call-By-Call",            "integer" ],
                251 => [ "Ascend-Transit-Number",          "string" ],
                252 => [ "Ascend-Host-Info",               "string" ],
                253 => [ "Ascend-PPP-Address",             "ipaddr" ],
                254 => [ "Ascend-MPP-Idle-Percent",        "integer" ],
                255 => [ "Ascend-Xmit-Rate",               "integer" ],
            },
            562 => {
                110 => [ "Nortel-User-Role",                     "string" ],
                166 => [ "Nortel-Privilege-Level",               "integer" ],
                170 => [ "Fabric-Attach-VLAN-Create",            "integer" ],
                171 => [ "Fabric-Attach-VLAN-ISID",              "string" ],
                172 => [ "Fabric-Attach-VLAN-PVID",              "integer" ],
                180 => [ "Fabric-Attach-Switch-Mode",            "integer" ],
                181 => [ "Fabric-Attach-Client-Id",              "string" ],
                182 => [ "Fabric-Attach-Client-Type",            "string" ],
                183 => [ "Fabric-Attach-Client-PSK",             "integer" ],
                184 => [ "Fabric-Attach-Client-Trust",           "integer" ],
                185 => [ "Fabric-Attach-Client-Trusted-Binding", "string" ],
                186 => [ "Fabric-Attach-Service-Request",        "string" ],
                200 => [ "Passport-Command-Scope",               "integer" ],
                201 => [ "Passport-Command-Impact",              "integer" ],
                202 => [ "Passport-Customer-Identifier",         "integer" ],
                203 => [ "Passport-Allowed-Access",              "integer" ],
                204 => [ "Passport-AllowedOut-Access",           "integer" ],
                205 => [ "Passport-Login-Directory",             "string" ],
                206 => [ "Passport-Timeout-Protocol",            "integer" ],
                207 => [ "Passport-Role",                        "string" ],
            },
            594 => { 1 => [ "SID-Auth", "string" ] },
            637 => {
                1536 => [ "A-AL-Maintenance",           "integer" ],
                1537 => [ "A-AL-Provisioning",          "integer" ],
                1538 => [ "A-AL-TL1-Security",          "integer" ],
                1539 => [ "A-AL-Test",                  "integer" ],
                1792 => [ "A-ESAM-VRF-Name",            "string" ],
                1793 => [ "A-ESAM-Vlan-Id",             "integer" ],
                1794 => [ "A-ESAM-QOS-Profile-Name",    "string" ],
                1795 => [ "A-ESAM-QOS-Params",          "string" ],
                1796 => [ "A-ESAM-Termination-Cause",   "integer" ],
                1797 => [ "A-AL-MAINTENANCE-BACKWARD",  "integer" ],
                1798 => [ "A-AL-PROVISIONING-BACKWARD", "integer" ],
                1799 => [ "A-AL-TL1-SECURITY-BACKWARD", "integer" ],
                1800 => [ "A-AL-TEST-BACKWARD",         "integer" ],
                1801 => [ "A-AL-AAA",                   "integer" ],
                1802 => [ "A-AL-ATM",                   "integer" ],
                1803 => [ "A-AL-Alarm",                 "integer" ],
                1804 => [ "A-AL-DHCP",                  "integer" ],
                1805 => [ "A-AL-EQP",                   "integer" ],
                1806 => [ "A-AL-IGMP",                  "integer" ],
                1807 => [ "A-AL-CPEProxy",              "integer" ],
                1808 => [ "A-AL-IP",                    "integer" ],
                1809 => [ "A-AL-PPPoE",                 "integer" ],
                1810 => [ "A-AL-QoS",                   "integer" ],
                1811 => [ "A-AL-SWMgt",                 "integer" ],
                1812 => [ "A-AL-Transport",             "integer" ],
                1813 => [ "A-AL-VLAN",                  "integer" ],
                1814 => [ "A-AL-XDSL",                  "integer" ],
                1815 => [ "A-AL-Security",              "integer" ],
                1816 => [ "A-AL-Cluster",               "integer" ],
                1817 => [ "A-AL-Prompt",                "string" ],
                1818 => [ "A-AL-Pwd-Timeout",           "integer" ],
                1819 => [ "A-AL-Description",           "string" ],
                1820 => [ "A-AL-SLOT-NUMBERING",        "integer" ],
            },
            664 => {
                100 => [ "Adtran-AP-Name",     "string" ],
                101 => [ "Adtran-AP-IP",       "ipaddr" ],
                102 => [ "Adtran-AP-Template", "string" ],
                103 => [ "Adtran-SSID",        "string" ],
                104 => [ "Adtran-Role",        "string" ],
            },
            674 => {
                1 => [ "DellEMC-AVpair",     "string" ],
                2 => [ "DellEMC-Group-Name", "string" ],
            },
            762 => {
                151 => [ "KarlNet-TurboCell-Name",    "string" ],
                152 => [ "KarlNet-TurboCell-TxRate",  "integer" ],
                153 => [ "KarlNet-TurboCell-OpState", "integer" ],
                154 => [ "KarlNet-TurboCell-OpMode",  "integer" ],
            },
            800 => {
                1   => [ "Xylan-Auth-Group",           "integer" ],
                2   => [ "Xylan-Slot-Port",            "string" ],
                3   => [ "Xylan-Time-of-Day",          "string" ],
                4   => [ "Xylan-Client-IP-Addr",       "ipaddr" ],
                5   => [ "Xylan-Group-Desc",           "string" ],
                6   => [ "Xylan-Port-Desc",            "string" ],
                7   => [ "Xylan-Profil-Numb",          "integer" ],
                8   => [ "Xylan-Auth-Group-Protocol",  "string" ],
                9   => [ "Xylan-Asa-Access",           "string" ],
                10  => [ "Xylan-End-User-Profile",     "integer" ],
                12  => [ "Xylan-Primary-Home-Agent",   "string" ],
                13  => [ "Xylan-Secondary-Home-Agent", "string" ],
                14  => [ "Xylan-Home-Agent-Password",  "string" ],
                15  => [ "Xylan-Home-Network-Name",    "string" ],
                16  => [ "Xylan-Access-Priv",          "integer" ],
                20  => [ "Xylan-Nms-Group",            "string" ],
                21  => [ "Xylan-Nms-First-Name",       "string" ],
                22  => [ "Xylan-Nms-Last-Name",        "string" ],
                23  => [ "Xylan-Nms-Description",      "string" ],
                33  => [ "Xylan-Acce-Priv-R1",         "octets" ],
                34  => [ "Xylan-Acce-Priv-R2",         "octets" ],
                35  => [ "Xylan-Acce-Priv-W1",         "octets" ],
                36  => [ "Xylan-Acce-Priv-W2",         "octets" ],
                37  => [ "Xylan-Acce-Priv-G1",         "octets" ],
                38  => [ "Xylan-Acce-Priv-G2",         "octets" ],
                39  => [ "Xylan-Acce-Priv-F-R1",       "octets" ],
                40  => [ "Xylan-Acce-Priv-F-R2",       "octets" ],
                41  => [ "Xylan-Acce-Priv-F-W1",       "octets" ],
                42  => [ "Xylan-Acce-Priv-F-W2",       "octets" ],
                100 => [ "Xylan-Policy-List",          "string" ],
                101 => [ "Xylan-Redirect-Url",         "string" ],
                152 => [ "Xylan-Device-Name",          "string" ],
                153 => [ "Xylan-Device-Location",      "string" ],
            },
            831 => {
                1   => [ "ALU-AAA-Access-Rule",                "string" ],
                2   => [ "ALU-AAA-AV-Pair",                    "string" ],
                3   => [ "ALU-AAA-GSM-Triplets-Needed",        "integer" ],
                4   => [ "ALU-AAA-GSM-Triplet",                "octets" ],
                5   => [ "ALU-AAA-AKA-Quintets-Needed",        "integer" ],
                6   => [ "ALU-AAA-AKA-Quintet",                "octets" ],
                7   => [ "ALU-AAA-AKA-RAND",                   "octets" ],
                8   => [ "ALU-AAA-AKA-AUTS",                   "octets" ],
                9   => [ "ALU-AAA-Service-Profile",            "string" ],
                10  => [ "ALU-AAA-Lawful-Intercept-Status",    "byte" ],
                11  => [ "ALU-AAA-DF-CC-Address",              "ipaddr" ],
                12  => [ "ALU-AAA-DF-CC-Port",                 "short" ],
                13  => [ "ALU-AAA-Client-Program",             "string" ],
                14  => [ "ALU-AAA-Client-Error-Action",        "integer" ],
                15  => [ "ALU-AAA-Client-OS",                  "string" ],
                16  => [ "ALU-AAA-Client-Version",             "string" ],
                17  => [ "ALU-AAA-Nonce",                      "octets" ],
                18  => [ "ALU-AAA-Femto-Public-Key-Hash",      "octets" ],
                19  => [ "ALU-AAA-Femto-Associated-User-Name", "string" ],
                100 => [ "ALU-AAA-String-0",                   "string" ],
                101 => [ "ALU-AAA-String-1",                   "string" ],
                102 => [ "ALU-AAA-String-2",                   "string" ],
                103 => [ "ALU-AAA-String-3",                   "string" ],
                104 => [ "ALU-AAA-Integer-0",                  "integer" ],
                105 => [ "ALU-AAA-Integer-1",                  "integer" ],
                106 => [ "ALU-AAA-Integer-2",                  "integer" ],
                107 => [ "ALU-AAA-Integer-3",                  "integer" ],
                112 => [ "ALU-AAA-Value-0",                    "octets" ],
                113 => [ "ALU-AAA-Value-1",                    "octets" ],
                114 => [ "ALU-AAA-Value-2",                    "octets" ],
                115 => [ "ALU-AAA-Value-3",                    "octets" ],
                116 => [ "ALU-AAA-Key-0",                      "octets" ],
                117 => [ "ALU-AAA-Key-1",                      "octets" ],
                118 => [ "ALU-AAA-Key-2",                      "octets" ],
                119 => [ "ALU-AAA-Key-3",                      "octets" ],
                120 => [ "ALU-AAA-Opaque-0",                   "octets" ],
                121 => [ "ALU-AAA-Opaque-1",                   "octets" ],
                122 => [ "ALU-AAA-Opaque-2",                   "octets" ],
                123 => [ "ALU-AAA-Opaque-3",                   "octets" ],
                124 => [ "ALU-AAA-Eval-0",                     "string" ],
                125 => [ "ALU-AAA-Eval-1",                     "string" ],
                126 => [ "ALU-AAA-Eval-2",                     "string" ],
                127 => [ "ALU-AAA-Eval-3",                     "string" ],
                128 => [ "ALU-AAA-Exec-0",                     "string" ],
                129 => [ "ALU-AAA-Exec-1",                     "string" ],
                130 => [ "ALU-AAA-Exec-2",                     "string" ],
                131 => [ "ALU-AAA-Exec-3",                     "string" ],
                199 => [ "ALU-AAA-Original-Receipt-Time",      "octets" ],
                201 => [ "ALU-AAA-Reply-Message",              "string" ],
                202 => [ "ALU-AAA-Called-Station-Id",          "string" ],
                203 => [ "ALU-AAA-NAS-IP-Address",             "ipaddr" ],
                204 => [ "ALU-AAA-NAS-Port",                   "integer" ],
                205 => [ "ALU-AAA-Old-State",                  "string" ],
                206 => [ "ALU-AAA-New-State",                  "string" ],
                207 => [ "ALU-AAA-Event",                      "string" ],
                208 => [ "ALU-AAA-Old-Timestamp",              "date" ],
                209 => [ "ALU-AAA-New-Timestamp",              "date" ],
                210 => [ "ALU-AAA-Delta-Session",              "integer" ],
                211 => [ "ALU-AAA-Civic-Location",             "octets" ],
                212 => [ "ALU-AAA-Geospatial-Location",        "octets" ],
            },
            838 => {
                1 => [ "Xedia-DNS-Server",              "ipaddr" ],
                2 => [ "Xedia-NetBios-Server",          "ipaddr" ],
                3 => [ "Xedia-Address-Pool",            "string" ],
                4 => [ "Xedia-PPP-Echo-Interval",       "integer" ],
                5 => [ "Xedia-SSH-Privileges",          "integer" ],
                6 => [ "Xedia-Client-Access-Network",   "string" ],
                7 => [ "Xedia-Client-Firewall-Setting", "integer" ],
                8 => [ "Xedia-Save-Password",           "integer" ],
            },
            841 => {
                4  => [ "Proxim_E1_VLAN_MODE",           "integer" ],
                5  => [ "Proxim_SU_VLAN_NAME",           "string" ],
                6  => [ "Proxim_E1_Access_VLAN_ID",      "integer" ],
                7  => [ "Proxim_E1_Access_VLAN_Pri",     "integer" ],
                8  => [ "Proxim_Mgmt_VLAN_ID",           "integer" ],
                9  => [ "Proxim_Mgmt_VLAN_Pri",          "integer" ],
                10 => [ "Proxim_E1_TrunkID_01",          "integer" ],
                11 => [ "Proxim_E1_TrunkID_02",          "integer" ],
                12 => [ "Proxim_E1_TrunkID_03",          "integer" ],
                13 => [ "Proxim_E1_TrunkID_04",          "integer" ],
                14 => [ "Proxim_E1_TrunkID_05",          "integer" ],
                15 => [ "Proxim_E1_TrunkID_06",          "integer" ],
                16 => [ "Proxim_E1_TrunkID_07",          "integer" ],
                17 => [ "Proxim_E1_TrunkID_08",          "integer" ],
                18 => [ "Proxim_E1_TrunkID_09",          "integer" ],
                19 => [ "Proxim_E1_TrunkID_10",          "integer" ],
                20 => [ "Proxim_E1_TrunkID_11",          "integer" ],
                21 => [ "Proxim_E1_TrunkID_12",          "integer" ],
                22 => [ "Proxim_E1_TrunkID_13",          "integer" ],
                23 => [ "Proxim_E1_TrunkID_14",          "integer" ],
                24 => [ "Proxim_E1_TrunkID_15",          "integer" ],
                25 => [ "Proxim_E1_TrunkID_16",          "integer" ],
                26 => [ "Proxim_SU_VLAN_Table_Status",   "integer" ],
                32 => [ "Proxim_Service_VLAN_ID",        "integer" ],
                33 => [ "Proxim_Service_VLAN_Pri",       "integer" ],
                34 => [ "Proxim_QoS_Class_Index",        "integer" ],
                35 => [ "Proxim_QoS_Class_SU_Status",    "integer" ],
                40 => [ "Proxim_E2_VLAN_MODE",           "integer" ],
                41 => [ "Proxim_E2_Access_VLAN_ID",      "integer" ],
                42 => [ "Proxim_E2_Access_VLAN_Pri",     "integer" ],
                43 => [ "Proxim_E2_TrunkID_01",          "integer" ],
                44 => [ "Proxim_E2_TrunkID_02",          "integer" ],
                45 => [ "Proxim_E2_TrunkID_03",          "integer" ],
                46 => [ "Proxim_E2_TrunkID_04",          "integer" ],
                47 => [ "Proxim_E2_TrunkID_05",          "integer" ],
                48 => [ "Proxim_E2_TrunkID_06",          "integer" ],
                49 => [ "Proxim_E2_TrunkID_07",          "integer" ],
                50 => [ "Proxim_E2_TrunkID_08",          "integer" ],
                51 => [ "Proxim_E2_TrunkID_09",          "integer" ],
                52 => [ "Proxim_E2_TrunkID_10",          "integer" ],
                53 => [ "Proxim_E2_TrunkID_11",          "integer" ],
                54 => [ "Proxim_E2_TrunkID_12",          "integer" ],
                55 => [ "Proxim_E2_TrunkID_13",          "integer" ],
                56 => [ "Proxim_E2_TrunkID_14",          "integer" ],
                57 => [ "Proxim_E2_TrunkID_15",          "integer" ],
                58 => [ "Proxim_E2_TrunkID_16",          "integer" ],
                59 => [ "Proxim_QinQ_Status",            "integer" ],
                60 => [ "Proxim_Service_VLAN_TPID",      "integer" ],
                61 => [ "Proxim_E1_Port_VLAN_ID",        "integer" ],
                62 => [ "Proxim_E1_Port_VLAN_Pri",       "integer" ],
                63 => [ "Proxim_E1_Allow_Untag",         "integer" ],
                64 => [ "Proxim_E2_Port_VLAN_ID",        "integer" ],
                65 => [ "Proxim_E2_Port_VLAN_Pri",       "integer" ],
                66 => [ "Proxim_E2_Allow_Untag",         "integer" ],
                68 => [ "Proxim_E1_SU_Allow_Untag_Mgmt", "integer" ],
                69 => [ "Proxim_E2_SU_Allow_Untag_Mgmt", "integer" ],
            },
            850 => {
                1 => [ "TrippLite-Authorization", "string" ],
                2 => [ "TrippLite-Outlet-Realms", "string" ],
                3 => [ "TrippLite-Message",       "string" ],
                4 => [ "TrippLite-User-Role",     "string" ],
            },
            890 => {
                3   => [ "Zyxel-Privilege-AVPair",      "string" ],
                192 => [ "Zyxel-Callback-Option",       "integer" ],
                193 => [ "Zyxel-Callback-Phone-Source", "integer" ],
            },
            969 => {
                10 => [ "UserLogon-Uid",                 "integer" ],
                11 => [ "UserLogon-Gid",                 "integer" ],
                12 => [ "UserLogon-HomeDir",             "string" ],
                13 => [ "UserLogon-Type",                "integer" ],
                14 => [ "UserLogon-QuotaBytes",          "integer" ],
                15 => [ "UserLogon-QuotaFiles",          "integer" ],
                16 => [ "UserLogon-Shell",               "string" ],
                17 => [ "UserLogon-Restriction",         "integer" ],
                18 => [ "UserLogon-GroupNames",          "string" ],
                19 => [ "UserLogon-DriveNames",          "string" ],
                20 => [ "UserLogon-UserDescription",     "string" ],
                21 => [ "UserLogon-UserFullName",        "string" ],
                22 => [ "UserLogon-UserDomain",          "string" ],
                23 => [ "UserLogon-LogonTask",           "string" ],
                24 => [ "UserLogon-LogoffTask",          "string" ],
                25 => [ "UserLogon-Expiration",          "string" ],
                26 => [ "UserLogon-UserProfile",         "string" ],
                50 => [ "UserLogon-Acct-TerminateCause", "string" ],
            },
            1076 => {
                1 => [ "Surfnet-AVPair",             "string" ],
                2 => [ "Surfnet-Service-Identifier", "string" ],
                3 => [ "Surfnet-Service-Provider",   "string" ],
            },
            1195 => {
                100 => [ "ITK-Auth-Serv-IP",           "ipaddr" ],
                101 => [ "ITK-Auth-Serv-Prot",         "integer" ],
                102 => [ "ITK-Provider-Id",            "integer" ],
                103 => [ "ITK-Usergroup",              "integer" ],
                104 => [ "ITK-Banner",                 "string" ],
                105 => [ "ITK-Username-Prompt",        "string" ],
                106 => [ "ITK-Password-Prompt",        "string" ],
                107 => [ "ITK-Welcome-Message",        "string" ],
                108 => [ "ITK-Prompt",                 "string" ],
                109 => [ "ITK-IP-Pool",                "integer" ],
                110 => [ "ITK-Tunnel-IP",              "ipaddr" ],
                111 => [ "ITK-Tunnel-Prot",            "integer" ],
                112 => [ "ITK-Acct-Serv-IP",           "ipaddr" ],
                113 => [ "ITK-Acct-Serv-Prot",         "integer" ],
                114 => [ "ITK-Filter-Rule",            "string" ],
                115 => [ "ITK-Channel-Binding",        "integer" ],
                116 => [ "ITK-Start-Delay",            "integer" ],
                117 => [ "ITK-NAS-Name",               "string" ],
                118 => [ "ITK-ISDN-Prot",              "integer" ],
                119 => [ "ITK-PPP-Auth-Type",          "integer" ],
                120 => [ "ITK-Dialout-Type",           "integer" ],
                121 => [ "ITK-Ftp-Auth-IP",            "ipaddr" ],
                122 => [ "ITK-Users-Default-Entry",    "string" ],
                123 => [ "ITK-Users-Default-Pw",       "string" ],
                124 => [ "ITK-Auth-Req-Type",          "string" ],
                125 => [ "ITK-Modem-Pool-Id",          "integer" ],
                126 => [ "ITK-Modem-Init-String",      "string" ],
                127 => [ "ITK-PPP-Client-Server-Mode", "integer" ],
                128 => [ "ITK-PPP-Compression-Prot",   "string" ],
                129 => [ "ITK-Username",               "string" ],
                130 => [ "ITK-Dest-No",                "string" ],
                131 => [ "ITK-DDI",                    "string" ],
            },
            1271 => {
                1   => [ "Ciena-CN4200-Priv-Level", "integer" ],
                10  => [ "Ciena-CES-Priv-Level",    "integer" ],
                11  => [ "Ciena-CES-NACM-Groups",   "string" ],
                220 => [ "Ciena-BP-Role",           "string" ],
                240 => [ "Ciena-NCS-Role",          "integer" ],
                250 => [ "Ciena-OC-Role",           "string" ],
                253 => [ "Ciena-CS-Client-IP",      "ipaddr" ],
                254 => [ "Ciena-CS-Acc-Level",      "integer" ],
                255 => [ "Ciena-CS-Priv-Level",     "integer" ],
            },
            1431 => {
                1   => [ "Telkom-Access-Type",   "string" ],
                2   => [ "Telkom-Service-Type",  "string" ],
                200 => [ "Telkom-Degrade-Token", "string" ],
            },
            1584 => {
                28  => [ "Annex-Filter",                   "string" ],
                29  => [ "Annex-CLI-Command",              "string" ],
                30  => [ "Annex-CLI-Filter",               "string" ],
                31  => [ "Annex-Host-Restrict",            "string" ],
                32  => [ "Annex-Host-Allow",               "string" ],
                33  => [ "Annex-Product-Name",             "string" ],
                34  => [ "Annex-SW-Version",               "string" ],
                35  => [ "Annex-Local-IP-Address",         "ipaddr" ],
                36  => [ "Annex-Callback-Portlist",        "integer" ],
                37  => [ "Annex-Sec-Profile-Index",        "integer" ],
                38  => [ "Annex-Tunnel-Authen-Type",       "integer" ],
                39  => [ "Annex-Tunnel-Authen-Mode",       "integer" ],
                40  => [ "Annex-Authen-Servers",           "string" ],
                41  => [ "Annex-Acct-Servers",             "string" ],
                42  => [ "Annex-User-Server-Location",     "integer" ],
                43  => [ "Annex-Local-Username",           "string" ],
                44  => [ "Annex-System-Disc-Reason",       "integer" ],
                45  => [ "Annex-Modem-Disc-Reason",        "integer" ],
                46  => [ "Annex-Disconnect-Reason",        "integer" ],
                47  => [ "Annex-Addr-Resolution-Protocol", "integer" ],
                48  => [ "Annex-Addr-Resolution-Servers",  "string" ],
                49  => [ "Annex-Domain-Name",              "string" ],
                50  => [ "Annex-Transmit-Speed",           "integer" ],
                51  => [ "Annex-Receive-Speed",            "integer" ],
                52  => [ "Annex-Input-Filter",             "string" ],
                53  => [ "Annex-Output-Filter",            "string" ],
                54  => [ "Annex-Primary-DNS-Server",       "ipaddr" ],
                55  => [ "Annex-Secondary-DNS-Server",     "ipaddr" ],
                56  => [ "Annex-Primary-NBNS-Server",      "ipaddr" ],
                57  => [ "Annex-Secondary-NBNS-Server",    "ipaddr" ],
                58  => [ "Annex-Syslog-Tap",               "integer" ],
                59  => [ "Annex-Keypress-Timeout",         "integer" ],
                60  => [ "Annex-Unauthenticated-Time",     "integer" ],
                61  => [ "Annex-Re-CHAP-Timeout",          "integer" ],
                62  => [ "Annex-MRRU",                     "integer" ],
                63  => [ "Annex-EDO",                      "string" ],
                64  => [ "Annex-PPP-Trace-Level",          "integer" ],
                65  => [ "Annex-Pre-Input-Octets",         "integer" ],
                66  => [ "Annex-Pre-Output-Octets",        "integer" ],
                67  => [ "Annex-Pre-Input-Packets",        "integer" ],
                68  => [ "Annex-Pre-Output-Packets",       "integer" ],
                69  => [ "Annex-Connect-Progress",         "integer" ],
                73  => [ "Annex-Multicast-Rate-Limit",     "integer" ],
                74  => [ "Annex-Maximum-Call-Duration",    "integer" ],
                75  => [ "Annex-Multilink-Id",             "integer" ],
                76  => [ "Annex-Num-In-Multilink",         "integer" ],
                79  => [ "Annex-Secondary-Srv-Endpoint",   "string" ],
                80  => [ "Annex-Gwy-Selection-Mode",       "integer" ],
                81  => [ "Annex-Logical-Channel-Number",   "integer" ],
                82  => [ "Annex-Wan-Number",               "integer" ],
                83  => [ "Annex-Port",                     "integer" ],
                85  => [ "Annex-Pool-Id",                  "integer" ],
                86  => [ "Annex-Compression-Protocol",     "string" ],
                87  => [ "Annex-Transmitted-Packets",      "integer" ],
                88  => [ "Annex-Retransmitted-Packets",    "integer" ],
                89  => [ "Annex-Signal-to-Noise-Ratio",    "integer" ],
                90  => [ "Annex-Retrain-Requests-Sent",    "integer" ],
                91  => [ "Annex-Retrain-Requests-Rcvd",    "integer" ],
                92  => [ "Annex-Rate-Reneg-Req-Sent",      "integer" ],
                93  => [ "Annex-Rate-Reneg-Req-Rcvd",      "integer" ],
                94  => [ "Annex-Begin-Receive-Line-Level", "integer" ],
                95  => [ "Annex-End-Receive-Line-Level",   "integer" ],
                96  => [ "Annex-Begin-Modulation",         "string" ],
                97  => [ "Annex-Error-Correction-Prot",    "string" ],
                98  => [ "Annex-End-Modulation",           "string" ],
                100 => [ "Annex-User-Level",               "integer" ],
                101 => [ "Annex-Audit-Level",              "integer" ],
                102 => [ "CES-Group",                      "string" ],
                192 => [ "Passport-Access-Priority",       "integer" ],
                193 => [ "Annex-Cli-Commands",             "string" ],
                194 => [ "Annex-Command-Access",           "integer" ],
                195 => [ "Commands",                       "string" ],
            },
            1588 => {
                1 => [ "Brocade-Auth-Role",         "string" ],
                2 => [ "Brocade-AVPairs1",          "string" ],
                3 => [ "Brocade-AVPairs2",          "string" ],
                4 => [ "Brocade-AVPairs3",          "string" ],
                5 => [ "Brocade-AVPairs4",          "string" ],
                6 => [ "Brocade-Passwd-ExpiryDate", "string" ],
                7 => [ "Brocade-Passwd-WarnPeriod", "string" ],
            },
            1768 => {
                16  => [ "Patton-Protocol",                       "string" ],
                17  => [ "Patton-Group",                          "string" ],
                18  => [ "Patton-Web-Privilege-Level",            "string" ],
                32  => [ "Patton-Setup-Time",                     "string" ],
                33  => [ "Patton-Connect-Time",                   "string" ],
                34  => [ "Patton-Disconnect-Time",                "string" ],
                35  => [ "Patton-Disconnect-Cause",               "integer" ],
                36  => [ "Patton-Disconnect-Source",              "string" ],
                37  => [ "Patton-Disconnect-Reason",              "string" ],
                48  => [ "Patton-Called-Unique-Id",               "string" ],
                49  => [ "Patton-Called-IP-Address",              "ipaddr" ],
                50  => [ "Patton-Called-Numbering-Plan",          "string" ],
                51  => [ "Patton-Called-Type-Of-Number",          "string" ],
                52  => [ "Patton-Called-Name",                    "string" ],
                53  => [ "Patton-Called-Station-Id",              "string" ],
                64  => [ "Patton-Called-Rx-Octets",               "integer" ],
                65  => [ "Patton-Called-Tx-Octets",               "integer" ],
                66  => [ "Patton-Called-Rx-Packets",              "integer" ],
                67  => [ "Patton-Called-Tx-Packets",              "integer" ],
                68  => [ "Patton-Called-Rx-Lost-Packets",         "integer" ],
                69  => [ "Patton-Called-Tx-Lost-Packets",         "integer" ],
                70  => [ "Patton-Called-Rx-Jitter",               "integer" ],
                71  => [ "Patton-Called-Tx-Jitter",               "integer" ],
                72  => [ "Patton-Called-Codec",                   "string" ],
                73  => [ "Patton-Called-Remote-Ip",               "integer" ],
                74  => [ "Patton-Called-Remote-Udp-Port",         "integer" ],
                75  => [ "Patton-Called-Local-Udp-Port",          "integer" ],
                76  => [ "Patton-Called-Qos",                     "integer" ],
                77  => [ "Patton-Called-MOS",                     "integer" ],
                78  => [ "Patton-Called-Round-Trip-Time",         "integer" ],
                80  => [ "Patton-Calling-Unique-Id",              "string" ],
                81  => [ "Patton-Calling-IP-Address",             "ipaddr" ],
                82  => [ "Patton-Calling-Numbering-Plan",         "string" ],
                83  => [ "Patton-Calling-Type-Of-Number",         "string" ],
                84  => [ "Patton-Calling-Name",                   "string" ],
                85  => [ "Patton-Calling-Station-Id",             "string" ],
                88  => [ "Patton-Calling-Presentation-Indicator", "string" ],
                89  => [ "Patton-Calling-Screening-Indicator",    "string" ],
                96  => [ "Patton-Calling-Rx-Octets",              "integer" ],
                97  => [ "Patton-Calling-Tx-Octets",              "integer" ],
                98  => [ "Patton-Calling-Rx-Packets",             "integer" ],
                99  => [ "Patton-Calling-Tx-Packets",             "integer" ],
                100 => [ "Patton-Calling-Lost-Tx-Packets",        "integer" ],
                101 => [ "Patton-Calling-Lost-Rx-Packets",        "integer" ],
                102 => [ "Patton-Calling-Rx-Jitter",              "integer" ],
                103 => [ "Patton-Calling-Tx-Jitter",              "integer" ],
                104 => [ "Patton-Calling-Codec",                  "string" ],
                105 => [ "Patton-Calling-Remote-Ip",              "integer" ],
                106 => [ "Patton-Calling-Remote-Udp-Port",        "integer" ],
                107 => [ "Patton-Calling-Local-Udp-Port",         "integer" ],
                108 => [ "Patton-Calling-Qos",                    "integer" ],
                109 => [ "Patton-Calling-MOS",                    "integer" ],
                110 => [ "Patton-Calling-Round-Trip-Time",        "integer" ],
            },
            1872 => {
                1  => [ "Alteon-Group-Mapping",         "string" ],
                3  => [ "Alteon-VPN-Id",                "integer" ],
                4  => [ "Alteon-Client-IP-Address",     "ipaddr" ],
                5  => [ "Alteon-Client-Netmask",        "ipaddr" ],
                6  => [ "Alteon-Primary-NBNS-Server",   "ipaddr" ],
                7  => [ "Alteon-Secondary-NBNS-Server", "ipaddr" ],
                8  => [ "Alteon-Primary-DNS-Server",    "ipaddr" ],
                9  => [ "Alteon-Secondary-DNS-Server",  "ipaddr" ],
                10 => [ "Alteon-Domain-Name",           "string" ],
                26 => [ "Alteon-Service-Type",          "integer" ],
            },
            1916 => {
                201 => [ "Extreme-CLI-Authorization",      "integer" ],
                202 => [ "Extreme-Shell-Command",          "string" ],
                203 => [ "Extreme-Netlogin-Vlan",          "string" ],
                204 => [ "Extreme-Netlogin-Url",           "string" ],
                205 => [ "Extreme-Netlogin-Url-Desc",      "string" ],
                206 => [ "Extreme-Netlogin-Only",          "integer" ],
                208 => [ "Extreme-User-Location",          "string" ],
                209 => [ "Extreme-Netlogin-Vlan-Tag",      "integer" ],
                211 => [ "Extreme-Netlogin-Extended-Vlan", "string" ],
                212 => [ "Extreme-Security-Profile",       "string" ],
                213 => [ "Extreme-VM-Name",                "string" ],
                214 => [ "Extreme-VM-VPP-Name",            "string" ],
                215 => [ "Extreme-VM-IP-Addr",             "ipaddr" ],
                216 => [ "Extreme-VM-VLAN-ID",             "integer" ],
                217 => [ "Extreme-VM-VR-Name",             "string" ],
            },
            1958 => {
                5  => [ "RedCreek-Tunneled-IP-Addr",      "ipaddr" ],
                6  => [ "RedCreek-Tunneled-IP-Netmask",   "ipaddr" ],
                7  => [ "RedCreek-Tunneled-Gateway",      "ipaddr" ],
                8  => [ "RedCreek-Tunneled-DNS-Server",   "string" ],
                9  => [ "RedCreek-Tunneled-WINS-Server1", "string" ],
                10 => [ "RedCreek-Tunneled-WINS-Server2", "string" ],
                11 => [ "RedCreek-Tunneled-HostName",     "string" ],
                12 => [ "RedCreek-Tunneled-DomainName",   "string" ],
                13 => [ "RedCreek-Tunneled-Search-List",  "string" ],
            },
            1966 => {
                99  => [ "Perle-Clustered-Port-Access", "integer" ],
                100 => [ "Perle-User-Level",            "integer" ],
                101 => [ "Perle-Line-Access-Port-1",    "integer" ],
                102 => [ "Perle-Line-Access-Port-2",    "integer" ],
                103 => [ "Perle-Line-Access-Port-3",    "integer" ],
                104 => [ "Perle-Line-Access-Port-4",    "integer" ],
                105 => [ "Perle-Line-Access-Port-5",    "integer" ],
                106 => [ "Perle-Line-Access-Port-6",    "integer" ],
                107 => [ "Perle-Line-Access-Port-7",    "integer" ],
                108 => [ "Perle-Line-Access-Port-8",    "integer" ],
                109 => [ "Perle-Line-Access-Port-9",    "integer" ],
                110 => [ "Perle-Line-Access-Port-10",   "integer" ],
                111 => [ "Perle-Line-Access-Port-11",   "integer" ],
                112 => [ "Perle-Line-Access-Port-12",   "integer" ],
                113 => [ "Perle-Line-Access-Port-13",   "integer" ],
                114 => [ "Perle-Line-Access-Port-14",   "integer" ],
                115 => [ "Perle-Line-Access-Port-15",   "integer" ],
                116 => [ "Perle-Line-Access-Port-16",   "integer" ],
                117 => [ "Perle-Line-Access-Port-17",   "integer" ],
                118 => [ "Perle-Line-Access-Port-18",   "integer" ],
                119 => [ "Perle-Line-Access-Port-19",   "integer" ],
                120 => [ "Perle-Line-Access-Port-20",   "integer" ],
                121 => [ "Perle-Line-Access-Port-21",   "integer" ],
                122 => [ "Perle-Line-Access-Port-22",   "integer" ],
                123 => [ "Perle-Line-Access-Port-23",   "integer" ],
                124 => [ "Perle-Line-Access-Port-24",   "integer" ],
                125 => [ "Perle-Line-Access-Port-25",   "integer" ],
                126 => [ "Perle-Line-Access-Port-26",   "integer" ],
                127 => [ "Perle-Line-Access-Port-27",   "integer" ],
                128 => [ "Perle-Line-Access-Port-28",   "integer" ],
                129 => [ "Perle-Line-Access-Port-29",   "integer" ],
                130 => [ "Perle-Line-Access-Port-30",   "integer" ],
                131 => [ "Perle-Line-Access-Port-31",   "integer" ],
                132 => [ "Perle-Line-Access-Port-32",   "integer" ],
                133 => [ "Perle-Line-Access-Port-33",   "integer" ],
                134 => [ "Perle-Line-Access-Port-34",   "integer" ],
                135 => [ "Perle-Line-Access-Port-35",   "integer" ],
                136 => [ "Perle-Line-Access-Port-36",   "integer" ],
                137 => [ "Perle-Line-Access-Port-37",   "integer" ],
                138 => [ "Perle-Line-Access-Port-38",   "integer" ],
                139 => [ "Perle-Line-Access-Port-39",   "integer" ],
                140 => [ "Perle-Line-Access-Port-40",   "integer" ],
                141 => [ "Perle-Line-Access-Port-41",   "integer" ],
                142 => [ "Perle-Line-Access-Port-42",   "integer" ],
                143 => [ "Perle-Line-Access-Port-43",   "integer" ],
                144 => [ "Perle-Line-Access-Port-44",   "integer" ],
                145 => [ "Perle-Line-Access-Port-45",   "integer" ],
                146 => [ "Perle-Line-Access-Port-46",   "integer" ],
                147 => [ "Perle-Line-Access-Port-47",   "integer" ],
                148 => [ "Perle-Line-Access-Port-48",   "integer" ],
                149 => [ "Perle-Line-Access-Port-49",   "integer" ],
            },
            1991 => {
                1  => [ "Foundry-Privilege-Level",          "integer" ],
                2  => [ "Foundry-Command-String",           "string" ],
                3  => [ "Foundry-Command-Exception-Flag",   "integer" ],
                4  => [ "Foundry-INM-Privilege",            "integer" ],
                5  => [ "Foundry-Access-List",              "string" ],
                6  => [ "Foundry-MAC-Authent-needs-802.1x", "integer" ],
                7  => [ "Foundry-802.1x-Valid-Lookup",      "integer" ],
                8  => [ "Foundry-MAC-Based-Vlan-QoS",       "integer" ],
                9  => [ "Foundry-INM-Role-Aor-List",        "string" ],
                10 => [ "Foundry-COA-Command",              "string" ],
                11 => [ "Foundry-Voice-Phone-Config",       "string" ],
            },
            2004 => {
                1  => [ "WB-AUTH-Time-Left",      "integer" ],
                2  => [ "WB-Auth-Accum-BW",       "integer" ],
                3  => [ "WB-Auth-BW-Quota",       "integer" ],
                4  => [ "WB-Auth-BW-Count",       "integer" ],
                5  => [ "WB-Auth-Upload-Limit",   "integer" ],
                6  => [ "WB-Auth-Download-Limit", "integer" ],
                7  => [ "WB-Auth-Login-Time",     "integer" ],
                8  => [ "WB-Auth-Logout-Time",    "integer" ],
                9  => [ "WB-Auth-Time-Diff",      "integer" ],
                10 => [ "WB-Auth-BW-Usage",       "integer" ],
            },
            2011 => {
                1   => [ "Huawei-Input-Burst-Size",            "integer" ],
                2   => [ "Huawei-Input-Average-Rate",          "integer" ],
                3   => [ "Huawei-Input-Peak-Rate",             "integer" ],
                4   => [ "Huawei-Output-Burst-Size",           "integer" ],
                5   => [ "Huawei-Output-Average-Rate",         "integer" ],
                6   => [ "Huawei-Output-Peak-Rate",            "integer" ],
                7   => [ "Huawei-In-Kb-Before-T-Switch",       "integer" ],
                8   => [ "Huawei-Out-Kb-Before-T-Switch",      "integer" ],
                9   => [ "Huawei-In-Pkt-Before-T-Switch",      "integer" ],
                10  => [ "Huawei-Out-Pkt-Before-T-Switch",     "integer" ],
                11  => [ "Huawei-In-Kb-After-T-Switch",        "integer" ],
                12  => [ "Huawei-Out-Kb-After-T-Switch",       "integer" ],
                13  => [ "Huawei-In-Pkt-After-T-Switch",       "integer" ],
                14  => [ "Huawei-Out-Pkt-After-T-Switch",      "integer" ],
                15  => [ "Huawei-Remanent-Volume",             "integer" ],
                16  => [ "Huawei-Tariff-Switch-Interval",      "integer" ],
                17  => [ "Huawei-ISP-ID",                      "string" ],
                18  => [ "Huawei-Max-Users-Per-Logic-Port",    "integer" ],
                20  => [ "Huawei-Command",                     "integer" ],
                22  => [ "Huawei-Priority",                    "integer" ],
                24  => [ "Huawei-Control-Identifier",          "integer" ],
                25  => [ "Huawei-Result-Code",                 "integer" ],
                26  => [ "Huawei-Connect-ID",                  "integer" ],
                27  => [ "Huawei-PortalURL",                   "string" ],
                28  => [ "Huawei-FTP-Directory",               "string" ],
                29  => [ "Huawei-Exec-Privilege",              "integer" ],
                30  => [ "Huawei-IP-Address",                  "integer" ],
                31  => [ "Huawei-Qos-Profile-Name",            "string" ],
                32  => [ "Huawei-SIP-Server",                  "string" ],
                33  => [ "Huawei-User-Password",               "string" ],
                34  => [ "Huawei-Command-Mode",                "string" ],
                35  => [ "Huawei-Renewal-Time",                "integer" ],
                36  => [ "Huawei-Rebinding-Time",              "integer" ],
                37  => [ "Huawei-IGMP-Enable",                 "integer" ],
                39  => [ "Huawei-Destnation-IP-Addr",          "string" ],
                40  => [ "Huawei-Destnation-Volume",           "string" ],
                59  => [ "Huawei-Startup-Stamp",               "integer" ],
                60  => [ "Huawei-IPHost-Addr",                 "string" ],
                61  => [ "Huawei-Up-Priority",                 "integer" ],
                62  => [ "Huawei-Down-Priority",               "integer" ],
                63  => [ "Huawei-Tunnel-VPN-Instance",         "string" ],
                64  => [ "Huawei-VT-Name",                     "integer" ],
                65  => [ "Huawei-User-Date",                   "string" ],
                66  => [ "Huawei-User-Class",                  "string" ],
                70  => [ "Huawei-PPP-NCP-Type",                "integer" ],
                71  => [ "Huawei-VSI-Name",                    "string" ],
                72  => [ "Huawei-Subnet-Mask",                 "ipaddr" ],
                73  => [ "Huawei-Gateway-Address",             "ipaddr" ],
                74  => [ "Huawei-Lease-Time",                  "integer" ],
                75  => [ "Huawei-Primary-WINS",                "ipaddr" ],
                76  => [ "Huawei-Secondary-WINS",              "ipaddr" ],
                77  => [ "Huawei-Input-Peak-Burst-Size",       "integer" ],
                78  => [ "Huawei-Output-Peak-Burst-Size",      "integer" ],
                79  => [ "Huawei-Reduced-CIR",                 "integer" ],
                80  => [ "Huawei-Tunnel-Session-Limit",        "integer" ],
                81  => [ "Huawei-Zone-Name",                   "string" ],
                82  => [ "Huawei-Data-Filter",                 "string" ],
                83  => [ "Huawei-Access-Service",              "string" ],
                84  => [ "Huawei-Accounting-Level",            "integer" ],
                85  => [ "Huawei-Portal-Mode",                 "integer" ],
                86  => [ "Huawei-DPI-Policy-Name",             "string" ],
                87  => [ "huawei-Policy-Route",                "ipaddr" ],
                88  => [ "Huawei-Framed-Pool",                 "string" ],
                89  => [ "Huawei-L2TP-Terminate-Cause",        "string" ],
                90  => [ "Huawei-Multi-Account-Mode",          "integer" ],
                91  => [ "Huawei-Queue-Profile",               "string" ],
                92  => [ "Huawei-Layer4-Session-Limit",        "integer" ],
                93  => [ "Huawei-Multicast-Profile",           "string" ],
                94  => [ "Huawei-VPN-Instance",                "string" ],
                95  => [ "Huawei-Policy-Name",                 "string" ],
                96  => [ "Huawei-Tunnel-Group-Name",           "string" ],
                97  => [ "Huawei-Multicast-Source-Group",      "string" ],
                98  => [ "Huawei-Multicast-Receive-Group",     "ipaddr" ],
                99  => [ "Huawei-User-Multicast-Type",         "integer" ],
                100 => [ "Huawei-Reduced-PIR",                 "integer" ],
                101 => [ "Huawei-LI-ID",                       "string" ],
                102 => [ "Huawei-LI-Md-Address",               "ipaddr" ],
                103 => [ "Huawei-LI-Md-Port",                  "integer" ],
                104 => [ "Huawei-LI-Md-VpnInstance",           "string" ],
                105 => [ "Huawei-Service-Chg-Cmd",             "integer" ],
                106 => [ "Huawei-Acct-Packet-Type",            "integer" ],
                107 => [ "Huawei-Call-Reference",              "integer" ],
                108 => [ "Huawei-PSTN-Port",                   "integer" ],
                109 => [ "Huawei-Voip-Service-Type",           "integer" ],
                110 => [ "Huawei-Acct-Connection-Time",        "integer" ],
                112 => [ "Huawei-Error-Reason",                "integer" ],
                113 => [ "Huawei-Remain-Monney",               "integer" ],
                123 => [ "Huawei-Org-GK-ipaddr",               "ipaddr" ],
                124 => [ "Huawei-Org-GW-ipaddr",               "ipaddr" ],
                125 => [ "Huawei-Dst-GK-ipaddr",               "ipaddr" ],
                126 => [ "Huawei-Dst-GW-ipaddr",               "ipaddr" ],
                127 => [ "Huawei-Access-Num",                  "string" ],
                128 => [ "Huawei-Remain-Time",                 "integer" ],
                131 => [ "Huawei-Codec-Type",                  "integer" ],
                132 => [ "Huawei-Transfer-Num",                "string" ],
                133 => [ "Huawei-New-User-Name",               "string" ],
                134 => [ "Huawei-Transfer-Station-Id",         "string" ],
                135 => [ "Huawei-Primary-DNS",                 "ipaddr" ],
                136 => [ "Huawei-Secondary-DNS",               "ipaddr" ],
                137 => [ "Huawei-ONLY-Account-Type",           "integer" ],
                138 => [ "Huawei-Domain-Name",                 "string" ],
                139 => [ "Huawei-ANCP-Profile",                "string" ],
                140 => [ "Huawei-HTTP-Redirect-URL",           "string" ],
                141 => [ "Huawei-Loopback-Address",            "string" ],
                142 => [ "Huawei-QoS-Profile-Type",            "integer" ],
                143 => [ "Huawei-Max-List-Num",                "integer" ],
                144 => [ "Huawei-Acct-IPv6-Input-Octets",      "integer" ],
                145 => [ "Huawei-Acct-IPv6-Output-Octets",     "integer" ],
                146 => [ "Huawei-Acct-IPv6-Input-Packets",     "integer" ],
                147 => [ "Huawei-Acct-IPv6-Output-Packets",    "integer" ],
                148 => [ "Huawei-Acct-IPv6-Input-Gigawords",   "integer" ],
                149 => [ "Huawei-Acct-IPv6-Output-Gigawords",  "integer" ],
                150 => [ "Huawei-DHCPv6-Option37",             "string" ],
                151 => [ "Huawei-DHCPv6-Option38",             "string" ],
                153 => [ "Huawei-User-Mac",                    "string" ],
                154 => [ "Huawei-DNS-Server-IPv6-address",     "ipv6addr" ],
                155 => [ "Huawei-DHCPv4-Option121",            "string" ],
                156 => [ "Huawei-DHCPv4-Option43",             "string" ],
                157 => [ "Huawei-Framed-Pool-Group",           "string" ],
                158 => [ "Huawei-Framed-IPv6-Address",         "ipv6addr" ],
                159 => [ "Huawei-Acct-Update-Address",         "integer" ],
                160 => [ "Huawei-NAT-Policy-Name",             "string" ],
                161 => [ "Huawei-NAT-Public-Address",          "ipaddr" ],
                162 => [ "Huawei-NAT-Start-Port",              "integer" ],
                163 => [ "Huawei-NAT-End-Port",                "integer" ],
                164 => [ "Huawei-NAT-Port-Forwarding",         "integer" ],
                165 => [ "Huawei-NAT-Port-Range-Update",       "integer" ],
                166 => [ "Huawei-DS-Lite-Tunnel-Name",         "string" ],
                167 => [ "Huawei-PCP-Server-Name",             "string" ],
                168 => [ "Huawei-Public-IP-Addr-State",        "integer" ],
                180 => [ "Huawei-Auth-Type",                   "integer" ],
                181 => [ "Huawei-Acct-Terminate-Subcause",     "string" ],
                182 => [ "Huawei-Down-QOS-Profile-Name",       "string" ],
                183 => [ "Huawei-Port-Mirror",                 "integer" ],
                184 => [ "Huawei-Account-Info",                "string" ],
                185 => [ "Huawei-Service-Info",                "string" ],
                187 => [ "Huawei-DHCP-Option",                 "octets" ],
                188 => [ "Huawei-AVpair",                      "string" ],
                191 => [ "Huawei-Delegated-IPv6-Prefix-Pool",  "string" ],
                192 => [ "Huawei-IPv6-Prefix-Lease",           "octets" ],
                193 => [ "Huawei-IPv6-Address-Lease",          "octets" ],
                194 => [ "Huawei-IPv6-Policy-Route",           "ipv6prefix" ],
                196 => [ "Huawei-MNG-IPv6",                    "integer" ],
                206 => [ "Huawei-DPSK-Info",                   "string" ],
                211 => [ "Huawei-Flow-Info",                   "string" ],
                212 => [ "Huawei-Flow-Id",                     "integer" ],
                214 => [ "Huawei-DHCP-Server-IP",              "ipaddr" ],
                215 => [ "Huawei-Application-Type",            "integer" ],
                216 => [ "Huawei-Indication-Flag",             "octets" ],
                217 => [ "Huawei-Original_NAS-IP_Address",     "ipaddr" ],
                218 => [ "Huawei-User-Priority",               "integer" ],
                219 => [ "Huawei-ACS-Url",                     "string" ],
                220 => [ "Huawei-Provision-Code",              "string" ],
                221 => [ "Huawei-Application-Scene",           "octets" ],
                222 => [ "Huawei-MS-Maximum-MAC-Study-Number", "octets" ],
                232 => [ "Huawei-GGSN-Vendor",                 "string" ],
                233 => [ "Huawei-GGSN-Version",                "string" ],
                238 => [ "Huawei-Ext-Specific",                "string" ],
                253 => [ "Huawei-Web-URL",                     "string" ],
                254 => [ "Huawei-Version",                     "string" ],
                255 => [ "Huawei-Product-ID",                  "string" ],
            },
            2167 => {
                1  => [ "Cajun-Service-Type",      "integer" ],
                12 => [ "Avaya-StaticVlan-Type",   "string" ],
                13 => [ "Avaya-PortPriority-Type", "integer" ],
            },
            2180 => { 1 => [ "Versanet-Termination-Cause", "integer" ] },
            2334 => {
                1 => [ "Packeteer-AVPair",    "string" ],
                2 => [ "Packeteer-PC-AVPair", "string" ],
            },
            2352 => {
                1   => [ "Client-DNS-Pri",                  "ipaddr" ],
                2   => [ "Client-DNS-Sec",                  "ipaddr" ],
                3   => [ "DHCP-Max-Leases",                 "integer" ],
                4   => [ "Context-Name",                    "string" ],
                5   => [ "Bridge-Group",                    "string" ],
                6   => [ "BG-Aging-Time",                   "string" ],
                7   => [ "BG-Path-Cost",                    "string" ],
                8   => [ "BG-Span-Dis",                     "string" ],
                9   => [ "BG-Trans-BPDU",                   "string" ],
                10  => [ "Rate-Limit-Rate",                 "integer" ],
                11  => [ "Rate-Limit-Burst",                "integer" ],
                12  => [ "Police-Rate",                     "integer" ],
                13  => [ "Police-Burst",                    "integer" ],
                14  => [ "Source-Validation",               "integer" ],
                15  => [ "Tunnel-Domain",                   "integer" ],
                16  => [ "Tunnel-Local-Name",               "string" ],
                17  => [ "Tunnel-Remote-Name",              "string" ],
                18  => [ "Tunnel-Function",                 "integer" ],
                19  => [ "Tunnel-Flow-Control",             "integer" ],
                20  => [ "Tunnel-Static",                   "integer" ],
                21  => [ "Tunnel-Max-Sessions",             "integer" ],
                22  => [ "Tunnel-Max-Tunnels",              "integer" ],
                23  => [ "Tunnel-Session-Auth",             "integer" ],
                24  => [ "Tunnel-Window",                   "integer" ],
                25  => [ "Tunnel-Retransmit",               "integer" ],
                26  => [ "Tunnel-Cmd-Timeout",              "integer" ],
                27  => [ "PPPOE-URL",                       "string" ],
                28  => [ "PPPOE-MOTM",                      "string" ],
                29  => [ "Tunnel-Group",                    "integer" ],
                30  => [ "Tunnel-Context",                  "string" ],
                31  => [ "Tunnel-Algorithm",                "integer" ],
                32  => [ "Tunnel-Deadtime",                 "integer" ],
                33  => [ "Mcast-Send",                      "integer" ],
                34  => [ "Mcast-Receive",                   "integer" ],
                35  => [ "Mcast-MaxGroups",                 "integer" ],
                36  => [ "Ip-Address-Pool-Name",            "string" ],
                37  => [ "Tunnel-DNIS",                     "integer" ],
                38  => [ "Medium-Type",                     "integer" ],
                39  => [ "PVC-Encapsulation-Type",          "integer" ],
                40  => [ "PVC-Profile-Name",                "string" ],
                41  => [ "PVC-Circuit-Padding",             "integer" ],
                42  => [ "Bind-Type",                       "integer" ],
                43  => [ "Bind-Auth-Protocol",              "integer" ],
                44  => [ "Bind-Auth-Max-Sessions",          "integer" ],
                45  => [ "Bind-Bypass-Bypass",              "string" ],
                46  => [ "Bind-Auth-Context",               "string" ],
                47  => [ "Bind-Auth-Service-Grp",           "string" ],
                48  => [ "Bind-Bypass-Context",             "string" ],
                49  => [ "Bind-Int-Context",                "string" ],
                50  => [ "Bind-Tun-Context",                "string" ],
                51  => [ "Bind-Ses-Context",                "string" ],
                52  => [ "Bind-Dot1q-Slot",                 "integer" ],
                53  => [ "Bind-Dot1q-Port",                 "integer" ],
                54  => [ "Bind-Dot1q-Vlan-Tag-Id",          "integer" ],
                55  => [ "Bind-Int-Interface-Name",         "string" ],
                56  => [ "Bind-L2TP-Tunnel-Name",           "string" ],
                57  => [ "Bind-L2TP-Flow-Control",          "integer" ],
                58  => [ "Bind-Sub-User-At-Context",        "string" ],
                59  => [ "Bind-Sub-Password",               "string" ],
                60  => [ "Ip-Host-Addr",                    "string" ],
                61  => [ "IP-TOS-Field",                    "integer" ],
                62  => [ "NAS-Real-Port",                   "integer" ],
                63  => [ "Tunnel-Session-Auth-Ctx",         "string" ],
                64  => [ "Tunnel-Session-Auth-Service-Grp", "string" ],
                65  => [ "Tunnel-Rate-Limit-Rate",          "integer" ],
                66  => [ "Tunnel-Rate-Limit-Burst",         "integer" ],
                67  => [ "Tunnel-Police-Rate",              "integer" ],
                68  => [ "Tunnel-Police-Burst",             "integer" ],
                69  => [ "Tunnel-L2F-Second-Password",      "string" ],
                70  => [ "ACL-Definition",                  "string" ],
                71  => [ "PPPoE-IP-Route-Add",              "string" ],
                72  => [ "TTY-Level-Max",                   "integer" ],
                73  => [ "TTY-Level-Start",                 "integer" ],
                74  => [ "Tunnel-Checksum",                 "integer" ],
                75  => [ "Tunnel-Profile",                  "string" ],
                78  => [ "Tunnel-Client-VPN",               "string" ],
                79  => [ "Tunnel-Server-VPN",               "string" ],
                80  => [ "Tunnel-Client-Rhost",             "string" ],
                81  => [ "Tunnel-Server-Rhost",             "string" ],
                82  => [ "Tunnel-Client-Int-Addr",          "ipaddr" ],
                83  => [ "Tunnel-Server-Int-Addr",          "ipaddr" ],
                84  => [ "PPP-Compression",                 "integer" ],
                85  => [ "Tunnel-Hello-Timer",              "integer" ],
                86  => [ "Redback-Reason",                  "integer" ],
                87  => [ "Qos-Policing-Profile-Name",       "string" ],
                88  => [ "Qos-Metering-Profile-Name",       "string" ],
                89  => [ "Qos-Policy-Queuing",              "string" ],
                90  => [ "IGMP-Service-Profile-Name",       "string" ],
                91  => [ "Subscriber-Profile-Name",         "string" ],
                92  => [ "Forward-Policy",                  "string" ],
                93  => [ "Remote-Port",                     "string" ],
                94  => [ "Reauth",                          "string" ],
                95  => [ "Reauth-More",                     "integer" ],
                96  => [ "Agent-Remote-Id",                 "octets" ],
                97  => [ "Agent-Circuit-Id",                "octets" ],
                98  => [ "Platform-Type",                   "integer" ],
                99  => [ "Client-NBNS-Pri",                 "ipaddr" ],
                100 => [ "Client-NBNS-Sec",                 "ipaddr" ],
                101 => [ "Shaping-Profile-Name",            "string" ],
                103 => [ "BG-Cct-Addr-Max",                 "integer" ],
                104 => [ "IP-Interface-Name",               "string" ],
                105 => [ "NAT-Policy-Name",                 "string" ],
                106 => [ "RB-NPM-Service-Id",               "string" ],
                107 => [ "HTTP-Redirect-Profile-Name",      "string" ],
                108 => [ "Bind-Auto-Sub-User",              "string" ],
                109 => [ "Bind-Auto-Sub-Context",           "string" ],
                110 => [ "Bind-Auto-Sub-Password",          "string" ],
                111 => [ "Circuit-Protocol-Encap",          "integer" ],
                112 => [ "OS-Version",                      "string" ],
                113 => [ "Session-Traffic-Limit",           "string" ],
                114 => [ "QOS-Reference",                   "string" ],
                121 => [ "Rate-Limit-Excess-Burst",         "octets" ],
                122 => [ "Police-Excess-Burst",             "octets" ],
                123 => [ "Tunnel-Rate-Limit-Excess-Burst",  "octets" ],
                124 => [ "Tunnel-Police-Excess-Burst",      "octets" ],
                125 => [ "DHCP-Vendor-Class-ID",            "string" ],
                126 => [ "Qos-Rate",                        "string" ],
                127 => [ "DHCP-Vendor-Encap-Option",        "string" ],
                128 => [ "Acct-Input-Octets-64",            "integer64" ],
                129 => [ "Acct-Output-Octets-64",           "integer64" ],
                130 => [ "Acct-Input-Packets-64",           "integer64" ],
                131 => [ "Acct-Output-Packets-64",          "integer64" ],
                132 => [ "Assigned-IP-Address",             "ipaddr" ],
                133 => [ "Acct-Mcast-In-Octets-64",         "integer64" ],
                134 => [ "Acct-Mcast-Out-Octets-64",        "integer64" ],
                135 => [ "Acct-Mcast-In-Packets-64",        "integer64" ],
                136 => [ "Acct-Mcast-Out-Packets-64",       "integer64" ],
                137 => [ "LAC-Port",                        "integer" ],
                138 => [ "LAC-Real-Port",                   "integer" ],
                139 => [ "LAC-Port-Type",                   "integer" ],
                140 => [ "LAC-Real-Port-Type",              "integer" ],
                141 => [ "Acct-Dyn-Ac-Ent",                 "string" ],
                142 => [ "Session-Error-Code",              "integer" ],
                143 => [ "Session-Error-Msg",               "string" ],
                144 => [ "Acct-Update-Reason",              "integer" ],
                145 => [ "Mac-Addr",                        "string" ],
                146 => [ "Vlan-Source-Info",                "string" ],
                147 => [ "Acct-Mcast-In-Octets",            "integer" ],
                148 => [ "Acct-Mcast-Out-Octets",           "integer" ],
                149 => [ "Acct-Mcast-In-Packets",           "integer" ],
                150 => [ "Acct-Mcast-Out-Packets",          "integer" ],
                151 => [ "Reauth-Session-Id",               "string" ],
                156 => [ "QOS-Rate-Inbound",                "string" ],
                157 => [ "QOS-Rate-Outbound",               "string" ],
                158 => [ "Route-Tag",                       "integer" ],
                159 => [ "LI-Id",                           "integer" ],
                160 => [ "LI-Md-Address",                   "ipaddr" ],
                161 => [ "LI-Md-Port",                      "integer" ],
                162 => [ "LI-Action",                       "integer" ],
                163 => [ "LI-Profile",                      "string" ],
                164 => [ "Dynamic-Policy-Filter",           "string" ],
                165 => [ "HTTP-Redirect-URL",               "string" ],
                166 => [ "DSL-Actual-Rate-Up",              "integer" ],
                167 => [ "DSL-Actual-Rate-Down",            "integer" ],
                168 => [ "DSL-Min-Rate-Up",                 "integer" ],
                169 => [ "DSL-Min-Rate-Down",               "integer" ],
                170 => [ "DSL-Attainable-Rate-Up",          "integer" ],
                171 => [ "DSL-Attainable-Rate-Down",        "integer" ],
                172 => [ "DSL-Max-Rate-Up",                 "integer" ],
                173 => [ "DSL-Max-Rate-Down",               "integer" ],
                174 => [ "DSL-Min-Low-Power-Rate-Up",       "integer" ],
                175 => [ "DSL-Min-Low-Power-Rate-Down",     "integer" ],
                176 => [ "DSL-Max-Inter-Delay-Up",          "integer" ],
                177 => [ "DSL-Actual-Inter-Delay-Up",       "integer" ],
                178 => [ "DSL-Max-Inter-Delay-Down",        "integer" ],
                179 => [ "DSL-Actual-Inter-Delay-Down",     "integer" ],
                180 => [ "DSL-Line-State",                  "integer" ],
                181 => [ "DSL-L2-Encapsulation",            "integer" ],
                182 => [ "DSL-Transmission-System",         "integer" ],
                183 => [ "DSL-PPPOA-PPPOE-Inter-Work-Flag", "integer" ],
                184 => [ "DSL-Combined-Line-Info",          "string" ],
                185 => [ "DSL-Actual-Rate-Down-Factor",     "integer" ],
                186 => [ "Class-Volume-limit",              "string" ],
                187 => [ "Class-Volume-In-Counter",         "string" ],
                188 => [ "Class-Volume-Out-Counter",        "string" ],
                189 => [ "Flow-FAC-Profile",                "string" ],
                190 => [ "Service-Name",                    "string" ],
                191 => [ "Service-Action",                  "integer" ],
                192 => [ "Service-Parameter",               "string" ],
                193 => [ "Service-Error-Cause",             "integer" ],
                194 => [ "Deactivate-Service-Name",         "string" ],
                195 => [ "Qos-Profile-Overhead",            "string" ],
                196 => [ "Dynamic-QoS-Param",               "string" ],
                197 => [ "Acct-Alt-Session-ID",             "string" ],
                198 => [ "Idle-Timeout-Threshold",          "integer" ],
                199 => [ "Double-Authentication",           "integer" ],
                200 => [ "SBC-Adjacency",                   "string" ],
                201 => [ "DHCP-Field",                      "octets" ],
                202 => [ "DHCP-Option",                     "octets" ],
                203 => [ "Security-Service",                "string" ],
                204 => [ "Reauth-Service-Name",             "string" ],
                205 => [ "Flow-IP-Profile",                 "string" ],
                206 => [ "Radius-Throttle-Watermark",       "integer" ],
                207 => [ "RB-IPV6-DNS",                     "string" ],
                208 => [ "RB-IPv6-Option",                  "string" ],
                209 => [ "Cluster-Partition-ID",            "string" ],
                210 => [ "Circuit-Group-Member",            "string" ],
                212 => [ "Delegated-Max-Prefix",            "integer" ],
                213 => [ "IPv4-Address-Release-Control",    "string" ],
                214 => [ "Acct-Input-IPv4-Octets",          "integer" ],
                215 => [ "Acct-Output-IPv4-Octets",         "integer" ],
                216 => [ "Acct-Input-IPv4-Packets",         "integer" ],
                217 => [ "Acct-Output-IPv4-Packets",        "integer" ],
                218 => [ "Acct-Input-IPv4-Gigawords",       "integer" ],
                219 => [ "Acct-Output-IPv4-Gigawords",      "integer" ],
                220 => [ "Acct-Input-IPv6-Octets",          "integer" ],
                221 => [ "Acct-Output-IPv6-Octets",         "integer" ],
                222 => [ "Acct-Input-IPv6-Packets",         "integer" ],
                223 => [ "Acct-Output-IPv6-Packets",        "integer" ],
                224 => [ "Acct-Input-IPv6-Gigawords",       "integer" ],
                225 => [ "Acct-Output-IPv6-Gigawords",      "integer" ],
            },
            2356 => {
                1  => [ "LCS-Traffic-Limit",           "integer" ],
                2  => [ "LCS-Mac-Address",             "string" ],
                3  => [ "LCS-Redirection-URL",         "string" ],
                4  => [ "LCS-Comment",                 "string" ],
                5  => [ "LCS-Account-End",             "integer" ],
                6  => [ "LCS-WPA-Passphrase",          "string" ],
                7  => [ "LCS-PbSpotUserName",          "string" ],
                8  => [ "LCS-TxRateLimit",             "integer" ],
                9  => [ "LCS-RxRateLimit",             "integer" ],
                11 => [ "LCS-Access-Rights",           "integer" ],
                12 => [ "LCS-Function-Rights",         "integer" ],
                13 => [ "LCS-Advertisement-URL",       "string" ],
                14 => [ "LCS-Advertisement-Interval",  "integer" ],
                15 => [ "LCS-Traffic-Limit-Gigawords", "integer" ],
                16 => [ "LCS-Orig-NAS-Identifier",     "string" ],
                17 => [ "LCS-Orig-NAS-IP-Address",     "ipaddr" ],
                18 => [ "LCS-Orig-NAS-IPv6-Address",   "ipv6addr" ],
                19 => [ "LCS-IKEv2-Local-Password",    "string" ],
                20 => [ "LCS-IKEv2-Remote-Password",   "string" ],
                21 => [ "LCS-DNS-Server-IPv4-Address", "ipaddr" ],
                22 => [ "LCS-VPN-IPv4-Rule",           "string" ],
                23 => [ "LCS-VPN-IPv6-Rule",           "string" ],
                24 => [ "LCS-Routing-Tag",             "integer" ],
                25 => [ "LCS-IKEv2-IPv4-Route",        "string" ],
                26 => [ "LCS-IKEv2-IPv6-Route",        "string" ],
                27 => [ "LCS-IKEv2-DNS-Domain",        "string" ],
                28 => [ "LCS-Load-Balancer",           "string" ],
            },
            2440 => {
                1  => [ "EfficientIP-Version",          "integer" ],
                2  => [ "EfficientIP-Service-Class",    "integer" ],
                3  => [ "EfficientIP-Identity-Type",    "integer" ],
                16 => [ "EfficientIP-First-Name",       "string" ],
                17 => [ "EfficientIP-Last-Name",        "string" ],
                18 => [ "EfficientIP-Pseudonym",        "string" ],
                19 => [ "EfficientIP-IP-Host",          "string" ],
                20 => [ "EfficientIP-Email",            "string" ],
                32 => [ "EfficientIP-First-Login-Path", "string" ],
                33 => [ "EfficientIP-Maintainer-Group", "string" ],
                34 => [ "EfficientIP-Groups",           "string" ],
                35 => [ "EfficientIP-Admin-Group",      "string" ],
                64 => [ "EfficientIP-Extra-Blob",       "string" ],
            },
            2454 => {
                1   => [ "SG-Filter-Redirect-Gw",                  "ipaddr" ],
                10  => [ "SG-Accounting",                          "integer" ],
                12  => [ "SG-Orig-Name",                           "string" ],
                13  => [ "SG-Auth-Type",                           "integer" ],
                14  => [ "SG-Action",                              "integer" ],
                15  => [ "SG-SSC-Host",                            "ipaddr" ],
                16  => [ "SG-Service-Name",                        "string" ],
                17  => [ "SG-Personal-Site",                       "string" ],
                18  => [ "SG-Mac-Address",                         "string" ],
                19  => [ "SG-User-Group",                          "integer" ],
                20  => [ "SG-Max-Allowed-Sessions",                "integer" ],
                21  => [ "SG-Class",                               "string" ],
                22  => [ "SG-Eds-Enc-Key",                         "string" ],
                23  => [ "SG-Eds-Cookie",                          "string" ],
                24  => [ "SG-Original-Url-Prefix",                 "string" ],
                25  => [ "SG-Max-Allowed-Nodes",                   "integer" ],
                26  => [ "SG-Parent-User-Name",                    "string" ],
                27  => [ "SG-Node-Group",                          "integer" ],
                28  => [ "SG-Node-Default-Service",                "string" ],
                29  => [ "SG-Node-Dynamic-Service",                "string" ],
                30  => [ "SG-Dhcp-Server",                         "ipaddr" ],
                31  => [ "SG-Opt82-Relay-Remote-Id",               "string" ],
                32  => [ "SG-Discover-Action",                     "integer" ],
                33  => [ "SG-Release-Action",                      "integer" ],
                34  => [ "SG-Fixed-Ip-Address",                    "string" ],
                35  => [ "SG-Node-Fixed-Ip-Address",               "string" ],
                36  => [ "SG-Lease-Time",                          "integer" ],
                40  => [ "SG-Protocol-Type",                       "integer" ],
                50  => [ "SG-Service-Timeout",                     "integer" ],
                51  => [ "SG-Next-Service-Name",                   "string" ],
                52  => [ "SG-Auto-Service-Name",                   "string" ],
                53  => [ "SG-Auth-Source",                         "integer" ],
                54  => [ "SG-Data-Quota",                          "string" ],
                55  => [ "SG-Acl-Data-Quota",                      "string" ],
                56  => [ "SG-Service-Cache",                       "integer" ],
                57  => [ "SG-Data-Quota-Used",                     "string" ],
                58  => [ "SG-Acl-Data-Quota-Used",                 "string" ],
                59  => [ "SG-Acl-Packet-Quota",                    "string" ],
                60  => [ "SG-Acl-Packet-Quota-Used",               "string" ],
                61  => [ "SG-Roaming",                             "integer" ],
                62  => [ "SG-Acl-Eds-Action",                      "string" ],
                63  => [ "SG-Acl-Idle-Ignore",                     "string" ],
                65  => [ "SG-Service-Quota-Ignore",                "string" ],
                66  => [ "SG-Service-Acl-Quota-Ignore",            "string" ],
                67  => [ "SG-Service-Acl-Quota-Indication",        "string" ],
                70  => [ "SG-Remote-Filter-Redirect-Gw",           "string" ],
                71  => [ "SG-Next-Hop",                            "ipaddr" ],
                72  => [ "SG-Nip-Pipe-Next-Hop",                   "ipaddr" ],
                73  => [ "SG-Advertise-Protocol",                  "integer" ],
                74  => [ "SG-Forward-Addr",                        "ipaddr" ],
                75  => [ "SG-Acl-Tcp-Nat-Redirect",                "string" ],
                76  => [ "SG-Acl-Next-Hop",                        "string" ],
                80  => [ "SG-Tunnel-Id",                           "string" ],
                81  => [ "SG-L2tp-Tunnel-Password",                "string" ],
                82  => [ "SG-Ip-Address",                          "string" ],
                83  => [ "SG-Tunnel-Assignment-Id",                "integer" ],
                84  => [ "SG-Tunnel-Client-Ip-Address",            "ipaddr" ],
                85  => [ "SG-Nativeip",                            "integer" ],
                86  => [ "SG-Ip-Tunnel",                           "string" ],
                90  => [ "SG-Up-Mean-Rate",                        "string" ],
                91  => [ "SG-Down-Mean-Rate",                      "string" ],
                92  => [ "SG-Acl-Up-Mean-Rate",                    "string" ],
                93  => [ "SG-Acl-Down-Mean-Rate",                  "string" ],
                94  => [ "SG-Cos",                                 "string" ],
                95  => [ "SG-Acl-Priority",                        "string" ],
                96  => [ "SG-Burst-Size",                          "integer" ],
                100 => [ "SG-Ip-Primary",                          "ipaddr" ],
                101 => [ "SG-Ip-Secondary",                        "ipaddr" ],
                110 => [ "SG-Wimax-Reduced-Resources",             "integer" ],
                111 => [ "SG-Wimax-Acl-Schedule-Type",             "string" ],
                112 => [ "SG-Wimax-Acl-Min-Reserved-Traffic-Rate", "string" ],
                113 => [ "SG-Wimax-Acl-Maximum-Traffic-Burst",     "string" ],
                114 => [ "SG-Wimax-Acl-Tolerated-Jitter",          "string" ],
                115 => [ "SG-Wimax-Acl-Maximum-Latency",           "string" ],
                116 => [ "SG-Wimax-Acl-Unsolicited-Grant-Int",     "string" ],
                117 => [ "SG-Wimax-Acl-Sdu-Size",                  "string" ],
                118 => [ "SG-Wimax-Acl-Unsolicited-Polling-Int",   "string" ],
                119 => [ "SG-Wimax-MSK-Lifetime",                  "integer" ],
                120 => [ "SG-Wimax-DM-Action-Code",                "integer" ],
                121 => [ "SG-Wimax-Acl-ARQ-Enable",                "string" ],
                122 => [ "SG-Wimax-Bsid-Next-Hop",                 "ipaddr" ],
                123 => [ "SG-Wimax-Mobility-Features-Supported",   "integer" ],
                124 => [ "SG-Wimax-Node-Disconnect",               "integer" ],
                125 => [ "SG-Wimax-Service-Flow-Modification",     "integer" ],
                126 => [ "SG-Wimax-Service-Flow-Down",             "string" ],
                130 => [ "SG-Node-Acct-Username",                  "string" ],
            },
            2544 => {
                100 => [ "Adva-User-Level",     "integer" ],
                101 => [ "Adva-Auth-Level-NM",  "string" ],
                102 => [ "Adva-UUM-User-Level", "integer" ],
            },
            2620 => {
                229 => [ "CP-Gaia-User-Role",        "string" ],
                230 => [ "CP-Gaia-SuperUser-Access", "integer" ],
            },
            2636 => {
                1   => [ "Juniper-Local-User-Name",             "string" ],
                2   => [ "Juniper-Allow-Commands",              "string" ],
                3   => [ "Juniper-Deny-Commands",               "string" ],
                4   => [ "Juniper-Allow-Configuration",         "string" ],
                5   => [ "Juniper-Deny-Configuration",          "string" ],
                8   => [ "Juniper-Interactive-Command",         "string" ],
                9   => [ "Juniper-Configuration-Change",        "string" ],
                10  => [ "Juniper-User-Permissions",            "string" ],
                11  => [ "Juniper-Junosspace-Profiles",         "string" ],
                21  => [ "Juniper-CTP-Group",                   "integer" ],
                22  => [ "Juniper-CTPView-APP-Group",           "integer" ],
                23  => [ "Juniper-CTPView-OS-Group",            "integer" ],
                31  => [ "Juniper-Primary-Dns",                 "ipaddr" ],
                32  => [ "Juniper-Primary-Wins",                "ipaddr" ],
                33  => [ "Juniper-Secondary-Dns",               "ipaddr" ],
                34  => [ "Juniper-Secondary-Wins",              "ipaddr" ],
                35  => [ "Juniper-Interface-id",                "string" ],
                36  => [ "Juniper-Ip-Pool-Name",                "string" ],
                37  => [ "Juniper-Keep-Alive",                  "integer" ],
                38  => [ "Juniper-CoS-Traffic-Control-Profile", "string" ],
                39  => [ "Juniper-CoS-Parameter",               "string" ],
                40  => [ "Juniper-encapsulation-overhead",      "integer" ],
                41  => [ "Juniper-cell-overhead",               "integer" ],
                42  => [ "Juniper-tx-connect-speed",            "integer" ],
                43  => [ "Juniper-rx-connect-speed",            "integer" ],
                44  => [ "Juniper-Firewall-filter-name",        "string" ],
                45  => [ "Juniper-Policer-Parameter",           "string" ],
                46  => [ "Juniper-Local-Group-Name",            "string" ],
                47  => [ "Juniper-Local-Interface",             "string" ],
                48  => [ "Juniper-Switching-Filter",            "string" ],
                49  => [ "Juniper-VoIP-Vlan",                   "string" ],
                50  => [ "Juniper-CWA-Redirect",                "string" ],
                52  => [ "Juniper-AV-Pair",                     "string" ],
                55  => [ "Juniper-DHCPv4-Options",              "octets" ],
                207 => [ "Juniper-DHCPv6-Options",              "octets" ],
                208 => [ "Juniper-DHCPv4-Packet-Header",        "octets" ],
                209 => [ "Juniper-DHCPv6-Packet-Header",        "octets" ],
            },
            2637 => {
                1   => [ "CVX-Identification",            "string" ],
                2   => [ "CVX-VPOP-ID",                   "integer" ],
                3   => [ "CVX-SS7-Session-ID-Type",       "integer" ],
                4   => [ "CVX-Radius-Redirect",           "integer" ],
                5   => [ "CVX-IPSVC-AZNLVL",              "integer" ],
                6   => [ "CVX-IPSVC-Mask",                "integer" ],
                7   => [ "CVX-Multilink-Match-Info",      "integer" ],
                8   => [ "CVX-Multilink-Group-Number",    "integer" ],
                9   => [ "CVX-PPP-Log-Mask",              "integer" ],
                10  => [ "CVX-Modem-Begin-Modulation",    "string" ],
                11  => [ "CVX-Modem-End-Modulation",      "string" ],
                12  => [ "CVX-Modem-Error-Correction",    "string" ],
                13  => [ "CVX-Modem-Data-Compression",    "string" ],
                14  => [ "CVX-Modem-Tx-Packets",          "integer" ],
                15  => [ "CVX-Modem-ReTx-Packets",        "integer" ],
                16  => [ "CVX-Modem-SNR",                 "integer" ],
                17  => [ "CVX-Modem-Local-Retrains",      "integer" ],
                18  => [ "CVX-Modem-Remote-Retrains",     "integer" ],
                19  => [ "CVX-Modem-Local-Rate-Negs",     "integer" ],
                20  => [ "CVX-Modem-Remote-Rate-Negs",    "integer" ],
                21  => [ "CVX-Modem-Begin-Recv-Line-Lvl", "integer" ],
                22  => [ "CVX-Modem-End-Recv-Line-Lvl",   "integer" ],
                23  => [ "CVX-Terminate-Component",       "integer" ],
                24  => [ "CVX-Terminate-Cause",           "integer" ],
                25  => [ "CVX-Reject-Reason",             "integer" ],
                135 => [ "CVX-Primary-DNS",               "ipaddr" ],
                136 => [ "CVX-Secondary-DNS",             "ipaddr" ],
                137 => [ "CVX-Client-Assign-DNS",         "integer" ],
                152 => [ "CVX-Multicast-Rate-Limit",      "integer" ],
                155 => [ "CVX-Multicast-Client",          "integer" ],
                195 => [ "CVX-Disconnect-Cause",          "integer" ],
                197 => [ "CVX-Data-Rate",                 "integer" ],
                198 => [ "CVX-PreSession-Time",           "integer" ],
                218 => [ "CVX-Assign-IP-Pool",            "integer" ],
                235 => [ "CVX-Maximum-Channels",          "integer" ],
                242 => [ "CVX-Data-Filter",               "string" ],
                244 => [ "CVX-Idle-Limit",                "integer" ],
                253 => [ "CVX-PPP-Address",               "ipaddr" ],
                255 => [ "CVX-Xmit-Rate",                 "integer" ],
            },
            2979 => {
                1  => [ "Waverider-Grade-Of-Service",     "integer" ],
                2  => [ "Waverider-Priority-Enabled",     "integer" ],
                3  => [ "Waverider-Authentication-Key",   "string" ],
                5  => [ "Waverider-Current-Password",     "string" ],
                6  => [ "Waverider-New-Password",         "string" ],
                7  => [ "Waverider-Radio-Frequency",      "integer" ],
                8  => [ "Waverider-SNMP-Read-Community",  "string" ],
                9  => [ "Waverider-SNMP-Write-Community", "string" ],
                10 => [ "Waverider-SNMP-Trap-Server",     "string" ],
                11 => [ "Waverider-SNMP-Contact",         "string" ],
                12 => [ "Waverider-SNMP-Location",        "string" ],
                13 => [ "Waverider-SNMP-Name",            "string" ],
                14 => [ "Waverider-Max-Customers",        "integer" ],
                15 => [ "Waverider-Rf-Power",             "integer" ],
            },
            3041 => {
                5   => [ "AAT-Client-Primary-DNS",         "ipaddr" ],
                6   => [ "AAT-Client-Primary-WINS-NBNS",   "ipaddr" ],
                7   => [ "AAT-Client-Secondary-WINS-NBNS", "ipaddr" ],
                8   => [ "AAT-Client-Secondary-DNS",       "ipaddr" ],
                9   => [ "AAT-PPP-Address",                "ipaddr" ],
                10  => [ "AAT-PPP-Netmask",                "ipaddr" ],
                12  => [ "AAT-Primary-Home-Agent",         "string" ],
                13  => [ "AAT-Secondary-Home-Agent",       "string" ],
                14  => [ "AAT-Home-Agent-Password",        "string" ],
                15  => [ "AAT-Home-Network-Name",          "string" ],
                16  => [ "AAT-Home-Agent-UDP-Port",        "integer" ],
                17  => [ "AAT-IP-Direct",                  "ipaddr" ],
                18  => [ "AAT-FR-Direct",                  "integer" ],
                19  => [ "AAT-FR-Direct-Profile",          "string" ],
                20  => [ "AAT-FR-Direct-DLCI",             "integer" ],
                21  => [ "AAT-ATM-Direct",                 "string" ],
                22  => [ "AAT-IP-TOS",                     "integer" ],
                23  => [ "AAT-IP-TOS-Precedence",          "integer" ],
                24  => [ "AAT-IP-TOS-Apply-To",            "integer" ],
                27  => [ "AAT-MCast-Client",               "integer" ],
                28  => [ "AAT-Modem-Port-No",              "integer" ],
                29  => [ "AAT-Modem-Slot-No",              "integer" ],
                30  => [ "AAT-Modem-Shelf-No",             "integer" ],
                60  => [ "AAT-Filter",                     "string" ],
                61  => [ "AAT-Vrouter-Name",               "string" ],
                62  => [ "AAT-Require-Auth",               "integer" ],
                63  => [ "AAT-IP-Pool-Definition",         "string" ],
                64  => [ "AAT-Assign-IP-Pool",             "integer" ],
                65  => [ "AAT-Data-Filter",                "string" ],
                66  => [ "AAT-Source-IP-Check",            "integer" ],
                67  => [ "AAT-Modem-Answer-String",        "string" ],
                68  => [ "AAT-Auth-Type",                  "integer" ],
                70  => [ "AAT-Qos",                        "integer" ],
                71  => [ "AAT-Qoa",                        "integer" ],
                72  => [ "AAT-Client-Assign-DNS",          "integer" ],
                128 => [ "AAT-ATM-VPI",                    "integer" ],
                129 => [ "AAT-ATM-VCI",                    "integer" ],
                130 => [ "AAT-Input-Octets-Diff",          "integer" ],
                131 => [ "AAT-Output-Octets-Diff",         "integer" ],
                132 => [ "AAT-User-MAC-Address",           "string" ],
                133 => [ "AAT-ATM-Traffic-Profile",        "string" ],
            },
            3076 => {},
            3085 => {
                1 => [ "Cosine-Connection-Profile-Name", "string" ],
                2 => [ "Cosine-Enterprise-ID",           "string" ],
                3 => [ "Cosine-Address-Pool-Name",       "string" ],
                4 => [ "Cosine-DS-Byte",                 "integer" ],
                5 => [ "Cosine-VPI-VCI",                 "octets" ],
                6 => [ "Cosine-DLCI",                    "integer" ],
                7 => [ "Cosine-LNS-IP-Address",          "ipaddr" ],
                8 => [ "Cosine-CLI-User-Permission-ID",  "string" ],
            },
            3199 => {
                1 => [ "Shasta-User-Privilege",  "integer" ],
                2 => [ "Shasta-Service-Profile", "string" ],
                3 => [ "Shasta-VPN-Name",        "string" ],
            },
            3224 => {
                1   => [ "NS-Admin-Privilege",       "integer" ],
                2   => [ "NS-VSYS-Name",             "string" ],
                3   => [ "NS-User-Group",            "string" ],
                4   => [ "NS-Primary-DNS",           "ipaddr" ],
                5   => [ "NS-Secondary-DNS",         "ipaddr" ],
                6   => [ "NS-Primary-WINS",          "ipaddr" ],
                7   => [ "NS-Secondary-WINS",        "ipaddr" ],
                220 => [ "NS-NSM-User-Domain-Name",  "string" ],
                221 => [ "NS-NSM-User-Role-Mapping", "string" ],
            },
            3309 => {
                1  => [ "Nomadix-Bw-Up",             "integer" ],
                2  => [ "Nomadix-Bw-Down",           "integer" ],
                3  => [ "Nomadix-URL-Redirection",   "string" ],
                4  => [ "Nomadix-IP-Upsell",         "integer" ],
                5  => [ "Nomadix-Expiration",        "string" ],
                6  => [ "Nomadix-Subnet",            "string" ],
                7  => [ "Nomadix-MaxBytesUp",        "integer" ],
                8  => [ "Nomadix-MaxBytesDown",      "integer" ],
                9  => [ "Nomadix-EndofSession",      "integer" ],
                10 => [ "Nomadix-Logoff-URL",        "string" ],
                11 => [ "Nomadix-Net-VLAN",          "integer" ],
                12 => [ "Nomadix-Config-URL",        "string" ],
                13 => [ "Nomadix-Goodbye-URL",       "string" ],
                14 => [ "Nomadix-Qos-Policy",        "string" ],
                17 => [ "Nomadix-SMTP-Redirect",     "integer" ],
                18 => [ "Nomadix-Centralized-Mgmt",  "string" ],
                19 => [ "Nomadix-Group-Policy-Id",   "integer" ],
                20 => [ "Nomadix-Group-Bw-Max-Up",   "integer" ],
                21 => [ "Nomadix-Group-Bw-Max-Down", "integer" ],
            },
            3375 => {
                1  => [ "F5-LTM-User-Role",           "integer" ],
                2  => [ "F5-LTM-User-Role-Universal", "integer" ],
                3  => [ "F5-LTM-User-Partition",      "string" ],
                4  => [ "F5-LTM-User-Console",        "integer" ],
                5  => [ "F5-LTM-User-Shell",          "string" ],
                10 => [ "F5-LTM-User-Context-1",      "integer" ],
                11 => [ "F5-LTM-User-Context-2",      "integer" ],
                12 => [ "F5-LTM-User-Info-1",         "string" ],
                13 => [ "F5-LTM-User-Info-2",         "string" ],
                14 => [ "F5-LTM-Audit-Msg",           "string" ],
            },
            3551 => {
                1  => [ "ST-Acct-VC-Connection-Id", "string" ],
                2  => [ "ST-Service-Name",          "string" ],
                3  => [ "ST-Service-Domain",        "integer" ],
                4  => [ "ST-Policy-Name",           "string" ],
                5  => [ "ST-Primary-DNS-Server",    "ipaddr" ],
                6  => [ "ST-Secondary-DNS-Server",  "ipaddr" ],
                7  => [ "ST-Primary-NBNS-Server",   "ipaddr" ],
                8  => [ "ST-Secondary-NBNS-Server", "ipaddr" ],
                9  => [ "ST-Physical-Port",         "integer" ],
                10 => [ "ST-Physical-Slot",         "integer" ],
                11 => [ "ST-Virtual-Path-ID",       "integer" ],
                12 => [ "ST-Virtual-Circuit-ID",    "integer" ],
                13 => [ "ST-Realm-Name",            "string" ],
                14 => [ "ST-IPSec-Pfs-Group",       "integer" ],
                15 => [ "ST-IPSec-Client-Firewall", "integer" ],
                16 => [ "ST-IPSec-Client-Subnet",   "string" ],
            },
            3561 => {
                1   => [ "ADSL-Agent-Circuit-Id",                  "octets" ],
                2   => [ "ADSL-Agent-Remote-Id",                   "octets" ],
                129 => [ "Actual-Data-Rate-Upstream",              "integer" ],
                130 => [ "Actual-Data-Rate-Downstream",            "integer" ],
                131 => [ "Minimum-Data-Rate-Upstream",             "integer" ],
                132 => [ "Minimum-Data-Rate-Downstream",           "integer" ],
                133 => [ "Attainable-Data-Rate-Upstream",          "integer" ],
                134 => [ "Attainable-Data-Rate-Downstream",        "integer" ],
                135 => [ "Maximum-Data-Rate-Upstream",             "integer" ],
                136 => [ "Maximum-Data-Rate-Downstream",           "integer" ],
                137 => [ "Minimum-Data-Rate-Upstream-Low-Power",   "integer" ],
                138 => [ "Minimum-Data-Rate-Downstream-Low-Power", "integer" ],
                139 => [ "Maximum-Interleaving-Delay-Upstream",    "integer" ],
                140 => [ "Actual-Interleaving-Delay-Upstream",     "integer" ],
                141 => [ "Maximum-Interleaving-Delay-Downstream",  "integer" ],
                142 => [ "Actual-Interleaving-Delay-Downstream",   "integer" ],
                144 => [ "Access-Loop-Encapsulation",              "octets" ],
                254 => [ "IWF-Session",                            "octets" ],
                255 => [ "ADSL-Forum-Gateway-Manufacturer-OUI",    "octets" ],
            },
            3902 => {
                1   => [ "ZTE-Client-DNS-Pri",              "ipaddr" ],
                2   => [ "ZTE-Client-DNS-Sec",              "ipaddr" ],
                4   => [ "ZTE-Context-Name",                "integer" ],
                21  => [ "ZTE-Tunnel-Max-Sessions",         "integer" ],
                22  => [ "ZTE-Tunnel-Max-Tunnels",          "integer" ],
                24  => [ "ZTE-Tunnel-Window",               "integer" ],
                25  => [ "ZTE-Tunnel-Retransmit",           "integer" ],
                26  => [ "ZTE-Tunnel-Cmd-Timeout",          "integer" ],
                27  => [ "ZTE-PPPOE-URL",                   "string" ],
                28  => [ "ZTE-PPPOE-MOTM",                  "string" ],
                31  => [ "ZTE-Tunnel-Algorithm",            "integer" ],
                32  => [ "ZTE-Tunnel-Deadtime",             "integer" ],
                33  => [ "ZTE-Mcast-Send",                  "integer" ],
                34  => [ "ZTE-Mcast-Receive",               "integer" ],
                35  => [ "ZTE-Mcast-MaxGroups",             "integer" ],
                74  => [ "ZTE-Access-Type",                 "integer" ],
                81  => [ "ZTE-QoS-Type",                    "integer" ],
                82  => [ "ZTE-QoS-Profile-Down",            "string" ],
                83  => [ "ZTE-Rate-Ctrl-SCR-Down",          "integer" ],
                84  => [ "ZTE-Rate-Ctrl-Burst-Down",        "integer" ],
                86  => [ "ZTE-Rate-Ctrl-PCR",               "integer" ],
                88  => [ "ZTE-TCP-Syn-Rate",                "integer" ],
                89  => [ "ZTE-Rate-Ctrl-SCR-Up",            "integer" ],
                90  => [ "ZTE-Priority-Level",              "integer" ],
                91  => [ "ZTE-Rate-Ctrl-Burst-Up",          "integer" ],
                92  => [ "ZTE-Rate-Ctrl-Burst-Max-Down",    "integer" ],
                93  => [ "ZTE-Rate-Ctrl-Burst-Max-Up",      "integer" ],
                94  => [ "ZTE-QOS-Profile-Up",              "string" ],
                95  => [ "ZTE-TCP-Limit-Num",               "integer" ],
                96  => [ "ZTE-TCP-Limit-Mode",              "integer" ],
                97  => [ "ZTE-IGMP-Service-Profile-Num",    "integer" ],
                101 => [ "ZTE-PPP-Sservice-Type",           "integer" ],
                104 => [ "ZTE-SW-Privilege",                "integer" ],
                151 => [ "ZTE-Access-Domain",               "string" ],
                190 => [ "ZTE-VPN-ID",                      "string" ],
                191 => [ "ZTE_Rate-Bust-DPIR",              "integer" ],
                192 => [ "ZTE_Rate-Bust-UPIR",              "integer" ],
                202 => [ "ZTE-Rate-Ctrl-PBS-Down",          "integer" ],
                203 => [ "ZTE-Rate-Ctrl-PBS-Up",            "integer" ],
                228 => [ "ZTE-Rate-Ctrl-SCR-Up-v6",         "integer" ],
                229 => [ "ZTE-Rate-Ctrl-Burst-Up-v6",       "integer" ],
                230 => [ "ZTE-Rate-Ctrl-Burst-Max-Up-v6",   "integer" ],
                231 => [ "ZTE-Rate-Ctrl-PBS-Up-v6",         "integer" ],
                232 => [ "ZTE-QoS-Profile-Up-v6",           "string" ],
                233 => [ "ZTE-Rate-Ctrl-SCR-Down-v6",       "integer" ],
                234 => [ "ZTE-Rate-Ctrl-Burst-Down-v6",     "integer" ],
                235 => [ "ZTE-Rate-Ctrl-Burst-Max-Down-v6", "integer" ],
                236 => [ "ZTE-Rate-Ctrl-PBS-Down-v6",       "integer" ],
                237 => [ "ZTE-QoS-Profile-Down-v6",         "string" ],
            },
            4329 => {
                1  => [ "Siemens-URL-Redirection", "string" ],
                2  => [ "Siemens-AP-Name",         "string" ],
                3  => [ "Siemens-AP-Serial",       "string" ],
                4  => [ "Siemens-VNS-Name",        "string" ],
                5  => [ "Siemens-SSID",            "string" ],
                6  => [ "Siemens-BSS-MAC",         "string" ],
                7  => [ "Siemens-Policy-Name",     "string" ],
                8  => [ "Siemens-Topology-Name",   "string" ],
                9  => [ "Siemens-Ingress-RC-Name", "string" ],
                10 => [ "Siemens-Egress-RC-Name",  "string" ],
            },
            4363 => {
                1 => [ "NN-Data-Rate",         "integer" ],
                2 => [ "NN-Data-Rate-Ceiling", "integer" ],
                3 => [ "NN-Homenode",          "ipaddr" ],
                4 => [ "NN-Homeservice",       "ipaddr" ],
                5 => [ "NN-Homeservice-Name",  "string" ],
            },
            4453 => {
                238 => [ "Infonet-Proxy",              "string" ],
                239 => [ "Infonet-Config",             "string" ],
                240 => [ "Infonet-MCS-Country",        "string" ],
                241 => [ "Infonet-MCS-Region",         "string" ],
                242 => [ "Infonet-MCS-Off-Peak",       "string" ],
                243 => [ "Infonet-MCS-Overflow",       "string" ],
                244 => [ "Infonet-MCS-Port",           "string" ],
                245 => [ "Infonet-MCS-Port-Count",     "string" ],
                246 => [ "Infonet-Random-IP-Pool",     "string" ],
                247 => [ "Infonet-Account-Number",     "string" ],
                248 => [ "Infonet-Type",               "string" ],
                249 => [ "Infonet-Realm-Type",         "string" ],
                250 => [ "Infonet-LoginHost-Dest",     "string" ],
                251 => [ "Infonet-Tunnel-Decision-IP", "string" ],
                252 => [ "Infonet-Pool-Request",       "string" ],
                254 => [ "Infonet-Surcharge-Type",     "integer" ],
                255 => [ "Infonet-NAS-Location",       "string" ],
            },
            4491 => {
                "0"  => [ "CableLabs-Reserved",                     "octets" ],
                "1"  => [ "CableLabs-Event-Message",                "octets" ],
                "3"  => [ "CableLabs-MTA-Endpoint-Name",            "string" ],
                "4"  => [ "CableLabs-Calling-Party-Number",         "string" ],
                "5"  => [ "CableLabs-Called-Party-Number",          "string" ],
                "6"  => [ "CableLabs-Database-ID",                  "string" ],
                "7"  => [ "CableLabs-Query-Type",                   "integer" ],
                "9"  => [ "CableLabs-Returned-Number",              "string" ],
                "11" => [ "CableLabs-Call-Termination-Cause",       "octets" ],
                "13" => [ "CableLabs-Related-Call-Billing-Crl-ID",  "octets" ],
                "14" => [ "CableLabs-First-Call-Calling-Party-Num", "string" ],
                "15" => [ "CableLabs-Second-Call-Calling-Party-Num", "string" ],
                "16" => [ "CableLabs-Charge-Number",                 "string" ],
                "17" => [ "CableLabs-Forwarded-Number",              "string" ],
                "18" => [ "CableLabs-Service-Name",                  "string" ],
                "20" => [ "CableLabs-Intl-Code",                     "string" ],
                "21" => [ "CableLabs-Dial-Around-Code",              "string" ],
                "22" => [ "CableLabs-Location-Routing-Number",       "string" ],
                "23" => [ "CableLabs-Carrier-Identification-Code",   "string" ],
                "24" => [ "CableLabs-Trunk-Group-ID",                "octets" ],
                "25" => [ "CableLabs-Routing-Number",                "string" ],
                "26" => [ "CableLabs-MTA-UDP-Portnum",              "integer" ],
                "29" => [ "CableLabs-Channel-State",                "integer" ],
                "30" => [ "CableLabs-SF-ID",                        "integer" ],
                "31" => [ "CableLabs-Error-Description",            "string" ],
                "32" => [ "CableLabs-QoS-Descriptor",               "octets" ],
                "37" => [ "CableLabs-Direction-indicator",          "integer" ],
                "38" => [ "CableLabs-Time-Adjustment",              "octets" ],
                "39" => [ "CableLabs-SDP-Upstream",                 "string" ],
                "40" => [ "CableLabs-SDP-Downstream",               "string" ],
                "41" => [ "CableLabs-User-Input",                   "string" ],
                "42" => [ "CableLabs-Translation-Input",            "string" ],
                "43" => [ "CableLabs-Redirected-From-Info",         "octets" ],
                "44" => [ "CableLabs-Electronic-Surveillance-Ind",  "octets" ],
                "45" => [ "CableLabs-Redirected-From-Party-Number", "string" ],
                "46" => [ "CableLabs-Redirected-To-Party-Number",   "string" ],
                "47" => [ "CableLabs-El-Surveillance-DF-Security",  "octets" ],
                "48" => [ "CableLabs-CCC-ID",                       "octets" ],
                "49" => [ "CableLabs-Financial-Entity-ID",          "string" ],
                "50" => [ "CableLabs-Flow-Direction",               "integer" ],
                "51" => [ "CableLabs-Signal-Type",                  "integer" ],
                "52" => [ "CableLabs-Alerting-Signal",              "integer" ],
                "53" => [ "CableLabs-Subject-Audible-Signal",       "integer" ],
                "54" => [ "CableLabs-Terminal-Display-Info",        "octets" ],
                "55" => [ "CableLabs-Switch-Hook-Flash",            "string" ],
                "56" => [ "CableLabs-Dialed-Digits",                "string" ],
                "57" => [ "CableLabs-Misc-Signaling-Information",   "string" ],
                "61" => [ "CableLabs-AM-Opaque-Data",               "integer" ],
                "62" => [ "CableLabs-Subscriber-ID",                "integer" ],
                "63" => [ "CableLabs-Volume-Usage-Limit",           "integer" ],
                "64" => [ "CableLabs-Gate-Usage-Info",              "integer" ],
                "65" => [ "CableLabs-Element-Requesting-QoS",       "integer" ],
                "66" => [ "CableLabs-QoS-Release-Reason",           "integer" ],
                "67" => [ "CableLabs-Policy-Denied-Reason",         "integer" ],
                "68" => [ "CableLabs-Policy-Deleted-Reason",        "integer" ],
                "69" => [ "CableLabs-Policy-Update-Reason",         "integer" ],
                "70" => [ "CableLabs-Policy-Decision-Status",       "integer" ],
                "71" => [ "CableLabs-Application-Manager-ID",       "integer" ],
                "72" => [ "CableLabs-Time-Usage-Limit",             "integer" ],
                "73" => [ "CableLabs-Gate-Time-Info",               "integer" ],
                "80" => [ "CableLabs-Account-Code",                 "string" ],
                "81" => [ "CableLabs-Authorization-Code",           "string" ],
            },
            4735 => {
                "0"  => [ "Prosoft-Home-Agent-Address",       "ipaddr" ],
                "1"  => [ "Prosoft-Default-Gateway",          "ipaddr" ],
                "2"  => [ "Prosoft-Primary-DNS",              "ipaddr" ],
                "3"  => [ "Prosoft-Secondary-DNS",            "ipaddr" ],
                "4"  => [ "Prosoft-Security-Parameter-Index", "integer" ],
                "5"  => [ "Prosoft-Security-Key",             "string" ],
                "7"  => [ "Prosoft-MAC-Address",              "string" ],
                "8"  => [ "Prosoft-Authentication-Reason",    "integer" ],
                "9"  => [ "Prosoft-ATM-Interface",            "integer" ],
                "10" => [ "Prosoft-ATM-VPI",                  "integer" ],
                "11" => [ "Prosoft-ATM-VCI",                  "integer" ],
                "12" => [ "Prosoft-RSC-Identifier",           "string" ],
                "13" => [ "Prosoft-NPM-Identifier",           "string" ],
                "14" => [ "Prosoft-NPM-IP",                   "string" ],
                "15" => [ "Prosoft-Sector-ID",                "string" ],
                "16" => [ "Prosoft-Auth-Role",                "integer" ],
            },
            4846 => {
                2     => [ "Lucent-Max-Shared-Users",               "integer" ],
                3     => [ "Lucent-IP-DSCP",                        "integer" ],
                4     => [ "Lucent-X25-X121-Source-Address",        "string" ],
                5     => [ "Lucent-PPP-Circuit",                    "integer" ],
                6     => [ "Lucent-PPP-Circuit-Name",               "string" ],
                7     => [ "Lucent-UU-Info",                        "string" ],
                8     => [ "Lucent-User-Priority",                  "integer" ],
                9     => [ "Lucent-CIR-Timer",                      "integer" ],
                10    => [ "Lucent-FR-08-Mode",                     "integer" ],
                11    => [ "Lucent-Destination-NAS-Port",           "integer" ],
                12    => [ "Lucent-FR-SVC-Addr",                    "string" ],
                13    => [ "Lucent-NAS-Port-Format",                "integer" ],
                14    => [ "Lucent-ATM-Fault-Management",           "integer" ],
                15    => [ "Lucent-ATM-Loopback-Cell-Loss",         "integer" ],
                16    => [ "Lucent-Ckt-Type",                       "integer" ],
                17    => [ "Lucent-SVC-Enabled",                    "integer" ],
                18    => [ "Lucent-Session-Type",                   "integer" ],
                19    => [ "Lucent-H323-Gatekeeper",                "ipaddr" ],
                20    => [ "Lucent-Global-Call-Id",                 "string" ],
                21    => [ "Lucent-H323-Conference-Id",             "integer" ],
                22    => [ "Lucent-H323-Destination-NAS-ID",        "ipaddr" ],
                23    => [ "Lucent-H323-Dialed-Time",               "integer" ],
                24    => [ "Lucent-Dialed-Number",                  "string" ],
                25    => [ "Lucent-Inter-Arrival-Jitter",           "integer" ],
                26    => [ "Lucent-Dropped-Octets",                 "integer" ],
                27    => [ "Lucent-Dropped-Packets",                "integer" ],
                28    => [ "Lucent-Auth-Delay",                     "integer" ],
                29    => [ "Lucent-X25-Pad-X3-Profile",             "integer" ],
                30    => [ "Lucent-X25-Pad-X3-Parameters",          "string" ],
                31    => [ "Lucent-Tunnel-VRouter-Name",            "string" ],
                32    => [ "Lucent-X25-Reverse-Charging",           "integer" ],
                33    => [ "Lucent-X25-Nui-Prompt",                 "string" ],
                34    => [ "Lucent-X25-Nui-Password-Prompt",        "string" ],
                35    => [ "Lucent-X25-Cug",                        "string" ],
                36    => [ "Lucent-X25-Pad-Alias-1",                "string" ],
                37    => [ "Lucent-X25-Pad-Alias-2",                "string" ],
                38    => [ "Lucent-X25-Pad-Alias-3",                "string" ],
                39    => [ "Lucent-X25-X121-Address",               "string" ],
                40    => [ "Lucent-X25-Nui",                        "string" ],
                41    => [ "Lucent-X25-Rpoa",                       "string" ],
                42    => [ "Lucent-X25-Pad-Prompt",                 "string" ],
                43    => [ "Lucent-X25-Pad-Banner",                 "string" ],
                44    => [ "Lucent-X25-Profile-Name",               "string" ],
                45    => [ "Lucent-Recv-Name",                      "string" ],
                46    => [ "Lucent-Bi-Directional-Auth",            "integer" ],
                47    => [ "Lucent-MTU",                            "integer" ],
                48    => [ "Lucent-Call-Direction",                 "integer" ],
                49    => [ "Lucent-Service-Type",                   "integer" ],
                50    => [ "Lucent-Filter-Required",                "integer" ],
                51    => [ "Lucent-Traffic-Shaper",                 "integer" ],
                52    => [ "Lucent-Access-Intercept-LEA",           "string" ],
                53    => [ "Lucent-Access-Intercept-Log",           "string" ],
                54    => [ "Lucent-Private-Route-Table-ID",         "string" ],
                55    => [ "Lucent-Private-Route-Required",         "integer" ],
                56    => [ "Lucent-Cache-Refresh",                  "integer" ],
                57    => [ "Lucent-Cache-Time",                     "integer" ],
                58    => [ "Lucent-Egress-Enabled",                 "integer" ],
                59    => [ "Lucent-QOS-Upstream",                   "string" ],
                60    => [ "Lucent-QOS-Downstream",                 "string" ],
                61    => [ "Lucent-ATM-Connect-Vpi",                "integer" ],
                62    => [ "Lucent-ATM-Connect-Vci",                "integer" ],
                63    => [ "Lucent-ATM-Connect-Group",              "integer" ],
                64    => [ "Lucent-ATM-Group",                      "integer" ],
                65    => [ "Lucent-IPX-Header-Compression",         "integer" ],
                66    => [ "Lucent-Calling-Id-Type-Of-Number",      "integer" ],
                67    => [ "Lucent-Calling-Id-Numbering-Plan",      "integer" ],
                68    => [ "Lucent-Calling-Id-Presentation",        "integer" ],
                69    => [ "Lucent-Calling-Id-Screening",           "integer" ],
                70    => [ "Lucent-BIR-Enable",                     "integer" ],
                71    => [ "Lucent-BIR-Proxy",                      "integer" ],
                72    => [ "Lucent-BIR-Bridge-Group",               "integer" ],
                73    => [ "Lucent-IPSEC-Profile",                  "string" ],
                74    => [ "Lucent-PPPoE-Enable",                   "integer" ],
                75    => [ "Lucent-Bridge-Non-PPPoE",               "integer" ],
                76    => [ "Lucent-ATM-Direct",                     "integer" ],
                77    => [ "Lucent-ATM-Direct-Profile",             "string" ],
                78    => [ "Lucent-Client-Primary-WINS",            "ipaddr" ],
                79    => [ "Lucent-Client-Secondary-WINS",          "ipaddr" ],
                80    => [ "Lucent-Client-Assign-WINS",             "integer" ],
                81    => [ "Lucent-Auth-Type",                      "integer" ],
                82    => [ "Lucent-Port-Redir-Protocol",            "integer" ],
                83    => [ "Lucent-Port-Redir-Portnum",             "integer" ],
                84    => [ "Lucent-Port-Redir-Server",              "ipaddr" ],
                85    => [ "Lucent-IP-Pool-Chaining",               "integer" ],
                86    => [ "Lucent-Owner-IP-Addr",                  "ipaddr" ],
                87    => [ "Lucent-IP-TOS",                         "integer" ],
                88    => [ "Lucent-IP-TOS-Precedence",              "integer" ],
                89    => [ "Lucent-IP-TOS-Apply-To",                "integer" ],
                90    => [ "Lucent-Filter",                         "string" ],
                91    => [ "Lucent-Telnet-Profile",                 "string" ],
                92    => [ "Lucent-Dsl-Rate-Type",                  "integer" ],
                93    => [ "Lucent-Redirect-Number",                "string" ],
                94    => [ "Lucent-ATM-Vpi",                        "integer" ],
                95    => [ "Lucent-ATM-Vci",                        "integer" ],
                96    => [ "Lucent-Source-IP-Check",                "integer" ],
                97    => [ "Lucent-Dsl-Rate-Mode",                  "integer" ],
                98    => [ "Lucent-Dsl-Upstream-Limit",             "integer" ],
                99    => [ "Lucent-Dsl-Downstream-Limit",           "integer" ],
                100   => [ "Lucent-Dsl-CIR-Recv-Limit",             "integer" ],
                101   => [ "Lucent-Dsl-CIR-Xmit-Limit",             "integer" ],
                102   => [ "Lucent-VRouter-Name",                   "string" ],
                103   => [ "Lucent-Source-Auth",                    "string" ],
                104   => [ "Lucent-Private-Route",                  "string" ],
                105   => [ "Lucent-Numbering-Plan-ID",              "integer" ],
                106   => [ "Lucent-FR-Link-Status-DLCI",            "integer" ],
                107   => [ "Lucent-Calling-Subaddress",             "string" ],
                108   => [ "Lucent-Callback-Delay",                 "integer" ],
                109   => [ "Lucent-Endpoint-Disc",                  "octets" ],
                110   => [ "Lucent-Remote-FW",                      "string" ],
                111   => [ "Lucent-Multicast-GLeave-Delay",         "integer" ],
                112   => [ "Lucent-CBCP-Enable",                    "integer" ],
                113   => [ "Lucent-CBCP-Mode",                      "integer" ],
                114   => [ "Lucent-CBCP-Delay",                     "integer" ],
                115   => [ "Lucent-CBCP-Trunk-Group",               "integer" ],
                116   => [ "Lucent-Appletalk-Route",                "string" ],
                117   => [ "Lucent-Appletalk-Peer-Mode",            "integer" ],
                118   => [ "Lucent-Route-Appletalk",                "integer" ],
                119   => [ "Lucent-FCP-Parameter",                  "string" ],
                120   => [ "Lucent-Modem-PortNo",                   "integer" ],
                121   => [ "Lucent-Modem-SlotNo",                   "integer" ],
                122   => [ "Lucent-Modem-ShelfNo",                  "integer" ],
                123   => [ "Lucent-Call-Attempt-Limit",             "integer" ],
                124   => [ "Lucent-Call-Block-Duration",            "integer" ],
                125   => [ "Lucent-Maximum-Call-Duration",          "integer" ],
                126   => [ "Lucent-Route-Preference",               "integer" ],
                127   => [ "Lucent-Tunneling-Protocol",             "integer" ],
                128   => [ "Lucent-Shared-Profile-Enable",          "integer" ],
                129   => [ "Lucent-Primary-Home-Agent",             "string" ],
                130   => [ "Lucent-Secondary-Home-Agent",           "string" ],
                131   => [ "Lucent-Dialout-Allowed",                "integer" ],
                132   => [ "Lucent-Client-Gateway",                 "ipaddr" ],
                133   => [ "Lucent-BACP-Enable",                    "integer" ],
                134   => [ "Lucent-DHCP-Maximum-Leases",            "integer" ],
                135   => [ "Lucent-Client-Primary-DNS",             "ipaddr" ],
                136   => [ "Lucent-Client-Secondary-DNS",           "ipaddr" ],
                137   => [ "Lucent-Client-Assign-DNS",              "integer" ],
                138   => [ "Lucent-User-Acct-Type",                 "integer" ],
                139   => [ "Lucent-User-Acct-Host",                 "ipaddr" ],
                140   => [ "Lucent-User-Acct-Port",                 "integer" ],
                141   => [ "Lucent-User-Acct-Key",                  "string" ],
                142   => [ "Lucent-User-Acct-Base",                 "integer" ],
                143   => [ "Lucent-User-Acct-Time",                 "integer" ],
                144   => [ "Lucent-Assign-IP-Client",               "ipaddr" ],
                145   => [ "Lucent-Assign-IP-Server",               "ipaddr" ],
                146   => [ "Lucent-Assign-IP-Global-Pool",          "string" ],
                147   => [ "Lucent-DHCP-Reply",                     "integer" ],
                148   => [ "Lucent-DHCP-Pool-Number",               "integer" ],
                149   => [ "Lucent-Expect-Callback",                "integer" ],
                150   => [ "Lucent-Event-Type",                     "integer" ],
                151   => [ "Lucent-Session-Svr-Key",                "string" ],
                152   => [ "Lucent-Multicast-Rate-Limit",           "integer" ],
                153   => [ "Lucent-IF-Netmask",                     "ipaddr" ],
                154   => [ "Lucent-Remote-Addr",                    "ipaddr" ],
                155   => [ "Lucent-Multicast-Client",               "integer" ],
                156   => [ "Lucent-FR-Circuit-Name",                "string" ],
                157   => [ "Lucent-FR-LinkUp",                      "integer" ],
                158   => [ "Lucent-FR-Nailed-Grp",                  "integer" ],
                159   => [ "Lucent-FR-Type",                        "integer" ],
                160   => [ "Lucent-FR-Link-Mgt",                    "integer" ],
                161   => [ "Lucent-FR-N391",                        "integer" ],
                162   => [ "Lucent-FR-DCE-N392",                    "integer" ],
                163   => [ "Lucent-FR-DTE-N392",                    "integer" ],
                164   => [ "Lucent-FR-DCE-N393",                    "integer" ],
                165   => [ "Lucent-FR-DTE-N393",                    "integer" ],
                166   => [ "Lucent-FR-T391",                        "integer" ],
                167   => [ "Lucent-FR-T392",                        "integer" ],
                168   => [ "Lucent-Bridge-Address",                 "string" ],
                169   => [ "Lucent-TS-Idle-Limit",                  "integer" ],
                170   => [ "Lucent-TS-Idle-Mode",                   "integer" ],
                171   => [ "Lucent-DBA-Monitor",                    "integer" ],
                172   => [ "Lucent-Base-Channel-Count",             "integer" ],
                173   => [ "Lucent-Minimum-Channels",               "integer" ],
                174   => [ "Lucent-IPX-Route",                      "string" ],
                175   => [ "Lucent-FT1-Caller",                     "integer" ],
                176   => [ "Lucent-Backup",                         "string" ],
                177   => [ "Lucent-Call-Type",                      "integer" ],
                178   => [ "Lucent-Group",                          "string" ],
                179   => [ "Lucent-FR-DLCI",                        "integer" ],
                180   => [ "Lucent-FR-Profile-Name",                "string" ],
                181   => [ "Lucent-Ara-PW",                         "string" ],
                182   => [ "Lucent-IPX-Node-Addr",                  "string" ],
                183   => [ "Lucent-Home-Agent-IP-Addr",             "ipaddr" ],
                184   => [ "Lucent-Home-Agent-Password",            "string" ],
                185   => [ "Lucent-Home-Network-Name",              "string" ],
                186   => [ "Lucent-Home-Agent-UDP-Port",            "integer" ],
                187   => [ "Lucent-Multilink-ID",                   "integer" ],
                188   => [ "Lucent-Num-In-Multilink",               "integer" ],
                189   => [ "Lucent-First-Dest",                     "ipaddr" ],
                190   => [ "Lucent-Pre-Input-Octets",               "integer" ],
                191   => [ "Lucent-Pre-Output-Octets",              "integer" ],
                192   => [ "Lucent-Pre-Input-Packets",              "integer" ],
                193   => [ "Lucent-Pre-Output-Packets",             "integer" ],
                194   => [ "Lucent-Maximum-Time",                   "integer" ],
                195   => [ "Lucent-Disconnect-Cause",               "integer" ],
                196   => [ "Lucent-Connect-Progress",               "integer" ],
                197   => [ "Lucent-Data-Rate",                      "integer" ],
                198   => [ "Lucent-PreSession-Time",                "integer" ],
                199   => [ "Lucent-Token-Idle",                     "integer" ],
                200   => [ "Lucent-Token-Immediate",                "integer" ],
                201   => [ "Lucent-Require-Auth",                   "integer" ],
                202   => [ "Lucent-Number-Sessions",                "string" ],
                203   => [ "Lucent-Authen-Alias",                   "string" ],
                204   => [ "Lucent-Token-Expiry",                   "integer" ],
                205   => [ "Lucent-Menu-Selector",                  "string" ],
                206   => [ "Lucent-Menu-Item",                      "string" ],
                207   => [ "Lucent-PW-Warntime",                    "integer" ],
                208   => [ "Lucent-PW-Lifetime",                    "integer" ],
                209   => [ "Lucent-IP-Direct",                      "ipaddr" ],
                210   => [ "Lucent-PPP-VJ-Slot-Comp",               "integer" ],
                211   => [ "Lucent-PPP-VJ-1172",                    "integer" ],
                212   => [ "Lucent-PPP-Async-Map",                  "integer" ],
                213   => [ "Lucent-Third-Prompt",                   "string" ],
                214   => [ "Lucent-Send-Secret",                    "string" ],
                215   => [ "Lucent-Receive-Secret",                 "string" ],
                216   => [ "Lucent-IPX-Peer-Mode",                  "integer" ],
                217   => [ "Lucent-IP-Pool-Definition",             "string" ],
                218   => [ "Lucent-Assign-IP-Pool",                 "integer" ],
                219   => [ "Lucent-FR-Direct",                      "integer" ],
                220   => [ "Lucent-FR-Direct-Profile",              "string" ],
                221   => [ "Lucent-FR-Direct-DLCI",                 "integer" ],
                222   => [ "Lucent-Handle-IPX",                     "integer" ],
                223   => [ "Lucent-Netware-timeout",                "integer" ],
                224   => [ "Lucent-IPX-Alias",                      "integer" ],
                225   => [ "Lucent-Metric",                         "integer" ],
                226   => [ "Lucent-PRI-Number-Type",                "integer" ],
                227   => [ "Lucent-Dial-Number",                    "string" ],
                228   => [ "Lucent-Route-IP",                       "integer" ],
                229   => [ "Lucent-Route-IPX",                      "integer" ],
                230   => [ "Lucent-Bridge",                         "integer" ],
                231   => [ "Lucent-Send-Auth",                      "integer" ],
                232   => [ "Lucent-Send-Passwd",                    "string" ],
                233   => [ "Lucent-Link-Compression",               "integer" ],
                234   => [ "Lucent-Target-Util",                    "integer" ],
                235   => [ "Lucent-Maximum-Channels",               "integer" ],
                236   => [ "Lucent-Inc-Channel-Count",              "integer" ],
                237   => [ "Lucent-Dec-Channel-Count",              "integer" ],
                238   => [ "Lucent-Seconds-Of-History",             "integer" ],
                239   => [ "Lucent-History-Weigh-Type",             "integer" ],
                240   => [ "Lucent-Add-Seconds",                    "integer" ],
                241   => [ "Lucent-Remove-Seconds",                 "integer" ],
                242   => [ "Lucent-Data-Filter",                    "abinary" ],
                243   => [ "Lucent-Call-Filter",                    "abinary" ],
                244   => [ "Lucent-Idle-Limit",                     "integer" ],
                245   => [ "Lucent-Preempt-Limit",                  "integer" ],
                246   => [ "Lucent-Callback",                       "integer" ],
                247   => [ "Lucent-Data-Svc",                       "integer" ],
                248   => [ "Lucent-Force-56",                       "integer" ],
                249   => [ "Lucent-Billing-Number",                 "string" ],
                250   => [ "Lucent-Call-By-Call",                   "integer" ],
                251   => [ "Lucent-Transit-Number",                 "string" ],
                252   => [ "Lucent-Host-Info",                      "string" ],
                253   => [ "Lucent-PPP-Address",                    "ipaddr" ],
                254   => [ "Lucent-MPP-Idle-Percent",               "integer" ],
                255   => [ "Lucent-Xmit-Rate",                      "integer" ],
                256   => [ "Lucent-Fr05-Traffic-Shaper",            "integer" ],
                257   => [ "Lucent-Fr05-Vpi",                       "integer" ],
                258   => [ "Lucent-Fr05-Vci",                       "integer" ],
                259   => [ "Lucent-Fr05-Enabled",                   "integer" ],
                260   => [ "Lucent-Tunnel-Auth-Type",               "octets" ],
                261   => [ "Lucent-MOH-Timeout",                    "integer" ],
                262   => [ "Lucent-ATM-Circuit-Name",               "string" ],
                263   => [ "Lucent-Priority-For-PPP",               "integer" ],
                264   => [ "Lucent-Max-RTP-Delay",                  "integer" ],
                265   => [ "Lucent-RTP-Port-Range",                 "string" ],
                266   => [ "Lucent-TOS-Copying",                    "integer" ],
                267   => [ "Lucent-Packet-Classification",          "integer" ],
                268   => [ "Lucent-No-High-Prio-Pkt-Duratio",       "integer" ],
                269   => [ "Lucent-AT-Answer-String",               "string" ],
                270   => [ "Lucent-IP-OUTGOING-TOS",                "integer" ],
                271   => [ "Lucent-IP-OUTGOING-TOS-Precedence",     "integer" ],
                272   => [ "Lucent-IP-OUTGOING-DSCP",               "integer" ],
                273   => [ "Lucent-TermSrv-Login-Prompt",           "string" ],
                274   => [ "Lucent-Multicast-Service-Profile-Name", "string" ],
                275   => [ "Lucent-Multicast-Max-Groups",           "integer" ],
                276   => [ "Lucent-Multicast-Service-Name",         "string" ],
                277   => [ "Lucent-Multicast-Service-Active",       "integer" ],
                278   => [ "Lucent-Multicast-Service-Snmp-Trap",    "integer" ],
                279   => [ "Lucent-Multicast-Service-Filter-Type",  "integer" ],
                280   => [ "Lucent-Multicast-Filter-Active",        "integer" ],
                281   => [ "Lucent-Multicast-Filter-Address",       "ipaddr" ],
                282   => [ "Lucent-Tunnel-TOS",                     "integer" ],
                283   => [ "Lucent-Tunnel-TOS-Precedence",          "integer" ],
                284   => [ "Lucent-Tunnel-DSCP",                    "integer" ],
                285   => [ "Lucent-Tunnel-TOS-Filter",              "string" ],
                286   => [ "Lucent-Tunnel-TOS-Copy",                "integer" ],
                287   => [ "Lucent-Http-Redirect-URL",              "string" ],
                288   => [ "Lucent-Http-Redirect-Port",             "integer" ],
                289   => [ "Lucent-L2TP-DCI-Disconnect-Code",       "integer" ],
                290   => [ "Lucent-L2TP-DCI-Protocol-Number",       "integer" ],
                291   => [ "Lucent-L2TP-DCI-Direction",             "integer" ],
                292   => [ "Lucent-L2TP-DCI-Message",               "string" ],
                293   => [ "Lucent-L2TP-Q931-Cause-Code",           "integer" ],
                294   => [ "Lucent-L2TP-Q931-Cause-Message",        "integer" ],
                295   => [ "Lucent-L2TP-Q931-Advisory-Message",     "string" ],
                296   => [ "Lucent-L2TP-RC-Result-Code",            "integer" ],
                297   => [ "Lucent-L2TP-RC-Error-Code",             "integer" ],
                298   => [ "Lucent-L2TP-RC-Error-Message",          "string" ],
                299   => [ "Lucent-L2TP-Disconnect-Scenario",       "integer" ],
                300   => [ "Lucent-L2TP-Peer-Disconnect-Cause",     "integer" ],
                301   => [ "Lucent-L2TP-Peer-Connect-Progress",     "integer" ],
                302   => [ "Lucent-QuickConnect-Attempted",         "integer" ],
                303   => [ "Lucent-Num-Moh-Sessions",               "integer" ],
                304   => [ "Lucent-Cumulative-Hold-Time",           "integer" ],
                305   => [ "Lucent-Modem-Modulation",               "integer" ],
                306   => [ "Lucent-User-Acct-Expiration",           "date" ],
                307   => [ "Lucent-User-Login-Level",               "integer" ],
                308   => [ "Lucent-First-Level-User",               "string" ],
                309   => [ "Lucent-IP-Source-If",                   "string" ],
                310   => [ "Lucent-Reverse-Path-Check",             "integer" ],
                321   => [ "Lucent-LCP-Keepalive-Period",           "integer" ],
                322   => [ "Lucent-LCP-Keepalive-Missed-Limit",     "integer" ],
                10000 => [ "Lucent-Dsl-Atuc-Chan-Uncorrect-Blks",   "integer" ],
                10001 => [ "Lucent-Dsl-Atuc-Chan-Corrected-Blks",   "integer" ],
                10002 => [ "Lucent-Dsl-Atuc-Chan-Xmit-Blks",        "integer" ],
                10003 => [ "Lucent-Dsl-Atuc-Chan-Recd-Blks",        "integer" ],
                10004 => [ "Lucent-Dsl-Atuc-Perf-Inits",            "integer" ],
                10005 => [ "Lucent-Dsl-Atuc-Perf-ESs",              "integer" ],
                10006 => [ "Lucent-Dsl-Atuc-Perf-Lprs",             "integer" ],
                10007 => [ "Lucent-Dsl-Atuc-Perf-Lols",             "integer" ],
                10008 => [ "Lucent-Dsl-Atuc-Perf-Loss",             "integer" ],
                10009 => [ "Lucent-Dsl-Atuc-Perf-Lofs",             "integer" ],
                10010 =>
                  [ "Lucent-Dsl-Atuc-Curr-Attainable-Rate-Dn", "integer" ],
                10011 => [ "Lucent-Dsl-Atuc-Curr-Output-Pwr-Dn", "integer" ],
                10012 => [ "Lucent-Dsl-Atuc-Curr-Atn-Up",        "integer" ],
                10013 => [ "Lucent-Dsl-Atuc-Curr-Snr-Mgn-Up",    "integer" ],
                10014 => [ "Lucent-Dsl-Atuc-PS-Fast-Retrains",   "integer" ],
                10015 =>
                  [ "Lucent-Dsl-Atuc-PS-Failed-Fast-Retrains", "integer" ],
                10016 => [ "Lucent-Dsl-Code-Violations",  "integer" ],
                10017 => [ "Lucent-Line-Type",            "integer" ],
                10018 => [ "Lucent-Dsl-Curr-Up-Rate",     "integer" ],
                10019 => [ "Lucent-Dsl-Curr-Dn-Rate",     "integer" ],
                10020 => [ "Lucent-Dsl-Physical-Slot",    "integer" ],
                10021 => [ "Lucent-Dsl-Physical-Line",    "integer" ],
                10022 => [ "Lucent-Dsl-If-Index",         "integer" ],
                10023 => [ "Lucent-Dsl-Oper-Status",      "integer" ],
                10024 => [ "Lucent-Dsl-Related-If-Index", "integer" ],
                10025 =>
                  [ "Lucent-Dsl-Atuc-Curr-Attainable-Rate-Up", "integer" ],
                10026 => [ "Lucent-Dsl-Atuc-Curr-Output-Pwr-Up",  "integer" ],
                10027 => [ "Lucent-Dsl-Atuc-Curr-Atn-Dn",         "integer" ],
                10028 => [ "Lucent-Dsl-Atuc-Curr-Snr-Mgn-D",      "integer" ],
                10029 => [ "Lucent-Dsl-Related-Slot",             "integer" ],
                10030 => [ "Lucent-Dsl-Related-Port",             "integer" ],
                10031 => [ "Lucent-Dsl-Sparing-Role",             "integer" ],
                10032 => [ "Lucent-Absolute-Time",                "integer" ],
                10033 => [ "Lucent-Configured-Rate-Up-Min",       "integer" ],
                10034 => [ "Lucent-Configured-Rate-Up-Max",       "integer" ],
                10035 => [ "Lucent-Configured-Rate-Dn-Min",       "integer" ],
                10036 => [ "Lucent-Configured-Rate-Dn-Max",       "integer" ],
                10037 => [ "Lucent-Dsl-Physical-Channel",         "integer" ],
                10100 => [ "Lucent-Sonet-Section-ESs",            "integer" ],
                10101 => [ "Lucent-Sonet-Section-SESs",           "integer" ],
                10102 => [ "Lucent-Sonet-Section-SEFSs",          "integer" ],
                10103 => [ "Lucent-Sonet-Section-CVs",            "integer" ],
                10104 => [ "Lucent-Sonet-Line-ESs-Near",          "integer" ],
                10105 => [ "Lucent-Sonet-Line-SESs-Near",         "integer" ],
                10106 => [ "Lucent-Sonet-Line-CVs-Near",          "integer" ],
                10107 => [ "Lucent-Sonet-Line-USs-Near",          "integer" ],
                10108 => [ "Lucent-Sonet-Line-ESs-Far",           "integer" ],
                10109 => [ "Lucent-Sonet-Line-SESs-Far",          "integer" ],
                10110 => [ "Lucent-Sonet-Line-CVs-Far",           "integer" ],
                10111 => [ "Lucent-Sonet-Line-USs-Far",           "integer" ],
                10112 => [ "Lucent-Sonet-Path-ESs-Near",          "integer" ],
                10113 => [ "Lucent-Sonet-Path-SESs-Near",         "integer" ],
                10114 => [ "Lucent-Sonet-Path-CVs-Near",          "integer" ],
                10115 => [ "Lucent-Sonet-Path-USs-Near",          "integer" ],
                10116 => [ "Lucent-Sonet-Path-ESs-Far",           "integer" ],
                10117 => [ "Lucent-Sonet-Path-SESs-Far",          "integer" ],
                10118 => [ "Lucent-Sonet-Path-CVs-Far",           "integer" ],
                10119 => [ "Lucent-Sonet-Path-USs-Far",           "integer" ],
                10200 => [ "Lucent-Ds3-F-Bit-Err",                "integer" ],
                10201 => [ "Lucent-Ds3-P-Bit-Err",                "integer" ],
                10202 => [ "Lucent-Ds3-CCVs",                     "integer" ],
                10203 => [ "Lucent-Ds3-PESs",                     "integer" ],
                10204 => [ "Lucent-Ds3-PSESs",                    "integer" ],
                10205 => [ "Lucent-Ds3-SEFs",                     "integer" ],
                10206 => [ "Lucent-Ds3-UASs",                     "integer" ],
                10207 => [ "Lucent-Ds3-LCVs",                     "integer" ],
                10208 => [ "Lucent-Ds3-PCVs",                     "integer" ],
                10209 => [ "Lucent-Ds3-LESs",                     "integer" ],
                10210 => [ "Lucent-Ds3-CESs",                     "integer" ],
                10211 => [ "Lucent-Ds3-CSESs",                    "integer" ],
                10300 => [ "Lucent-Rtp-Local-Number-Of-Samples",  "integer" ],
                10301 => [ "Lucent-Rtp-Remote-Number-Of-Samples", "integer" ],
                10302 => [ "Lucent-Rtp-Local-Jitter-Minimum",     "integer" ],
                10303 => [ "Lucent-Rtp-Local-Jitter-Maximum",     "integer" ],
                10304 => [ "Lucent-Rtp-Local-Jitter-Mean",        "integer" ],
                10305 => [ "Lucent-Rtp-Local-Jitter-Variance",    "integer" ],
                10306 => [ "Lucent-Rtp-Local-Delay-Minimum",      "integer" ],
                10307 => [ "Lucent-Rtp-Local-Delay-Maximum",      "integer" ],
                10308 => [ "Lucent-Rtp-Local-Delay-Mean",         "integer" ],
                10309 => [ "Lucent-Rtp-Local-Delay-Variance",     "integer" ],
                10310 => [ "Lucent-Rtp-Local-Packets-Sent",       "integer" ],
                10311 => [ "Lucent-Rtp-Local-Packets-Lost",       "integer" ],
                10312 => [ "Lucent-Rtp-Local-Packets-Late",       "integer" ],
                10313 => [ "Lucent-Rtp-Local-Bytes-Sent",         "integer" ],
                10314 => [ "Lucent-Rtp-Local-Silence-Percent",    "integer" ],
                10315 => [ "Lucent-Rtp-Remote-Jitter-Minimum",    "integer" ],
                10316 => [ "Lucent-Rtp-Remote-Jitter-Maximum",    "integer" ],
                10317 => [ "Lucent-Rtp-Remote-Jitter-Mean",       "integer" ],
                10318 => [ "Lucent-Rtp-Remote-Jitter-Variance",   "integer" ],
                10319 => [ "Lucent-Rtp-Remote-Delay-Minimum",     "integer" ],
                10320 => [ "Lucent-Rtp-Remote-Delay-Maximum",     "integer" ],
                10321 => [ "Lucent-Rtp-Remote-Delay-Mean",        "integer" ],
                10322 => [ "Lucent-Rtp-Remote-Delay-Variance",    "integer" ],
                10323 => [ "Lucent-Rtp-Remote-Packets-Sent",      "integer" ],
                10324 => [ "Lucent-Rtp-Remote-Packets-Lost",      "integer" ],
                10325 => [ "Lucent-Rtp-Remote-Packets-Late",      "integer" ],
                10326 => [ "Lucent-Rtp-Remote-Bytes-Sent",        "integer" ],
                10327 => [ "Lucent-Rtp-Remote-Silence-Percent",   "integer" ],
                19999 => [ "Lucent-Tunnel-Auth-Type2",            "integer" ],
                20000 => [ "Lucent-Multi-Packet-Separator",       "integer" ],
                20100 => [ "Lucent-Min-Xmit-Rate",                "integer" ],
                20101 => [ "Lucent-Max-Xmit-Rate",                "integer" ],
                20102 => [ "Lucent-Min-Recv-Rate",                "integer" ],
                20103 => [ "Lucent-Max-Recv-Rate",                "integer" ],
                20104 => [ "Lucent-Error-Correction-Protocol",    "integer" ],
                20105 => [ "Lucent-Compression-Protocol",         "integer" ],
                20106 => [ "Lucent-Modulation",                   "integer" ],
                20107 => [ "Lucent-Xmit-Symbol-Rate",             "integer" ],
                20108 => [ "Lucent-Recv-Symbol-Rate",             "integer" ],
                20109 => [ "Lucent-Current-Xmit-Level",           "integer" ],
                20110 => [ "Lucent-Current-Recv-Level",           "integer" ],
                20111 => [ "Lucent-Current-Line-Quality",         "integer" ],
                20112 => [ "Lucent-Current-SNR",                  "integer" ],
                20113 => [ "Lucent-Min-SNR",                      "integer" ],
                20114 => [ "Lucent-Max-SNR",                      "integer" ],
                20115 => [ "Lucent-Local-Retrain-Requested",      "integer" ],
                20116 => [ "Lucent-Remote-Retrain-Requested",     "integer" ],
                20117 => [ "Lucent-Connection-Time",              "integer" ],
                20118 => [ "Lucent-Modem-Disconnect-Reason",      "integer" ],
                20119 => [ "Lucent-Retrain-Reason",               "integer" ],
            },
            4874 => {
                1   => [ "ERX-Virtual-Router-Name",            "string" ],
                2   => [ "ERX-Address-Pool-Name",              "string" ],
                3   => [ "ERX-Local-Loopback-Interface",       "string" ],
                4   => [ "ERX-Primary-Dns",                    "ipaddr" ],
                5   => [ "ERX-Secondary-Dns",                  "ipaddr" ],
                6   => [ "ERX-Primary-Wins",                   "ipaddr" ],
                7   => [ "ERX-Secondary-Wins",                 "ipaddr" ],
                8   => [ "ERX-Tunnel-Virtual-Router",          "string" ],
                9   => [ "ERX-Tunnel-Password",                "string" ],
                10  => [ "ERX-Ingress-Policy-Name",            "string" ],
                11  => [ "ERX-Egress-Policy-Name",             "string" ],
                12  => [ "ERX-Ingress-Statistics",             "integer" ],
                13  => [ "ERX-Egress-Statistics",              "integer" ],
                14  => [ "ERX-Atm-Service-Category",           "integer" ],
                15  => [ "ERX-Atm-PCR",                        "integer" ],
                16  => [ "ERX-Atm-SCR",                        "integer" ],
                17  => [ "ERX-Atm-MBS",                        "integer" ],
                18  => [ "ERX-Cli-Initial-Access-Level",       "string" ],
                19  => [ "ERX-Cli-Allow-All-VR-Access",        "integer" ],
                20  => [ "ERX-Alternate-Cli-Access-Level",     "string" ],
                21  => [ "ERX-Alternate-Cli-Vrouter-Name",     "string" ],
                22  => [ "ERX-Sa-Validate",                    "integer" ],
                23  => [ "ERX-Igmp-Enable",                    "integer" ],
                24  => [ "ERX-Pppoe-Description",              "string" ],
                25  => [ "ERX-Redirect-VR-Name",               "string" ],
                26  => [ "ERX-Qos-Profile-Name",               "string" ],
                27  => [ "ERX-Pppoe-Max-Sessions",             "integer" ],
                28  => [ "ERX-Pppoe-Url",                      "string" ],
                29  => [ "ERX-Qos-Profile-Interface-Type",     "integer" ],
                30  => [ "ERX-Tunnel-Nas-Port-Method",         "integer" ],
                31  => [ "ERX-Service-Bundle",                 "string" ],
                32  => [ "ERX-Tunnel-Tos",                     "integer" ],
                33  => [ "ERX-Tunnel-Maximum-Sessions",        "integer" ],
                34  => [ "ERX-Framed-Ip-Route-Tag",            "string" ],
                35  => [ "ERX-Dial-Out-Number",                "string" ],
                36  => [ "ERX-PPP-Username",                   "string" ],
                37  => [ "ERX-PPP-Password",                   "string" ],
                38  => [ "ERX-PPP-Auth-Protocol",              "integer" ],
                39  => [ "ERX-Minimum-BPS",                    "integer" ],
                40  => [ "ERX-Maximum-BPS",                    "integer" ],
                41  => [ "ERX-Bearer-Type",                    "integer" ],
                42  => [ "ERX-Input-Gigapkts",                 "integer" ],
                43  => [ "ERX-Output-Gigapkts",                "integer" ],
                44  => [ "ERX-Tunnel-Interface-Id",            "string" ],
                45  => [ "ERX-IpV6-Virtual-Router",            "string" ],
                46  => [ "ERX-IpV6-Local-Interface",           "string" ],
                47  => [ "ERX-Ipv6-Primary-Dns",               "ipv6addr" ],
                48  => [ "ERX-Ipv6-Secondary-Dns",             "ipv6addr" ],
                49  => [ "Sdx-Service-Name",                   "string" ],
                50  => [ "Sdx-Session-Volume-Quota",           "string" ],
                51  => [ "Sdx-Tunnel-Disconnect-Cause-Info",   "string" ],
                52  => [ "ERX-Radius-Client-Address",          "ipaddr" ],
                53  => [ "ERX-Service-Description",            "string" ],
                54  => [ "ERX-L2tp-Recv-Window-Size",          "integer" ],
                55  => [ "ERX-Dhcp-Options",                   "octets" ],
                56  => [ "ERX-Dhcp-Mac-Addr",                  "string" ],
                57  => [ "ERX-Dhcp-Gi-Address",                "ipaddr" ],
                58  => [ "ERX-LI-Action",                      "integer" ],
                59  => [ "ERX-Med-Dev-Handle",                 "octets" ],
                60  => [ "ERX-Med-Ip-Address",                 "ipaddr" ],
                61  => [ "ERX-Med-Port-Number",                "integer" ],
                62  => [ "ERX-MLPPP-Bundle-Name",              "string" ],
                63  => [ "ERX-Interface-Desc",                 "string" ],
                64  => [ "ERX-Tunnel-Group",                   "string" ],
                65  => [ "ERX-Service-Activate",               "string" ],
                66  => [ "ERX-Service-Deactivate",             "string" ],
                67  => [ "ERX-Service-Volume",                 "integer" ],
                68  => [ "ERX-Service-Timeout",                "integer" ],
                69  => [ "ERX-Service-Statistics",             "integer" ],
                70  => [ "ERX-DF-Bit",                         "integer" ],
                71  => [ "ERX-IGMP-Access-Name",               "string" ],
                72  => [ "ERX-IGMP-Access-Src-Name",           "string" ],
                73  => [ "ERX-IGMP-OIF-Map-Name",              "string" ],
                74  => [ "ERX-MLD-Access-Name",                "string" ],
                75  => [ "ERX-MLD-Access-Src-Name",            "string" ],
                76  => [ "ERX-MLD-OIF-Map-Name",               "string" ],
                77  => [ "ERX-MLD-Version",                    "integer" ],
                78  => [ "ERX-IGMP-Version",                   "integer" ],
                79  => [ "ERX-IP-Mcast-Adm-Bw-Limit",          "integer" ],
                80  => [ "ERX-IPv6-Mcast-Adm-Bw-Limit",        "integer" ],
                82  => [ "ERX-Qos-Parameters",                 "string" ],
                83  => [ "ERX-Service-Session",                "string" ],
                84  => [ "ERX-Mobile-IP-Algorithm",            "integer" ],
                85  => [ "ERX-Mobile-IP-SPI",                  "integer" ],
                86  => [ "ERX-Mobile-IP-Key",                  "string" ],
                87  => [ "ERX-Mobile-IP-Replay",               "integer" ],
                88  => [ "ERX-Mobile-IP-Access-Control",       "string" ],
                89  => [ "ERX-Mobile-IP-Lifetime",             "integer" ],
                90  => [ "ERX-L2TP-Resynch-Method",            "integer" ],
                91  => [ "ERX-Tunnel-Switch-Profile",          "string" ],
                92  => [ "ERX-L2c-Up-Stream-Data",             "string" ],
                93  => [ "ERX-L2c-Down-Stream-Data",           "string" ],
                94  => [ "ERX-Tunnel-Tx-Speed-Method",         "integer" ],
                95  => [ "ERX-IGMP-Query-Interval",            "integer" ],
                96  => [ "ERX-IGMP-Max-Resp-Time",             "integer" ],
                97  => [ "ERX-IGMP-Immediate-Leave",           "integer" ],
                98  => [ "ERX-MLD-Query-Interval",             "integer" ],
                99  => [ "ERX-MLD-Max-Resp-Time",              "integer" ],
                100 => [ "ERX-MLD-Immediate-Leave",            "integer" ],
                101 => [ "ERX-IP-Block-Multicast",             "integer" ],
                102 => [ "ERX-IGMP-Explicit-Tracking",         "integer" ],
                103 => [ "ERX-IGMP-No-Tracking-V2-Grps",       "integer" ],
                104 => [ "ERX-MLD-Explicit-Tracking",          "integer" ],
                105 => [ "ERX-MLD-No-Tracking-V1-Grps",        "integer" ],
                106 => [ "ERX-IPv6-Ingress-Policy-Name",       "string" ],
                107 => [ "ERX-IPv6-Egress-Policy-Name",        "string" ],
                108 => [ "ERX-CoS-Shaping-Pmt-Type",           "string" ],
                109 => [ "ERX-DHCP-Guided-Relay-Server",       "ipaddr" ],
                110 => [ "ERX-Acc-Loop-Cir-Id",                "string" ],
                111 => [ "ERX-Acc-Aggr-Cir-Id-Bin",            "octets" ],
                112 => [ "ERX-Acc-Aggr-Cir-Id-Asc",            "string" ],
                113 => [ "ERX-Act-Data-Rate-Up",               "integer" ],
                114 => [ "ERX-Act-Data-Rate-Dn",               "integer" ],
                115 => [ "ERX-Min-Data-Rate-Up",               "integer" ],
                116 => [ "ERX-Min-Data-Rate-Dn",               "integer" ],
                117 => [ "ERX-Att-Data-Rate-Up",               "integer" ],
                118 => [ "ERX-Att-Data-Rate-Dn",               "integer" ],
                119 => [ "ERX-Max-Data-Rate-Up",               "integer" ],
                120 => [ "ERX-Max-Data-Rate-Dn",               "integer" ],
                121 => [ "ERX-Min-LP-Data-Rate-Up",            "integer" ],
                122 => [ "ERX-Min-LP-Data-Rate-Dn",            "integer" ],
                123 => [ "ERX-Max-Interlv-Delay-Up",           "integer" ],
                124 => [ "ERX-Act-Interlv-Delay-Up",           "integer" ],
                125 => [ "ERX-Max-Interlv-Delay-Dn",           "integer" ],
                126 => [ "ERX-Act-Interlv-Delay-Dn",           "integer" ],
                127 => [ "ERX-DSL-Line-State",                 "integer" ],
                128 => [ "ERX-DSL-Type",                       "integer" ],
                129 => [ "ERX-IPv6-NdRa-Prefix",               "ipv6prefix" ],
                130 => [ "ERX-Qos-Set-Name",                   "string" ],
                140 => [ "ERX-Service-Acct-Interval",          "integer" ],
                141 => [ "ERX-DownStream-Calc-Rate",           "integer" ],
                142 => [ "ERX-UpStream-Calc-Rate",             "integer" ],
                143 => [ "ERX-Max-Clients-Per-Interface",      "integer" ],
                144 => [ "ERX-PPP-Monitor-Ingress-Only",       "integer" ],
                146 => [ "ERX-CoS-Scheduler-Pmt-Type",         "string" ],
                147 => [ "ERX-Backup-Address-Pool",            "string" ],
                150 => [ "ERX-ICR-Partition-Id",               "string" ],
                151 => [ "ERX-IPv6-Acct-Input-Octets",         "integer" ],
                152 => [ "ERX-IPv6-Acct-Output-Octets",        "integer" ],
                153 => [ "ERX-IPv6-Acct-Input-Packets",        "integer" ],
                154 => [ "ERX-IPv6-Acct-Output-Packets",       "integer" ],
                155 => [ "ERX-IPv6-Acct-Input-Gigawords",      "integer" ],
                156 => [ "ERX-IPv6-Acct-Output-Gigawords",     "integer" ],
                157 => [ "ERX-IPv6-NdRa-Pool-Name",            "string" ],
                158 => [ "ERX-PppoE-Padn",                     "string" ],
                159 => [ "ERX-Dhcp-Option-82",                 "octets" ],
                160 => [ "ERX-Vlan-Map-Id",                    "integer" ],
                161 => [ "ERX-IPv6-Delegated-Pool-Name",       "string" ],
                162 => [ "ERX-Tx-Connect-Speed",               "integer" ],
                163 => [ "ERX-Rx-Connect-Speed",               "integer" ],
                173 => [ "ERX-Service-Activate-Type",          "integer" ],
                174 => [ "ERX-Client-Profile-Name",            "string" ],
                175 => [ "ERX-Redirect-GW-Address",            "ipaddr" ],
                176 => [ "ERX-APN-Name",                       "string" ],
                177 => [ "ERX-Cos-Shaping-Rate",               "string" ],
                178 => [ "ERX-Action-Reason",                  "string" ],
                179 => [ "ERX-Service-Volume-Gigawords",       "integer" ],
                180 => [ "ERX-Update-Service",                 "string" ],
                181 => [ "ERX-DHCPv6-Guided-Relay-Server",     "ipv6addr" ],
                182 => [ "ERX-Acc-Loop-Remote-Id",             "string" ],
                183 => [ "ERX-Acc-Loop-Encap",                 "octets" ],
                184 => [ "ERX-Inner-Vlan-Map-Id",              "integer" ],
                185 => [ "ERX-Core-Facing-Interface",          "string" ],
                189 => [ "ERX-DHCP-First-Relay-IPv4-Address",  "ipaddr" ],
                190 => [ "ERX-DHCP-First-Relay-IPv6-Address",  "ipv6addr" ],
                191 => [ "ERX-Input-Interface-Filter",         "string" ],
                192 => [ "ERX-Output-Interface-Filter",        "string" ],
                193 => [ "ERX-Pim-Enable",                     "integer" ],
                194 => [ "ERX-Bulk-CoA-Transaction-Id",        "integer" ],
                195 => [ "ERX-Bulk-CoA-Identifier",            "integer" ],
                196 => [ "ERX-IPv4-Input-Service-Set",         "string" ],
                197 => [ "ERX-IPv4-Output-Service-Set",        "string" ],
                198 => [ "ERX-IPv4-Input-Service-Filter",      "string" ],
                199 => [ "ERX-IPv4-Output-Service-Filter",     "string" ],
                200 => [ "ERX-IPv6-Input-Service-Set",         "string" ],
                201 => [ "ERX-IPv6-Output-Service-Set",        "string" ],
                202 => [ "ERX-IPv6-Input-Service-Filter",      "string" ],
                203 => [ "ERX-IPv6-Output-Service-Filter",     "string" ],
                204 => [ "ERX-Adv-Pcef-Profile-Name",          "string" ],
                205 => [ "ERX-Adv-Pcef-Rule-Name",             "string" ],
                206 => [ "ERX-Re-Authentication-Catalyst",     "integer" ],
                207 => [ "ERX-DHCPv6-Options",                 "octets" ],
                208 => [ "ERX-DHCP-Header",                    "octets" ],
                209 => [ "ERX-DHCPv6-Header",                  "octets" ],
                210 => [ "ERX-Acct-Request-Reason",            "integer" ],
                211 => [ "ERX-Inner-Tag-Protocol-Id",          "string" ],
                212 => [ "ERX-Routing-Services",               "integer" ],
                213 => [ "ERX-Interface-Set-Targeting-Weight", "integer" ],
                214 => [ "ERX-Interface-Targeting-Weight",     "integer" ],
                216 => [ "ERX-Hybrid-Access-DSL-Downstream-Speed", "integer" ],
                217 => [ "ERX-Hybrid-Access-LTE-Downstream-Speed", "integer" ],
                219 => [ "ERX-PON-Access-Type",                    "integer" ],
                220 =>
                  [ "ERX-ONT-ONU-Average-Data-Rate-Downstream", "integer" ],
                221 => [ "ERX-ONT-ONU-Peak-Data-Rate-Downstream",   "integer" ],
                222 => [ "ERX-ONT-ONU-Maximum-Data-Rate-Upstream",  "integer" ],
                223 => [ "ERX-ONT-ONU-Assured-Data-Rate-Upstream",  "integer" ],
                224 => [ "ERX-PON-Tree-Maximum-Data-Rate-Upstream", "integer" ],
                225 =>
                  [ "ERX-PON-Tree-Maximum-Data-Rate-Downstream", "integer" ],
                226 => [ "ERX-Expected-Throughput-Upstream",   "integer" ],
                227 => [ "ERX-Expected-Throughput-Downstream", "integer" ],
                228 =>
                  [ "ERX-Attainable-Expected-Throughput-Upstream", "integer" ],
                229 => [
                    "ERX-Attainable-Expected-Throughput-Downstream", "integer"
                ],
                230 => [ "ERX-Gamma-Data-Rate-Upstream",            "integer" ],
                231 => [ "ERX-Gamma-Data-Rate-Downstream",          "integer" ],
                232 => [ "ERX-Attainable-Gamma-Data-Rate-Upstream", "integer" ],
                233 =>
                  [ "ERX-Attainable-Gamma-Data-Rate-Downstream", "integer" ],
            },
            5003 => { 35 => [ "ACL-Auth-Level",       "integer" ] },
            5089 => { 1  => [ "Clavister-User-Group", "string" ] },
            5263 => { 1  => [ "CBBSM-Bandwidth",      "integer" ] },
            5323 => { 1  => [ "Telrad-Reference-QOS-Profile-Name", "string" ] },
            5468 => { 1  => [ "Actelis-Privilege",                 "string" ] },
            5535 => {
                1  => [ "3GPP2-Ike-Preshared-Secret-Request",  "integer" ],
                2  => [ "3GPP2-Security-Level",                "integer" ],
                3  => [ "3GPP2-Pre-Shared-Secret",             "string" ],
                4  => [ "3GPP2-Reverse-Tunnel-Spec",           "integer" ],
                5  => [ "3GPP2-Diffserv-Class-Option",         "integer" ],
                6  => [ "3GPP2-Accounting-Container",          "octets" ],
                7  => [ "3GPP2-Home-Agent-IP-Address",         "ipaddr" ],
                8  => [ "3GPP2-KeyID",                         "string" ],
                9  => [ "3GPP2-PCF-IP-Address",                "ipaddr" ],
                10 => [ "3GPP2-BSID",                          "string" ],
                11 => [ "3GPP2-User-Id",                       "integer" ],
                12 => [ "3GPP2-Forward-FCH-Mux-Option",        "integer" ],
                13 => [ "3GPP2-Reverse-FCH-Mux-Option",        "integer" ],
                16 => [ "3GPP2-Service-Option",                "integer" ],
                17 => [ "3GPP2-Forward-Traffic-Type",          "integer" ],
                18 => [ "3GPP2-Reverse-Traffic-Type",          "integer" ],
                19 => [ "3GPP2-FCH-Frame-Size",                "integer" ],
                20 => [ "3GPP2-Forward-FCH-RC",                "integer" ],
                21 => [ "3GPP2-Reverse-FCH-RC",                "integer" ],
                22 => [ "3GPP2-IP-Technology",                 "integer" ],
                23 => [ "3GPP2-Compulsory-Tunnel-Indicator",   "integer" ],
                24 => [ "3GPP2-Release-Indicator",             "integer" ],
                25 => [ "3GPP2-Bad-PPP-Frame-Count",           "integer" ],
                30 => [ "3GPP2-Number-Active-Transitions",     "integer" ],
                31 => [ "3GPP2-Terminating-SDB-Octet-Count",   "integer" ],
                32 => [ "3GPP2-Originating-SDB-OCtet-Count",   "integer" ],
                33 => [ "3GPP2-Terminating-Number-SDBs",       "integer" ],
                34 => [ "3GPP2-Originating-Number-SDBs",       "integer" ],
                36 => [ "3GPP2-IP-QoS",                        "integer" ],
                39 => [ "3GPP2-Airlink-Priority",              "integer" ],
                40 => [ "3GPP2-Airlink-Record-Type",           "integer" ],
                41 => [ "3GPP2-R-P-Session-ID",                "octets" ],
                42 => [ "3GPP2-Airlink-Sequence-Number",       "integer" ],
                43 => [ "3GPP2-Received-HDLC-Octets",          "integer" ],
                44 => [ "3GPP2-Correlation-Id",                "string" ],
                45 => [ "3GPP2-Module-Orig-Term-Indicator",    "octets" ],
                46 => [ "3GPP2-Inbound-Mobile-IP-Sig-Octets",  "integer" ],
                47 => [ "3GPP2-Outbound-Mobile-IP-Sig-Octets", "integer" ],
                48 => [ "3GPP2-Session-Continue",              "integer" ],
                49 => [ "3GPP2-Active-Time",                   "integer" ],
                50 => [ "3GPP2-DCCH-Frame-Size",               "integer" ],
                51 => [ "3GPP2-Begin-Session",                 "integer" ],
                52 => [ "3GPP2-ESN",                           "string" ],
                54 => [ "3GPP2-S-Key",                         "octets" ],
                55 => [ "3GPP2-S-Request",                     "integer" ],
                56 => [ "3GPP2-S-Lifetime",                    "date" ],
                57 => [ "3GPP2-MN-HA-SPI",                     "integer" ],
                58 => [ "3GPP2-MN-HA-Shared-Key",              "string" ],
                59 => [ "3GPP2-Remote-IP-Qualifier",           "short" ],
                60 => [ "3GPP2-HRPD-Access-Authorization",     "integer" ],
                61 => [ "3GPP2-AT-Hardware-Identifier-Value",  "octets" ],
                70 => [ "3GPP2-Remote-IPv6-Address-Qualifier", "tlv" ],
                71 => [ "3GPP2-Remote-Address-Table-Index-Qualifier", "short" ],
                72 => [
                    "3GPP2-Remote-IPv4-Addr-Octet-Count-Reverse-Overflow",
                    "short",
                ],
                73 =>
                  [ "3GPP2-Allowed-Diffserv-Marking-Reverse-Runnel", "short" ],
                74 => [ "3GPP2-Service-Option-Profile-Option",   "short" ],
                75 => [ "3GPP2-DNS-Update-Required",             "integer" ],
                78 => [ "3GPP2-Always-On",                       "integer" ],
                79 => [ "3GPP2-Foreign-Agent-Address",           "ipaddr" ],
                80 => [ "3GPP2-Last-User-Activity-Time",         "integer" ],
                81 => [ "3GPP2-MN-AAA-Removal-Indication",       "integer" ],
                82 => [ "3GPP2-RN-Packet-Data-Inactivity-Timer", "integer" ],
                83 => [ "3GPP2-Forward-PDCH-RC",                 "integer" ],
                84 => [ "3GPP2-Forward-DCCH-Mux-Option",         "integer" ],
                85 => [ "3GPP2-Reverse-DCCH-Mux-Option",         "integer" ],
                86 => [ "3GPP2-Forward-DCCH-RC",                 "integer" ],
                87 => [ "3GPP2-Reverse-DHHC-RC",                 "integer" ],
                88 => [ "3GPP2-Session-Termination-Capability",  "integer" ],
                89 => [ "3GPP2-Allowed-Persistent-TFTs",         "integer" ],
                90 => [ "3GPP2-Prepaid-Acct-Quota-UpdateReason", "short" ],
                91 => [ "3GPP2-Prepaid-acct-Capability",         "octets" ],
                92 => [ "3GPP2-MIP-Lifetime",                    "octets" ],
                93 => [ "3GPP2-Acct-Stop-Trigger",               "integer" ],
                94 => [ "3GPP2-Service-Reference-Main-SC-Indicator", "short" ],
                95 => [ "3GPP2-DNS-Update-Capability", "integer" ],
                96 => [ "3GPP2-Disconnect-Reason",     "integer" ],
                97 =>
                  [ "3GPP2-Remote-IPv6-Reverse-Octet-Count-Overflow", "short" ],
                98 => [
                    "3GPP2-Prepaid-Time-Interval-After-Tariff-Switch-Update",
                    "integer",
                ],
                108 => [ "3GPP2-Subnet-Sector-ID",             "octets" ],
                116 => [ "3GPP2-MEID",                         "octets" ],
                117 => [ "3GPP2-DNS-Server-Entity-Type",       "byte" ],
                118 => [ "3GPP2-MIP6-Home-Agent",              "ipv6addr" ],
                119 => [ "3GPP2-MIP6-CoA",                     "ipv6addr" ],
                120 => [ "3GPP2-MIP6-HoA-Not-Authorized",      "integer" ],
                121 => [ "3GPP2-MIP6-Session-Key",             "octets" ],
                122 => [ "3GPP2-MIP6-Accounting-Indication",   "string" ],
                123 => [ "3GPP2-MIP6-Mesg-ID",                 "octets" ],
                124 => [ "3GPP2-Filter-Rule",                  "string" ],
                125 => [ "3GPP2-HTTP-Redirection-Rule",        "string" ],
                126 => [ "3GPP2-IP-Redirection-Rule",          "string" ],
                127 => [ "3GGP2-Hot-Line-Capability",          "integer" ],
                128 => [ "3GPP2-MIP6-Home-Link-Prefix",        "octets" ],
                130 => [ "3GPP2-Max-Auth-Aggregate-Bandwidth", "integer" ],
                131 => [ "3GPP2-Auth-Flow-Profile-ID-Bi-Direction", "short" ],
                132 =>
                  [ "3GPP2-Granted-QoS-Params-Delay-Var-Sensitive", "short" ],
                133 => [ "3GPP2-Max-Per-Flow-Priority",            "integer" ],
                134 => [ "3GPP2-MIP6-Authenticator",               "octets" ],
                138 => [ "3GPP2-MIP6-MAC-Mobility-Data",           "octets" ],
                139 => [ "3GPP2-Inter-User-Priority",              "integer" ],
                140 => [ "3GPP2-MIP6-Home-Agent-Attr-B",           "ipv6addr" ],
                141 => [ "3GPP2-MIP6-HoA",                         "ipv6addr" ],
                142 => [ "3GPP2-Carrier-ID",                       "string" ],
                143 => [ "3GPP2-GMT-Time-Zone-Offset",             "signed" ],
                144 => [ "3GPP2-Flow-ID-Flow-ID",                  "short" ],
                145 => [ "3GPP2-Flow-Status",                      "integer" ],
                146 => [ "3GPP2-Filtered-Octet-Count-Terminating", "integer" ],
                147 => [ "3GPP2-Filtered-Octet-Count-Originating", "integer" ],
                163 => [ "3GPP2-RSVP-Outbound-Octet-Count",        "integer" ],
                164 => [ "3GPP2-RSVP-Inbound-Octet-Count",         "integer" ],
                165 => [ "3GPP2-RSVP-Outbound-Packet-Count",       "integer" ],
                168 => [ "3GPP2-HA-Request",                       "integer" ],
                169 => [ "3GPP2-HA-Authorised",                    "integer" ],
                172 => [ "3GPP2-IP-Ver-Authorised",                "integer" ],
                173 => [ "3GPP2-MIPv4-Mesg-Id",                    "string" ],
                179 =>
                  [ "3GPP2-MIP6-HA-Local-Assigment-Capability", "integer" ],
                203 => [
                    "3GPP2-HAAA-MIP6-HA-Protocol-Capability-Indication",
                    "integer",
                ],
                205 => [ "3GPP2-VAAA-Assigned-MIP6-HA", "ipv6addr" ],
                206 => [ "3GPP2-VAAA-Assigned-MIP6-HL", "octets" ],
                207 => [
                    "3GPP2-VAAA-MIP6-HA-Protocol-Capability-Indication",
                    "integer",
                ],
                214 => [ "3GPP2-DNS-Server-IPv6-Address-Entity-Type", "byte" ],
            },
            5567 => {
                1 => [ "Riverstone-Command",            "string" ],
                2 => [ "Riverstone-System-Event",       "string" ],
                3 => [ "Riverstone-SNMP-Config-Change", "string" ],
                4 => [ "Riverstone-User-Level",         "integer" ],
            },
            5597 => { 1 => [ "MBG-Management-Privilege-Level", "integer" ] },
            5925 => {
                51 => [ "IPU-MIP-Spi",         "integer" ],
                52 => [ "IPU-MIP-Key",         "string" ],
                53 => [ "IPU-MIP-Alg-Type",    "integer" ],
                54 => [ "IPU-MIP-Alg-Mode",    "integer" ],
                55 => [ "IPU-MIP-Replay-Prot", "integer" ],
                61 => [ "IPU-IKE-Remote-Addr", "ipaddr" ],
                62 => [ "IPU-IKE-Local-Addr",  "ipaddr" ],
                63 => [ "IPU-IKE-Auth",        "string" ],
                64 => [ "IPU-IKE-Conf-Name",   "string" ],
                65 => [ "IPU-IKE-Cmd",         "string" ],
            },
            5948 => {
                1  => [ "Issanni-SoftFlow-Template", "string" ],
                2  => [ "Issanni-NAT-Support",       "string" ],
                3  => [ "Issanni-Routing-Context",   "string" ],
                4  => [ "Issanni-Tunnel-Name",       "string" ],
                5  => [ "Issanni-IP-Pool-Name",      "string" ],
                6  => [ "Issanni-PPPoE-URL",         "string" ],
                7  => [ "Issanni-PPPoE-MOTM",        "string" ],
                8  => [ "Issanni-Service",           "string" ],
                9  => [ "Issanni-Pri-DNS",           "ipaddr" ],
                10 => [ "Issanni-Sec-DNS",           "ipaddr" ],
                11 => [ "Issanni-Pri-NBNS",          "ipaddr" ],
                12 => [ "Issanni-Sec-NBNS",          "ipaddr" ],
                13 => [ "Issanni-Traffic-Class",     "string" ],
                14 => [ "Issanni-Tunnel-Type",       "integer" ],
                15 => [ "Issanni-NAT-Type",          "integer" ],
                16 => [ "Issanni-QOS-Class",         "string" ],
                17 => [ "Issanni-Interface-Name",    "string" ],
            },
            6027 => { 1 => [ "Force10-AVPair", "string" ] },
            6321 => {
                1   => [ "Calix-Role",                       "string" ],
                220 => [ "Calix-CMS-User-Group",             "string" ],
                221 => [ "Calix-CMS-Alarm-Filter",           "integer" ],
                222 => [ "Calix-CMS-Event-Filter",           "integer" ],
                223 => [ "Calix-CMS-Threshold-Event-Filter", "integer" ],
            },
            6431 => {
                1   => [ "BWAS-Record-id",                          "string" ],
                2   => [ "BWAS-Service-provider",                   "string" ],
                3   => [ "BWAS-Type",                               "string" ],
                4   => [ "BWAS-User-Number",                        "string" ],
                5   => [ "BWAS-Group-Number",                       "string" ],
                6   => [ "BWAS-Direction",                          "string" ],
                7   => [ "BWAS-Calling-Number",                     "string" ],
                8   => [ "BWAS-Calling-Presentation-Indic",         "string" ],
                9   => [ "BWAS-Called-Number",                      "string" ],
                10  => [ "BWAS-Start-Time",                         "string" ],
                11  => [ "BWAS-User-Timezone",                      "string" ],
                12  => [ "BWAS-Answer-Indic",                       "string" ],
                13  => [ "BWAS-Answer-Time",                        "string" ],
                14  => [ "BWAS-Release-Time",                       "string" ],
                15  => [ "BWAS-Termination-Cause",                  "string" ],
                16  => [ "BWAS-Network-Type",                       "string" ],
                17  => [ "BWAS-Carrier-Identification-Code",        "string" ],
                18  => [ "BWAS-Dialed-Digits",                      "string" ],
                19  => [ "BWAS-Call-Category",                      "string" ],
                20  => [ "BWAS-Network-Call-Type",                  "string" ],
                21  => [ "BWAS-Network-Translated-Number",          "string" ],
                22  => [ "BWAS-Network-Translated-Group",           "string" ],
                23  => [ "BWAS-Releasing-Party",                    "string" ],
                24  => [ "BWAS-Route",                              "string" ],
                25  => [ "BWAS-Network-Callid",                     "string" ],
                26  => [ "BWAS-Codec",                              "string" ],
                27  => [ "BWAS-Access-Device-Address",              "string" ],
                28  => [ "BWAS-Access-Callid",                      "string" ],
                29  => [ "BWAS-Spare-29",                           "string" ],
                30  => [ "BWAS-Failover-Correlation-Id",            "string" ],
                31  => [ "BWAS-Spare-31",                           "string" ],
                32  => [ "BWAS-Group",                              "string" ],
                33  => [ "BWAS-Department",                         "string" ],
                34  => [ "BWAS-Account-Code",                       "string" ],
                35  => [ "BWAS-Authorization-Code",                 "string" ],
                36  => [ "BWAS-Original-Called-Number",             "string" ],
                37  => [ "BWAS-Original-Called-Presentation-Indic", "string" ],
                38  => [ "BWAS-Original-Called-Reason",             "string" ],
                39  => [ "BWAS-Redirecting-Number",                 "string" ],
                40  => [ "BWAS-Redirecting-Presentation-Indic",     "string" ],
                41  => [ "BWAS-Redirecting-Reason",                 "string" ],
                42  => [ "BWAS-Charge-Indic",                       "string" ],
                43  => [ "BWAS-Type-Of-Network",                    "string" ],
                44  => [ "BWAS-VP-Calling-Invoke-Time",             "string" ],
                45  => [ "BWAS-Local-Callid",                       "string" ],
                46  => [ "BWAS-Remote-Callid",                      "string" ],
                47  => [ "BWAS-Calling-Party-Category",             "string" ],
                48  => [ "BWAS-Conference-Invoke-Time",             "string" ],
                49  => [ "BWAS-Conference-Callid",                  "string" ],
                50  => [ "BWAS-Conference-To",                      "string" ],
                51  => [ "BWAS-Conference-From",                    "string" ],
                52  => [ "BWAS-Conference-Id",                      "string" ],
                53  => [ "BWAS-Conference-Role",                    "string" ],
                54  => [ "BWAS-Conference-Bridge",                  "string" ],
                55  => [ "BWAS-Conference-Owner",                   "string" ],
                56  => [ "BWAS-Conference-Owner-Dn",                "string" ],
                57  => [ "BWAS-Conference-Title",                   "string" ],
                58  => [ "BWAS-Conference-Project-Code",            "string" ],
                59  => [ "BWAS-Charging-Vector-Key",                "string" ],
                60  => [ "BWAS-Charging-Vection-Creator",           "string" ],
                61  => [ "BWAS-Charging-Vection-Orig",              "string" ],
                62  => [ "BWAS-Charging-Vection-Term",              "string" ],
                63  => [ "BWAS-Acc-Per-Call-Invoke-Time",           "string" ],
                64  => [ "BWAS-Acc-Per-Call-Fac-Result",            "string" ],
                65  => [ "BWAS-Acb-Act-Invoke-Time",                "string" ],
                66  => [ "BWAS-Acb-Act-Fac-Result",                 "string" ],
                67  => [ "BWAS-Acb-Deact-Invoke-Time",              "string" ],
                68  => [ "BWAS-Acb-Deact-Fac-Result",               "string" ],
                69  => [ "BWAS-Call-Park-Invoke-Time",              "string" ],
                70  => [ "BWAS-Call-Park-Fac-Result",               "string" ],
                71  => [ "BWAS-Call-Park-Retr-Invoke-Time",         "string" ],
                72  => [ "BWAS-Call-Park-Retr-Fac-Result",          "string" ],
                73  => [ "BWAS-Call-Pickup-Invoke-Time",            "string" ],
                74  => [ "BWAS-Call-Pickup-Fac-Result",             "string" ],
                75  => [ "BWAS-Directed-Call-Pickup-Invoke-Time",   "string" ],
                76  => [ "BWAS-Directed-Call-Pickup-Fac-Result",    "string" ],
                77  => [ "BWAS-Dpubi-Invoke-Time",                  "string" ],
                78  => [ "BWAS-Dpubi-Fac-Result",                   "string" ],
                79  => [ "BWAS-Cancel-Cwt-Per-Call-Invoke-Time",    "string" ],
                80  => [ "BWAS-Cancel-Cwt-Per-Call-Fac-Result",     "string" ],
                81  => [ "BWAS-Cfa-Act-Invoke-Time",                "string" ],
                82  => [ "BWAS-Cfa-Act-Fac-Result",                 "string" ],
                83  => [ "BWAS-Cfa-Deact-Invoke-Time",              "string" ],
                84  => [ "BWAS-Cfa-Deact-Fac-Result",               "string" ],
                85  => [ "BWAS-Cfb-Act-Invoke-Time",                "string" ],
                86  => [ "BWAS-Cfb-Act-Fac-Result",                 "string" ],
                87  => [ "BWAS-Cfb-Deact-Invoke-Time",              "string" ],
                88  => [ "BWAS-Cfb-Deact-Fac-Result",               "string" ],
                89  => [ "BWAS-Cfna-Act-Invoke-Time",               "string" ],
                90  => [ "BWAS-Cfna-Act-Fac-Result",                "string" ],
                91  => [ "BWAS-Cfna-Deact-Invoke-Time",             "string" ],
                92  => [ "BWAS-Cfna-Deact-Fac-Result",              "string" ],
                93  => [ "BWAS-Clid-Delivery-Per-Call-Invoke-Time", "string" ],
                94  => [ "BWAS-Clid-Delivery-Per-Call-Fac-Result",  "string" ],
                95  => [ "BWAS-Clid-Blocking-Per-Call-Invoke-Time", "string" ],
                96  => [ "BWAS-Clid-Blocking-Per-Call-Fac-Result",  "string" ],
                97  => [ "BWAS-Cot-Invoke-Time",                    "string" ],
                98  => [ "BWAS-Cot-Fac-Result",                     "string" ],
                99  => [ "BWAS-Direct-Vm-Xfer-Invoke-Time",         "string" ],
                100 => [ "BWAS-Direct-Vm-Xfer-Fac-Result",          "string" ],
                101 => [ "BWAS-Dnd-Act-Invoke-Time",                "string" ],
                102 => [ "BWAS-Dnd-Act-Fac-Result",                 "string" ],
                103 => [ "BWAS-Dnd-Deact-Invoke-Time",              "string" ],
                104 => [ "BWAS-Dnd-Deact-Fac-Result",               "string" ],
                105 => [ "BWAS-Sac-Lock-Invoke-Time",               "string" ],
                106 => [ "BWAS-Sac-Lock-Fac-Result",                "string" ],
                107 => [ "BWAS-Sac-Unlock-Invoke-Time",             "string" ],
                108 => [ "BWAS-Sac-Unlock-Fac-Result",              "string" ],
                109 => [ "BWAS-Flash-Call-Hold-Invoke-Time",        "string" ],
                110 => [ "BWAS-Flash-Call-Hold-Fac-Result",         "string" ],
                111 => [ "BWAS-Last-Number-Redial-Invoke-Time",     "string" ],
                112 => [ "BWAS-Last-Number-Redial-Fac-Result",      "string" ],
                113 => [ "BWAS-Return-Call-Invoke-Time",            "string" ],
                114 => [ "BWAS-Return-Call-Fac-Result",             "string" ],
                115 => [ "BWAS-Sd100-Programming-Invoke-Time",      "string" ],
                116 => [ "BWAS-Sd100-Programming-Fac-Result",       "string" ],
                117 => [ "BWAS-Sd8-Programming-Invoke-Time",        "string" ],
                118 => [ "BWAS-Sd8-Programming-Fac-Result",         "string" ],
                119 => [ "BWAS-Clear-Mwi-Invoke-Time",              "string" ],
                120 => [ "BWAS-Clear-Mwi-Fac-Result",               "string" ],
                121 => [ "BWAS-UserId",                             "string" ],
                122 => [ "BWAS-Other-Party-Name",                   "string" ],
                123 => [ "BWAS-Other-Party-Name-Pres-Indic",        "string" ],
                125 => [ "BWAS-Moh-Deact-Fac-Result",               "string" ],
                126 => [ "BWAS-Push-to-Talk-Invoke-Time",           "string" ],
                127 => [ "BWAS-Push-to-Talk-Fac-Result",            "string" ],
                128 => [ "BWAS-Hoteling-Invoke-Time",               "string" ],
                129 => [ "BWAS-Hoteling-Group",                     "string" ],
                130 => [ "BWAS-Hoteling-UserId",                    "string" ],
                131 => [ "BWAS-Hoteling-User-Number",               "string" ],
                132 => [ "BWAS-Hoteling-Group-Number",              "string" ],
                133 => [ "BWAS-Diversion-Inhibitor-Invoke-time",    "string" ],
                134 => [ "BWAS-Diversion-Inhibitor-Fac-Result",     "string" ],
                135 => [ "BWAS-Trunk-Group-Name",                   "string" ],
                136 => [ "BWAS-Spare-136",                          "string" ],
                137 => [ "BWAS-InstantGroupCall-Invoke-Time",       "string" ],
                138 => [ "BWAS-InstantGroupCall-PushToTalk",        "string" ],
                139 => [ "BWAS-InstantGroupCall-Related-Callid",    "string" ],
                140 => [ "BWAS-CustomRingback-Invoke-Time",         "string" ],
                141 => [ "BWAS-CLID-Permitted",                     "string" ],
                142 => [ "BWAS-AHR-Invoke-Time",                    "string" ],
                143 => [ "BWAS-AHR-Action",                         "string" ],
                144 => [ "BWAS-Access-Network-Info",                "string" ],
                145 => [ "BWAS-Charging-Function-Addresses",        "string" ],
                146 => [ "BWAS-Charge-Number",                      "string" ],
                147 => [ "BWAS-Related-CallId",                     "string" ],
                148 => [ "BWAS-Related-CallId-Reason",              "string" ],
                149 => [ "BWAS-Transfer-Invoke-Time",               "string" ],
                150 => [ "BWAS-Transfer-Result",                    "string" ],
                151 => [ "BWAS-Transfer-Related-CallId",            "string" ],
                152 => [ "BWAS-Transfer-Type",                      "string" ],
                153 => [ "BWAS-Conf-Start-Time",                    "string" ],
                154 => [ "BWAS-Conf-Stop-Time",                     "string" ],
                155 => [ "BWAS-Conf-Id",                            "string" ],
                156 => [ "BWAS-Conf-Type",                          "string" ],
                157 => [ "BWAS-Codec-Usage",                        "string" ],
                158 => [ "BWAS-Vmb-Act-Invoke-Time",                "string" ],
                159 => [ "BWAS-Vmb-Act-Fac-Result",                 "string" ],
                160 => [ "BWAS-Vmb-Deact-Invoke-Time",              "string" ],
                161 => [ "BWAS-Vmb-Deact-Fac-Result",               "string" ],
                162 => [ "BWAS-Vmna-Act-Invoke-Time",               "string" ],
                163 => [ "BWAS-Vmna-Act-Fac-Result",                "string" ],
                164 => [ "BWAS-Vmna-Deact-Invoke-Time",             "string" ],
                165 => [ "BWAS-Vmna-Deact-Fac-Result",              "string" ],
                166 => [ "BWAS-Vma-Act-Invoke-Time",                "string" ],
                167 => [ "BWAS-Vma-Act-Fac-Result",                 "string" ],
                168 => [ "BWAS-Vma-Deact-Invoke-Time",              "string" ],
                169 => [ "BWAS-Vma-Deact-Fac-Result",               "string" ],
                170 => [ "BWAS-No-Answer-Set-Invoke-Time",          "string" ],
                171 => [ "BWAS-No-Answer-Set-Fac-Result",           "string" ],
                172 => [ "BWAS-Clid-Blocking-Act-Invoke-Time",      "string" ],
                173 => [ "BWAS-Clid-Blocking-Act-Fac-Result",       "string" ],
                174 => [ "BWAS-Clid-Blocking-Deact-Invoke-Time",    "string" ],
                175 => [ "BWAS-Clid-Blocking-Deact-Fac-Result",     "string" ],
                176 => [ "BWAS-Call-Waiting-Act-Invoke-Time",       "string" ],
                177 => [ "BWAS-Call-Waiting-Act-Fac-Result",        "string" ],
                178 => [ "BWAS-Call-Waiting-Deact-Invoke-Time",     "string" ],
                179 => [ "BWAS-Call-Waiting-Deact-Fac-Result",      "string" ],
                180 => [ "BWAS-Fax-Messaging",                      "string" ],
                181 => [ "BWAS-TSD-Digits",                         "string" ],
                182 => [ "BWAS-Trunk-Group-Info",                   "string" ],
                183 => [ "BWAS-Recall-Type",                        "string" ],
                184 => [ "BWAS-Cfnrc-Act-Invoke-Time",              "string" ],
                185 => [ "BWAS-Cfnrc-Act-Fac-Result",               "string" ],
                186 => [ "BWAS-Cfnrc-Deact-Invoke-Time",            "string" ],
                187 => [ "BWAS-Cfnrc-Deact-Fac-Result",             "string" ],
                188 => [ "BWAS-Q850-Cause",                         "string" ],
                189 => [ "BWAS-Dialed-Digits-Context",              "string" ],
                190 => [ "BWAS-Called-Number-Context",              "string" ],
                191 => [ "BWAS-Network-Translated-Number-Context",  "string" ],
                192 => [ "BWAS-Calling-Number-Context",             "string" ],
                193 => [ "BWAS-Original-Called-Number-Context",     "string" ],
                194 => [ "BWAS-Redirecting-Number-Context",         "string" ],
                195 => [ "BWAS-Location-Control-Act-Result",        "string" ],
                196 => [ "BWAS-Location-Control-Deact-Result",      "string" ],
                197 => [ "BWAS-Call-Retrieve-Result",               "string" ],
                198 => [ "BWAS-Routing-Number",                     "string" ],
                199 => [ "BWAS-Origination-Method",                 "string" ],
                200 => [ "BWAS-Call-Parked-Invoke-Time",            "string" ],
                201 => [ "BWAS-BA-Related-Call-Id",                 "string" ],
                202 => [ "BWAS-Acr-Act-Invoke-Time",                "string" ],
                203 => [ "BWAS-Acr-Act-Fac-Result",                 "string" ],
                204 => [ "BWAS-Acr-Deact-Invoke-Time",              "string" ],
                205 => [ "BWAS-Acr-Deact-Fac-Result",               "string" ],
                206 => [ "BWAS-Outside-Access-Code",                "string" ],
                207 => [ "BWAS-Primary-Device-Line-Port",           "string" ],
                208 => [ "BWAS-Called-Asserted-Identity",           "string" ],
                209 => [ "BWAS-Called-Asserted-Pres-Indicator",     "string" ],
                210 => [ "BWAS-SDP",                                "string" ],
                211 => [ "BWAS-Media-Initiator-Flag",               "string" ],
                212 => [ "BWAS-SDP-Offer-Timestamp",                "string" ],
                213 => [ "BWAS-SDP-Answer-Timestamp",               "string" ],
                214 => [ "BWAS-Early-Media-SDP",                    "string" ],
                215 => [ "BWAS-Early-Media-Initiator-Flag",         "string" ],
                216 => [ "BWAS-Body-Content-Type",                  "string" ],
                217 => [ "BWAS-Body-Content-Length",                "string" ],
                218 => [ "BWAS-Body-Content-Disposition",           "string" ],
                219 => [ "BWAS-Body-Originator",                    "string" ],
                220 => [ "BWAS-SIP-Error-Code",                     "string" ],
                221 => [ "BWAS-OtherInfoInPCV",                     "string" ],
                222 => [ "BWAS-Received-Calling-Number",            "string" ],
                223 => [ "BWAS-CustomRingback-Media-Selection",     "string" ],
                224 => [ "BWAS-AOC-Type",                           "string" ],
                225 => [ "BWAS-AOC-Charge",                         "string" ],
                226 => [ "BWAS-AOC-Currency",                       "string" ],
                227 => [ "BWAS-AOC-Time",                           "string" ],
                228 => [ "BWAS-AOC-Sum",                            "string" ],
                229 => [ "BWAS-AOC-Activation-Time",                "string" ],
                230 => [ "BWAS-AOC-Result",                         "string" ],
                231 => [ "BWAS-AS-Call-Type",                       "string" ],
                232 => [ "BWAS-Scf-Act-Invoke-Time",                "string" ],
                233 => [ "BWAS-Scf-Act-Fac-Result",                 "string" ],
                234 => [ "BWAS-Scf-Deact-Invoke-Time",              "string" ],
                235 => [ "BWAS-Scf-Deact-Fac-Result",               "string" ],
                236 => [ "BWAS-Cfa-Inter-Invoke-Time",              "string" ],
                237 => [ "BWAS-Cfa-Inter-Fac-Result",               "string" ],
                238 => [ "BWAS-Cfna-Inter-Invoke-Time",             "string" ],
                239 => [ "BWAS-Cfna-Inter-Fac-Result",              "string" ],
                240 => [ "BWAS-Cfb-Inter-Invoke-Time",              "string" ],
                241 => [ "BWAS-Cfb-Inter-Fac-Result",               "string" ],
                242 => [ "BWAS-CBF-Auth-Code",                      "string" ],
                243 => [ "BWAS-Call-Bridge-Result",                 "string" ],
                244 =>
                  [ "BWAS-Return-Call-Number-Deletion-Invoke-Time", "string" ],
                245 =>
                  [ "BWAS-Return-Call-Number-Deletion-Fac-Result", "string" ],
                246 => [ "BWAS-Prepaid-Status",    "string" ],
                247 => [ "BWAS-Configurable-CLID", "string" ],
                248 =>
                  [ "BWAS-Call-Center-Night-Service-Act-Result", "string" ],
                249 =>
                  [ "BWAS-Call-Center-Night-Service-Deact-Result", "string" ],
                250 =>
                  [ "BWAS-Call-Center-Forced-Forwarding-Act-Result", "string" ],
                251 => [
                    "BWAS-Call-Center-Forced-Forwarding-Deact-Result", "string"
                ],
                252 =>
                  [ "BWAS-Call-Center-Outgoing-Call-Fac-Result", "string" ],
                253 => [
                    "BWAS-Call-Center-Outgoing-Personal-Call-Fac-Result",
                    "string",
                ],
                254 => [ "BWAS-Call-Center-Outgoing-Phone-Number", "string" ],
                255 => [ "BroadSoft-Attr-255",                     "string" ],
            },
            6504 => { 1 => [ "Navini-AVPair", "string" ] },
            6527 => {
                1   => [ "Timetra-Access",                         "integer" ],
                2   => [ "Timetra-Home-Directory",                 "string" ],
                3   => [ "Timetra-Restrict-To-Home",               "integer" ],
                4   => [ "Timetra-Profile",                        "string" ],
                5   => [ "Timetra-Default-Action",                 "integer" ],
                6   => [ "Timetra-Cmd",                            "string" ],
                7   => [ "Timetra-Action",                         "integer" ],
                8   => [ "Timetra-Exec-File",                      "string" ],
                9   => [ "Alc-Primary-Dns",                        "ipaddr" ],
                10  => [ "Alc-Secondary-Dns",                      "ipaddr" ],
                11  => [ "Alc-Subsc-ID-Str",                       "string" ],
                12  => [ "Alc-Subsc-Prof-Str",                     "string" ],
                13  => [ "Alc-SLA-Prof-Str",                       "string" ],
                14  => [ "Alc-Force-Renew",                        "string" ],
                15  => [ "Alc-Create-Host",                        "string" ],
                16  => [ "Alc-ANCP-Str",                           "string" ],
                17  => [ "Alc-Retail-Serv-Id",                     "integer" ],
                18  => [ "Alc-Default-Router",                     "ipaddr" ],
                19  => [ "Alc-Acct-I-Inprof-Octets-64",            "octets" ],
                20  => [ "Alc-Acct-I-Outprof-Octets-64",           "octets" ],
                21  => [ "Alc-Acct-O-Inprof-Octets-64",            "octets" ],
                22  => [ "Alc-Acct-O-Outprof-Octets-64",           "octets" ],
                23  => [ "Alc-Acct-I-Inprof-Pkts-64",              "octets" ],
                24  => [ "Alc-Acct-I-Outprof-Pkts-64",             "octets" ],
                25  => [ "Alc-Acct-O-Inprof-Pkts-64",              "octets" ],
                26  => [ "Alc-Acct-O-Outprof-Pkts-64",             "octets" ],
                27  => [ "Alc-Client-Hardware-Addr",               "string" ],
                28  => [ "Alc-Int-Dest-Id-Str",                    "string" ],
                29  => [ "Alc-Primary-Nbns",                       "ipaddr" ],
                30  => [ "Alc-Secondary-Nbns",                     "ipaddr" ],
                31  => [ "Alc-MSAP-Serv-Id",                       "integer" ],
                32  => [ "Alc-MSAP-Policy",                        "string" ],
                33  => [ "Alc-MSAP-Interface",                     "string" ],
                34  => [ "Alc-PPPoE-PADO-Delay",                   "integer" ],
                35  => [ "Alc-PPPoE-Service-Name",                 "string" ],
                36  => [ "Alc-DHCP-Vendor-Class-Id",               "string" ],
                37  => [ "Alc-Acct-OC-I-Inprof-Octets-64",         "octets" ],
                38  => [ "Alc-Acct-OC-I-Outprof-Octets-64",        "octets" ],
                39  => [ "Alc-Acct-OC-O-Inprof-Octets-64",         "octets" ],
                40  => [ "Alc-Acct-OC-O-Outprof-Octets-64",        "octets" ],
                41  => [ "Alc-Acct-OC-I-Inprof-Pkts-64",           "octets" ],
                42  => [ "Alc-Acct-OC-I-Outprof-Pkts-64",          "octets" ],
                43  => [ "Alc-Acct-OC-O-Inprof-Pkts-64",           "octets" ],
                44  => [ "Alc-Acct-OC-O-Outprof-Pkts-64",          "octets" ],
                45  => [ "Alc-App-Prof-Str",                       "string" ],
                46  => [ "Alc-Tunnel-Group",                       "string" ],
                47  => [ "Alc-Tunnel-Algorithm",                   "integer" ],
                48  => [ "Alc-Tunnel-Max-Sessions",                "integer" ],
                49  => [ "Alc-Tunnel-Idle-Timeout",                "integer" ],
                50  => [ "Alc-Tunnel-Hello-Interval",              "integer" ],
                51  => [ "Alc-Tunnel-Destruct-Timeout",            "integer" ],
                52  => [ "Alc-Tunnel-Max-Retries-Estab",           "integer" ],
                53  => [ "Alc-Tunnel-Max-Retries-Not-Estab",       "integer" ],
                54  => [ "Alc-Tunnel-AVP-Hiding",                  "integer" ],
                55  => [ "Alc-BGP-Policy",                         "string" ],
                56  => [ "Alc-BGP-Auth-Keychain",                  "string" ],
                57  => [ "Alc-BGP-Auth-Key",                       "octets" ],
                58  => [ "Alc-BGP-Export-Policy",                  "string" ],
                59  => [ "Alc-BGP-Import-Policy",                  "string" ],
                60  => [ "Alc-BGP-PeerAS",                         "integer" ],
                61  => [ "Alc-IPsec-Serv-Id",                      "integer" ],
                62  => [ "Alc-IPsec-Interface",                    "string" ],
                63  => [ "Alc-IPsec-Tunnel-Template-Id",           "integer" ],
                64  => [ "Alc-IPsec-SA-Lifetime",                  "integer" ],
                65  => [ "Alc-IPsec-SA-PFS-Group",                 "integer" ],
                66  => [ "Alc-IPsec-SA-Encr-Algorithm",            "integer" ],
                67  => [ "Alc-IPsec-SA-Auth-Algorithm",            "integer" ],
                68  => [ "Alc-IPsec-SA-Replay-Window",             "integer" ],
                69  => [ "Alc-Acct-I-High-Octets-Drop_64",         "octets" ],
                70  => [ "Alc-Acct-I-Low-Octets-Drop_64",          "octets" ],
                71  => [ "Alc-Acct-I-High-Pack-Drop_64",           "octets" ],
                72  => [ "Alc-Acct-I-Low-Pack-Drop_64",            "octets" ],
                73  => [ "Alc-Acct-I-High-Octets-Offer_64",        "octets" ],
                74  => [ "Alc-Acct-I-Low-Octets-Offer_64",         "octets" ],
                75  => [ "Alc-Acct-I-High-Pack-Offer_64",          "octets" ],
                76  => [ "Alc-Acct-I-Low-Pack-Offer_64",           "octets" ],
                77  => [ "Alc-Acct-I-Unc-Octets-Offer_64",         "octets" ],
                78  => [ "Alc-Acct-I-Unc-Pack-Offer_64",           "octets" ],
                79  => [ "Alc-Acct-I-All-Octets-Offer_64",         "octets" ],
                80  => [ "Alc-Acct-I-All-Pack-Offer_64",           "octets" ],
                81  => [ "Alc-Acct-O-Inprof-Pack-Drop_64",         "octets" ],
                82  => [ "Alc-Acct-O-Outprof-Pack-Drop_64",        "octets" ],
                83  => [ "Alc-Acct-O-Inprof-Octs-Drop_64",         "octets" ],
                84  => [ "Alc-Acct-O-Outprof-Octs-Drop_64",        "octets" ],
                85  => [ "Alc-Acct-OC-I-All-Octs-Offer_64",        "octets" ],
                86  => [ "Alc-Acct-OC-I-All-Pack-Offer_64",        "octets" ],
                87  => [ "Alc-Acct-OC-I-Inpr-Octs-Drop_64",        "octets" ],
                88  => [ "Alc-Acct-OC-I-Outpr-Octs-Drop_64",       "octets" ],
                89  => [ "Alc-Acct-OC-I-Inpr-Pack-Drop_64",        "octets" ],
                90  => [ "Alc-Acct-OC-I-Outpr-Pack-Drop_64",       "octets" ],
                91  => [ "Alc-Acct-OC-O-Inpr-Pack-Drop_64",        "octets" ],
                92  => [ "Alc-Acct-OC-O-Outpr-Pack-Drop_64",       "octets" ],
                93  => [ "Alc-Acct-OC-O-Inpr-Octs-Drop_64",        "octets" ],
                94  => [ "Alc-Acct-OC-O-Outpr-Octs-Drop_64",       "octets" ],
                95  => [ "Alc-Credit-Control-CategoryMap",         "string" ],
                96  => [ "Alc-Credit-Control-Quota",               "string" ],
                97  => [ "Alc-Tunnel-Challenge",                   "integer" ],
                98  => [ "Alc-Force-Nak",                          "string" ],
                99  => [ "Alc-Ipv6-Address",                       "ipv6addr" ],
                100 => [ "Alc-Serv-Id",                            "integer" ],
                101 => [ "Alc-Interface",                          "string" ],
                102 => [ "Alc-ToServer-Dhcp-Options",              "octets" ],
                103 => [ "Alc-ToClient-Dhcp-Options",              "octets" ],
                104 => [ "Alc-Tunnel-Serv-Id",                     "integer" ],
                105 => [ "Alc-Ipv6-Primary-Dns",                   "ipv6addr" ],
                106 => [ "Alc-Ipv6-Secondary-Dns",                 "ipv6addr" ],
                107 => [ "Alc-Acct-I-statmode",                    "string" ],
                108 => [ "Alc-Acct-I-Hiprio-Octets_64",            "octets" ],
                109 => [ "Alc-Acct-I-Lowprio-Octets_64",           "octets" ],
                110 => [ "Alc-Acct-O-Hiprio-Octets_64",            "octets" ],
                111 => [ "Alc-Acct-O-Lowprio-Octets_64",           "octets" ],
                112 => [ "Alc-Acct-I-Hiprio-Packets_64",           "octets" ],
                113 => [ "Alc-Acct-I-Lowprio-Packets_64",          "octets" ],
                114 => [ "Alc-Acct-O-Hiprio-Packets_64",           "octets" ],
                115 => [ "Alc-Acct-O-Lowprio-Packets_64",          "octets" ],
                116 => [ "Alc-Acct-I-All-Octets_64",               "octets" ],
                117 => [ "Alc-Acct-O-All-Octets_64",               "octets" ],
                118 => [ "Alc-Acct-I-All-Packets_64",              "octets" ],
                119 => [ "Alc-Acct-O-All-Packets_64",              "octets" ],
                120 => [ "Alc-Tunnel-Rx-Window-Size",              "integer" ],
                121 => [ "Alc-Nat-Port-Range",                     "string" ],
                122 => [ "Alc-LI-Action",                          "integer" ],
                123 => [ "Alc-LI-Destination",                     "string" ],
                124 => [ "Alc-LI-FC",                              "integer" ],
                125 => [ "Alc-LI-Direction",                       "integer" ],
                126 => [ "Alc-Subscriber-QoS-Override",            "string" ],
                127 => [ "Alc-Acct-O-statmode",                    "string" ],
                128 => [ "Alc-ATM-Ingress-TD-Profile",             "integer" ],
                129 => [ "Alc-ATM-Egress-TD-Profile",              "integer" ],
                130 => [ "Alc-AA-Transit-IP",                      "integer" ],
                131 => [ "Alc-Delegated-IPv6-Pool",                "string" ],
                132 => [ "Alc-Access-Loop-Rate-Down",              "integer" ],
                133 => [ "Alc-Access-Loop-Encap-Offset",           "octets" ],
                134 => [ "Alc-Subscriber-Filter",                  "string" ],
                135 => [ "Alc-PPP-Force-IPv6CP",                   "integer" ],
                136 => [ "Alc-Onetime-Http-Redirection-Filter-Id", "string" ],
                137 => [ "Alc-Authentication-Policy-Name",         "string" ],
                138 => [ "Alc-LI-Intercept-Id",                    "integer" ],
                139 => [ "Alc-LI-Session-Id",                      "integer" ],
                140 => [ "Alc-Nat-Outside-Serv-Id",                "integer" ],
                141 => [ "Alc-Nat-Outside-Ip-Addr",                "ipaddr" ],
                142 => [ "Alc-APN-Password",                       "string" ],
                143 => [ "Alc-APN-Name",                           "string" ],
                144 => [ "Alc-Tunnel-Acct-Policy",                 "string" ],
                145 => [ "Alc-Mgw-Interface-Type",                 "integer" ],
                146 => [ "Alc-Wlan-APN-Name",                      "string" ],
                147 => [ "Alc-MsIsdn",                             "string" ],
                148 => [ "Alc-RSSI",                               "integer" ],
                149 => [ "Alc-Num-Attached-UEs",                   "integer" ],
                150 => [ "Alc-Charging-Prof-ID",                   "integer" ],
                156 => [ "Alc-AA-Group-Partition-Isa-Id",          "string" ],
                157 => [ "Alc-AA-Peer-Identifier",                 "string" ],
                158 => [ "Alc-Nas-Filter-Rule-Shared",             "string" ],
                159 => [ "Alc-Ascend-Data-Filter-Host-Spec",       "abinary" ],
                160 => [ "Alc-Relative-Session-Timeout",           "integer" ],
                163 => [ "Alc-Acct-Triggered-Reason",              "integer" ],
                172 => [ "Alc-Wlan-Portal-Redirect",               "string" ],
                173 => [ "Alc-Wlan-Portal-Url",                    "string" ],
                174 => [ "Alc-Lease-Time",                         "integer" ],
                175 => [ "Alc-DSL-Line-State",                     "integer" ],
                176 => [ "Alc-DSL-Type",                           "integer" ],
                177 => [ "Alc-Portal-Url",                         "string" ],
                178 => [ "Alc-Ipv6-Portal-Url",                    "string" ],
                180 => [ "Alc-SAP-Session-Index",                  "integer" ],
                181 => [ "Alc-SLAAC-IPv6-Pool",                    "string" ],
                183 => [ "Alc-WPP-ErrorCode",                      "integer" ],
                185 => [ "Alc-Onetime-Http-Redirect-Reactivate",   "string" ],
                191 => [ "Alc-ToServer-Dhcp6-Options",             "octets" ],
                192 => [ "Alc-ToClient-Dhcp6-Options",             "octets" ],
                200 => [ "Alc-v6-Preferred-Lifetime",              "integer" ],
                201 => [ "Alc-v6-Valid-Lifetime",                  "integer" ],
                202 => [ "Alc-Dhcp6-Renew-Time",                   "integer" ],
                203 => [ "Alc-Dhcp6-Rebind-Time",                  "integer" ],
                206 => [ "Alc-Wlan-SSID-VLAN",                     "string" ],
                217 => [ "Alc-UPnP-Sub-Override-Policy",           "string" ],
                228 => [ "Alc-Trigger-Acct-Interim",               "string" ],
                232 => [ "Alc-Acct-Interim-Level",                 "integer" ],
                234 => [ "Alc-DNAT-Override",                      "string" ],
                238 => [ "Alc-Remove-Override",                    "string" ],
                242 => [ "Alc-Radius-Py",                          "octets" ],
                244 => [ "Alc-Force-DHCP-Relay",                   "string" ],
            },
            6618 => {
                1   => [ "Quintum-AVPair",                   "string" ],
                2   => [ "Quintum-NAS-Port",                 "string" ],
                23  => [ "Quintum-h323-remote-address",      "string" ],
                24  => [ "Quintum-h323-conf-id",             "string" ],
                25  => [ "Quintum-h323-setup-time",          "string" ],
                26  => [ "Quintum-h323-call-origin",         "string" ],
                27  => [ "Quintum-h323-call-type",           "string" ],
                28  => [ "Quintum-h323-connect-time",        "string" ],
                29  => [ "Quintum-h323-disconnect-time",     "string" ],
                30  => [ "Quintum-h323-disconnect-cause",    "string" ],
                31  => [ "Quintum-h323-voice-quality",       "string" ],
                33  => [ "Quintum-h323-gw-id",               "string" ],
                35  => [ "Quintum-h323-incoming-conf-id",    "string" ],
                101 => [ "Quintum-h323-credit-amount",       "string" ],
                102 => [ "Quintum-h323-credit-time",         "string" ],
                103 => [ "Quintum-h323-return-code",         "string" ],
                104 => [ "Quintum-h323-prompt-id",           "string" ],
                105 => [ "Quintum-h323-time-and-day",        "string" ],
                106 => [ "Quintum-h323-redirect-number",     "string" ],
                107 => [ "Quintum-h323-preferred-lang",      "string" ],
                108 => [ "Quintum-h323-redirect-ip-address", "string" ],
                109 => [ "Quintum-h323-billing-model",       "string" ],
                110 => [ "Quintum-h323-currency-type",       "string" ],
                230 => [ "Quintum-Trunkid-In",               "string" ],
                231 => [ "Quintum-Trunkid-Out",              "string" ],
            },
            6983 => {
                1 => [ "SofaWare-Admin",   "string" ],
                2 => [ "SofaWare-VPN",     "string" ],
                3 => [ "SofaWare-Hotspot", "string" ],
                4 => [ "SofaWare-UFP",     "string" ],
            },
            7000 => { 1 => [ "Slipstream-Auth", "string" ] },
            7064 => {
                140 => [ "UTStarcom-VLAN-ID",              "integer" ],
                142 => [ "UTStarcom-CommittedBandwidth",   "integer" ],
                143 => [ "UTStarcom-MaxBandwidth",         "integer" ],
                145 => [ "UTStarcom-Priority",             "integer" ],
                147 => [ "UTStarcom-Error-Reason",         "integer" ],
                152 => [ "UTStarcom-PrimaryDNS",           "integer" ],
                153 => [ "UTStarcom-SecondaryDNS",         "integer" ],
                161 => [ "UTStarcom-MaxBurstSize",         "integer" ],
                162 => [ "UTStarcom-MaxDelay",             "integer" ],
                163 => [ "UTStarcom-MaxJitter",            "integer" ],
                165 => [ "UTStarcom-DeviceId",             "string" ],
                166 => [ "UTStarcom-Module-Id",            "integer" ],
                167 => [ "UTStarcom-Port-No",              "integer" ],
                168 => [ "UTStarcom-Logical-Port-No",      "integer" ],
                169 => [ "UTStarcom-UNI-MAX-MAC",          "integer" ],
                170 => [ "UTStarcom-Default-Gateway",      "integer" ],
                171 => [ "UTStarcom-CLI-Access-Level",     "integer" ],
                180 => [ "UTStarcom-Act-Input-Octets",     "string" ],
                181 => [ "UTStarcom-Act-Output-Octets",    "string" ],
                182 => [ "UTStarcom-Act-Input-Frames",     "string" ],
                183 => [ "UTStarcom-Act-Output-Frames",    "string" ],
                184 => [ "UTStarcom-Onu-MC-Filter-Enable", "integer" ],
                185 => [ "UTStarcom-UNI-Auto-Negotiation", "integer" ],
                186 => [ "UTStarcom-UNI-Speed",            "integer" ],
                187 => [ "UTStarcom-UNI-Duplex",           "integer" ],
                188 => [ "UTStarcom-ONU-Admin_status",     "integer" ],
                189 => [ "UTStarcom-ONU-FW-SC-Upgrade",    "integer" ],
            },
            7119 => { 33 => [ "NetSensory-Privilege",       "string" ] },
            7146 => { 1  => [ "Zeus-ZXTM-Group",            "string" ] },
            7262 => { 1  => [ "DragonWave-Privilege-Level", "integer" ] },
            7751 => {
                1  => [ "Azaire-Triplets",           "octets" ],
                2  => [ "Azaire-IMSI",               "octets" ],
                3  => [ "Azaire-MSISDN",             "octets" ],
                4  => [ "Azaire-APN",                "string" ],
                5  => [ "Azaire-QoS",                "octets" ],
                6  => [ "Azaire-Selection-Mode",     "integer" ],
                7  => [ "Azaire-APN-Resolution-Req", "integer" ],
                8  => [ "Azaire-Start-Time",         "octets" ],
                9  => [ "Azaire-NAS-Type",           "integer" ],
                10 => [ "Azaire-Status",             "integer" ],
                11 => [ "Azaire-APN-OI",             "string" ],
                12 => [ "Azaire-Auth-Type",          "integer" ],
                13 => [ "Azaire-Gn-User-Name",       "string" ],
                14 => [ "Azaire-Brand-Code",         "string" ],
                15 => [ "Azaire-Policy-Name",        "string" ],
                16 => [ "Azaire-Client-Local-IP",    "ipaddr" ],
            },
            7779 => {
                1 => [ "Infoblox-windows-group", "string" ],
                2 => [ "Infoblox-variable-1",    "string" ],
                3 => [ "Infoblox-variable-2",    "string" ],
                4 => [ "Infoblox-variable-3",    "string" ],
                5 => [ "Infoblox-variable-4",    "string" ],
                6 => [ "Infoblox-variable-5",    "string" ],
                7 => [ "Infoblox-Version",       "string" ],
                8 => [ "Infoblox-Product-Name",  "string" ],
                9 => [ "Infoblox-Group-Info",    "string" ],
            },
            8164 => {
                1     => [ "SN-VPN-ID",                       "integer" ],
                2     => [ "SN-VPN-Name",                     "string" ],
                3     => [ "SN-Disconnect-Reason",            "integer" ],
                4     => [ "SN-PPP-Progress-Code",            "integer" ],
                5     => [ "SN-Primary-DNS-Server",           "ipaddr" ],
                6     => [ "SN-Secondary-DNS-Server",         "ipaddr" ],
                7     => [ "SN-Re-CHAP-Interval",             "integer" ],
                8     => [ "SN-IP-Pool-Name",                 "string" ],
                9     => [ "SN-PPP-Data-Compression",         "integer" ],
                10    => [ "SN-IP-Filter-In",                 "string" ],
                11    => [ "SN-IP-Filter-Out",                "string" ],
                13    => [ "SN-Local-IP-Address",             "ipaddr" ],
                14    => [ "SN-IP-Source-Validation",         "integer" ],
                15    => [ "SN-PPP-Outbound-Password",        "string" ],
                16    => [ "SN-PPP-Keepalive",                "integer" ],
                17    => [ "SN-IP-In-ACL",                    "string" ],
                18    => [ "SN-IP-Out-ACL",                   "string" ],
                19    => [ "SN-PPP-Data-Compression-Mode",    "integer" ],
                20    => [ "SN-Subscriber-Permission",        "integer" ],
                21    => [ "SN-Admin-Permission",             "integer" ],
                22    => [ "SN-Simultaneous-SIP-MIP",         "integer" ],
                23    => [ "SN-Min-Compress-Size",            "integer" ],
                24    => [ "SN-Service-Type",                 "integer" ],
                25    => [ "SN-DNS-Proxy-Use-Subscr-Addr",    "integer" ],
                26    => [ "SN-Tunnel-Password",              "octets" ],
                27    => [ "SN-Tunnel-Load-Balancing",        "integer" ],
                30    => [ "SN-MN-HA-Timestamp-Tolerance",    "integer" ],
                31    => [ "SN-Prepaid-Compressed-Count",     "integer" ],
                32    => [ "SN-Prepaid-Inbound-Octets",       "integer" ],
                33    => [ "SN-Prepaid-Outbound-Octets",      "integer" ],
                34    => [ "SN-Prepaid-Total-Octets",         "integer" ],
                35    => [ "SN-Prepaid-Timeout",              "integer" ],
                36    => [ "SN-Prepaid-Watermark",            "integer" ],
                37    => [ "SN-NAI-Construction-Domain",      "string" ],
                38    => [ "SN-Tunnel-ISAKMP-Crypto-Map",     "string" ],
                39    => [ "SN-Tunnel-ISAKMP-Secret",         "string" ],
                41    => [ "SN-Ext-Inline-Srvr-Context",      "string" ],
                43    => [ "SN-L3-to-L2-Tun-Addr-Policy",     "integer" ],
                44    => [ "SN-Long-Duration-Timeout",        "integer" ],
                45    => [ "SN-Long-Duration-Action",         "integer" ],
                46    => [ "SN-PDSN-Handoff-Req-IP-Addr",     "integer" ],
                47    => [ "SN-HA-Send-DNS-ADDRESS",          "integer" ],
                48    => [ "SN-MIP-Send-Term-Verification",   "integer" ],
                49    => [ "SN-Data-Tunnel-Ignore-DF-Bit",    "integer" ],
                50    => [ "SN-MIP-AAA-Assign-Addr",          "integer" ],
                51    => [ "SN-MIP-Match-AAA-Assign-Addr",    "integer" ],
                52    => [ "SN-Proxy-MIP",                    "integer" ],
                53    => [ "SN-IP-Alloc-Method",              "integer" ],
                54    => [ "SN-Gratuitous-ARP-Aggressive",    "integer" ],
                55    => [ "SN-Ext-Inline-Srvr-Up-Addr",      "ipaddr" ],
                56    => [ "SN-Ext-Inline-Srvr-Down-Addr",    "ipaddr" ],
                57    => [ "SN-Ext-Inline-Srvr-Preference",   "integer" ],
                58    => [ "SN-Ext-Inline-Srvr-Up-VLAN",      "octets" ],
                59    => [ "SN-Ext-Inline-Srvr-Down-VLAN",    "octets" ],
                60    => [ "SN-IP-Hide-Service-Address",      "integer" ],
                61    => [ "SN-PPP-Outbound-Username",        "string" ],
                62    => [ "SN-GTP-Version",                  "integer" ],
                63    => [ "SN-Access-link-IP-Frag",          "integer" ],
                64    => [ "SN-Subscriber-Accounting",        "integer" ],
                65    => [ "SN-Nw-Reachability-Server-Name",  "string" ],
                67    => [ "SN-Subscriber-IP-Hdr-Neg-Mode",   "integer" ],
                68    => [ "SN-GGSN-MIP-Required",            "integer" ],
                69    => [ "SN-Subscriber-Acct-Start",        "integer" ],
                70    => [ "SN-Subscriber-Acct-Interim",      "integer" ],
                71    => [ "SN-Subscriber-Acct-Stop",         "integer" ],
                73    => [ "SN-QoS-Tp-Dnlk",                  "integer" ],
                74    => [ "SN-Tp-Dnlk-Committed-Data-Rate",  "integer" ],
                75    => [ "SN-Tp-Dnlk-Peak-Data-Rate",       "integer" ],
                76    => [ "SN-Tp-Dnlk-Burst-Size",           "integer" ],
                77    => [ "SN-Tp-Dnlk-Exceed-Action",        "integer" ],
                78    => [ "SN-Tp-Dnlk-Violate-Action",       "integer" ],
                79    => [ "SN-QoS-Tp-Uplk",                  "integer" ],
                80    => [ "SN-Tp-Uplk-Committed-Data-Rate",  "integer" ],
                81    => [ "SN-Tp-Uplk-Peak-Data-Rate",       "integer" ],
                82    => [ "SN-Tp-Uplk-Burst-Size",           "integer" ],
                83    => [ "SN-Tp-Uplk-Exceed-Action",        "integer" ],
                84    => [ "SN-Tp-Uplk-Violate-Action",       "integer" ],
                85    => [ "SN-Subscriber-IP-TOS-Copy",       "integer" ],
                86    => [ "SN-QoS-Conversation-Class",       "octets" ],
                87    => [ "SN-QoS-Streaming-Class",          "octets" ],
                88    => [ "SN-QoS-Interactive1-Class",       "octets" ],
                89    => [ "SN-QoS-Interactive2-Class",       "octets" ],
                90    => [ "SN-QoS-Interactive3-Class",       "octets" ],
                91    => [ "SN-QoS-Background-Class",         "octets" ],
                92    => [ "SN-PPP-NW-Layer-IPv4",            "integer" ],
                93    => [ "SN-PPP-NW-Layer-IPv6",            "integer" ],
                94    => [ "SN-Virtual-APN-Name",             "string" ],
                95    => [ "SN-PPP-Accept-Peer-v6Ifid",       "integer" ],
                96    => [ "SN-IPv6-rtr-advt-interval",       "integer" ],
                97    => [ "SN-IPv6-num-rtr-advt",            "integer" ],
                98    => [ "SN-NPU-Qos-Priority",             "integer" ],
                99    => [ "SN-MN-HA-Hash-Algorithm",         "integer" ],
                100   => [ "SN-Subscriber-Acct-Rsp-Action",   "integer" ],
                101   => [ "SN-IPv6-Primary-DNS",             "ipv6addr" ],
                102   => [ "SN-IPv6-Secondary-DNS",           "octets" ],
                103   => [ "SN-IPv6-Egress-Filtering",        "integer" ],
                104   => [ "SN-Mediation-VPN-Name",           "string" ],
                105   => [ "SN-Mediation-Acct-Rsp-Action",    "integer" ],
                106   => [ "SN-Home-Sub-Use-GGSN",            "integer" ],
                107   => [ "SN-Visiting-Sub-Use-GGSN",        "integer" ],
                108   => [ "SN-Roaming-Sub-Use-GGSN",         "integer" ],
                109   => [ "SN-Home-Profile",                 "integer" ],
                110   => [ "SN-IP-Src-Validation-Drop-Limit", "integer" ],
                111   => [ "SN-QoS-Class-Conversational-PHB", "integer" ],
                112   => [ "SN-QoS-Class-Streaming-PHB",      "integer" ],
                113   => [ "SN-QoS-Class-Background-PHB",     "integer" ],
                114   => [ "SN-QoS-Class-Interactive-1-PHB",  "integer" ],
                115   => [ "SN-QoS-Class-Interactive-2-PHB",  "integer" ],
                116   => [ "SN-QoS-Class-Interactive-3-PHB",  "integer" ],
                117   => [ "SN-Visiting-Profile",             "integer" ],
                118   => [ "SN-Roaming-Profile",              "integer" ],
                119   => [ "SN-Home-Behavior",                "integer" ],
                120   => [ "SN-Visiting-Behavior",            "integer" ],
                121   => [ "SN-Roaming-Behavior",             "integer" ],
                122   => [ "SN-Internal-SM-Index",            "integer" ],
                123   => [ "SN-Mediation-Enabled",            "integer" ],
                124   => [ "SN-IPv6-Sec-Pool",                "string" ],
                125   => [ "SN-IPv6-Sec-Prefix",              "octets" ],
                126   => [ "SN-IPv6-DNS-Proxy",               "integer" ],
                127   => [ "SN-Subscriber-Nexthop-Address",   "integer" ],
                128   => [ "SN-Prepaid",                      "integer" ],
                129   => [ "SN-Prepaid-Preference",           "integer" ],
                130   => [ "SN-PPP-Always-On-Vse",            "integer" ],
                131   => [ "SN-Voice-Push-List-Name",         "string" ],
                132   => [ "SN-Unclassify-List-Name",         "string" ],
                133   => [ "SN-Subscriber-No-Interims",       "integer" ],
                134   => [ "SN-Permit-User-Mcast-PDUs",       "integer" ],
                135   => [ "SN-Prepaid-Final-Duration-Alg",   "integer" ],
                136   => [ "SN-IPv6-Min-Link-MTU",            "integer" ],
                137   => [ "SN-Charging-VPN-Name",            "string" ],
                138   => [ "SN-Chrg-Char-Selection-Mode",     "integer" ],
                139   => [ "SN-Cause-For-Rec-Closing",        "integer" ],
                140   => [ "SN-Change-Condition",             "integer" ],
                141   => [ "SN-Dynamic-Addr-Alloc-Ind-Flag",  "octets" ],
                142   => [ "SN-Ntk-Initiated-Ctx-Ind-Flag",   "octets" ],
                143   => [ "SN-Ntk-Session-Disconnect-Flag",  "integer" ],
                144   => [ "SN-Enable-QoS-Renegotiation",     "integer" ],
                145   => [ "SN-QoS-Renegotiation-Timeout",    "integer" ],
                146   => [ "SN-Mediation-No-Interims",        "integer" ],
                147   => [ "SN-QoS-Negotiated",               "string" ],
                148   => [ "SN-Primary-NBNS-Server",          "ipaddr" ],
                149   => [ "SN-Secondary-NBNS-Server",        "ipaddr" ],
                150   => [ "SN-IP-Header-Compression",        "integer" ],
                151   => [ "SN-Mode",                         "integer" ],
                152   => [ "SN-Assigned-VLAN-ID",             "short" ],
                153   => [ "SN-Direction",                    "integer" ],
                154   => [ "SN-MIP-HA-Assignment-Table",      "string" ],
                156   => [ "SN-Tun-Addr-Policy",              "integer" ],
                157   => [ "SN-DHCP-Lease-Expiry-Policy",     "integer" ],
                158   => [ "SN-Subscriber-Template-Name",     "string" ],
                159   => [ "SN-Subs-IMSA-Service-Name",       "string" ],
                161   => [ "SN-Traffic-Group",                "integer" ],
                162   => [ "SN-Rad-APN-Name",                 "octets" ],
                163   => [ "SN-MIP-Send-Ancid",               "integer" ],
                164   => [ "SN-MIP-Send-Imsi",                "integer" ],
                165   => [ "SN-MIP-Dual-Anchor",              "integer" ],
                166   => [ "SN-MIP-ANCID",                    "octets" ],
                167   => [ "SN-IMS-AM-Address",               "ipaddr" ],
                168   => [ "SN-IMS-AM-Domain-Name",           "octets" ],
                169   => [ "SN-Service-Address",              "ipaddr" ],
                170   => [ "SN-PDIF-MIP-Required",            "integer" ],
                171   => [ "SN-FMC-Location",                 "octets" ],
                172   => [ "SN-PDIF-MIP-Release-TIA",         "integer" ],
                173   => [ "SN-PDIF-MIP-Simple-IP-Fallback",  "integer" ],
                174   => [ "SN-Tunnel-Gn",                    "integer" ],
                175   => [ "SN-MIP-Reg-Lifetime-Realm",       "integer" ],
                176   => [ "SN-Ecs-Data-Volume",              "octets" ],
                177   => [ "SN-QoS-Traffic-Policy",           "octets" ],
                178   => [ "SN-ANID",                         "octets" ],
                187   => [ "SN-PPP-Reneg-Disc",               "integer" ],
                188   => [ "SN-MIP-Send-Correlation-Info",    "integer" ],
                189   => [ "SN-PDSN-Correlation-Id",          "octets" ],
                190   => [ "SN-PDSN-NAS-Id",                  "string" ],
                191   => [ "SN-PDSN-NAS-IP-Address",          "ipaddr" ],
                192   => [ "SN-Subscriber-Acct-Mode",         "integer" ],
                193   => [ "SN-IP-In-Plcy-Grp",               "string" ],
                194   => [ "SN-IP-Out-Plcy-Grp",              "string" ],
                196   => [ "SN-IP-Source-Violate-No-Acct",    "integer" ],
                198   => [ "SN-Firewall-Enabled",             "integer" ],
                200   => [ "SNA-PPP-Unfr-data-In-Oct",        "integer" ],
                201   => [ "SNA-PPP-Unfr-data-Out-Oct",       "integer" ],
                202   => [ "SNA-PPP-Unfr-Data-In-Gig",        "integer" ],
                203   => [ "SNA-PPP-Unfr-Data-Out-Gig",       "integer" ],
                204   => [ "SN-Admin-Expiry",                 "integer" ],
                206   => [ "SNA-Input-Gigawords",             "integer" ],
                207   => [ "SNA-Output-Gigawords",            "integer" ],
                214   => [ "SN-DNS-Proxy-Intercept-List",     "string" ],
                219   => [ "SN-Subscriber-Class",             "integer" ],
                220   => [ "SN-CFPolicy-ID",                  "integer" ],
                221   => [ "SN-Subs-VJ-Slotid-Cmp-Neg-Mode",  "integer" ],
                223   => [ "SN-Primary-DCCA-Peer",            "string" ],
                224   => [ "SN-Secondary-DCCA-Peer",          "string" ],
                225   => [ "SN-Subs-Acc-Flow-Traffic-Valid",  "integer" ],
                226   => [ "SN-Acct-Input-Packets-Dropped",   "integer" ],
                227   => [ "SN-Acct-Output-Packets-Dropped",  "integer" ],
                228   => [ "SN-Acct-Input-Octets-Dropped",    "integer64" ],
                229   => [ "SN-Acct-Output-Octets-Dropped",   "integer64" ],
                230   => [ "SN-Acct-Input-Giga-Dropped",      "integer" ],
                231   => [ "SN-Acct-Output-Giga-Dropped",     "integer" ],
                233   => [ "SN-Overload-Disc-Connect-Time",   "integer" ],
                235   => [ "SN-Overload-Disconnect",          "integer" ],
                236   => [ "SN-Radius-Returned-Username",     "integer" ],
                238   => [ "SN-ROHC-Profile-Name",            "string" ],
                239   => [ "SN-Firewall-Policy",              "octets" ],
                247   => [ "SN-Transparent-Data",             "octets" ],
                248   => [ "SN-MS-ISDN",                      "octets" ],
                249   => [ "SN-Routing-Area-Id",              "string" ],
                250   => [ "SN-Rulebase",                     "string" ],
                251   => [ "SN-Call-Id",                      "integer" ],
                252   => [ "SN-IMSI",                         "octets" ],
                253   => [ "SN-Long-Duration-Notification",   "integer" ],
                254   => [ "SN-SIP-Method",                   "integer" ],
                255   => [ "SN-Event",                        "string" ],
                256   => [ "SN-Role-Of-Node",                 "integer" ],
                257   => [ "SN-Session-Id",                   "string" ],
                258   => [ "SN-SIP-Request-Time-Stamp",       "string" ],
                259   => [ "SN-SIP-Response-Time-Stamp",      "string" ],
                260   => [ "SN-IMS-Charging-Identifier",      "string" ],
                261   => [ "SN-Originating-IOI",              "string" ],
                262   => [ "SN-Terminating-IOI",              "string" ],
                263   => [ "SN-SDP-Session-Description",      "string" ],
                264   => [ "SN-GGSN-Address",                 "ipaddr" ],
                265   => [ "SN-Sec-IP-Pool-Name",             "string" ],
                266   => [ "SN-Authorised-Qos",               "string" ],
                267   => [ "SN-Cause-Code",                   "integer" ],
                268   => [ "SN-Node-Functionality",           "integer" ],
                269   => [ "SN-Is-Unregistered-Subscriber",   "string" ],
                270   => [ "SN-Content-Type",                 "string" ],
                271   => [ "SN-Content-Length",               "string" ],
                272   => [ "SN-Content-Disposition",          "string" ],
                273   => [ "SN-CSCF-Rf-SDP-Media-Components", "octets" ],
                274   => [ "SN-ROHC-Flow-Marking-Mode",       "integer" ],
                275   => [ "SN-CSCF-App-Server-Info",         "octets" ],
                276   => [ "SN-ISC-Template-Name",            "string" ],
                277   => [ "SN-CF-Forward-Unconditional",     "string" ],
                278   => [ "SN-CF-Forward-No-Answer",         "string" ],
                279   => [ "SN-CF-Forward-Busy-Line",         "string" ],
                280   => [ "SN-CF-Forward-Not-Regd",          "string" ],
                281   => [ "SN-CF-Follow-Me",                 "string" ],
                282   => [ "SN-CF-CId-Display",               "integer" ],
                283   => [ "SN-CF-CId-Display-Blocked",       "integer" ],
                284   => [ "SN-CF-Call-Waiting",              "integer" ],
                285   => [ "SN-CF-Call-Transfer",             "integer" ],
                287   => [ "SN-Cscf-Subscriber-Ip-Address",   "ipaddr" ],
                288   => [ "SN-Software-Version",             "string" ],
                290   => [ "SN-Max-Sec-Contexts-Per-Subs",    "integer" ],
                291   => [ "SN-CF-Call-Local",                "integer" ],
                292   => [ "SN-CF-Call-LongDistance",         "integer" ],
                293   => [ "SN-CF-Call-International",        "integer" ],
                294   => [ "SN-CF-Call-Premium",              "integer" ],
                295   => [ "SN-CR-International-Cid",         "integer" ],
                296   => [ "SN-CR-LongDistance-Cid",          "integer" ],
                297   => [ "SN-NAT-IP-Address",               "ipaddr" ],
                298   => [ "SN-CF-Call-RoamingInternatnl",    "integer" ],
                299   => [ "SN-PDG-TTG-Required",             "integer" ],
                300   => [ "SN-Bandwidth-Policy",             "string" ],
                301   => [ "SN-Acs-Credit-Control-Group",     "string" ],
                302   => [ "SN-CBB-Policy",                   "string" ],
                303   => [ "SN-QOS-HLR-Profile",              "octets" ],
                304   => [ "SN-Fast-Reauth-Username",         "octets" ],
                305   => [ "SN-Pseudonym-Username",           "octets" ],
                306   => [ "SN-WiMAX-Auth-Only",              "integer" ],
                307   => [ "SN-TrafficSelector-Class",        "integer" ],
                309   => [ "SN-DHCP-Options",                 "octets" ],
                310   => [ "SN-Handoff-Indicator",            "integer" ],
                313   => [ "SN-User-Privilege",               "integer" ],
                314   => [ "SN-IPv6-Alloc-Method",            "integer" ],
                315   => [ "SN-Congestion-Mgmt-Policy",       "string" ],
                316   => [ "SN-WSG-MIP-Required",             "integer" ],
                317   => [ "SN-WSG-MIP-Release-TIA",          "integer" ],
                318   => [ "SN-WSG-MIP-Simple-IP-Fallback",   "integer" ],
                319   => [ "SN-WLAN-AP-Identifier",           "octets" ],
                320   => [ "SN-WLAN-UE-Identifier",           "octets" ],
                1001  => [ "SNA-PPP-Ctrl-Input-Octets",       "integer" ],
                1002  => [ "SNA-PPP-Ctrl-Output-Octets",      "integer" ],
                1003  => [ "SNA-PPP-Ctrl-Input-Packets",      "integer" ],
                1004  => [ "SNA-PPP-Ctrl-Output-Packets",     "integer" ],
                1005  => [ "SNA-PPP-Framed-Input-Octets",     "integer" ],
                1006  => [ "SNA-PPP-Framed-Output-Octets",    "integer" ],
                1007  => [ "SNA-PPP-Discards-Input",          "integer" ],
                1008  => [ "SNA-PPP-Discards-Output",         "integer" ],
                1009  => [ "SNA-PPP-Errors-Input",            "integer" ],
                1010  => [ "SNA-PPP-Errors-Output",           "integer" ],
                1011  => [ "SNA-PPP-Bad-Addr",                "integer" ],
                1012  => [ "SNA-PPP-Bad-Ctrl",                "integer" ],
                1013  => [ "SNA-PPP-Packet-Too-Long",         "integer" ],
                1014  => [ "SNA-PPP-Bad-FCS",                 "integer" ],
                1015  => [ "SNA-PPP-Echo-Req-Input",          "integer" ],
                1016  => [ "SNA-PPP-Echo-Req-Output",         "integer" ],
                1017  => [ "SNA-PPP-Echo-Rsp-Input",          "integer" ],
                1018  => [ "SNA-PPP-Echo-Rsp-Output",         "integer" ],
                1019  => [ "SNA-RPRRQ-Rcvd-Total",            "integer" ],
                1020  => [ "SNA-RPRRQ-Rcvd-Acc-Reg",          "integer" ],
                1021  => [ "SNA-RPRRQ-Rcvd-Acc-Dereg",        "integer" ],
                1022  => [ "SNA-RPRRQ-Rcvd-Msg-Auth-Fail",    "integer" ],
                1023  => [ "SNA-RPRRQ-Rcvd-Mis-ID",           "integer" ],
                1024  => [ "SNA-RPRRQ-Rcvd-Badly-Formed",     "integer" ],
                1025  => [ "SNA-RPRRQ-Rcvd-VID-Unsupported",  "integer" ],
                1026  => [ "SNA-RPRRQ-Rcvd-T-Bit-Not-Set",    "integer" ],
                1027  => [ "SNA-RPRAK-Rcvd-Total",            "integer" ],
                1028  => [ "SNA-RPRAK-Rcvd-Acc-Ack",          "integer" ],
                1029  => [ "SNA-RPRAK-Rcvd-Msg-Auth-Fail",    "integer" ],
                1030  => [ "SNA-RPRAK-Rcvd-Mis-ID",           "integer" ],
                1031  => [ "SNA-RP-Reg-Reply-Sent-Total",     "integer" ],
                1032  => [ "SNA-RP-Reg-Reply-Sent-Acc-Reg",   "integer" ],
                1033  => [ "SNA-RP-Reg-Reply-Sent-Acc-Dereg", "integer" ],
                1034  => [ "SNA-RP-Reg-Reply-Sent-Bad-Req",   "integer" ],
                1035  => [ "SNA-RP-Reg-Reply-Sent-Denied",    "integer" ],
                1036  => [ "SNA-RP-Reg-Reply-Sent-Mis-ID",    "integer" ],
                1037  => [ "SNA-RP-Reg-Reply-Sent-Send-Err",  "integer" ],
                1038  => [ "SNA-RP-Reg-Upd-Sent",             "integer" ],
                1039  => [ "SNA-RP-Reg-Upd-Re-Sent",          "integer" ],
                1040  => [ "SNA-RP-Reg-Upd-Send-Err",         "integer" ],
                65530 => [ "SN-Proxy-MIPV6",                  "integer" ],
            },
            8708 => {
                1 => [ "Infinera-User-Category",     "string" ],
                2 => [ "Infinera-ENM-User-Category", "string" ],
            },
            8741 => {
                1 => [ "SonicWall-User-Privilege", "integer" ],
                3 => [ "SonicWall-User-Group",     "string" ],
            },
            8742 => {
                1  => [ "Alphion-User-Role",                  "string" ],
                2  => [ "Alphion-User-Vlan",                  "integer" ],
                3  => [ "Alphion-Priv-Admin-User",            "integer" ],
                4  => [ "Alphion-Admin-Role",                 "string" ],
                5  => [ "Alphion-Essid-Name",                 "string" ],
                6  => [ "Alphion-Location-Id",                "string" ],
                7  => [ "Alphion-Port-Identifier",            "string" ],
                8  => [ "Alphion-MMS-User-Template",          "string" ],
                9  => [ "Alphion-Named-User-Vlan",            "string" ],
                10 => [ "Alphion-AP-Group",                   "string" ],
                11 => [ "Alphion-Framed-IPv6-Address",        "string" ],
                12 => [ "Alphion-Device-Type",                "string" ],
                14 => [ "Alphion-No-DHCP-Fingerprint",        "integer" ],
                15 => [ "Alphion-Mdps-Device-Udid",           "string" ],
                16 => [ "Alphion-Mdps-Device-Imei",           "string" ],
                17 => [ "Alphion-Mdps-Device-Iccid",          "string" ],
                18 => [ "Alphion-Mdps-Max-Devices",           "integer" ],
                19 => [ "Alphion-Mdps-Device-Name",           "string" ],
                20 => [ "Alphion-Mdps-Device-Product",        "string" ],
                21 => [ "Alphion-Mdps-Device-Version",        "string" ],
                22 => [ "Alphion-Mdps-Device-Serial",         "string" ],
                23 => [ "Alphion-CPPM-Role",                  "string" ],
                24 => [ "Alphion-AirGroup-User-Name",         "string" ],
                25 => [ "Alphion-AirGroup-Shared-User",       "string" ],
                26 => [ "Alphion-AirGroup-Shared-Role",       "string" ],
                27 => [ "Alphion-AirGroup-Device-Type",       "integer" ],
                28 => [ "Alphion-Auth-Survivability",         "string" ],
                29 => [ "Alphion-AS-User-Name",               "string" ],
                30 => [ "Alphion-AS-Credential-Hash",         "string" ],
                31 => [ "Alphion-WorkSpace-App-Name",         "string" ],
                32 => [ "Alphion-Mdps-Provisioning-Settings", "string" ],
                33 => [ "Alphion-Mdps-Device-Profile",        "string" ],
                34 => [ "Alphion-AP-IP-Address",              "ipaddr" ],
                35 => [ "Alphion-AirGroup-Shared-Group",      "string" ],
                36 => [ "Alphion-User-Group",                 "string" ],
                37 => [ "Alphion-Network-SSO-Token",          "string" ],
                38 => [ "Alphion-AirGroup-Version",           "integer" ],
                40 => [ "Alphion-Port-Bounce-Host",           "integer" ],
                41 => [ "Alphion-Calea-Server-Ip",            "ipaddr" ],
                42 => [ "Alphion-Admin-Path",                 "string" ],
                43 => [ "Alphion-Captive-Portal-URL",         "string" ],
                44 => [ "Alphion-MPSK-Passphrase",            "octets" ],
                45 => [ "Alphion-ACL-Server-Query-Info",      "string" ],
                46 => [ "Alphion-Command-String",             "string" ],
            },
            8744 => {
                "0" => [ "Colubris-AVPair",    "string" ],
                "1" => [ "Colubris-Intercept", "integer" ],
            },
            9148 => {
                1   => [ "Acme-FlowID_FS1_F",                      "string" ],
                2   => [ "Acme-FlowType_FS1_F",                    "string" ],
                3   => [ "Acme-Session-Ingress-CallId",            "string" ],
                4   => [ "Acme-Session-Egress-CallId",             "string" ],
                10  => [ "Acme-Flow-In-Realm_FS1_F",               "string" ],
                11  => [ "Acme-Flow-In-Src-Addr_FS1_F",            "ipaddr" ],
                12  => [ "Acme-Flow-In-Src-Port_FS1_F",            "integer" ],
                13  => [ "Acme-Flow-In-Dst-Addr_FS1_F",            "ipaddr" ],
                14  => [ "Acme-Flow-In-Dst-Port_FS1_F",            "integer" ],
                20  => [ "Acme-Flow-Out-Realm_FS1_F",              "string" ],
                21  => [ "Acme-Flow-Out-Src-Addr_FS1_F",           "ipaddr" ],
                22  => [ "Acme-Flow-Out-Src-Port_FS1_F",           "integer" ],
                23  => [ "Acme-Flow-Out-Dst-Addr_FS1_F",           "ipaddr" ],
                24  => [ "Acme-Flow-Out-Dst-Port_FS1_F",           "integer" ],
                28  => [ "Acme-Calling-Octets_FS1",                "integer" ],
                29  => [ "Acme-Calling-Packets_FS1",               "integer" ],
                32  => [ "Acme-Calling-RTCP-Packets-Lost_FS1",     "integer" ],
                33  => [ "Acme-Calling-RTCP-Avg-Jitter_FS1",       "integer" ],
                34  => [ "Acme-Calling-RTCP-Avg-Latency_FS1",      "integer" ],
                35  => [ "Acme-Calling-RTCP-MaxJitter_FS1",        "integer" ],
                36  => [ "Acme-Calling-RTCP-MaxLatency_FS1",       "integer" ],
                37  => [ "Acme-Calling-RTP-Packets-Lost_FS1",      "integer" ],
                38  => [ "Acme-Calling-RTP-Avg-Jitter_FS1",        "integer" ],
                39  => [ "Acme-Calling-RTP-MaxJitter_FS1",         "integer" ],
                40  => [ "Acme-Session-Generic-Id",                "string" ],
                41  => [ "Acme-Session-Ingress-Realm",             "string" ],
                42  => [ "Acme-Session-Egress-Realm",              "string" ],
                43  => [ "Acme-Session-Protocol-Type",             "string" ],
                44  => [ "Acme-Called-Octets_FS1",                 "integer" ],
                45  => [ "Acme-Called-Packets_FS1",                "integer" ],
                46  => [ "Acme-Called-RTCP-Packets-Lost_FS1",      "integer" ],
                47  => [ "Acme-Called-RTCP-Avg-Jitter_FS1",        "integer" ],
                48  => [ "Acme-Called-RTCP-Avg-Latency_FS1",       "integer" ],
                49  => [ "Acme-Called-RTCP-MaxJitter_FS1",         "integer" ],
                50  => [ "Acme-Called-RTCP-MaxLatency_FS1",        "integer" ],
                51  => [ "Acme-Called-RTP-Packets-Lost_FS1",       "integer" ],
                52  => [ "Acme-Called-RTP-Avg-Jitter_FS1",         "integer" ],
                53  => [ "Acme-Called-RTP-MaxJitter_FS1",          "integer" ],
                54  => [ "Acme-Session-Charging-Vector",           "string" ],
                55  => [ "Acme-Session-Charging-Function_Address", "string" ],
                56  => [ "Acme-Firmware-Version",                  "string" ],
                57  => [ "Acme-Local-Time-Zone",                   "string" ],
                58  => [ "Acme-Post-Dial-Delay",                   "integer" ],
                59  => [ "Acme-CDR-Sequence-Number",               "integer" ],
                60  => [ "Acme-Session-Disposition",               "integer" ],
                61  => [ "Acme-Disconnect-Initiator",              "integer" ],
                62  => [ "Acme-Disconnect-Cause",                  "integer" ],
                63  => [ "Acme-Intermediate_Time",                 "string" ],
                64  => [ "Acme-Primary-Routing-Number",            "string" ],
                65  => [ "Acme-Originating-Trunk-Group",           "string" ],
                66  => [ "Acme-Terminating-Trunk-Group",           "string" ],
                67  => [ "Acme-Originating-Trunk-Context",         "string" ],
                68  => [ "Acme-Terminating-Trunk-Context",         "string" ],
                69  => [ "Acme-P-Asserted-ID",                     "string" ],
                70  => [ "Acme-SIP-Diversion",                     "string" ],
                71  => [ "Acme-SIP-Status",                        "integer" ],
                74  => [ "Acme-Ingress-Local-Addr",                "string" ],
                75  => [ "Acme-Ingress-Remote-Addr",               "string" ],
                76  => [ "Acme-Egress-Local-Addr",                 "string" ],
                77  => [ "Acme-Egress-Remote-Addr",                "string" ],
                78  => [ "Acme-FlowID_FS1_R",                      "string" ],
                79  => [ "Acme-FlowType_FS1_R",                    "string" ],
                80  => [ "Acme-Flow-In-Realm_FS1_R",               "string" ],
                81  => [ "Acme-Flow-In-Src-Addr_FS1_R",            "ipaddr" ],
                82  => [ "Acme-Flow-In-Src-Port_FS1_R",            "integer" ],
                83  => [ "Acme-Flow-In-Dst-Addr_FS1_R",            "ipaddr" ],
                84  => [ "Acme-Flow-In-Dst-Port_FS1_R",            "integer" ],
                85  => [ "Acme-Flow-Out-Realm_FS1_R",              "string" ],
                86  => [ "Acme-Flow-Out-Src-Addr_FS1_R",           "ipaddr" ],
                87  => [ "Acme-Flow-Out-Src-Port_FS1_R",           "integer" ],
                88  => [ "Acme-Flow-Out-Dst-Addr_FS1_R",           "ipaddr" ],
                89  => [ "Acme-Flow-Out-Dst-Port_FS1_R",           "integer" ],
                90  => [ "Acme-FlowID_FS2_F",                      "string" ],
                91  => [ "Acme-FlowType_FS2_F",                    "string" ],
                92  => [ "Acme-Flow-In-Realm_FS2_F",               "string" ],
                93  => [ "Acme-Flow-In-Src-Addr_FS2_F",            "ipaddr" ],
                94  => [ "Acme-Flow-In-Src-Port_FS2_F",            "integer" ],
                95  => [ "Acme-Flow-In-Dst-Addr_FS2_F",            "ipaddr" ],
                96  => [ "Acme-Flow-In-Dst-Port_FS2_F",            "integer" ],
                97  => [ "Acme-Flow-Out-Realm_FS2_F",              "string" ],
                98  => [ "Acme-Flow-Out-Src-Addr_FS2_F",           "ipaddr" ],
                99  => [ "Acme-Flow-Out-Src-Port_FS2_F",           "integer" ],
                100 => [ "Acme-Flow-Out-Dst-Addr_FS2_F",           "ipaddr" ],
                101 => [ "Acme-Flow-Out-Dst-Port_FS2_F",           "integer" ],
                102 => [ "Acme-Calling-Octets_FS2",                "integer" ],
                103 => [ "Acme-Calling-Packets_FS2",               "integer" ],
                104 => [ "Acme-Calling-RTCP-Packets-Lost_FS2",     "integer" ],
                105 => [ "Acme-Calling-RTCP-Avg-Jitter_FS2",       "integer" ],
                106 => [ "Acme-Calling-RTCP-Avg-Latency_FS2",      "integer" ],
                107 => [ "Acme-Calling-RTCP-MaxJitter_FS2",        "integer" ],
                108 => [ "Acme-Calling-RTCP-MaxLatency_FS2",       "integer" ],
                109 => [ "Acme-Calling-RTP-Packets-Lost_FS2",      "integer" ],
                110 => [ "Acme-Calling-RTP-Avg-Jitter_FS2",        "integer" ],
                111 => [ "Acme-Calling-RTP-MaxJitter_FS2",         "integer" ],
                112 => [ "Acme-FlowID_FS2_R",                      "string" ],
                113 => [ "Acme-FlowType_FS2_R",                    "string" ],
                114 => [ "Acme-Flow-In-Realm_FS2_R",               "string" ],
                115 => [ "Acme-Flow-In-Src-Addr_FS2_R",            "ipaddr" ],
                116 => [ "Acme-Flow-In-Src-Port_FS2_R",            "integer" ],
                117 => [ "Acme-Flow-In-Dst-Addr_FS2_R",            "ipaddr" ],
                118 => [ "Acme-Flow-In-Dst-Port_FS2_R",            "integer" ],
                119 => [ "Acme-Flow-Out-Realm_FS2_R",              "string" ],
                120 => [ "Acme-Flow-Out-Src-Addr_FS2_R",           "ipaddr" ],
                121 => [ "Acme-Flow-Out-Src-Port_FS2_R",           "integer" ],
                122 => [ "Acme-Flow-Out-Dst-Addr_FS2_R",           "ipaddr" ],
                123 => [ "Acme-Flow-Out-Dst-Port_FS2_R",           "integer" ],
                124 => [ "Acme-Called-Octets_FS2",                 "integer" ],
                125 => [ "Acme-Called-Packets_FS2",                "integer" ],
                126 => [ "Acme-Called-RTCP-Packets-Lost_FS2",      "integer" ],
                127 => [ "Acme-Called-RTCP-Avg-Jitter_FS2",        "integer" ],
                128 => [ "Acme-Called-RTCP-Avg-Latency_FS2",       "integer" ],
                129 => [ "Acme-Called-RTCP-MaxJitter_FS2",         "integer" ],
                130 => [ "Acme-Called-RTCP-MaxLatency_FS2",        "integer" ],
                131 => [ "Acme-Called-RTP-Packets-Lost_FS2",       "integer" ],
                132 => [ "Acme-Called-RTP-Avg-Jitter_FS2",         "integer" ],
                133 => [ "Acme-Called-RTP-MaxJitter_FS2",          "integer" ],
                134 => [ "Acme-Egress-Final-Routing-Number",       "string" ],
                135 => [ "Acme-Session-Ingress-RPH",               "string" ],
                136 => [ "Acme-Session-Egress-RPH",                "string" ],
                137 => [ "Acme-Ingress-Network-Interface-Id",      "string" ],
                138 => [ "Acme-Ingress-Vlan-Tag-Value",            "integer" ],
                139 => [ "Acme-Egress-Network-Interface-Id",       "string" ],
                140 => [ "Acme-Egress-Vlan-Tag-Value",             "integer" ],
                141 => [ "Acme-Refer-Call-Transfer-Id",            "string" ],
                142 => [ "Acme-FlowMediaType_FS1_F",               "string" ],
                143 => [ "Acme-FlowMediaType_FS1_R",               "string" ],
                144 => [ "Acme-FlowMediaType_FS2_F",               "string" ],
                145 => [ "Acme-FlowMediaType_FS2_R",               "string" ],
                146 => [ "Acme-Flow-PTime_FS1_F",                  "integer" ],
                147 => [ "Acme-Flow-PTime_FS1_R",                  "integer" ],
                148 => [ "Acme-Flow-PTime_FS2_F",                  "integer" ],
                149 => [ "Acme-Flow-PTime_FS2_R",                  "integer" ],
                150 => [ "Acme-Session-Media-Process",             "string" ],
                151 => [ "Acme-Calling-R-Factor",                  "integer" ],
                152 => [ "Acme-Calling-MOS",                       "integer" ],
                153 => [ "Acme-Called-R-Factor",                   "integer" ],
                154 => [ "Acme-Called-MOS",                        "integer" ],
                155 => [ "Acme-Flow-In-Src-IPv6_Addr_FS1_F",       "ipv6addr" ],
                156 => [ "Acme-Flow-In-Dst-IPv6_Addr_FS1_F",       "ipv6addr" ],
                157 => [ "Acme-Flow-Out-Src-IPv6_Addr_FS1_F",      "ipv6addr" ],
                158 => [ "Acme-Flow-Out-Dst-IPv6_Addr_FS1_F",      "ipv6addr" ],
                159 => [ "Acme-Flow-In-Src-IPv6_Addr_FS1_R",       "ipv6addr" ],
                160 => [ "Acme-Flow-In-Dst-IPv6_Addr_FS1_R",       "ipv6addr" ],
                161 => [ "Acme-Flow-Out-Src-IPv6_Addr_FS1_R",      "ipv6addr" ],
                162 => [ "Acme-Flow-Out-Dst-IPv6_Addr_FS1_R",      "ipv6addr" ],
                163 => [ "Acme-Flow-In-Src-IPv6_Addr_FS2_F",       "ipv6addr" ],
                164 => [ "Acme-Flow-In-Dst-IPv6_Addr_FS2_F",       "ipv6addr" ],
                165 => [ "Acme-Flow-Out-Src-IPv6_Addr_FS2_F",      "ipv6addr" ],
                166 => [ "Acme-Flow-Out-Dst-IPv6_Addr_FS2_F",      "ipv6addr" ],
                167 => [ "Acme-Flow-In-Src-IPv6_Addr_FS2_R",       "ipv6addr" ],
                168 => [ "Acme-Flow-In-Dst-IPv6_Addr_FS2_R",       "ipv6addr" ],
                169 => [ "Acme-Flow-Out-Src-IPv6_Addr_FS2_R",      "ipv6addr" ],
                170 => [ "Acme-Flow-Out-Dst-IPv6_Addr_FS2_R",      "ipv6addr" ],
                171 => [ "Acme-Session-Forked-Call-Id",            "string" ],
                200 => [ "Acme-Custom-VSA-200",                    "string" ],
                201 => [ "Acme-Custom-VSA-201",                    "string" ],
                202 => [ "Acme-Custom-VSA-202",                    "string" ],
                203 => [ "Acme-Custom-VSA-203",                    "string" ],
                204 => [ "Acme-Custom-VSA-204",                    "string" ],
                205 => [ "Acme-Custom-VSA-205",                    "string" ],
                206 => [ "Acme-Custom-VSA-206",                    "string" ],
                207 => [ "Acme-Custom-VSA-207",                    "string" ],
                208 => [ "Acme-Custom-VSA-208",                    "string" ],
                209 => [ "Acme-Custom-VSA-209",                    "string" ],
                210 => [ "Acme-Custom-VSA-210",                    "string" ],
                211 => [ "Acme-Custom-VSA-211",                    "string" ],
                212 => [ "Acme-Custom-VSA-212",                    "string" ],
                213 => [ "Acme-Custom-VSA-213",                    "string" ],
                214 => [ "Acme-Custom-VSA-214",                    "string" ],
                215 => [ "Acme-Custom-VSA-215",                    "string" ],
                216 => [ "Acme-Custom-VSA-216",                    "string" ],
                217 => [ "Acme-Custom-VSA-217",                    "string" ],
                218 => [ "Acme-Custom-VSA-218",                    "string" ],
                219 => [ "Acme-Custom-VSA-219",                    "string" ],
                220 => [ "Acme-Custom-VSA-220",                    "string" ],
                221 => [ "Acme-Custom-VSA-221",                    "string" ],
                222 => [ "Acme-Custom-VSA-222",                    "string" ],
                223 => [ "Acme-Custom-VSA-223",                    "string" ],
                224 => [ "Acme-Custom-VSA-224",                    "string" ],
                225 => [ "Acme-Custom-VSA-225",                    "string" ],
                226 => [ "Acme-Custom-VSA-226",                    "string" ],
                227 => [ "Acme-Custom-VSA-227",                    "string" ],
                228 => [ "Acme-Custom-VSA-228",                    "string" ],
                229 => [ "Acme-Custom-VSA-229",                    "string" ],
                230 => [ "Acme-Custom-VSA-230",                    "string" ],
                231 => [ "Acme-Flow-Calling-Media-Stop-Time-FS1",  "string" ],
                232 => [ "Acme-Flow-Called-Media-Stop-Time-FS1",   "string" ],
                233 => [ "Acme-Flow-Calling-Media-Stop-Time-FS2",  "string" ],
                234 => [ "Acme-Flow-Called-Media-Stop-Time-FS2",   "string" ],
                235 => [ "Acme-SIP-Method-Type",                   "string" ],
                236 => [ "Acme-Domain-Name",                       "string" ],
                237 => [ "Acme-SIP-Contact",                       "string" ],
                238 => [ "Acme-SIP-Expires",                       "integer" ],
                239 => [ "Acme-Reason-Phrase",                     "string" ],
                253 => [ "Acme-User-Privilege",                    "string" ],
                254 => [ "Acme-User-Class",                        "string" ],
            },
            9694  => { 1 => [ "Arbor-Privilege-Level", "string" ] },
            10055 => {
                1 => [ "RP-Upstream-Speed-Limit",   "integer" ],
                2 => [ "RP-Downstream-Speed-Limit", "integer" ],
                3 => [ "RP-HURL",                   "string" ],
                4 => [ "RP-MOTM",                   "string" ],
                5 => [ "RP-Max-Sessions-Per-User",  "integer" ],
            },
            10415 => {
                1  => [ "3GPP-IMSI",                          "string" ],
                2  => [ "3GPP-Charging-ID",                   "integer" ],
                3  => [ "3GPP-PDP-Type",                      "integer" ],
                4  => [ "3GPP-Charging-Gateway-Address",      "ipaddr" ],
                5  => [ "3GPP-GPRS-Negotiated-QoS-profile",   "string" ],
                6  => [ "3GPP-SGSN-Address",                  "ipaddr" ],
                7  => [ "3GPP-GGSN-Address",                  "ipaddr" ],
                8  => [ "3GPP-IMSI-MCC-MNC",                  "string" ],
                9  => [ "3GPP-GGSN-MCC-MNC",                  "string" ],
                10 => [ "3GPP-NSAPI",                         "string" ],
                11 => [ "3GPP-Session-Stop-Indicator",        "byte" ],
                12 => [ "3GPP-Selection-Mode",                "string" ],
                13 => [ "3GPP-Charging-Characteristics",      "string" ],
                14 => [ "3GPP-Charging-Gateway-IPv6-Address", "ipv6addr" ],
                15 => [ "3GPP-SGSN-IPv6-Address",             "ipv6addr" ],
                16 => [ "3GPP-GGSN-IPv6-Address",             "ipv6addr" ],
                17 => [ "3GPP-IPv6-DNS-Servers",              "octets" ],
                18 => [ "3GPP-SGSN-MCC-MNC",                  "string" ],
                19 => [ "3GPP-Teardown-Indicator",            "byte" ],
                20 => [ "3GPP-IMEISV",                        "string" ],
                21 => [ "3GPP-RAT-Type",                      "byte" ],
                22 => [ "3GPP-User-Location-Info",            "octets" ],
                23 => [ "3GPP-MS-Time-Zone",                  "octets" ],
                24 => [ "3GPP-Camel-Charging-Info",           "octets" ],
                25 => [ "3GPP-Packet-Filter",                 "octets" ],
                26 => [ "3GPP-Negotiated-DSCP",               "byte" ],
                27 => [ "3GPP-Allocate-IP-Type",              "byte" ],
            },
            10529 => {
                21 => [ "Acct-Session-Input-Octets",     "integer" ],
                22 => [ "Acct-Session-Input-Gigawords",  "integer" ],
                23 => [ "Acct-Session-Output-Octets",    "integer" ],
                24 => [ "Acct-Session-Output-Gigawords", "integer" ],
                25 => [ "Acct-Session-Octets",           "integer" ],
                26 => [ "Acct-Session-Gigawords",        "integer" ],
            },
            10923 => {
                30 => [ "Suggested-Rule-Space",           "string" ],
                31 => [ "Suggested-Secondary-Rule-Space", "string" ],
            },
            11344 => {
                1   => [ "FreeRADIUS-802.1X-Anonce",           "octets" ],
                2   => [ "FreeRADIUS-802.1X-EAPoL-Key-Msg",    "octets" ],
                127 => [ "FreeRADIUS-Statistics-Type",         "integer" ],
                128 => [ "FreeRADIUS-Total-Access-Requests",   "integer" ],
                129 => [ "FreeRADIUS-Total-Access-Accepts",    "integer" ],
                130 => [ "FreeRADIUS-Total-Access-Rejects",    "integer" ],
                131 => [ "FreeRADIUS-Total-Access-Challenges", "integer" ],
                132 => [ "FreeRADIUS-Total-Auth-Responses",    "integer" ],
                133 =>
                  [ "FreeRADIUS-Total-Auth-Duplicate-Requests", "integer" ],
                134 =>
                  [ "FreeRADIUS-Total-Auth-Malformed-Requests", "integer" ],
                135 => [ "FreeRADIUS-Total-Auth-Invalid-Requests", "integer" ],
                136 => [ "FreeRADIUS-Total-Auth-Dropped-Requests", "integer" ],
                137 => [ "FreeRADIUS-Total-Auth-Unknown-Types",    "integer" ],
                138 => [ "FreeRADIUS-Total-Proxy-Access-Requests", "integer" ],
                139 => [ "FreeRADIUS-Total-Proxy-Access-Accepts",  "integer" ],
                140 => [ "FreeRADIUS-Total-Proxy-Access-Rejects",  "integer" ],
                141 =>
                  [ "FreeRADIUS-Total-Proxy-Access-Challenges", "integer" ],
                142 => [ "FreeRADIUS-Total-Proxy-Auth-Responses", "integer" ],
                143 => [
                    "FreeRADIUS-Total-Proxy-Auth-Duplicate-Requests", "integer"
                ],
                144 => [
                    "FreeRADIUS-Total-Proxy-Auth-Malformed-Requests", "integer"
                ],
                145 =>
                  [ "FreeRADIUS-Total-Proxy-Auth-Invalid-Requests", "integer" ],
                146 =>
                  [ "FreeRADIUS-Total-Proxy-Auth-Dropped-Requests", "integer" ],
                147 =>
                  [ "FreeRADIUS-Total-Proxy-Auth-Unknown-Types", "integer" ],
                148 => [ "FreeRADIUS-Total-Accounting-Requests",  "integer" ],
                149 => [ "FreeRADIUS-Total-Accounting-Responses", "integer" ],
                150 =>
                  [ "FreeRADIUS-Total-Acct-Duplicate-Requests", "integer" ],
                151 =>
                  [ "FreeRADIUS-Total-Acct-Malformed-Requests", "integer" ],
                152 => [ "FreeRADIUS-Total-Acct-Invalid-Requests", "integer" ],
                153 => [ "FreeRADIUS-Total-Acct-Dropped-Requests", "integer" ],
                154 => [ "FreeRADIUS-Total-Acct-Unknown-Types",    "integer" ],
                155 =>
                  [ "FreeRADIUS-Total-Proxy-Accounting-Requests", "integer" ],
                156 =>
                  [ "FreeRADIUS-Total-Proxy-Accounting-Responses", "integer" ],
                157 => [
                    "FreeRADIUS-Total-Proxy-Acct-Duplicate-Requests", "integer"
                ],
                158 => [
                    "FreeRADIUS-Total-Proxy-Acct-Malformed-Requests", "integer"
                ],
                159 =>
                  [ "FreeRADIUS-Total-Proxy-Acct-Invalid-Requests", "integer" ],
                160 =>
                  [ "FreeRADIUS-Total-Proxy-Acct-Dropped-Requests", "integer" ],
                161 =>
                  [ "FreeRADIUS-Total-Proxy-Acct-Unknown-Types", "integer" ],
                162 => [ "FreeRADIUS-Queue-Len-Internal",      "integer" ],
                163 => [ "FreeRADIUS-Queue-Len-Proxy",         "integer" ],
                164 => [ "FreeRADIUS-Queue-Len-Auth",          "integer" ],
                165 => [ "FreeRADIUS-Queue-Len-Acct",          "integer" ],
                166 => [ "FreeRADIUS-Queue-Len-Detail",        "integer" ],
                167 => [ "FreeRADIUS-Stats-Client-IP-Address", "ipaddr" ],
                168 => [ "FreeRADIUS-Stats-Client-Number",     "integer" ],
                169 => [ "FreeRADIUS-Stats-Client-Netmask",    "integer" ],
                170 => [ "FreeRADIUS-Stats-Server-IP-Address", "ipaddr" ],
                171 => [ "FreeRADIUS-Stats-Server-Port",       "integer" ],
                172 =>
                  [ "FreeRADIUS-Stats-Server-Outstanding-Requests", "integer" ],
                173 => [ "FreeRADIUS-Stats-Server-State",          "integer" ],
                174 => [ "FreeRADIUS-Stats-Server-Time-Of-Death",  "date" ],
                175 => [ "FreeRADIUS-Stats-Server-Time-Of-Life",   "date" ],
                176 => [ "FreeRADIUS-Stats-Server-Src-IP-Address", "ipaddr" ],
                177 => [ "FreeRADIUS-Stats-Server-Src-IPv6-Address", "ipaddr" ],
                178 => [ "FreeRADIUS-Server-EMA-Window",         "integer" ],
                179 => [ "FreeRADIUS-Server-EMA-USEC-Window-1",  "integer" ],
                180 => [ "FreeRADIUS-Server-EMA-USEC-Window-10", "integer" ],
                181 => [ "FreeRADIUS-Queue-PPS-In",              "integer" ],
                182 => [ "FreeRADIUS-Queue-PPS-Out",             "integer" ],
                183 => [ "FreeRADIUS-Queue-Use-Percentage",      "integer" ],
                184 => [ "FreeRADIUS-Stats-Last-Packet-Recv",    "date" ],
                185 => [ "FreeRADIUS-Stats-Last-Packet-Sent",    "date" ],
                186 => [ "FreeRADIUS-EAP-TRAP-PAC-Type",         "short" ],
                187 => [ "FreeRADIUS-Stats-Error",               "string" ],
                188 => [ "FreeRADIUS-Stats-Client-IPv6-Address", "ipv6addr" ],
                189 => [ "FreeRADIUS-Stats-Server-IPv6-Address", "ipv6addr" ],
                190 => [ "FreeRADIUS-EAP-TEAP-Trusted-Server-Root", "octets" ],
                191 => [ "FreeRADIUS-Total-Auth-Conflicts",         "integer" ],
                192 => [ "FreeRADIUS-Total-Acct-Conflicts",         "integer" ],
                193 => [ "FreeRADIUS-Stats-Threads-Active",         "integer" ],
                194 => [ "FreeRADIUS-Stats-Threads-Total",          "integer" ],
                195 => [ "FreeRADIUS-Stats-Threads-Max",            "integer" ],
            },
            11862 => {
                "0" => [ "Sip-Method",                 "integer" ],
                "1" => [ "Sip-From",                   "string" ],
                "2" => [ "Sip-To",                     "string" ],
                "4" => [ "Sip-Translated-Request-URI", "string" ],
            },
            11863 => {
                1 => [ "TPLink-Recv-limit",              "integer" ],
                2 => [ "TPLink-Xmit-limit",              "integer" ],
                3 => [ "TPLink-Authentication-FindKey",  "octets" ],
                4 => [ "TPLink-Authentication-FoundKey", "octets" ],
                5 => [ "TPLink-User-Command",            "string" ],
                6 => [ "TPLink-Site",                    "string" ],
                7 => [ "TPLink-Omada",                   "string" ],
                8 => [ "TPLink-Redirect-Url",            "string" ],
                9 => [ "TPLink-Portal-Access-Status",    "integer" ],
            },
            12356 => {
                1  => [ "Fortinet-Group-Name",                    "string" ],
                2  => [ "Fortinet-Client-IP-Address",             "ipaddr" ],
                3  => [ "Fortinet-Vdom-Name",                     "string" ],
                4  => [ "Fortinet-Client-IPv6-Address",           "octets" ],
                5  => [ "Fortinet-Interface-Name",                "string" ],
                6  => [ "Fortinet-Access-Profile",                "string" ],
                7  => [ "Fortinet-SSID",                          "string" ],
                8  => [ "Fortinet-AP-Name",                       "string" ],
                11 => [ "Fortinet-FAC-Auth-Status",               "string" ],
                12 => [ "Fortinet-FAC-Token-ID",                  "string" ],
                15 => [ "Fortinet-FAC-Challenge-Code",            "string" ],
                16 => [ "Fortinet-Webfilter-Category-Allow",      "octets" ],
                17 => [ "Fortinet-Webfilter-Category-Block",      "octets" ],
                18 => [ "Fortinet-Webfilter-Category-Monitor",    "octets" ],
                19 => [ "Fortinet-AppCtrl-Category-Allow",        "octets" ],
                20 => [ "Fortinet-AppCtrl-Category-Block",        "octets" ],
                21 => [ "Fortinet-AppCtrl-Risk-Allow",            "octets" ],
                22 => [ "Fortinet-AppCtrl-Risk-Block",            "octets" ],
                23 => [ "Fortinet-WirelessController-Device-MAC", "ether" ],
                24 => [ "Fortinet-WirelessController-WTP-ID",     "string" ],
                25 => [ "Fortinet-WirelessController-Assoc-Time", "date" ],
                26 => [ "Fortinet-FortiWAN-AVPair",               "string" ],
                30 => [ "Fortinet-FDD-Access-Profile",            "string" ],
                31 => [ "Fortinet-FDD-Trusted-Hosts",             "string" ],
                32 => [ "Fortinet-FDD-SPP-Name",                  "string" ],
                33 => [ "Fortinet-FDD-Is-System-Admin",           "string" ],
                34 => [ "Fortinet-FDD-Is-SPP-Admin",              "string" ],
                35 => [ "Fortinet-FDD-SPP-Policy-Group",          "string" ],
                36 => [ "Fortinet-FDD-Allow-API-Access",          "string" ],
                40 => [ "Fortinet-Fpc-User-Role",                 "string" ],
                41 => [ "Fortinet-Tenant-Identification",         "string" ],
                42 => [ "Fortinet-Host-Port-AVPair",              "string" ],
            },
            12394 => {
                1   => [ "Breezecom-Attr1",  "string" ],
                2   => [ "Breezecom-Attr2",  "string" ],
                3   => [ "Breezecom-Attr3",  "string" ],
                4   => [ "Breezecom-Attr4",  "string" ],
                5   => [ "Breezecom-Attr5",  "string" ],
                6   => [ "Breezecom-Attr6",  "string" ],
                7   => [ "Breezecom-Attr7",  "string" ],
                8   => [ "Breezecom-Attr8",  "string" ],
                9   => [ "Breezecom-Attr9",  "string" ],
                10  => [ "Breezecom-Attr10", "string" ],
                11  => [ "Breezecom-Attr11", "string" ],
                12  => [ "Alvarion-VSA-12",  "string" ],
                13  => [ "Alvarion-VSA-13",  "string" ],
                14  => [ "Alvarion-VSA-14",  "string" ],
                15  => [ "Alvarion-VSA-15",  "string" ],
                16  => [ "Alvarion-VSA-16",  "string" ],
                17  => [ "Alvarion-VSA-17",  "string" ],
                18  => [ "Alvarion-VSA-18",  "string" ],
                19  => [ "Alvarion-VSA-19",  "string" ],
                20  => [ "Alvarion-VSA-20",  "string" ],
                21  => [ "Alvarion-VSA-21",  "string" ],
                22  => [ "Alvarion-VSA-22",  "string" ],
                23  => [ "Alvarion-VSA-23",  "string" ],
                24  => [ "Alvarion-VSA-24",  "string" ],
                25  => [ "Alvarion-VSA-25",  "string" ],
                26  => [ "Alvarion-VSA-26",  "string" ],
                27  => [ "Alvarion-VSA-27",  "string" ],
                28  => [ "Alvarion-VSA-28",  "string" ],
                29  => [ "Alvarion-VSA-29",  "string" ],
                30  => [ "Alvarion-VSA-30",  "string" ],
                31  => [ "Alvarion-VSA-31",  "string" ],
                32  => [ "Alvarion-VSA-32",  "string" ],
                33  => [ "Alvarion-VSA-33",  "string" ],
                34  => [ "Alvarion-VSA-34",  "string" ],
                35  => [ "Alvarion-VSA-35",  "string" ],
                36  => [ "Alvarion-VSA-36",  "string" ],
                37  => [ "Alvarion-VSA-37",  "string" ],
                38  => [ "Alvarion-VSA-38",  "string" ],
                39  => [ "Alvarion-VSA-39",  "string" ],
                40  => [ "Alvarion-VSA-40",  "string" ],
                41  => [ "Alvarion-VSA-41",  "string" ],
                42  => [ "Alvarion-VSA-42",  "string" ],
                43  => [ "Alvarion-VSA-43",  "string" ],
                44  => [ "Alvarion-VSA-44",  "string" ],
                45  => [ "Alvarion-VSA-45",  "string" ],
                46  => [ "Alvarion-VSA-46",  "string" ],
                47  => [ "Alvarion-VSA-47",  "string" ],
                48  => [ "Alvarion-VSA-48",  "string" ],
                49  => [ "Alvarion-VSA-49",  "string" ],
                50  => [ "Alvarion-VSA-50",  "string" ],
                51  => [ "Alvarion-VSA-51",  "string" ],
                52  => [ "Alvarion-VSA-52",  "string" ],
                53  => [ "Alvarion-VSA-53",  "string" ],
                54  => [ "Alvarion-VSA-54",  "string" ],
                55  => [ "Alvarion-VSA-55",  "string" ],
                56  => [ "Alvarion-VSA-56",  "string" ],
                57  => [ "Alvarion-VSA-57",  "string" ],
                58  => [ "Alvarion-VSA-58",  "string" ],
                59  => [ "Alvarion-VSA-59",  "string" ],
                60  => [ "Alvarion-VSA-60",  "string" ],
                61  => [ "Alvarion-VSA-61",  "string" ],
                62  => [ "Alvarion-VSA-62",  "string" ],
                63  => [ "Alvarion-VSA-63",  "string" ],
                64  => [ "Alvarion-VSA-64",  "string" ],
                65  => [ "Alvarion-VSA-65",  "string" ],
                66  => [ "Alvarion-VSA-66",  "string" ],
                67  => [ "Alvarion-VSA-67",  "string" ],
                68  => [ "Alvarion-VSA-68",  "string" ],
                69  => [ "Alvarion-VSA-69",  "string" ],
                70  => [ "Alvarion-VSA-70",  "string" ],
                71  => [ "Alvarion-VSA-71",  "string" ],
                72  => [ "Alvarion-VSA-72",  "string" ],
                73  => [ "Alvarion-VSA-73",  "string" ],
                74  => [ "Alvarion-VSA-74",  "string" ],
                75  => [ "Alvarion-VSA-75",  "string" ],
                76  => [ "Alvarion-VSA-76",  "string" ],
                77  => [ "Alvarion-VSA-77",  "string" ],
                78  => [ "Alvarion-VSA-78",  "string" ],
                79  => [ "Alvarion-VSA-79",  "string" ],
                80  => [ "Alvarion-VSA-80",  "string" ],
                81  => [ "Alvarion-VSA-81",  "string" ],
                82  => [ "Alvarion-VSA-82",  "string" ],
                83  => [ "Alvarion-VSA-83",  "string" ],
                84  => [ "Alvarion-VSA-84",  "string" ],
                85  => [ "Alvarion-VSA-85",  "string" ],
                86  => [ "Alvarion-VSA-86",  "string" ],
                87  => [ "Alvarion-VSA-87",  "string" ],
                88  => [ "Alvarion-VSA-88",  "string" ],
                89  => [ "Alvarion-VSA-89",  "string" ],
                90  => [ "Alvarion-VSA-90",  "string" ],
                91  => [ "Alvarion-VSA-91",  "string" ],
                92  => [ "Alvarion-VSA-92",  "string" ],
                93  => [ "Alvarion-VSA-93",  "string" ],
                94  => [ "Alvarion-VSA-94",  "string" ],
                95  => [ "Alvarion-VSA-95",  "string" ],
                96  => [ "Alvarion-VSA-96",  "string" ],
                97  => [ "Alvarion-VSA-97",  "string" ],
                98  => [ "Alvarion-VSA-98",  "string" ],
                99  => [ "Alvarion-VSA-99",  "string" ],
                100 => [ "Alvarion-VSA-100", "string" ],
                101 => [ "Alvarion-VSA-101", "string" ],
                102 => [ "Alvarion-VSA-102", "string" ],
                103 => [ "Alvarion-VSA-103", "string" ],
                104 => [ "Alvarion-VSA-104", "string" ],
                105 => [ "Alvarion-VSA-105", "string" ],
                106 => [ "Alvarion-VSA-106", "string" ],
                107 => [ "Alvarion-VSA-107", "string" ],
                108 => [ "Alvarion-VSA-108", "string" ],
                109 => [ "Alvarion-VSA-109", "string" ],
                110 => [ "Alvarion-VSA-110", "string" ],
                111 => [ "Alvarion-VSA-111", "string" ],
                112 => [ "Alvarion-VSA-112", "string" ],
                113 => [ "Alvarion-VSA-113", "string" ],
                114 => [ "Alvarion-VSA-114", "string" ],
                115 => [ "Alvarion-VSA-115", "string" ],
                116 => [ "Alvarion-VSA-116", "string" ],
                117 => [ "Alvarion-VSA-117", "string" ],
                118 => [ "Alvarion-VSA-118", "string" ],
                119 => [ "Alvarion-VSA-119", "string" ],
                120 => [ "Alvarion-VSA-120", "string" ],
                121 => [ "Alvarion-VSA-121", "string" ],
                122 => [ "Alvarion-VSA-122", "string" ],
                123 => [ "Alvarion-VSA-123", "string" ],
                124 => [ "Alvarion-VSA-124", "string" ],
                125 => [ "Alvarion-VSA-125", "string" ],
                126 => [ "Alvarion-VSA-126", "string" ],
                127 => [ "Alvarion-VSA-127", "string" ],
                128 => [ "Alvarion-VSA-128", "string" ],
                129 => [ "Alvarion-VSA-129", "string" ],
                130 => [ "Alvarion-VSA-130", "string" ],
                131 => [ "Alvarion-VSA-131", "string" ],
                132 => [ "Alvarion-VSA-132", "string" ],
                133 => [ "Alvarion-VSA-133", "string" ],
                134 => [ "Alvarion-VSA-134", "string" ],
                135 => [ "Alvarion-VSA-135", "string" ],
                136 => [ "Alvarion-VSA-136", "string" ],
                137 => [ "Alvarion-VSA-137", "string" ],
                138 => [ "Alvarion-VSA-138", "string" ],
                139 => [ "Alvarion-VSA-139", "string" ],
                140 => [ "Alvarion-VSA-140", "string" ],
                141 => [ "Alvarion-VSA-141", "string" ],
                142 => [ "Alvarion-VSA-142", "string" ],
                143 => [ "Alvarion-VSA-143", "string" ],
                144 => [ "Alvarion-VSA-144", "string" ],
                145 => [ "Alvarion-VSA-145", "string" ],
                146 => [ "Alvarion-VSA-146", "string" ],
                147 => [ "Alvarion-VSA-147", "string" ],
                148 => [ "Alvarion-VSA-148", "string" ],
                149 => [ "Alvarion-VSA-149", "string" ],
                150 => [ "Alvarion-VSA-150", "string" ],
                151 => [ "Alvarion-VSA-151", "string" ],
                152 => [ "Alvarion-VSA-152", "string" ],
                153 => [ "Alvarion-VSA-153", "string" ],
                154 => [ "Alvarion-VSA-154", "string" ],
                155 => [ "Alvarion-VSA-155", "string" ],
                156 => [ "Alvarion-VSA-156", "string" ],
                157 => [ "Alvarion-VSA-157", "string" ],
                158 => [ "Alvarion-VSA-158", "string" ],
                159 => [ "Alvarion-VSA-159", "string" ],
                160 => [ "Alvarion-VSA-160", "string" ],
                161 => [ "Alvarion-VSA-161", "string" ],
                162 => [ "Alvarion-VSA-162", "string" ],
                163 => [ "Alvarion-VSA-163", "string" ],
                164 => [ "Alvarion-VSA-164", "string" ],
                165 => [ "Alvarion-VSA-165", "string" ],
                166 => [ "Alvarion-VSA-166", "string" ],
                167 => [ "Alvarion-VSA-167", "string" ],
                168 => [ "Alvarion-VSA-168", "string" ],
                169 => [ "Alvarion-VSA-169", "string" ],
                170 => [ "Alvarion-VSA-170", "string" ],
                171 => [ "Alvarion-VSA-171", "string" ],
                172 => [ "Alvarion-VSA-172", "string" ],
                173 => [ "Alvarion-VSA-173", "string" ],
                174 => [ "Alvarion-VSA-174", "string" ],
                175 => [ "Alvarion-VSA-175", "string" ],
                176 => [ "Alvarion-VSA-176", "string" ],
                177 => [ "Alvarion-VSA-177", "string" ],
                178 => [ "Alvarion-VSA-178", "string" ],
                179 => [ "Alvarion-VSA-179", "string" ],
                180 => [ "Alvarion-VSA-180", "string" ],
                181 => [ "Alvarion-VSA-181", "string" ],
                182 => [ "Alvarion-VSA-182", "string" ],
                183 => [ "Alvarion-VSA-183", "string" ],
                184 => [ "Alvarion-VSA-184", "string" ],
                185 => [ "Alvarion-VSA-185", "string" ],
                186 => [ "Alvarion-VSA-186", "string" ],
                187 => [ "Alvarion-VSA-187", "string" ],
                188 => [ "Alvarion-VSA-188", "string" ],
                189 => [ "Alvarion-VSA-189", "string" ],
                190 => [ "Alvarion-VSA-190", "string" ],
                191 => [ "Alvarion-VSA-191", "string" ],
                192 => [ "Alvarion-VSA-192", "string" ],
                193 => [ "Alvarion-VSA-193", "string" ],
                194 => [ "Alvarion-VSA-194", "string" ],
                195 => [ "Alvarion-VSA-195", "string" ],
                196 => [ "Alvarion-VSA-196", "string" ],
                197 => [ "Alvarion-VSA-197", "string" ],
                198 => [ "Alvarion-VSA-198", "string" ],
                199 => [ "Alvarion-VSA-199", "string" ],
                200 => [ "Alvarion-VSA-200", "string" ],
                201 => [ "Alvarion-VSA-201", "string" ],
                202 => [ "Alvarion-VSA-202", "string" ],
                203 => [ "Alvarion-VSA-203", "string" ],
                204 => [ "Alvarion-VSA-204", "string" ],
                205 => [ "Alvarion-VSA-205", "string" ],
                206 => [ "Alvarion-VSA-206", "string" ],
                207 => [ "Alvarion-VSA-207", "string" ],
                208 => [ "Alvarion-VSA-208", "string" ],
                209 => [ "Alvarion-VSA-209", "string" ],
                210 => [ "Alvarion-VSA-210", "string" ],
                211 => [ "Alvarion-VSA-211", "string" ],
                212 => [ "Alvarion-VSA-212", "string" ],
                213 => [ "Alvarion-VSA-213", "string" ],
                214 => [ "Alvarion-VSA-214", "string" ],
                215 => [ "Alvarion-VSA-215", "string" ],
                216 => [ "Alvarion-VSA-216", "string" ],
                217 => [ "Alvarion-VSA-217", "string" ],
                218 => [ "Alvarion-VSA-218", "string" ],
                219 => [ "Alvarion-VSA-219", "string" ],
                220 => [ "Alvarion-VSA-220", "string" ],
                221 => [ "Alvarion-VSA-221", "string" ],
                222 => [ "Alvarion-VSA-222", "string" ],
                223 => [ "Alvarion-VSA-223", "string" ],
                224 => [ "Alvarion-VSA-224", "string" ],
                225 => [ "Alvarion-VSA-225", "string" ],
                226 => [ "Alvarion-VSA-226", "string" ],
                227 => [ "Alvarion-VSA-227", "string" ],
                228 => [ "Alvarion-VSA-228", "string" ],
                229 => [ "Alvarion-VSA-229", "string" ],
                230 => [ "Alvarion-VSA-230", "string" ],
                231 => [ "Alvarion-VSA-231", "string" ],
                232 => [ "Alvarion-VSA-232", "string" ],
                233 => [ "Alvarion-VSA-233", "string" ],
                234 => [ "Alvarion-VSA-234", "string" ],
                235 => [ "Alvarion-VSA-235", "string" ],
                236 => [ "Alvarion-VSA-236", "string" ],
                237 => [ "Alvarion-VSA-237", "string" ],
                238 => [ "Alvarion-VSA-238", "string" ],
                239 => [ "Alvarion-VSA-239", "string" ],
                240 => [ "Alvarion-VSA-240", "string" ],
                241 => [ "Alvarion-VSA-241", "string" ],
                242 => [ "Alvarion-VSA-242", "string" ],
                243 => [ "Alvarion-VSA-243", "string" ],
                244 => [ "Alvarion-VSA-244", "string" ],
                245 => [ "Alvarion-VSA-245", "string" ],
                246 => [ "Alvarion-VSA-246", "string" ],
                247 => [ "Alvarion-VSA-247", "string" ],
                248 => [ "Alvarion-VSA-248", "string" ],
                249 => [ "Alvarion-VSA-249", "string" ],
                250 => [ "Alvarion-VSA-250", "string" ],
                251 => [ "Alvarion-VSA-251", "string" ],
                252 => [ "Alvarion-VSA-252", "string" ],
                253 => [ "Alvarion-VSA-253", "string" ],
                254 => [ "Alvarion-VSA-254", "string" ],
                255 => [ "Alvarion-VSA-255", "string" ],
            },
            12740 => {
                1 => [ "Equallogic-Admin-Full-Name",        "string" ],
                2 => [ "Equallogic-Admin-Email",            "string" ],
                3 => [ "Equallogic-Admin-Phone",            "string" ],
                4 => [ "Equallogic-Admin-Mobile",           "string" ],
                5 => [ "Equallogic-Poll-Interval",          "integer" ],
                6 => [ "Equallogic-EQL-Admin-Privilege",    "integer" ],
                7 => [ "Equallogic-Admin-Pool-Access",      "string" ],
                8 => [ "Equallogic-Admin-Repl-Site-Access", "string" ],
                9 => [ "Equallogic-Admin-Account-Type",     "string" ],
            },
            12951 => {
                200 => [ "Acct-Interim-Record-Number", "integer" ],
                201 => [ "UE-Info-Type",               "integer" ],
                202 => [ "UE-Info-Value",              "string" ],
                203 => [ "Dynamic-Address-Flag",       "integer" ],
                204 => [ "Local-Seq-Number",           "integer" ],
                205 => [ "Time-First-Usage",           "date" ],
                206 => [ "Time-Last-Usage",            "date" ],
                207 => [ "Charging-Group-ID",          "string" ],
                210 => [ "Service-Data-Container-Bin", "octets" ],
                211 => [ "Service-Data-Container",     "tlv" ],
            },
            13209 => {
                1   => [ "Aptilo-Subnet-Name",            "string" ],
                2   => [ "Aptilo-Octets-Limit",           "integer" ],
                3   => [ "Aptilo-Gigawords-Limit",        "integer" ],
                4   => [ "Aptilo-Input-Octets-Limit",     "integer" ],
                5   => [ "Aptilo-Input-Gigawords-Limit",  "integer" ],
                6   => [ "Aptilo-Output-Octets-Limit",    "integer" ],
                7   => [ "Aptilo-Output-Gigawords-Limit", "integer" ],
                8   => [ "Aptilo-Limit-Mode",             "integer" ],
                9   => [ "Aptilo-Apc-ID",                 "string" ],
                10  => [ "Aptilo-Opaque-Key",             "string" ],
                11  => [ "Aptilo-Denied-Cause",           "integer" ],
                12  => [ "Aptilo-Realm-ID",               "integer" ],
                13  => [ "Aptilo-Ap-ID",                  "integer" ],
                14  => [ "Aptilo-User-ID",                "integer" ],
                15  => [ "Aptilo-Zone",                   "string" ],
                16  => [ "Aptilo-First-Name",             "string" ],
                17  => [ "Aptilo-Last-Name",              "string" ],
                18  => [ "Aptilo-Phone",                  "string" ],
                19  => [ "Aptilo-Email",                  "string" ],
                20  => [ "Aptilo-Organization",           "string" ],
                21  => [ "Aptilo-Access-Profile",         "string" ],
                22  => [ "Aptilo-Realm-Concurrent-Login", "integer" ],
                23  => [ "Aptilo-Auth-Result",            "integer" ],
                24  => [ "Aptilo-Hotline-Indicator",      "string" ],
                25  => [ "Aptilo-User-Type",              "integer" ],
                26  => [ "Aptilo-Exclusive-Count",        "integer" ],
                27  => [ "Aptilo-Duration-Quota",         "integer" ],
                28  => [ "Aptilo-Volume-Quota",           "string" ],
                29  => [ "Aptilo-RX-Volume-Quota",        "string" ],
                30  => [ "Aptilo-TX-Volume-Quota",        "string" ],
                31  => [ "Aptilo-Resource-Quota",         "integer" ],
                32  => [ "Aptilo-Quota-ID",               "string" ],
                33  => [ "Aptilo-RX-Limit",               "integer" ],
                34  => [ "Aptilo-TX-Limit",               "integer" ],
                35  => [ "Aptilo-TRX-Limit",              "integer" ],
                36  => [ "Aptilo-Bw-Min-Up",              "integer" ],
                37  => [ "Aptilo-Bw-Max-Up",              "integer" ],
                38  => [ "Aptilo-Bw-Min-Down",            "integer" ],
                39  => [ "Aptilo-Bw-Max-Down",            "integer" ],
                40  => [ "Aptilo-Service-Profile",        "string" ],
                41  => [ "Aptilo-Automatic-Service",      "string" ],
                42  => [ "Aptilo-Auth-Type",              "integer" ],
                43  => [ "Aptilo-NAS-Capabilities",       "integer" ],
                44  => [ "Aptilo-Service",                "string" ],
                45  => [ "Aptilo-Service-Profile-ID",     "integer" ],
                50  => [ "Aptilo-Auth-Param",             "integer" ],
                53  => [ "Aptilo-Access-Profile-ID",      "integer" ],
                56  => [ "Aptilo-NAS-Model",              "string" ],
                57  => [ "Aptilo-Debug-Option",           "integer" ],
                58  => [ "Aptilo-Session-Id",             "string" ],
                59  => [ "Aptilo-Prepaid-Capabilities",   "octets" ],
                60  => [ "Aptilo-Octets-Quota",           "octets" ],
                61  => [ "Aptilo-Octets-Threshold",       "octets" ],
                62  => [ "Aptilo-Resource-Threshold",     "integer" ],
                63  => [ "Aptilo-Duration-Threshold",     "integer" ],
                64  => [ "Aptilo-Octets-Balance",         "octets" ],
                65  => [ "Aptilo-Resource-Balance",       "integer" ],
                66  => [ "Aptilo-Duration-Balance",       "integer" ],
                67  => [ "Aptilo-Octets-Used",            "octets" ],
                68  => [ "Aptilo-Resource-Used",          "integer" ],
                69  => [ "Aptilo-Duration-Used",          "integer" ],
                70  => [ "Aptilo-Octets-Request",         "octets" ],
                71  => [ "Aptilo-Resource-Request",       "integer" ],
                72  => [ "Aptilo-Duration-Request",       "integer" ],
                73  => [ "Aptilo-QoS-Indicator",          "string" ],
                74  => [ "Aptilo-Circuit-ID",             "octets" ],
                75  => [ "Aptilo-Remote-ID",              "octets" ],
                76  => [ "Aptilo-Location-Name",          "string" ],
                231 => [ "Aptilo-Key-IPv6-1",             "ipv6addr" ],
                232 => [ "Aptilo-Key-IPv6-2",             "ipv6addr" ],
                233 => [ "Aptilo-Key-IPv6-3",             "ipv6addr" ],
                234 => [ "Aptilo-Key-IPv6-4",             "ipv6addr" ],
                235 => [ "Aptilo-Key-IPv6-5",             "ipv6addr" ],
                236 => [ "Aptilo-Key-Octets-1",           "octets" ],
                237 => [ "Aptilo-Key-Octets-2",           "octets" ],
                238 => [ "Aptilo-Key-Octets-3",           "octets" ],
                239 => [ "Aptilo-Key-Octets-4",           "octets" ],
                240 => [ "Aptilo-Key-Octets-5",           "octets" ],
                241 => [ "Aptilo-Key-String-1",           "string" ],
                242 => [ "Aptilo-Key-String-2",           "string" ],
                243 => [ "Aptilo-Key-String-3",           "string" ],
                244 => [ "Aptilo-Key-String-4",           "string" ],
                245 => [ "Aptilo-Key-String-5",           "string" ],
                246 => [ "Aptilo-Key-IP-1",               "ipaddr" ],
                247 => [ "Aptilo-Key-IP-2",               "ipaddr" ],
                248 => [ "Aptilo-Key-IP-3",               "ipaddr" ],
                249 => [ "Aptilo-Key-IP-4",               "ipaddr" ],
                250 => [ "Aptilo-Key-IP-5",               "ipaddr" ],
                251 => [ "Aptilo-Key-Integer-1",          "integer" ],
                252 => [ "Aptilo-Key-Integer-2",          "integer" ],
                253 => [ "Aptilo-Key-Integer-3",          "integer" ],
                254 => [ "Aptilo-Key-Integer-4",          "integer" ],
                255 => [ "Aptilo-Key-Integer-5",          "integer" ],
            },
            13644 => {
                1 => [ "pfSense-Bandwidth-Max-Up",   "integer" ],
                2 => [ "pfSense-Bandwidth-Max-Down", "integer" ],
                3 => [ "pfSense-Max-Total-Octets",   "integer" ],
            },
            14122 => {
                1  => [ "WISPr-Location-ID",                  "string" ],
                2  => [ "WISPr-Location-Name",                "string" ],
                3  => [ "WISPr-Logoff-URL",                   "string" ],
                4  => [ "WISPr-Redirection-URL",              "string" ],
                5  => [ "WISPr-Bandwidth-Min-Up",             "integer" ],
                6  => [ "WISPr-Bandwidth-Min-Down",           "integer" ],
                7  => [ "WISPr-Bandwidth-Max-Up",             "integer" ],
                8  => [ "WISPr-Bandwidth-Max-Down",           "integer" ],
                9  => [ "WISPr-Session-Terminate-Time",       "string" ],
                10 => [ "WISPr-Session-Terminate-End-Of-Day", "string" ],
                11 => [ "WISPr-Billing-Class-Of-Service",     "string" ],
                12 => [ "WBA-Offered-Service",                "string" ],
                13 => [ "WBA-Financial-Clearing-Provider",    "string" ],
                14 => [ "WBA-Data-Clearing-Provider",         "string" ],
                15 => [ "WBA-Linear-Volume-Rate",             "octets" ],
                16 => [ "WBA-Identity-Provider",              "string" ],
                17 => [ "WBA-Custom-SLA",                     "string" ],
            },
            14179 => {
                1 => [ "Airespace-Wlan-Id",                         "integer" ],
                2 => [ "Airespace-QOS-Level",                       "integer" ],
                3 => [ "Airespace-DSCP",                            "integer" ],
                4 => [ "Airespace-8021p-Tag",                       "integer" ],
                5 => [ "Airespace-Interface-Name",                  "string" ],
                6 => [ "Airespace-ACL-Name",                        "string" ],
                7 => [ "Airespace-Data-Bandwidth-Average-Contract", "integer" ],
                8 => [
                    "Airespace-Real-Time-Bandwidth-Average-Contract", "integer"
                ],
                9  => [ "Airespace-Data-Bandwidth-Burst-Contract", "integer" ],
                10 =>
                  [ "Airespace-Real-Time-Bandwidth-Burst-Contract", "integer" ],
                11 => [ "Airespace-Guest-Role-Name", "string" ],
                13 => [
                    "Airespace-Data-Bandwidth-Average-Contract-Upstream",
                    "integer",
                ],
                14 => [
                    "Airespace-Real-Time-Bandwidth-Average-Contract-Upstream",
                    "integer",
                ],
                15 => [
                    "Airespace-Data-Bandwidth-Burst-Contract-Upstream",
                    "integer"
                ],
                16 => [
                    "Airespace-Real-Time-Bandwidth-Burst-Contract-Upstream",
                    "integer",
                ],
            },
            14436 => {
                1 => [ "Quiconnect-AVPair",          "string" ],
                2 => [ "Quiconnect-VNP-Information", "string" ],
                3 => [ "Quiconnect-HSP-Information", "string" ],
            },
            14501 => {
                1 => [ "Blue-Coat-Group",         "string" ],
                2 => [ "Blue-Coat-Authorization", "integer" ],
            },
            14525 => {
                1  => [ "Trapeze-VLAN-Name",           "string" ],
                2  => [ "Trapeze-Mobility-Profile",    "string" ],
                3  => [ "Trapeze-Encryption-Type",     "string" ],
                4  => [ "Trapeze-Time-Of-Day",         "string" ],
                5  => [ "Trapeze-SSID",                "string" ],
                6  => [ "Trapeze-End-Date",            "string" ],
                7  => [ "Trapeze-Start-Date",          "string" ],
                8  => [ "Trapeze-URL",                 "string" ],
                9  => [ "Trapeze-User-Group-Name",     "string" ],
                10 => [ "Trapeze-QoS-Profile",         "string" ],
                11 => [ "Trapeze-Simultaneous-Logins", "string" ],
                12 => [ "Trapeze-CoA-Username",        "string" ],
                13 => [ "Trapeze-Audit",               "string" ],
            },
            14529 => {
                1  => [ "Tropos-Unicast-Cipher",       "integer" ],
                2  => [ "Tropos-Layer2-Input-Octets",  "integer" ],
                3  => [ "Tropos-Layer2-Output-Octets", "integer" ],
                4  => [ "Tropos-Layer2-Input-Frames",  "integer" ],
                5  => [ "Tropos-Layer2-Output-Frames", "integer" ],
                6  => [ "Tropos-Layer2-Input-Drops",   "integer" ],
                7  => [ "Tropos-Noise-Floor",          "ifid" ],
                8  => [ "Tropos-Noise-Upper-Bound",    "ifid" ],
                9  => [ "Tropos-Release",              "string" ],
                11 => [ "Tropos-Secondary-IP",         "octets" ],
                12 => [ "Tropos-Terminate-Cause",      "integer" ],
                13 => [ "Tropos-Average-RSSI",         "integer" ],
                15 => [ "Tropos-Channel",              "ifid" ],
                16 => [ "Tropos-Retries-Sent",         "integer" ],
                17 => [ "Tropos-Retry-Bits",           "integer" ],
                18 => [ "Tropos-Rates-Sent",           "octets" ],
                19 => [ "Tropos-Rates-Received",       "octets" ],
                21 => [ "Tropos-Routed-Time",          "integer" ],
                22 => [ "Tropos-Routless-Since",       "integer" ],
                23 => [ "Tropos-Capability-Info",      "octets" ],
                24 => [ "Tropos-Input-Cap",            "integer" ],
                25 => [ "Tropos-Output-Cap",           "integer" ],
                26 => [ "Tropos-Class-Mult",           "integer" ],
                27 => [ "Tropos-Cell-Name",            "string" ],
                28 => [ "Tropos-Cell-Location",        "string" ],
                29 => [ "Tropos-Serial-Number",        "string" ],
                30 => [ "Tropos-Latitude",             "string" ],
                31 => [ "Tropos-Longitude",            "string" ],
            },
            14559 => {
                1   => [ "ChilliSpot-Max-Input-Octets",   "integer" ],
                2   => [ "ChilliSpot-Max-Output-Octets",  "integer" ],
                3   => [ "ChilliSpot-Max-Total-Octets",   "integer" ],
                4   => [ "ChilliSpot-Bandwidth-Max-Up",   "integer" ],
                5   => [ "ChilliSpot-Bandwidth-Max-Down", "integer" ],
                6   => [ "ChilliSpot-Config",             "string" ],
                7   => [ "ChilliSpot-Lang",               "string" ],
                8   => [ "ChilliSpot-Version",            "string" ],
                9   => [ "ChilliSpot-OriginalURL",        "string" ],
                100 => [ "ChilliSpot-UAM-Allowed",        "string" ],
                101 => [ "ChilliSpot-MAC-Allowed",        "string" ],
                102 => [ "ChilliSpot-Interval",           "integer" ],
            },
            14823 => {
                1  => [ "Aruba-User-Role",                    "string" ],
                2  => [ "Aruba-User-Vlan",                    "integer" ],
                3  => [ "Aruba-Priv-Admin-User",              "integer" ],
                4  => [ "Aruba-Admin-Role",                   "string" ],
                5  => [ "Aruba-Essid-Name",                   "string" ],
                6  => [ "Aruba-Location-Id",                  "string" ],
                7  => [ "Aruba-Port-Identifier",              "string" ],
                8  => [ "Aruba-MMS-User-Template",            "string" ],
                9  => [ "Aruba-Named-User-Vlan",              "string" ],
                10 => [ "Aruba-AP-Group",                     "string" ],
                11 => [ "Aruba-Framed-IPv6-Address",          "string" ],
                12 => [ "Aruba-Device-Type",                  "string" ],
                14 => [ "Aruba-No-DHCP-Fingerprint",          "integer" ],
                15 => [ "Aruba-Mdps-Device-Udid",             "string" ],
                16 => [ "Aruba-Mdps-Device-Imei",             "string" ],
                17 => [ "Aruba-Mdps-Device-Iccid",            "string" ],
                18 => [ "Aruba-Mdps-Max-Devices",             "integer" ],
                19 => [ "Aruba-Mdps-Device-Name",             "string" ],
                20 => [ "Aruba-Mdps-Device-Product",          "string" ],
                21 => [ "Aruba-Mdps-Device-Version",          "string" ],
                22 => [ "Aruba-Mdps-Device-Serial",           "string" ],
                23 => [ "Aruba-CPPM-Role",                    "string" ],
                24 => [ "Aruba-AirGroup-User-Name",           "string" ],
                25 => [ "Aruba-AirGroup-Shared-User",         "string" ],
                26 => [ "Aruba-AirGroup-Shared-Role",         "string" ],
                27 => [ "Aruba-AirGroup-Device-Type",         "integer" ],
                28 => [ "Aruba-Auth-Survivability",           "string" ],
                29 => [ "Aruba-AS-User-Name",                 "string" ],
                30 => [ "Aruba-AS-Credential-Hash",           "string" ],
                31 => [ "Aruba-WorkSpace-App-Name",           "string" ],
                32 => [ "Aruba-Mdps-Provisioning-Settings",   "string" ],
                33 => [ "Aruba-Mdps-Device-Profile",          "string" ],
                34 => [ "Aruba-AP-IP-Address",                "ipaddr" ],
                35 => [ "Aruba-AirGroup-Shared-Group",        "string" ],
                36 => [ "Aruba-User-Group",                   "string" ],
                37 => [ "Aruba-Network-SSO-Token",            "string" ],
                38 => [ "Aruba-AirGroup-Version",             "integer" ],
                39 => [ "Aruba-Auth-SurvMethod",              "integer" ],
                40 => [ "Aruba-Port-Bounce-Host",             "integer" ],
                41 => [ "Aruba-Calea-Server-Ip",              "ipaddr" ],
                42 => [ "Aruba-Admin-Path",                   "string" ],
                43 => [ "Aruba-Captive-Portal-URL",           "string" ],
                44 => [ "Aruba-MPSK-Passphrase",              "octets" ],
                45 => [ "Aruba-ACL-Server-Query-Info",        "string" ],
                46 => [ "Aruba-Command-String",               "string" ],
                47 => [ "Aruba-Network-Profile",              "string" ],
                48 => [ "Aruba-Admin-Device-Group",           "string" ],
                49 => [ "Aruba-PoE-Priority",                 "integer" ],
                50 => [ "Aruba-Port-Auth-Mode",               "integer" ],
                51 => [ "Aruba-NAS-Filter-Rule",              "string" ],
                52 => [ "Aruba-QoS-Trust-Mode",               "integer" ],
                53 => [ "Aruba-UBT-Gateway-Role",             "string" ],
                54 => [ "Aruba-Gateway-Zone",                 "string" ],
                55 => [ "Aruba-DPP-Bootstrapping-Key-SHA256", "string" ],
                56 =>
                  [ "Aruba-DPP-Bootstrapping-Net-Access-Key-SHA256", "string" ],
                57 => [ "Aruba-DPP-Bootstrapping-Key-B64", "string" ],
                58 => [ "Aruba-STP-Admin-Edge-Port",       "integer" ],
                59 => [ "Aruba-UBT-Gateway-CPPM-Role",     "string" ],
                60 => [ "Aruba-AP-MAC-Address",            "string" ],
                61 => [ "Aruba-Device-MAC-Address",        "string" ],
                62 => [ "Aruba-MPSK-Key-Name",             "string" ],
                63 => [ "Aruba-Device-Traffic-Class",      "integer" ],
                64 => [ "Aruba-PVLAN-Port-Type",           "integer" ],
                65 => [ "Aruba-Network-Test",              "integer" ],
                66 => [ "Aruba-MPSK-Lookup-Info",          "string" ],
                67 => [ "Aruba-AVPair",                    "string" ],
                68 => [ "Aruba-DPP-Service-Type",          "integer" ],
                69 => [ "Aruba-User-Mgmt-Interface",       "string" ],
                70 => [ "Aruba-Poe-Allocate-By-Method",    "integer" ],
                71 => [ "Aruba-DPP-AKMs",                  "string" ],
                72 => [ "Aruba-DPP-Passphrase",            "string" ],
            },
            14895 => {
                1 => [ "Propel-Accelerate",            "integer" ],
                2 => [ "Propel-Dialed-Digits",         "string" ],
                3 => [ "Propel-Client-IP-Address",     "ipaddr" ],
                4 => [ "Propel-Client-NAS-IP-Address", "ipaddr" ],
                5 => [ "Propel-Client-Source-ID",      "integer" ],
                6 => [ "Propel-Content-Filter-ID",     "integer" ],
            },
            14988 => {
                1  => [ "Mikrotik-Recv-Limit",             "integer" ],
                2  => [ "Mikrotik-Xmit-Limit",             "integer" ],
                3  => [ "Mikrotik-Group",                  "string" ],
                4  => [ "Mikrotik-Wireless-Forward",       "integer" ],
                5  => [ "Mikrotik-Wireless-Skip-Dot1x",    "integer" ],
                6  => [ "Mikrotik-Wireless-Enc-Algo",      "integer" ],
                7  => [ "Mikrotik-Wireless-Enc-Key",       "string" ],
                8  => [ "Mikrotik-Rate-Limit",             "string" ],
                9  => [ "Mikrotik-Realm",                  "string" ],
                10 => [ "Mikrotik-Host-IP",                "ipaddr" ],
                11 => [ "Mikrotik-Mark-Id",                "string" ],
                12 => [ "Mikrotik-Advertise-URL",          "string" ],
                13 => [ "Mikrotik-Advertise-Interval",     "integer" ],
                14 => [ "Mikrotik-Recv-Limit-Gigawords",   "integer" ],
                15 => [ "Mikrotik-Xmit-Limit-Gigawords",   "integer" ],
                16 => [ "Mikrotik-Wireless-PSK",           "string" ],
                17 => [ "Mikrotik-Total-Limit",            "integer" ],
                18 => [ "Mikrotik-Total-Limit-Gigawords",  "integer" ],
                19 => [ "Mikrotik-Address-List",           "string" ],
                20 => [ "Mikrotik-Wireless-MPKey",         "string" ],
                21 => [ "Mikrotik-Wireless-Comment",       "string" ],
                22 => [ "Mikrotik-Delegated-IPv6-Pool",    "string" ],
                23 => [ "Mikrotik-DHCP-Option-Set",        "string" ],
                24 => [ "Mikrotik-DHCP-Option-Param-STR1", "string" ],
                25 => [ "Mikrotik-DHCP-Option-ParamSTR2",  "string" ],
                26 => [ "Mikrotik-Wireless-VLANID",        "integer" ],
                27 => [ "Mikrotik-Wireless-VLANID-Type",   "integer" ],
                28 => [ "Mikrotik-Wireless-Minsignal",     "string" ],
                29 => [ "Mikrotik-Wireless-Maxsignal",     "string" ],
                30 => [ "Mikrotik-Switching-Filter",       "string" ],
            },
            15004 => { 2 => [ "RuggedCom-Privilege-level", "string" ] },
            15983 => {
                1 => [ "Meru-Access-Point-Id",   "integer" ],
                2 => [ "Meru-Access-Point-Name", "string" ],
            },
            16108 => {
                1 => [ "Garderos-Location-Name", "string" ],
                2 => [ "Garderos-Service-Name",  "string" ],
                3 => [ "Garderos-MSISDN",        "string" ],
                4 => [ "Garderos-Proxy",         "string" ],
            },
            16313 => {
                1  => [ "VNC-PPPoE-CBQ-RX",          "integer" ],
                2  => [ "VNC-PPPoE-CBQ-TX",          "integer" ],
                3  => [ "VNC-PPPoE-CBQ-RX-Fallback", "integer" ],
                4  => [ "VNC-PPPoE-CBQ-TX-Fallback", "integer" ],
                10 => [ "VNC-Splash",                "integer" ],
            },
            16445 => {
                2  => [ "Kineto-UMA-Release-Indicator",            "octets" ],
                3  => [ "Kineto-UMA-AP-Radio-Identity",            "octets" ],
                4  => [ "Kineto-UMA-Cell-Identity",                "octets" ],
                5  => [ "Kineto-UMA-Location-Area-Identification", "octets" ],
                6  => [ "Kineto-UMA-Coverage-Indicator",           "octets" ],
                7  => [ "Kineto-UMA-Classmark",                    "octets" ],
                8  => [ "Kineto-UMA-Geographical-Location",        "octets" ],
                9  => [ "Kineto-UMA-SGW-IP-Address",               "octets" ],
                10 => [ "Kineto-UMA-SGW-FQDN",                     "octets" ],
                11 => [ "Kineto-UMA-Redirection-Counter",          "octets" ],
                12 => [ "Kineto-UMA-Discovery-Reject-Cause",       "octets" ],
                17 => [ "Kineto-UMA-RRC-State",                    "octets" ],
                21 => [ "Kineto-UMA-Register-Reject-Cause",        "octets" ],
                41 => [ "Kineto-UMA-Routing-Area-Code",            "octets" ],
                42 => [ "Kineto-UMA-AP-Location",                  "octets" ],
                44 => [ "Kineto-UMA-Location-Status",              "octets" ],
                49 => [ "Kineto-UMA-Utran-Cell-Identity",          "octets" ],
                58 => [ "Kineto-UMA-Location-Blacklist-Indicator", "octets" ],
                61 => [ "Kineto-UMA-AP-Service-Name",              "octets" ],
                62 => [ "Kineto-UMA-Service-Zone-Information",     "octets" ],
                67 => [ "Kineto-UMA-Serving-UNC-Table-Indicator",  "octets" ],
                68 => [ "Kineto-UMA-Registration-Indicators",      "octets" ],
                69 => [ "Kineto-UMA-UMA-PLMN-List",                "octets" ],
                71 => [ "Kineto-UMA-Required-UMA-Services",        "octets" ],
                73 => [ "Kineto-UMA-3G-Cell-Identity",             "octets" ],
                96 => [ "Kineto-UMA-MS-Radio-Identity",            "octets" ],
                97 => [ "Kineto-UMA-UNC-IP-Address",               "octets" ],
                98 => [ "Kineto-UMA-UNC-FQDN",                     "octets" ],
                65281 => [ "Kineto-URR-Transaction-Type",        "octets" ],
                65282 => [ "Kineto-Location-Key",                "octets" ],
                65283 => [ "Kineto-UP-Client-Remote-Address",    "octets" ],
                65284 => [ "Kineto-Hand-In-Control-Flag",        "octets" ],
                65285 => [ "Kineto-Hand-Out-Control-Flag",       "octets" ],
                65286 => [ "Kineto-Billing-Rate-Indicator",      "octets" ],
                65289 => [ "Kineto-Service-Area-Code",           "octets" ],
                65408 => [ "KW-IUH-MESSAGE-TYPE",                "string" ],
                65409 => [ "KW-HNB-REMOTE-ADDRESS",              "ipaddr" ],
                65410 => [ "KW-HNB-IDENTITY",                    "string" ],
                65411 => [ "KW-HNB-LOC-INFO-MACRO-COVERAGE-IND", "integer" ],
                65412 => [ "KW-HNB-LOC-INFO-GERAN-CELL-ID",      "string" ],
                65413 => [ "KW-HNB-LOC-INFO-UTRAN-CELL-ID",      "string" ],
                65414 => [ "KW-HNB-LOC-INFO-GEO-COORDINATES",    "integer" ],
                65415 => [ "KW-HNB-LOC-INFO-ALTITUDE-Direction", "integer" ],
                65416 => [ "KW-HNB-LOC-INFO-IP-ADDRESS",         "string" ],
                65417 => [ "KW-HNB-PLMN-ID",                     "string" ],
                65418 => [ "KW-HNB-CELL-ID",                     "string" ],
                65419 => [ "KW-HNB-LAC",                         "string" ],
                65420 => [ "KW-HNB-RAC",                         "string" ],
                65421 => [ "KW-HNB-SAC",                         "string" ],
                65422 => [ "KW-HNB-CSG-ID",                      "string" ],
                65423 => [ "KW-UE-Capabilities",                 "integer" ],
                65424 => [ "KW-HNB-LOCATION-AREA-IND",           "octets" ],
                65425 => [ "KW-IUH-BILLING-RATE-INDICATOR",      "octets" ],
                65426 => [ "KW-REGISTRATION-REJECT-CAUSE",       "octets" ],
                65427 => [ "KW-HNB-LOCATION-BLACKLIST-IND",      "octets" ],
                65428 => [ "KW-HNB-CELL-ACCESS-MODE",            "octets" ],
                65429 => [ "KW-UE-MEMBERSHIP-STATUS",            "octets" ],
            },
            16459 => {
                1   => [ "Epygi-AVPair",                   "string" ],
                2   => [ "Epygi-NAS-Port",                 "string" ],
                23  => [ "Epygi-h323-remote-address",      "string" ],
                24  => [ "Epygi-h323-conf-id",             "string" ],
                25  => [ "Epygi-h323-setup-time",          "string" ],
                26  => [ "Epygi-h323-call-origin",         "string" ],
                27  => [ "Epygi-h323-call-type",           "string" ],
                28  => [ "Epygi-h323-connect-time",        "string" ],
                29  => [ "Epygi-h323-disconnect-time",     "string" ],
                30  => [ "Epygi-h323-disconnect-cause",    "string" ],
                31  => [ "Epygi-h323-voice-quality",       "string" ],
                33  => [ "Epygi-h323-gw-id",               "string" ],
                35  => [ "Epygi-h323-incoming-conf-id",    "string" ],
                101 => [ "Epygi-h323-credit-amount",       "string" ],
                102 => [ "Epygi-h323-credit-time",         "string" ],
                103 => [ "Epygi-h323-return-code",         "string" ],
                104 => [ "Epygi-h323-prompt-id",           "string" ],
                105 => [ "Epygi-h323-time-and-day",        "string" ],
                106 => [ "Epygi-h323-redirect-number",     "string" ],
                107 => [ "Epygi-h323-preferred-lang",      "string" ],
                108 => [ "Epygi-h323-redirect-ip-address", "string" ],
                109 => [ "Epygi-h323-billing-model",       "string" ],
                110 => [ "Epygi-h323-currency",            "string" ],
                150 => [ "Epygi-RegExpDate",               "string" ],
                151 => [ "Epygi-FiadID",                   "string" ],
                152 => [ "Epygi-PortID",                   "string" ],
                153 => [ "Epygi-AccessType",               "string" ],
                154 => [ "Epygi-CallInfo",                 "string" ],
                170 => [ "Epygi-OrigCallID",               "string" ],
                171 => [ "Epygi-ParentCallID",             "string" ],
                172 => [ "Epygi-CallType",                 "integer" ],
                173 => [ "Epygi-DeviceName",               "string" ],
                174 => [ "Epygi-InterfaceName",            "integer" ],
                175 => [ "Epygi-InterfaceNumber",          "integer" ],
                176 => [ "Epygi-TimeslotNumber",           "integer" ],
                177 => [ "Epygi-OrigIpAddr",               "integer" ],
                178 => [ "Epygi-DestIpAddr",               "integer" ],
                179 => [ "Epygi-OrigIpPort",               "integer" ],
                180 => [ "Epygi-DestIpPort",               "integer" ],
                181 => [ "Epygi-CallingPartyNumber",       "string" ],
                182 => [ "Epygi-CalledPartyNumber",        "string" ],
                183 => [ "Epygi-DateTimeOrigination",      "integer" ],
                184 => [ "Epygi-DateTimeConnect",          "integer" ],
                185 => [ "Epygi-DateTimeDisconnect",       "integer" ],
                186 => [ "Epygi-Duration",                 "integer" ],
                187 => [ "Epygi-OutSourceRTP_IP",          "integer" ],
                188 => [ "Epygi-OutDestRTP_IP",            "integer" ],
                189 => [ "Epygi-InSourceRTP_IP",           "integer" ],
                190 => [ "Epygi-InDestRTP_IP",             "integer" ],
                191 => [ "Epygi-OutSourceRTP_port",        "integer" ],
                192 => [ "Epygi-OutDestRTP_port",          "integer" ],
                193 => [ "Epygi-InSourceRTP_port",         "integer" ],
                194 => [ "Epygi-InDestRTP_port",           "integer" ],
                195 => [ "Epygi-CallRedirectReason",       "integer" ],
                196 => [ "Epygi-CallDisconnectReason",     "integer" ],
                197 => [ "Epygi-OutRTP_Payload",           "integer" ],
                198 => [ "Epygi-OutRTP_PacketSize",        "integer" ],
                199 => [ "Epygi-OutRTP_Packets",           "integer" ],
                200 => [ "Epygi-OutRTP_Octets",            "integer" ],
                201 => [ "Epygi-InRTP_Payload",            "integer" ],
                202 => [ "Epygi-InRTP_PacketSize",         "integer" ],
                203 => [ "Epygi-InRTP_Packets",            "integer" ],
                204 => [ "Epygi-InRTP_Octets",             "integer" ],
                205 => [ "Epygi-InRTP_PacketsLost",        "integer" ],
                206 => [ "Epygi-InRTP_PacketsDupl",        "integer" ],
                207 => [ "Epygi-InRTP_Jitter",             "integer" ],
                208 => [ "Epygi-InRTP_Latency",            "integer" ],
            },
            16787 => {
                1  => [ "T-Systems-Nova-Location-ID",              "string" ],
                2  => [ "T-Systems-Nova-Location-Name",            "string" ],
                3  => [ "T-Systems-Nova-Logoff-URL",               "string" ],
                4  => [ "T-Systems-Nova-Redirection-URL",          "string" ],
                5  => [ "T-Systems-Nova-Bandwidth-Min-Up",         "integer" ],
                6  => [ "T-Systems-Nova-Bandwidth-Min-Down",       "integer" ],
                7  => [ "T-Systems-Nova-Bandwidth-Max-Up",         "integer" ],
                8  => [ "T-Systems-Nova-Bandwidth-Max-Down",       "integer" ],
                9  => [ "T-Systems-Nova-Session-Terminate-Time",   "integer" ],
                10 => [ "T-Systems-Nova-Session-Terminate-EoD",    "integer" ],
                11 => [ "T-Systems-Nova-Billing-Class-Of-Service", "string" ],
                12 => [ "T-Systems-Nova-Service-Name",             "string" ],
                13 => [ "T-Systems-Nova-Price-Of-Service",         "integer" ],
                14 => [ "T-Systems-Nova-Visiting-Provider-Code",   "string" ],
                15 => [ "T-Systems-Nova-UnknownAVP",               "string" ],
            },
            16924 => {
                1 => [ "Sky-Wifi-AP-ID",                "integer" ],
                2 => [ "Sky-Wifi-Service-ID",           "integer" ],
                3 => [ "Sky-Wifi-Filter-Profile",       "string" ],
                4 => [ "Sky-Wifi-Billing-Class",        "octets" ],
                5 => [ "Sky-Wifi-Provider-ID",          "integer" ],
                6 => [ "Sky-Wifi-Credentials",          "string" ],
                7 => [ "Sky-Wifi-Replicated-Packet",    "string" ],
                8 => [ "Sky-Wifi-Protocol-Restriction", "integer" ],
            },
            17163 => { 1 => [ "Riverbed-Local-User", "string" ] },
            17713 => {
                1  => [ "Cambium-Auth-Role",                        "integer" ],
                21 => [ "Cambium-ePMP-Data-VLAN-Id",                "integer" ],
                22 => [ "Cambium-ePMP-Management-VLAN-Id",          "integer" ],
                26 => [ "Cambium-ePMP-Max-Burst-Uplink-Rate",       "integer" ],
                27 => [ "Cambium-ePMP-Max-Burst-Downlink-Rate",     "integer" ],
                50 => [ "Cambium-ePMP-UserLevel",                   "integer" ],
                51 => [ "Cambium-ePMP-SM-Priority",                 "integer" ],
                52 => [ "Cambium-ePMP-VLAN-Membersip-Set",          "integer" ],
                53 => [ "Cambium-ePMP-Management-VLAN-Priority",    "integer" ],
                54 => [ "Cambium-ePMP-Data-VLAN-Priority",          "integer" ],
                55 => [ "Cambium-ePMP-Separate-Management-VLAN-Id", "integer" ],
                56 => [
                    "Cambium-ePMP-Separate-Management-VLAN-Priority", "integer"
                ],
                57  => [ "Cambium-ePMP-Multicast-VLAN-Id",          "integer" ],
                58  => [ "Cambium-ePMP-VLAN-Mapping",               "integer" ],
                151 => [ "Cambium-Traffic-Quota-Limit-Up",          "integer" ],
                152 => [ "Cambium-Traffic-Quota-Limit-Down",        "integer" ],
                153 => [ "Cambium-Traffic-Quota-Limit-Up-Gigwords", "integer" ],
                154 =>
                  [ "Cambium-Traffic-Quota-Limit-Down-Gigwords", "integer" ],
                155 => [ "Cambium-Traffic-Quota-Limit-Total", "integer" ],
                156 =>
                  [ "Cambium-Traffic-Quota-Limit-Total-Gigwords", "integer" ],
                157 => [ "Cambium-VLAN-Pool-Id",         "string" ],
                158 => [ "Cambium-Authorize-Bytes-Left", "integer64" ],
                159 => [ "Cambium-Acct-Output-Packets",  "integer" ],
                160 => [ "Cambium-Walled-Garden-State",  "integer" ],
            },
            18022 => {
                1 => [ "Covaro-User-Privilege",  "integer" ],
                2 => [ "Covaro-Max-Sessions",    "integer" ],
                3 => [ "Covaro-Session-Timeout", "integer" ],
                4 => [ "Covaro-Inhibit-Message", "integer" ],
                5 => [ "Covaro-Inhibit-Dbchg",   "integer" ],
                6 => [ "Covaro-Inhibit-Pmrept",  "integer" ],
            },
            18681 => {
                1  => [ "TP-Gateway-Version",                "string" ],
                2  => [ "TP-Firmware-Variant",               "string" ],
                3  => [ "TP-Firmware-Version",               "string" ],
                4  => [ "TP-Gateway-Config",                 "string" ],
                5  => [ "TP-ENC-IV",                         "string" ],
                6  => [ "TP-Password",                       "string" ],
                7  => [ "TP-User-Agent",                     "string" ],
                8  => [ "TP-Auth-Reply",                     "integer" ],
                9  => [ "TP-Access-Class-Id",                "string" ],
                10 => [ "TP-Host-Name",                      "string" ],
                11 => [ "TP-DHCP-Request-Option-List",       "string" ],
                12 => [ "TP-DHCP-Parameter-Request-List",    "string" ],
                13 => [ "TP-DHCP-Vendor-Class-Id",           "string" ],
                14 => [ "TP-DHCP-Client-Id",                 "string" ],
                15 => [ "TP-Location-Id",                    "string" ],
                16 => [ "TP-NAT-IP-Address",                 "ipaddr" ],
                17 => [ "TP-Zone-Id",                        "string" ],
                18 => [ "TP-Monitor-Id",                     "string" ],
                19 => [ "TP-Related-Session-Id",             "string" ],
                20 => [ "TP-Monitor-Session-Id",             "integer" ],
                21 => [ "TP-Max-Input-Octets",               "integer64" ],
                22 => [ "TP-Max-Output-Octets",              "integer64" ],
                23 => [ "TP-Max-Total-Octets",               "integer64" ],
                24 => [ "TP-Exit-Access-Class-Id",           "string" ],
                25 => [ "TP-Access-Rule",                    "string" ],
                26 => [ "TP-Access-Group",                   "string" ],
                27 => [ "TP-NAT-Pool-Id",                    "string" ],
                28 => [ "TP-NAT-Port-Start",                 "integer" ],
                29 => [ "TP-NAT-Port-End",                   "integer" ],
                30 => [ "TP-Keep-Alive-Timeout",             "integer" ],
                31 => [ "TP-TLS-Auth-Type",                  "integer" ],
                32 => [ "TP-TLS-Pre-Shared-Key",             "string" ],
                33 => [ "TP-CAPWAP-Timestamp",               "integer" ],
                34 => [ "TP-CAPWAP-WTP-Version",             "string" ],
                35 => [ "TP-CAPWAP-Session-Id",              "octets" ],
                36 => [ "TP-CAPWAP-Radio-Id",                "integer" ],
                37 => [ "TP-CAPWAP-WWAN-Id",                 "integer" ],
                38 => [ "TP-CAPWAP-WWAN-RAT",                "integer" ],
                39 => [ "TP-CAPWAP-WWAN-RSSi",               "integer" ],
                40 => [ "TP-CAPWAP-WWAN-CREG",               "integer" ],
                41 => [ "TP-CAPWAP-WWAN-LAC",                "integer" ],
                42 => [ "TP-CAPWAP-WWAN-Latency",            "integer" ],
                43 => [ "TP-CAPWAP-WWAN-MCC",                "integer" ],
                44 => [ "TP-CAPWAP-WWAN-MNC",                "integer" ],
                45 => [ "TP-CAPWAP-WWAN-Cell-Id",            "integer" ],
                46 => [ "TP-CAPWAP-POWER-SAVE-IDLE-TIMEOUT", "integer" ],
                47 => [ "TP-CAPWAP-POWER-SAVE-BUSY-TIMEOUT", "integer" ],
                48 => [ "TP-CAPWAP-SSID",                    "string" ],
                49 => [ "TP-CAPWAP-Max-WIFI-Clients",        "integer" ],
                50 => [ "TP-CAPWAP-Walled-Garden",           "string" ],
                51 => [ "TP-CAPWAP-GPS-Latitude",            "string" ],
                52 => [ "TP-CAPWAP-GPS-Longitude",           "string" ],
                53 => [ "TP-CAPWAP-GPS-Altitude",            "string" ],
                54 => [ "TP-CAPWAP-GPS-Hdop",                "string" ],
                55 => [ "TP-CAPWAP-GPS-Timestamp",           "string" ],
                56 => [ "TP-CAPWAP-Hardware-Version",        "string" ],
                57 => [ "TP-CAPWAP-Software-Version",        "string" ],
                58 => [ "TP-CAPWAP-Boot-Version",            "string" ],
                59 => [ "TP-CAPWAP-Other-Software-Version",  "string" ],
            },
            19220 => {
                192 => [ "Local-Web-Client-Ip",                 "string" ],
                193 => [ "Local-Web-Border-Router",             "string" ],
                200 => [ "Local-Web-Tx-Limit",                  "integer" ],
                201 => [ "Local-Web-Rx-Limit",                  "integer" ],
                210 => [ "Local-Web-Acct-Time",                 "integer" ],
                211 => [ "Local-Web-Acct-Duration",             "integer" ],
                212 => [ "Local-Web-Acct-Interim-Tx-Bytes",     "integer" ],
                213 => [ "Local-Web-Acct-Interim-Rx-Bytes",     "integer" ],
                214 => [ "Local-Web-Acct-Interim-Tx-Gigawords", "integer" ],
                215 => [ "Local-Web-Acct-Interim-Rx-Gigawords", "integer" ],
                216 => [ "Local-Web-Acct-Interim-Tx-Mgmt",      "integer" ],
                217 => [ "Local-Web-Acct-Interim-Rx-Mgmt",      "integer" ],
                230 => [ "Local-Web-Acct-Tx-Mgmt",              "integer" ],
                231 => [ "Local-Web-Acct-Rx-Mgmt",              "integer" ],
                240 => [ "Local-Web-Reauth-Counter",            "integer" ],
            },
            19382 => {
                1  => [ "Manzara-User-UID",          "integer" ],
                2  => [ "Manzara-User-GID",          "integer" ],
                3  => [ "Manzara-User-Home",         "string" ],
                4  => [ "Manzara-User-Shell",        "string" ],
                5  => [ "Manzara-PPP-Addr-String",   "string" ],
                6  => [ "Manzara-Full-Login-String", "string" ],
                7  => [ "Manzara-Tariff-Units",      "integer" ],
                8  => [ "Manzara-Tariff-Type",       "integer" ],
                9  => [ "Manzara-ECP-Session-Key",   "octets" ],
                10 => [ "Manzara-Map-Name",          "string" ],
                11 => [ "Manzara-Map-Key",           "string" ],
                12 => [ "Manzara-Map-Value",         "string" ],
                13 => [ "Manzara-Map-Error",         "string" ],
                14 => [ "Manzara-Service-Type",      "string" ],
            },
            21074 => {
                1 => [ "Purewave-Client-Profile",    "integer" ],
                2 => [ "Purewave-CS-Type",           "integer" ],
                3 => [ "Purewave-Max-Downlink-Rate", "integer" ],
                4 => [ "Purewave-Max-Uplink-Rate",   "integer" ],
                5 => [ "Purewave-IP-Address",        "ipaddr" ],
                6 => [ "Purewave-IP-Netmask",        "ipaddr" ],
                7 => [ "Purewave-Service-Enable",    "integer" ],
            },
            21274 => {
                1 => [ "Camiant-MI-role",  "string" ],
                2 => [ "Camiant-SUI-role", "integer" ],
                3 => [ "Camiant-MI-scope", "string" ],
            },
            22197 => {
                1   => [ "SoftBank-BB-Unit-MAC",               "string" ],
                2   => [ "SoftBank-BB-Unit-Manufacturer",      "string" ],
                3   => [ "SoftBank-BB-Unit-Model",             "string" ],
                4   => [ "SoftBank-BB-Unit-HW-Revision",       "string" ],
                185 => [ "SoftBank-TFTP-Config-Server",        "ipaddr" ],
                186 => [ "SoftBank-TFTP-Config-File",          "string" ],
                198 => [ "SoftBank-DNS-IPv6-Primary",          "ipv6addr" ],
                199 => [ "SoftBank-DNS-IPv6-Secondary",        "ipv6addr" ],
                201 => [ "SoftBank-Syslog-Server",             "ipv6addr" ],
                203 => [ "SoftBank-SNTP-Server",               "ipv6addr" ],
                204 => [ "SoftBank-IPv4-Tunnel-Local-Address", "ipaddr" ],
                207 => [ "SoftBank-IPv4-Tunnel-Endpoint",      "ipv6addr" ],
                215 => [ "SoftBank-RouteInfo-Server",          "string" ],
            },
            22472 => {
                7  => [ "BW-Venue-Id",          "string" ],
                8  => [ "BW-Venue-TZ",          "string" ],
                9  => [ "BW-Service-Type",      "string" ],
                10 => [ "BW-Class",             "string" ],
                11 => [ "BW-Venue-Description", "string" ],
                12 => [ "BW-Venue-Price-Type",  "string" ],
                13 => [ "BW-Venue-Port-Type",   "string" ],
                14 => [ "BW-ISO-Country-Code",  "string" ],
                15 => [ "BW-e164-Country-Code", "string" ],
                16 => [ "BW-State-Name",        "string" ],
                17 => [ "BW-City-Name",         "string" ],
                18 => [ "BW-Area-Code",         "integer" ],
                19 => [ "CL-Brand",             "string" ],
                20 => [ "CL-Software-Version",  "string" ],
                21 => [ "CL-Reg-Number",        "string" ],
                22 => [ "CL-Method-Version",    "string" ],
                23 => [ "CL-Token-Version",     "string" ],
                24 => [ "CL-APDB-Version",      "string" ],
                25 => [ "CL-User-Agent",        "string" ],
                26 => [ "CL-SSC",               "string" ],
                27 => [ "BW-User-Group",        "string" ],
                29 => [ "BW-Venue-Name",        "string" ],
                30 => [ "BW-Category",          "string" ],
                32 => [ "BW-User-Role",         "string" ],
                33 => [ "BW-User-Name",         "string" ],
                34 => [ "BW-User-Password",     "string" ],
                35 => [ "BW-User-Prefix",       "string" ],
                36 => [ "BW-User-Realm",        "string" ],
                37 => [ "BW-Operator-Name",     "string" ],
            },
            22736 => {
                101 => [ "Asterisk-Acc-Code",    "string" ],
                102 => [ "Asterisk-Src",         "string" ],
                103 => [ "Asterisk-Dst",         "string" ],
                104 => [ "Asterisk-Dst-Ctx",     "string" ],
                105 => [ "Asterisk-Clid",        "string" ],
                106 => [ "Asterisk-Chan",        "string" ],
                107 => [ "Asterisk-Dst-Chan",    "string" ],
                108 => [ "Asterisk-Last-App",    "string" ],
                109 => [ "Asterisk-Last-Data",   "string" ],
                110 => [ "Asterisk-Start-Time",  "string" ],
                111 => [ "Asterisk-Answer-Time", "string" ],
                112 => [ "Asterisk-End-Time",    "string" ],
                113 => [ "Asterisk-Duration",    "integer" ],
                114 => [ "Asterisk-Bill-Sec",    "integer" ],
                115 => [ "Asterisk-Disposition", "string" ],
                116 => [ "Asterisk-AMA-Flags",   "string" ],
                117 => [ "Asterisk-Unique-ID",   "string" ],
                118 => [ "Asterisk-User-Field",  "string" ],
            },
            23782 => {
                1   => [ "ASN-IP-Pool-Name",          "string" ],
                100 => [ "ASN-Kbps-Down",             "integer" ],
                101 => [ "ASN-Kbps-Up",               "integer" ],
                102 => [ "ASN-Pps-Down",              "integer" ],
                103 => [ "ASN-Pps-Up",                "integer" ],
                104 => [ "ASN-TCP-Connlimit",         "integer" ],
                105 => [ "ASN-Firewall-State",        "integer" ],
                106 => [ "ASN-Firewall-Open",         "string" ],
                107 => [ "ASN-Firewall-Block-Ping",   "integer" ],
                108 => [ "ASN-QoS-State",             "integer" ],
                109 => [ "ASN-IP-Redirect",           "string" ],
                110 => [ "ASN-Firewall-Available",    "integer" ],
                111 => [ "ASN-QoS-Available",         "integer" ],
                112 => [ "ASN-Kbps-Down-Localmedia",  "integer" ],
                113 => [ "ASN-Webfilter-Mode",        "integer" ],
                114 => [ "ASN-Webfilter-Redirect",    "string" ],
                115 => [ "ASN-Webfilter-Destination", "string" ],
                116 => [ "ASN-Webfilter-Domain",      "string" ],
            },
            24023 => {
                1  => [ "AM-Interrupt-HTMLFile",      "string" ],
                2  => [ "AM-Interrupt-Interval",      "integer" ],
                3  => [ "AM-Interrupt-Timeout",       "integer" ],
                4  => [ "AM-Status-HTMLFile",         "string" ],
                5  => [ "AM-HTTP-Proxy-Port",         "integer" ],
                6  => [ "AM-ACK-HTMLFile",            "string" ],
                7  => [ "AM-NAK-HTMLFile",            "string" ],
                8  => [ "AM-Bandwidth-Pool",          "string" ],
                9  => [ "AM-Bandwidth-Pool-Max-Up",   "integer" ],
                10 => [ "AM-Bandwidth-Pool-Max-Down", "integer" ],
                11 => [ "AM-Mirroring",               "integer" ],
                12 => [ "AM-Disconnect-Access",       "integer" ],
            },
            24757 => {
                1  => [ "WiMAX-Authorized-Ethernet-Services",    "byte" ],
                2  => [ "WiMAX-Device-Authentication-Indicator", "byte" ],
                3  => [ "WiMAX-GMT-Timezone-offset",             "signed" ],
                4  => [ "WiMAX-AAA-Session-Id",                  "octets" ],
                5  => [ "WiMAX-MSK",                             "octets" ],
                6  => [ "WiMAX-hHA-IP-MIP4",                     "ipaddr" ],
                7  => [ "WiMAX-hHA-IP-MIP6",                     "ipv6addr" ],
                10 => [ "WiMAX-MN-hHA-MIP4-Key",                 "octets" ],
                11 => [ "WiMAX-MN-hHA-MIP4-SPI",                 "integer" ],
                12 => [ "WiMAX-MN-hHA-MIP6-Key",                 "octets" ],
                13 => [ "WiMAX-MN-hHA-MIP6-SPI",                 "integer" ],
                14 => [ "WiMAX-FA-RK-Key",                       "octets" ],
                15 => [ "WiMAX-HA-RK-Key",                       "octets" ],
                16 => [ "WiMAX-HA-RK-SPI",                       "integer" ],
                17 => [ "WiMAX-HA-RK-Lifetime",                  "integer" ],
                19 => [ "WiMAX-RRQ-MN-HA-Key",                   "octets" ],
                20 => [ "WiMAX-RRQ-MN-HA-SPI",                   "integer" ],
                21 => [ "WiMAX-Session-Continue",                "integer" ],
                22 => [ "WiMAX-Beginning-Of-Session",            "integer" ],
                23 => [ "WiMAX-IP-Technology",                   "integer" ],
                24 => [ "WiMAX-Hotline-Indicator",               "string" ],
                25 => [ "WiMAX-Prepaid-Indicator",               "byte" ],
                26 => [ "WiMAX-PDFID",                           "short" ],
                27 => [ "WiMAX-SDFID",                           "short" ],
                28 => [ "WiMAX-802.1p",                          "octets" ],
                29 => [ "WiMAX-DHCP-Option-Container",           "string" ],
                30 => [ "WiMAX-Uplink-Granted-QoS",              "string" ],
                31 => [ "WiMAX-Control-Packets-In",              "integer" ],
                32 => [ "WiMAX-Control-Octets-In",               "integer" ],
                33 => [ "WiMAX-Control-Packets-Out",             "integer" ],
                34 => [ "WiMAX-Control-Octets-Out",              "integer" ],
                35 => [ "WiMAX-Available-In-Client",             "integer" ],
                36 => [ "WiMAX-Session-Termination-Capability",  "integer" ],
                37 => [ "WiMAX-Cost-Information-AVP",            "octets" ],
                38 => [ "WiMAX-Time-Interval-After",             "integer" ],
                39 => [ "WiMAX-Active-Time-Duration",            "integer" ],
                40 => [ "WiMAX-DHCP-RK",                         "octets" ],
                41 => [ "WiMAX-DHCP-RK-Key-Id",                  "integer" ],
                42 => [ "WiMAX-DHCP-RK-Lifetime",                "integer" ],
                43 => [ "WiMAX-DHCP-Msg-Server-IP",              "ipaddr" ],
                44 => [ "WiMAX-Idle-Mode-Transition",            "byte" ],
                45 => [ "WiMAX-NAP-Id",                          "octets" ],
                46 => [ "WiMAX-BS-Id",                           "octets" ],
                47 => [ "WiMAX-Location",                        "octets" ],
                48 => [ "WiMAX-Acct-Input-Packets-Gigaword",     "integer" ],
                49 => [ "WiMAX-Acct-Output-Packets-Gigaword",    "integer" ],
                50 => [ "WiMAX-Uplink-Flow-Description",         "string" ],
                51 => [ "WiMAX-Blu-Coa-IPv6",                    "ipv6addr" ],
                53 => [ "WiMAX-Hotline-Profile-Id",              "string" ],
                54 => [ "WiMAX-HTTP-Redirection-Rule",           "string" ],
                55 => [ "WiMAX-IP-Redirection-Rule",             "string" ],
                56 => [ "WiMAX-Hotline-Session-Timer",           "integer" ],
                57 => [ "WiMAX-NSP-Id",                          "octets" ],
                58 => [ "WiMAX-HA-RK-Key-Requested",             "integer" ],
                59 => [ "WiMAX-Count-Type",                      "byte" ],
                60 => [ "WiMAX-DM-Action-Code",                  "integer" ],
                61 => [ "WiMAX-FA-RK-SPI",                       "integer" ],
                62 => [ "WiMAX-Downlink-Flow-Description",       "string" ],
                63 => [ "WiMAX-Downlink-Granted-QoS",            "tlv" ],
                64 => [ "WiMAX-vHA-IP-MIP4",                     "ipaddr" ],
                65 => [ "WiMAX-vHA-IP-MIP6",                     "ipv6addr" ],
                66 => [ "WiMAX-vHA-MIP4-Key",                    "octets" ],
                67 => [ "WiMAX-vHA-RK-Key",                      "octets" ],
                68 => [ "WiMAX-vHA-RK-SPI",                      "integer" ],
                69 => [ "WiMAX-vHA-RK-Lifetime",                 "integer" ],
                70 => [ "WiMAX-MN-vHA-MIP6-Key",                 "octets" ],
                71 => [ "WiMAX-MN-vHA-MIP4-SPI",                 "integer" ],
                72 => [ "WiMAX-MN-vHA-MIP6-SPI",                 "integer" ],
                73 => [ "WiMAX-vDHCPv4-Server",                  "ipaddr" ],
                74 => [ "WiMAX-vDHCPv6-Server",                  "ipv6addr" ],
                75 => [ "WiMAX-vDHCP-RK",                        "octets" ],
                76 => [ "WiMAX-vDHCP-RK-Key-ID",                 "integer" ],
                77 => [ "WiMAX-vDHCP-RK-Lifetime",               "integer" ],
                78 => [ "WiMAX-PMIP-Authenticated-Network-Identity", "string" ],
                79 => [ "WiMAX-Visited-Framed-IP-Address",           "ipaddr" ],
                80  => [ "WiMAX-Visited-Framed-IPv6-Prefix",  "ipv6prefix" ],
                81  => [ "WiMAX-Visited-Framed-Interface-Id", "ifid" ],
                82  => [ "WiMAX-MIP-Authorization-Status",    "integer" ],
                83  => [ "WiMAX-Flow-Descriptor-v2",          "tlv" ],
                84  => [ "WiMAX-PFDv2-VLAN-Tag-Rule-Id",      "short" ],
                85  => [ "WiMAX-VLAN-Tag-Local-Config-Info",  "octets" ],
                86  => [ "WiMAX-hDHCP-DHCP-RK-Lifetime",      "integer" ],
                87  => [ "WiMAX-vDHCP-DHCP-RK-Lifetime",      "integer" ],
                88  => [ "WiMAX-BS-Location",                 "octets" ],
                89  => [ "WiMAX-Visited-IPv4-HoA-PMIP6",      "byte" ],
                90  => [ "WiMAX-MS-Authenticated",            "byte" ],
                126 => [ "WiMAX-PMIP6-Service-Info",          "short" ],
                127 => [ "WiMAX-hLMA-IPv6-PMIP6",             "ipv6addr" ],
                128 => [ "WiMAX-hLMA-IPv4-PMIP6",             "ipaddr" ],
                129 => [ "WiMAX-vLMA-IPv6-PMIP6",             "ipv6addr" ],
                130 => [ "WiMAX-vLMA-IPv4-PMIP6",             "ipaddr" ],
                131 => [ "WiMAX-PMIP6-RK-Key",                "octets" ],
                132 => [ "WiMAX-PMIP6-RK-SPI",                "integer" ],
                133 => [ "WiMAX-Home-HNP-PMIP6",              "ipv6prefix" ],
                134 => [ "WiMAX-Home-Interface-Id-PMIP6",     "ifid" ],
                135 => [ "WiMAX-Home-IPv4-HoA-PMIP6",         "ipaddr" ],
                136 => [ "WiMAX-Visited-HNP-PMIP6",           "ipv6prefix" ],
                137 => [ "WiMAX-Visited-Interface-Id-PMIP6",  "ifid" ],
                138 => [ "WiMAX-Visited-IPv4-HoA-PMIP6-2",    "ipaddr" ],
                143 => [ "WiMAX-AE-Command-Code",             "byte" ],
                144 => [ "WiMAX-Re-synchronization-Info",     "octets" ],
                145 => [ "WiMAX-E-UTRAN-Vector-KASME",        "octets" ],
                146 => [ "WiMAX-Visited-PLMN-ID",             "octets" ],
                150 => [ "WiMAX-RAT-Type",                    "integer" ],
                151 => [ "WiMAX-Software-Version",            "string" ],
                154 => [ "WiMAX-UE-AMBR-UL",                  "integer" ],
                155 => [ "WiMAX-Cancellation-Type",           "byte" ],
                156 => [ "WiMAX-Age-Of-Location-Information", "integer" ],
                166 => [ "WiMAX-Service-Selection",           "string" ],
            },
            25053 => {
                1   => [ "Ruckus-User-Groups",                 "string" ],
                2   => [ "Ruckus-Sta-RSSI",                    "integer" ],
                3   => [ "Ruckus-SSID",                        "string" ],
                4   => [ "Ruckus-Wlan-Id",                     "integer" ],
                5   => [ "Ruckus-Location",                    "string" ],
                6   => [ "Ruckus-Grace-Period",                "integer" ],
                7   => [ "Ruckus-SCG-CBlade-IP",               "integer" ],
                8   => [ "Ruckus-SCG-DBlade-IP",               "integer" ],
                9   => [ "Ruckus-VLAN-ID",                     "integer" ],
                10  => [ "Ruckus-WSG-User",                    "string" ],
                11  => [ "Ruckus-Sta-UUID",                    "string" ],
                12  => [ "Ruckus-Accept-Enhancement-Reason",   "integer" ],
                13  => [ "Ruckus-Sta-Inner-Id",                "string" ],
                14  => [ "Ruckus-BSSID",                       "octets" ],
                20  => [ "Ruckus-FlexAuth-AVP",                "string" ],
                101 => [ "Ruckus-Triplets",                    "octets" ],
                102 => [ "Ruckus-IMSI",                        "octets" ],
                103 => [ "Ruckus-MSISDN",                      "octets" ],
                104 => [ "Ruckus-APN-NI",                      "string" ],
                105 => [ "Ruckus-QoS",                         "octets" ],
                106 => [ "Ruckus-Selection-Mode",              "integer" ],
                107 => [ "Ruckus-APN-Resolution-Req",          "integer" ],
                108 => [ "Ruckus-Start-Time",                  "octets" ],
                109 => [ "Ruckus-NAS-Type",                    "integer" ],
                110 => [ "Ruckus-Status",                      "integer" ],
                111 => [ "Ruckus-APN-OI",                      "string" ],
                112 => [ "Ruckus-Auth-Type",                   "integer" ],
                113 => [ "Ruckus-Gn-User-Name",                "string" ],
                114 => [ "Ruckus-Brand-Code",                  "string" ],
                115 => [ "Ruckus-Policy-Name",                 "string" ],
                116 => [ "Ruckus-Client-Local-IP",             "ipaddr" ],
                117 => [ "Ruckus-SGSN-IP",                     "ipaddr" ],
                118 => [ "Ruckus-Charging-Charac",             "octets" ],
                119 => [ "Ruckus-PDP-Type",                    "octets" ],
                120 => [ "Ruckus-Dynamic-Address-Flag",        "octets" ],
                121 => [ "Ruckus-ChCh-Selection-Mode",         "octets" ],
                122 => [ "Ruckus-AAA-IP",                      "ipaddr" ],
                123 => [ "Ruckus-CDR-TYPE",                    "integer" ],
                124 => [ "Ruckus-SGSN-Number",                 "octets" ],
                125 => [ "Ruckus-Session-Type",                "integer" ],
                126 => [ "Ruckus-Accounting-Status",           "integer" ],
                127 => [ "Ruckus-Zone-Id",                     "string" ],
                128 => [ "Ruckus-Auth-Server-Id",              "string" ],
                129 => [ "Ruckus-Utp-Id",                      "string" ],
                130 => [ "Ruckus-Area-Code",                   "octets" ],
                131 => [ "Ruckus-Cell-Identifier",             "octets" ],
                132 => [ "Ruckus-Wispr-Redirect-Policy",       "string" ],
                133 => [ "Ruckus-Eth-Profile-Id",              "integer" ],
                134 => [ "Ruckus-Zone-Name",                   "string" ],
                135 => [ "Ruckus-Wlan-Name",                   "string" ],
                136 => [ "Ruckus-AP-Roamed",                   "integer" ],
                137 => [ "Ruckus-Read-Preference",             "octets" ],
                138 => [ "Ruckus-Client-Host-Name",            "string" ],
                139 => [ "Ruckus-Client-Os-Type",              "string" ],
                140 => [ "Ruckus-Client-Os-Class",             "string" ],
                141 => [ "Ruckus-Vlan-Pool",                   "string" ],
                142 => [ "Ruckus-DPSK",                        "octets" ],
                143 => [ "Ruckus-CP-Token",                    "string" ],
                144 => [ "Ruckus-Max-DL-UL-Quota",             "integer" ],
                145 => [ "Ruckus-Traffic-Class-Attribute-Ids", "string" ],
                146 => [ "Ruckus-TC-Quota",                    "octets" ],
                147 => [ "Ruckus-Nat-Pool-Name",               "string" ],
                148 => [ "Ruckus-Sta-SVlan-Id",                "integer" ],
                149 => [ "Ruckus-Acct-Ctrs_Output-Packets",    "integer" ],
                152 => [ "Ruckus-AAA-Id",                      "string" ],
                153 => [ "Ruckus-DPSK-EAPOL-Key-Frame",        "octets" ],
                154 => [ "Ruckus-Cluster-Name",                "string" ],
                155 => [ "Ruckus-Domain-Name",                 "string" ],
                156 => [ "Ruckus-Client-Device-Type",          "string" ],
                157 => [ "Ruckus-Vlan-Name",                   "string" ],
                200 => [ "Ruckus-SCI-Role",                    "string" ],
                201 => [ "Ruckus-SCI-Resource-Group",          "string" ],
            },
            25178 => {
                10 => [ "Eduroam-SP-Country",         "string" ],
                11 => [ "Eduroam-Monitoring-Inflate", "string" ],
            },
            25461 => {
                1  => [ "PaloAlto-Admin-Role",                   "string" ],
                2  => [ "PaloAlto-Admin-Access-Domain",          "string" ],
                3  => [ "PaloAlto-Panorama-Admin-Role",          "string" ],
                4  => [ "PaloAlto-Panorama-Admin-Access-Domain", "string" ],
                5  => [ "PaloAlto-User-Group",                   "string" ],
                6  => [ "PaloAlto-User-Domain",                  "string" ],
                7  => [ "PaloAlto-Client-Source-IP",             "string" ],
                8  => [ "PaloAlto-Client-OS",                    "string" ],
                9  => [ "PaloAlto-Client-Hostname",              "string" ],
                10 => [ "PaloAlto-GlobalProtect-Client-Version", "string" ],
            },
            25506 => {
                1   => [ "H3C-Input-Peak-Rate",              "integer" ],
                2   => [ "H3C-Input-Average-Rate",           "integer" ],
                3   => [ "H3C-Input-Basic-Rate",             "integer" ],
                4   => [ "H3C-Output-Peak-Rate",             "integer" ],
                5   => [ "H3C-Output-Average-Rate",          "integer" ],
                6   => [ "H3C-Output-Basic-Rate",            "integer" ],
                15  => [ "H3C-Remanent-Volume",              "integer" ],
                17  => [ "H3C-ISP-ID",                       "string" ],
                20  => [ "H3C-Command",                      "integer" ],
                24  => [ "H3C-Control-Identifier",           "integer" ],
                25  => [ "H3C-Result-Code",                  "integer" ],
                26  => [ "H3C-Connect_Id",                   "integer" ],
                27  => [ "H3C-Portal-URL",                   "string" ],
                28  => [ "H3C-Ftp-Directory",                "string" ],
                29  => [ "H3C-Exec-Privilege",               "integer" ],
                32  => [ "H3C-NAT-IP-Address",               "ipaddr" ],
                33  => [ "H3C-NAT-Start-Port",               "integer" ],
                34  => [ "H3C-NAT-End-Port",                 "integer" ],
                59  => [ "H3C-NAS-Startup-Timestamp",        "integer" ],
                60  => [ "H3C-Ip-Host-Addr",                 "string" ],
                61  => [ "H3C-User-Notify",                  "string" ],
                62  => [ "H3C-User-HeartBeat",               "string" ],
                98  => [ "H3C-IPv4-Multicast-Receive-Group", "ipaddr" ],
                100 => [ "H3C-IPv6-Multicast-Receive-Group", "ipv6addr" ],
                101 => [ "H3C-MLD-Access-Limit",             "integer" ],
                102 => [ "H3C-L2TP-Local-Name",              "string" ],
                103 => [ "H3C-IGMP-Access-Limit",            "integer" ],
                104 => [ "H3C-VPN-Instance",                 "string" ],
                105 => [ "H3C-ANCP-Profile",                 "string" ],
                106 => [ "H3C-Up-Priority",                  "integer" ],
                107 => [ "H3C-Down-Priority",                "integer" ],
                111 => [ "H3C-Longitude-Latitude",           "string" ],
                135 => [ "H3C-Client-Primary-DNS",           "ipaddr" ],
                136 => [ "H3C-Client-Secondary-DNS",         "ipaddr" ],
                140 => [ "H3C-User-Group",                   "string" ],
                141 => [ "H3C-Security-Level",               "integer" ],
                144 => [ "H3C-Acct-IPv6-Input-Octets",       "integer" ],
                145 => [ "H3C-Acct-IPv6-Output-Octets",      "integer" ],
                146 => [ "H3C-Acct-IPv6-Input-Packets",      "integer" ],
                147 => [ "H3C-Acct-IPv6-Output-Packets",     "integer" ],
                148 => [ "H3C-Acct-IPv6-Input-Gigawords",    "integer" ],
                149 => [ "H3C-Acct-IPv6-Output-Gigawords",   "integer" ],
                155 => [ "H3C-User-Role",                    "string" ],
                201 => [ "H3C-Input-Interval-Octets",        "integer" ],
                202 => [ "H3C-Output-Interval-Octets",       "integer" ],
                203 => [ "H3C-Input-Interval-Packets",       "integer" ],
                204 => [ "H3C-Output-Interval-Packets",      "integer" ],
                205 => [ "H3C-Input-Interval-Gigawords",     "integer" ],
                206 => [ "H3C-Output-Interval-Gigawords",    "integer" ],
                207 => [ "H3C-Backup-NAS-IP",                "ipaddr" ],
                210 => [ "H3C-Av-Pair",                      "string" ],
                215 => [ "H3C-Accounting-Level",             "integer" ],
                216 => [ "H3C-Ita-Policy",                   "string" ],
                230 => [ "H3C-NAS-Port-Name",                "string" ],
                246 => [ "H3C-Auth-Detail-Result",           "integer" ],
                247 => [ "H3C-Input-Committed-Burst-Size",   "integer" ],
                248 => [ "H3C-Output-Committed-Burst-Size",  "integer" ],
                249 => [ "H3C-Authentication-Type",          "integer" ],
                250 => [ "H3C-WEB-URL",                      "string" ],
                251 => [ "H3C-Subscriber-ID",                "string" ],
                252 => [ "H3C-Subscriber-Profile",           "string" ],
                255 => [ "H3C-Product-ID",                   "string" ],
            },
            25622 => {
                128 => [ "UKERNA-GSS-Acceptor-Service-Name",     "string" ],
                129 => [ "UKERNA-GSS-Acceptor-Host-Name",        "string" ],
                130 => [ "UKERNA-GSS-Acceptor-Service-Specific", "string" ],
                131 => [ "UKERNA-GSS-Acceptor-Realm-Name",       "string" ],
                132 => [ "SAML-AAA-Assertion",                   "string" ],
                135 => [ "EAP-Channel-Binding-Message",          "octets" ],
                136 => [ "Trust-Router-COI",                     "string" ],
                137 => [ "Trust-Router-APC",                     "string" ],
                138 => [ "Moonshot-Host-TargetedId",             "string" ],
                139 => [ "Moonshot-Realm-TargetedId",            "string" ],
                140 => [ "Moonshot-TR-COI-TargetedId",           "string" ],
                141 => [ "Moonshot-MSTID-GSS-Acceptor",          "string" ],
                142 => [ "Moonshot-MSTID-Namespace",             "string" ],
                143 => [ "Moonshot-MSTID-TargetedId",            "string" ],
                144 => [ "Moonshot-OTP-Secret",                  "string" ],
            },
            26928 => {
                1   => [ "Extreme-User-Vlan",                 "integer" ],
                3   => [ "Extreme-Libsip-Patron-Info",        "octets" ],
                4   => [ "Extreme-Libsip-Action",             "integer" ],
                5   => [ "Extreme-Libsip-Additional-Message", "octets" ],
                6   => [ "Extreme-User-Profile-Attribute",    "integer" ],
                7   => [ "Extreme-Data-Usage-Limit",          "octets" ],
                8   => [ "Extreme-AVPair",                    "string" ],
                9   => [ "Extreme-Radius-Code",               "integer" ],
                201 => [ "Extreme-PPSK-Request",              "octets" ],
                202 => [ "Extreme-PPSK-PMK",                  "octets" ],
                203 => [ "Extreme-IDM-Message",               "integer" ],
                204 => [ "Extreme-NT-Identity",               "integer" ],
                205 => [ "Extreme-User-Language",             "string" ],
                207 => [ "Extreme-Time-Zone-Offset",          "integer" ],
                208 => [ "Extreme-Daylight-Saving-Offset",    "integer" ],
                209 => [ "Extreme-Client-Monitor-Session",    "octets" ],
                210 => [ "Extreme-Client-Monitor-Problem",    "integer" ],
                211 => [ "Extreme-IDM-Redirect-URL",          "string" ],
                212 => [ "Extreme-MGT-MAC-Address",           "string" ],
                213 => [ "Extreme-Auth-Source",               "integer" ],
            },
            27030 => {
                1 => [ "Wichorus-Policy-Name",    "string" ],
                2 => [ "Wichorus-User-Privilege", "string" ],
            },
            27262 => { 1 => [ "Default-TTL", "integer" ] },
            27880 => {
                1  => [ "Freeswitch-AVPair",           "string" ],
                2  => [ "Freeswitch-CLID",             "string" ],
                3  => [ "Freeswitch-Dialplan",         "string" ],
                4  => [ "Freeswitch-Src",              "string" ],
                5  => [ "Freeswitch-Dst",              "string" ],
                6  => [ "Freeswitch-Src-Channel",      "string" ],
                7  => [ "Freeswitch-Dst-Channel",      "string" ],
                8  => [ "Freeswitch-Ani",              "string" ],
                9  => [ "Freeswitch-Aniii",            "string" ],
                10 => [ "Freeswitch-Lastapp",          "string" ],
                11 => [ "Freeswitch-Lastdata",         "string" ],
                12 => [ "Freeswitch-Disposition",      "string" ],
                13 => [ "Freeswitch-Hangupcause",      "integer" ],
                15 => [ "Freeswitch-Billusec",         "integer" ],
                16 => [ "Freeswitch-AMAFlags",         "integer" ],
                17 => [ "Freeswitch-RDNIS",            "string" ],
                18 => [ "Freeswitch-Context",          "string" ],
                19 => [ "Freeswitch-Source",           "string" ],
                20 => [ "Freeswitch-Callstartdate",    "string" ],
                21 => [ "Freeswitch-Callanswerdate",   "string" ],
                22 => [ "Freeswitch-Calltransferdate", "string" ],
                23 => [ "Freeswitch-Callenddate",      "string" ],
                24 => [ "Freeswitch-Signalbond",       "string" ],
            },
            27975 => { 1 => [ "Centec-Exec-Privilege", "integer" ] },
            28557 => {
                1   => [ "Hillstone-User-vsys-id",             "integer" ],
                2   => [ "Hillstone-User-Type",                "integer" ],
                3   => [ "Hillstone-User-Admin-Privilege",     "integer" ],
                4   => [ "Hillstone-User-Login-Type",          "integer" ],
                5   => [ "Hillstone-User-Mobile-Number",       "string" ],
                6   => [ "Hillstone-User-Mobile-Operator",     "integer" ],
                7   => [ "Hillstone-User-Policy-dst-ip-begin", "ipaddr" ],
                8   => [ "Hillstone-User-Policy-dst-ip-end",   "ipaddr" ],
                9   => [ "Hillstone-User-Role-Bame",           "string" ],
                100 => [ "Hillstone-VPN-DHCP-Gateway",         "string" ],
                101 => [ "Hillstone-VPN-DHCP-Mask",            "string" ],
                102 => [ "Hillstone-VPN-DHCP-Pool",            "string" ],
                103 => [ "Hillstone-VPN-WINS",                 "string" ],
                104 => [ "Hillstone-VPN-DNS",                  "string" ],
                105 => [ "Hillstone-VPN-Split-Route",          "string" ],
                106 => [ "Hillstone-VPN-Tunnel-IP",            "string" ],
                107 => [ "Hillstone-VPN-SNAT",                 "integer" ],
            },
            29464 => {
                1  => [ "PacketFence-RPC-Server",           "string" ],
                2  => [ "PacketFence-RPC-Port",             "string" ],
                3  => [ "PacketFence-RPC-User",             "string" ],
                4  => [ "PacketFence-RPC-Pass",             "string" ],
                5  => [ "PacketFence-RPC-Proto",            "string" ],
                6  => [ "PacketFence-Mac",                  "string" ],
                7  => [ "PacketFence-UserName",             "string" ],
                8  => [ "PacketFence-Switch-Id",            "string" ],
                9  => [ "PacketFence-Switch-Mac",           "string" ],
                10 => [ "PacketFence-Switch-Ip-Address",    "string" ],
                11 => [ "PacketFence-Eap-Type",             "string" ],
                12 => [ "PacketFence-Connection-Type",      "string" ],
                13 => [ "PacketFence-Source",               "string" ],
                14 => [ "PacketFence-SSID",                 "string" ],
                15 => [ "PacketFence-IsPhone",              "string" ],
                16 => [ "PacketFence-AutoReg",              "string" ],
                17 => [ "PacketFence-Role",                 "string" ],
                18 => [ "PacketFence-Status",               "string" ],
                19 => [ "PacketFence-IfIndex",              "string" ],
                20 => [ "PacketFence-Profile",              "string" ],
                21 => [ "PacketFence-Domain",               "string" ],
                22 => [ "PacketFence-Computer-Name",        "string" ],
                23 => [ "PacketFence-Handled",              "string" ],
                24 => [ "PacketFence-Request-Time",         "integer" ],
                25 => [ "PacketFence-NasName",              "string" ],
                26 => [ "PacketFence-Proxied-To",           "string" ],
                27 => [ "PacketFence-Authorization-Status", "string" ],
                29 => [ "PacketFence-ShortName",            "string" ],
                30 => [ "PacketFence-Proxied-From",         "string" ],
                31 => [ "PacketFence-UserNameAttribute",    "string" ],
                32 => [ "PacketFence-KeyBalanced",          "string" ],
                33 => [ "PacketFence-Radius-Ip",            "string" ],
                34 => [ "PacketFence-NTCacheHash",          "string" ],
                35 => [ "PacketFence-NTLMv2-Only",          "string" ],
                36 => [ "PacketFence-Outer-User",           "string" ],
                37 => [ "PacketFence-UserDN",               "string" ],
                38 => [ "PacketFence-reply-insert",         "string" ],
                39 => [ "PacketFence-UserPassword",         "string" ],
                40 => [ "PacketFence-ConnectorID",          "string" ],
                41 => [ "PacketFence-NTLM-Auth-Host",       "string" ],
                42 => [ "PacketFence-NTLM-Auth-Port",       "string" ],
            },
            29671 => {
                1 => [ "Meraki-Device-Name",  "string" ],
                2 => [ "Meraki-Network-Name", "string" ],
                3 => [ "Meraki-Ap-Name",      "string" ],
                4 => [ "Meraki-Ap-Tags",      "string" ],
            },
            30065 => {
                1  => [ "Arista-AVPair",          "string" ],
                2  => [ "Arista-User-Priv-Level", "integer" ],
                3  => [ "Arista-User-Role",       "string" ],
                4  => [ "Arista-CVP-Role",        "string" ],
                5  => [ "Arista-Command",         "string" ],
                6  => [ "Arista-WebAuth",         "integer" ],
                7  => [ "Arista-BlockMac",        "string" ],
                8  => [ "Arista-UnblockMac",      "string" ],
                9  => [ "Arista-PortFlap",        "integer" ],
                10 => [ "Arista-Captive-Portal",  "string" ],
            },
            30585 => {
                2 => [ "SSS-Proxy-Id",         "string" ],
                3 => [ "SSS-Proxy-Identifier", "string" ],
                4 => [ "SSS-Proxy-Location",   "string" ],
            },
            33049 => { 1 => [ "Mellanox-Local-User-Name", "string" ] },
            34536 => {
                1  => [ "fdXtended-Bandwidth-Up",   "integer" ],
                2  => [ "fdXtended-Bandwidth-Down", "integer" ],
                3  => [ "fdXtended-PostAuthURL",    "string" ],
                4  => [ "fdXtended-One2onenat-IP",  "string" ],
                5  => [ "fdXtended-ContentFilter",  "integer" ],
                6  => [ "fdXtended-NetworkPolicy",  "integer" ],
                7  => [ "fdXtended-BytesDown",      "integer" ],
                8  => [ "fdXtended-BytesUp",        "integer" ],
                9  => [ "fdXtended-Expiration",     "string" ],
                10 => [ "fdXtended-SessionTimeout", "integer" ],
                11 => [ "fdXtended-Wan-Interface",  "string" ],
            },
            35098 => {
                1 => [ "Pica8-AVPair",                   "string" ],
                2 => [ "Pica8-IP-Downloadable-ACL-Rule", "string" ],
                3 => [ "Pica8-IP-Downloadable-ACL-Name", "string" ],
                4 => [ "Pica8-Redirect-URL",             "string" ],
            },
            35265 => {
                1  => [ "Eltex-AVPair",                "string" ],
                11 => [ "Eltex-Disconnect-Code-Local", "integer" ],
            },
            35987 => {
                1  => [ "NetBorder-AVPair",           "string" ],
                2  => [ "NetBorder-CLID",             "string" ],
                3  => [ "NetBorder-Dialplan",         "string" ],
                4  => [ "NetBorder-Src",              "string" ],
                5  => [ "NetBorder-Dst",              "string" ],
                6  => [ "NetBorder-Src-Channel",      "string" ],
                7  => [ "NetBorder-Dst-Channel",      "string" ],
                8  => [ "NetBorder-Ani",              "string" ],
                9  => [ "NetBorder-Aniii",            "string" ],
                10 => [ "NetBorder-Lastapp",          "string" ],
                11 => [ "NetBorder-Lastdata",         "string" ],
                12 => [ "NetBorder-Disposition",      "string" ],
                13 => [ "NetBorder-Hangupcause",      "integer" ],
                15 => [ "NetBorder-Billusec",         "integer" ],
                16 => [ "NetBorder-AMAFlags",         "integer" ],
                17 => [ "NetBorder-RDNIS",            "string" ],
                18 => [ "NetBorder-Context",          "string" ],
                19 => [ "NetBorder-Source",           "string" ],
                20 => [ "NetBorder-Callstartdate",    "string" ],
                21 => [ "NetBorder-Callanswerdate",   "string" ],
                22 => [ "NetBorder-Calltransferdate", "string" ],
                23 => [ "NetBorder-Callenddate",      "string" ],
                24 => [ "NetBorder-Signalbond",       "string" ],
            },
            37538 => {
                1 => [ "BSN-User-Role", "string" ],
                2 => [ "BSN-AVPair",    "string" ]
            },
            40676 => {
                1 => [ "Microsemi-User-Full-Name",        "string" ],
                2 => [ "Microsemi-User-Name",             "string" ],
                3 => [ "Microsemi-User-Initials",         "string" ],
                4 => [ "Microsemi-User-Email",            "string" ],
                5 => [ "Microsemi-User-Group",            "string" ],
                6 => [ "Microsemi-Fallback-User-Group",   "string" ],
                7 => [ "Microsemi-Network-Element-Group", "string" ],
            },
            40808 => {
                1 => [ "HS20-Subscription-Remediation-Needed", "octets" ],
                2 => [ "HS20-AP-Version",                      "byte" ],
                3 => [ "HS20-Mobile-Device-Version",           "octets" ],
                4 => [ "HS20-Deauthentication-Request",        "octets" ],
                5 => [ "HS20-Session-Information-URL",         "octets" ],
                6 => [ "HS20-Roaming-Consortium",              "octets" ],
            },
            41482 => {
                1 => [ "Yubikey-Key",        "octets" ],
                2 => [ "Yubikey-Public-ID",  "string" ],
                3 => [ "Yubikey-Private-ID", "octets" ],
                4 => [ "Yubikey-Counter",    "integer" ],
                5 => [ "Yubikey-Timestamp",  "integer" ],
                6 => [ "Yubikey-Random",     "integer" ],
                7 => [ "Yubikey-OTP",        "string" ],
            },
            43356 => {
                1  => [ "Mimosa-Device-Configuration-Parameter",    "string" ],
                2  => [ "Mimosa-FirmwareVersion-Parameter",         "string" ],
                3  => [ "Mimosa-FirmwareLocation-Parameter",        "string" ],
                4  => [ "Mimosa-WirelessProtocol-Parameter",        "string" ],
                5  => [ "Mimosa-ManagementIPAddressMode-Parameter", "string" ],
                6  => [ "Mimosa-ManagementIPAddress-Parameter",     "ipaddr" ],
                7  => [ "Mimosa-ManagementIPNetmask-Parameter",     "ipaddr" ],
                8  => [ "Mimosa-ManagementIPGateway-Parameter",     "ipaddr" ],
                9  => [ "Mimosa-ManagementVlanStatus-Parameter",    "byte" ],
                10 => [ "Mimosa-ManagementVlan-Parameter",          "string" ],
                11 => [ "Mimosa-ManagementPassword-Parameter",      "string" ],
                12 => [ "Mimosa-DeviceName-Parameter",              "string" ],
                13 => [ "Mimosa-TrafficShapingPeak-Parameter",      "string" ],
                14 => [ "Mimosa-TrafficShapingCommitted-Parameter", "string" ],
                15 => [ "Mimosa-EthernetPortSpeed-Parameter",       "string" ],
                16 => [ "Mimosa-DNS1-Parameter",                    "ipaddr" ],
                17 => [ "Mimosa-DNS2-Parameter",                    "ipaddr" ],
                18 => [ "Mimosa-HTTPPort-Parameter",                "integer" ],
                19 => [ "Mimosa-EnableHTTPS-Parameter",             "byte" ],
                20 => [ "Mimosa-HTTPSPort-Parameter",               "integer" ],
                21 => [ "Mimosa-CloudManagement-Parameter",         "byte" ],
                22 => [ "Mimosa-EnableSNMP-Parameter",              "byte" ],
                23 => [ "Mimosa-SNMPCommunityString-Parameter",     "string" ],
                24 => [ "Mimosa-SNMPTrapServer-Parameter",          "ipaddr" ],
                25 => [ "Mimosa-NTPServerAddress-Parameter",        "string" ],
                26 => [ "Mimosa-EnableSyslog-Parameter",            "byte" ],
                27 => [ "Mimosa-SyslogServerAddress-Parameter",     "ipaddr" ],
                28 => [ "Mimosa-SyslogPort-Parameter",              "integer" ],
                29 => [ "Mimosa-SyslogProtocol-Parameter",          "string" ],
            },
            43823 => {
                1  => [ "VasExperts-Policing-Profile",        "string" ],
                2  => [ "VasExperts-Service-Profile",         "string" ],
                3  => [ "VasExperts-Enable-Service",          "string" ],
                4  => [ "VasExperts-Multi-IP-User",           "integer" ],
                5  => [ "VasExperts-UserName",                "string" ],
                6  => [ "VasExperts-Service-Type",            "integer" ],
                7  => [ "VasExperts-Restrict-User",           "integer" ],
                8  => [ "VasExperts-Enable-Interconnect",     "integer" ],
                9  => [ "VasExperts-OutVLAN",                 "integer" ],
                10 => [ "VasExperts-Command-Code",            "integer" ],
                11 => [ "VasExperts-OutMAC",                  "string" ],
                16 => [ "VasExperts-Acct-Traffic-Class-Name", "string" ],
                17 =>
                  [ "VasExperts-Acct-Traffic-Class-Input-Octets", "integer64" ],
                18 => [
                    "VasExperts-Acct-Traffic-Class-Output-Octets", "integer64"
                ],
                19 => [
                    "VasExperts-Acct-Traffic-Class-Input-Packets", "integer64"
                ],
                20 => [
                    "VasExperts-Acct-Traffic-Class-Output-Packets", "integer64"
                ],
                21 => [ "VasExperts-NAT-IP",                  "ipaddr" ],
                32 => [ "VasExperts-DHCP-Hostname",           "octets" ],
                33 => [ "VasExperts-DHCP-ClientId",           "octets" ],
                34 => [ "VasExperts-DHCP-ClassId",            "octets" ],
                35 => [ "VasExperts-DHCP-RelayInfo",          "octets" ],
                36 => [ "VasExperts-DHCP-ClientIP",           "ipaddr" ],
                37 => [ "VasExperts-DHCP-Request",            "integer" ],
                38 => [ "VasExperts-DHCP-RelayRemoteId",      "octets" ],
                39 => [ "VasExperts-DHCP-RelayCircuitId",     "octets" ],
                40 => [ "VasExperts-DHCP-Option",             "octets" ],
                41 => [ "VasExperts-DHCP-DNS",                "ipaddr" ],
                42 => [ "VasExperts-DHCP-Gateway",            "ipaddr" ],
                43 => [ "VasExperts-BOOTP-SName",             "string" ],
                44 => [ "VasExperts-BOOTP-File",              "string" ],
                45 => [ "VasExperts-DHCP-Option-IP",          "string" ],
                46 => [ "VasExperts-DHCP-Option-Num",         "string" ],
                47 => [ "VasExperts-DHCP-Option-String",      "string" ],
                48 => [ "VasExperts-DHCP-Option-Bin",         "string" ],
                60 => [ "VasExperts-ARP-SourceIP",            "ipaddr" ],
                61 => [ "VasExperts-ARP-TargetIP",            "ipaddr" ],
                70 => [ "VasExperts-DHCPv6-Request",          "integer" ],
                71 => [ "VasExperts-DHCPv6-UserClass",        "octets" ],
                72 => [ "VasExperts-DHCPv6-VendorClass",      "octets" ],
                73 => [ "VasExperts-DHCPv6-RemoteId",         "octets" ],
                74 => [ "VasExperts-DHCPv6-SubsId",           "octets" ],
                75 => [ "VasExperts-DHCPv6-Delegated",        "integer" ],
                80 => [ "VasExperts-DHCP-Option-IPv6",        "string" ],
                81 => [ "VasExperts-DHCP-Option-IPv6-Prefix", "string" ],
                82 => [ "VasExperts-DHCP6-Option-Num",        "string" ],
                83 => [ "VasExperts-DHCP6-Option-String",     "string" ],
                84 => [ "VasExperts-DHCP6-Option-Bin",        "string" ],
            },
            46235 => {
                1 => [ "RCNTEC-RPCM-Group",          "string" ],
                2 => [ "RCNTEC-RPCM-Session-Expire", "integer" ],
            },
            49426 => {
                1  => [ "BELRAS-Up-Speed-Limit",         "integer" ],
                2  => [ "BELRAS-Down-Speed-Limit",       "integer" ],
                3  => [ "BELRAS-Qos-Speed",              "integer" ],
                4  => [ "BELRAS-User",                   "string" ],
                5  => [ "BELRAS-DHCP-Router-IP-Address", "ipaddr" ],
                6  => [ "BELRAS-DHCP-Mask",              "integer" ],
                7  => [ "BELRAS-Redirect",               "integer" ],
                8  => [ "BELRAS-redirect-Pool",          "integer" ],
                9  => [ "BELRAS-DHCP-Option82",          "octets" ],
                10 => [ "BELRAS-Session-Octets-Limit",   "integer" ],
                11 => [ "BELRAS-Octets-Direction",       "integer" ],
                12 => [ "BELRAS-AKAMAI-Speed",           "integer" ],
                13 => [ "BELRAS-CACHE-Speed",            "integer" ],
                14 => [ "BELRAS-CacheFly-Speed",         "integer" ],
                15 => [ "BELRAS-GGC-Speed",              "integer" ],
                16 => [ "BELRAS-GOOGLE-Speed",           "integer" ],
                17 => [ "BELRAS-Incapsula-Speed",        "integer" ],
                18 => [ "BELRAS-LIMELIGHT-Speed",        "integer" ],
                19 => [ "BELRAS-OTHERS-Speed",           "integer" ],
                20 => [ "BELRAS-REDIFF-Speed",           "integer" ],
                21 => [ "BELRAS-TORRENT-Speed",          "integer" ],
                22 => [ "BELRAS-BELCACHE-Speed",         "integer" ],
                23 => [ "BELRAS-DHCP-Lease-Time",        "integer" ],
                24 => [ "BELRAS-Group",                  "integer" ],
                25 => [ "BELRAS-LIMIT",                  "string" ],
                26 => [ "BELRAS-Auth",                   "string" ],
                27 => [ "BELRAS-Acct",                   "string" ],
                28 => [ "BELRAS-Framed-IP-Address",      "string" ],
                29 => [ "BELRAS-BL",                     "string" ],
                30 => [ "BELRAS-IN",                     "string" ],
                31 => [ "BELRAS-CO",                     "string" ],
            },
            52970 => { 3 => [ "Eleven-EAPOL-STMAC", "octets" ] },
            54268 => {
                1   => [ "NetElastic-Input-Burst-Size",           "integer" ],
                2   => [ "NetElastic-Input-Average-Rate",         "integer" ],
                3   => [ "NetElastic-Input-Peak-Rate",            "integer" ],
                4   => [ "NetElastic-Output-Burst-Size",          "integer" ],
                5   => [ "NetElastic-Output-Average-Rate",        "integer" ],
                6   => [ "NetElastic-Output-Peak-Rate",           "integer" ],
                15  => [ "NetElastic-Remanent-Volume",            "integer" ],
                17  => [ "NetElastic-ISP-ID",                     "string" ],
                27  => [ "NetElastic-PortalURL",                  "string" ],
                31  => [ "NetElastic-Qos-Profile-Name",           "string" ],
                74  => [ "NetElastic-Lease-Time",                 "integer" ],
                77  => [ "NetElastic-Input-Peak-Burst-Size",      "integer" ],
                78  => [ "NetElastic-Output-Peak-Burst-Size",     "integer" ],
                82  => [ "NetElastic-Data-Filter",                "string" ],
                85  => [ "NetElastic-Portal-Mode",                "integer" ],
                95  => [ "NetElastic-Policy-Name",                "string" ],
                135 => [ "NetElastic-Primary-DNS",                "ipaddr" ],
                136 => [ "NetElastic-Secondary-DNS",              "ipaddr" ],
                138 => [ "NetElastic-Domain-Name",                "string" ],
                140 => [ "NetElastic-HTTP-Redirect-URL",          "string" ],
                144 => [ "NetElastic-Acct-IPv6-Input-Octets",     "integer" ],
                145 => [ "NetElastic-Acct-IPv6-Output-Octets",    "integer" ],
                146 => [ "NetElastic-Acct-IPv6-Input-Packets",    "integer" ],
                147 => [ "NetElastic-Acct-IPv6-Output-Packets",   "integer" ],
                148 => [ "NetElastic-Acct-IPv6-Input-Gigawords",  "integer" ],
                149 => [ "NetElastic-Acct-IPv6-Output-Gigawords", "integer" ],
                153 => [ "NetElastic-User-Mac",                   "string" ],
                158 => [ "NetElastic-Framed-IPv6-Address",        "ipv6addr" ],
                161 => [ "NetElastic-NAT-Public-Address",         "ipaddr" ],
                162 => [ "NetElastic-NAT-Start-Port",             "integer" ],
                163 => [ "NetElastic-NAT-End-Port",               "integer" ],
                247 => [ "NetElastic-Tariff-Input-Octets",        "string" ],
                248 => [ "NetElastic-Tariff-Output-Octets",       "string" ],
                249 => [ "NetElastic-Tariff-Input-Gigawords",     "string" ],
                250 => [ "NetElastic-Tariff-Output-Gigawords",    "string" ],
                251 => [ "NetElastic-Remanent-Volume-Type",       "integer" ],
                252 => [ "NetElastic-Web-COA",                    "integer" ],
            },
            58313 => {
                1 => [ "Nile-Redirect-URL", "string" ],
                2 => [ "Nile-Netseg",       "string" ],
                3 => [ "Nile-AVPair",       "string" ],
            },
            58888 => { 1  => [ "OpenWiFi-AP-MAC-Address", "string" ] },
            61349 => { 10 => [ "CKey-Auth-Info",          "integer" ] },
        },
        rvsaval => {
            5 => {
                1 => {
                    "0"  => "No-reason-No-Failure",
                    "1"  => "Resource-shortage",
                    "2"  => "Session-already-open",
                    "3"  => "Too-many-RADIUS-users",
                    "4"  => "No-authentication-server",
                    "5"  => "No-authentication-response",
                    "6"  => "No-accounting-server",
                    "7"  => "No-accounting-response",
                    "8"  => "Access-Denied",
                    "9"  => "Temporary-buffer-shortage",
                    "10" => "Protocol-error",
                    "11" => "Invalid-attribute",
                    "12" => "Invalid-service-type",
                    "13" => "Invalid-framed-protocol",
                    "14" => "Invalid-attribute-value",
                    "15" => "Invalid-user-information",
                    "16" => "Invalid-IP-address",
                    "17" => "Invalid-integer-syntax",
                    "18" => "Invalid-NAS-port",
                    "19" => "Requested-by-user",
                    "20" => "Network-disconnect",
                    "21" => "Service-interruption",
                    "22" => "Physical-port-error",
                    "23" => "Idle-timeout",
                    "24" => "Session-timeout",
                    "25" => "Administrative-reset",
                    "26" => "NAS-reload-or-reset",
                    "27" => "NAS-error",
                    "28" => "NAS-request",
                    "29" => "Undefined-reason-given",
                    "30" => "Conflicting-attributes",
                    "31" => "Port-limit-exceeded",
                    "32" => "Facility-not-available",
                    "33" => "Internal-config-error",
                    "34" => "Bad-route-specification",
                    "35" => "Access-Partition-bind-failure",
                    "36" => "Security-violation",
                    "37" => "Request-type-conflict",
                    "38" => "Configuration-disallowed",
                    "39" => "Missing-attribute",
                    "40" => "Invalid-request",
                    "41" => "Missing-parameter",
                    "42" => "Invalid-parameter",
                    "43" => "Call-cleared-with-cause",
                    "44" => "Inopportune-config-request",
                    "45" => "Invalid-config-parameter",
                    "46" => "Missing-config-parameter",
                    "47" => "Incompatible-service-profile",
                    "48" => "Administrative-reset-2",
                    "49" => "Administrative-reload",
                    "50" => "Port-unneeded",
                    "51" => "Port-preempted",
                    "52" => "Port-suspended",
                    "53" => "Service-unavailable",
                    "54" => "Callback",
                    "55" => "User-error",
                    "56" => "Host-request",
                },
                2  => { 1 => "Disabled", 2 => "Enabled" },
                9  => { 1 => "Funnel",   2 => "Direct" },
                10 => { 1 => "Enabled",  2 => "Disabled" },
                15 => {
                    "0"   => "Cause-unspecified",
                    "1"   => "Unassigned-number",
                    "2"   => "No-route-to-transit-network",
                    "3"   => "No-route-to-destination",
                    "6"   => "Channel-unacceptable",
                    "7"   => "Call-awarded-being-delivered",
                    "16"  => "Normal-clearing",
                    "17"  => "User-busy",
                    "18"  => "No-user-responding",
                    "19"  => "User-alerted-no-answer",
                    "21"  => "Call-rejected",
                    "22"  => "Number-changed",
                    "26"  => "Non-selected-user-clearing",
                    "27"  => "Destination-out-of-order",
                    "28"  => "Invalid-or-incomplete-number",
                    "29"  => "Facility-rejected",
                    "30"  => "Response-to-status-inquiry",
                    "31"  => "Normal-unspecified-cause",
                    "34"  => "No-circuit-or-channel-available",
                    "38"  => "Network-out-of-order",
                    "41"  => "Temporary-failure",
                    "42"  => "Switching-equipment-congestion",
                    "43"  => "Access-information-discarded",
                    "44"  => "Circuit-or-channel-unavailable",
                    "45"  => "Circuit-or-channed-preempted",
                    "47"  => "Resources-unavailable",
                    "49"  => "Quality-of-service-unavailable",
                    "50"  => "Facility-not-subscribed",
                    "52"  => "Outgoing-calls-barred",
                    "54"  => "Incoming-calls-barred",
                    "57"  => "Bearer-capability-unauthorized",
                    "58"  => "Bearer-capability-not-available",
                    "63"  => "Service-not-available",
                    "65"  => "Bearer-capablity-not-implmented",
                    "66"  => "Channel-type-not-implemented",
                    "69"  => "Facility-not-implemented",
                    "70"  => "Restrcted-digtal-infrmtion-only",
                    "79"  => "Service-not-implemented",
                    "81"  => "Invalid-call-reference",
                    "82"  => "Identified-channel-doesnt-exist",
                    "84"  => "Call-identify-in-use",
                    "85"  => "No-call-suspended",
                    "86"  => "Suspended-call-cleared",
                    "88"  => "Incompatible-destination",
                    "91"  => "Invalid-transit-network-selctin",
                    "95"  => "Invalid-message",
                    "96"  => "Mandtory-infrmtion-elment-miss",
                    "97"  => "Message-not-implemented",
                    "98"  => "Inopportune-message",
                    "99"  => "Infrmtion-elemnt-not-implmented",
                    "100" => "Invlid-infrmtion-element-contnt",
                    "101" => "Message-incompatible-with-state",
                    "102" => "Recovery-on-timer-expiration",
                    "103" => "Mndtry-infrmtion-elmnt-lngt-err",
                    "111" => "Protocol-error",
                    "127" => "Interworking",
                },
                16 => {
                    "0"  => "Local-or-remote-user",
                    "1"  => "Prvte-ntwork-serving-local-user",
                    "2"  => "Pblic-ntwork-serving-local-user",
                    "3"  => "Transit-network",
                    "4"  => "Prvte-ntwork-serv-remote-user",
                    "5"  => "Pblic-ntwork-serv-remote-user",
                    "6"  => "International-network",
                    "10" => "Beyond-interworking-point",
                },
                18 => {
                    1 => "Ring-Indication",
                    2 => "Dial-Request",
                    3 => "User-Authentication",
                    4 => "Tunnel-Authentication",
                },
                19 => { 1 => "Disabled", 2 => "Enabled" },
                20 => { 1 => "False",    2 => "True" },
                21 => {
                    "0" => "NAS-Reset",
                    "1" => "NAS-Reload",
                    "2" => "Configuration-Reset",
                    "3" => "Configuration-Reload",
                    "4" => "Enabled",
                    "5" => "Disabled",
                },
                28 => { 1 => "Disabled", 2 => "Enabled" },
                29 => { 1 => "Disabled", 2 => "Enabled" },
                36 => {
                    "0" => "User-Auth",
                    "3" => "User-Specified-E-164",
                    "6" => "CBCP-Callback",
                    "7" => "CLI-Callback",
                },
                37 => {
                    1 => "CBCP-None",
                    2 => "CBCP-User-Specified",
                    3 => "CBCP-Pre-Specified"
                },
                38 => { 1 => "PAP", 2 => "CHAP", 3 => "CHAP-PAP", 4 => "NONE" },
                42 => { 1 => "PUBLIC", 2 => "NETMAN" },
                43 => {
                    1 => "No-Access-Partition",
                    2 => "Access-Partition-Disabled",
                    3 => "Partition-Portlimit-Exceeded",
                    4 => "License-Portlimit-Exceeded",
                    5 => "Home-Server-Down",
                    6 => "Rejected-By-Home-Server",
                    7 => "NAS-Administratively-Disabled",
                },
                47 => { 1 => "Enabled", 2 => "Disabled" },
                48 => { 1 => "V1",      2 => "V2" },
            },
            9 => {
                195 => {
                    "0"   => "No-Reason",
                    "1"   => "No-Disconnect",
                    "2"   => "Unknown",
                    "3"   => "Call-Disconnect",
                    "4"   => "CLID-Authentication-Failure",
                    "9"   => "No-Modem-Available",
                    "10"  => "No-Carrier",
                    "11"  => "Lost-Carrier",
                    "12"  => "No-Detected-Result-Codes",
                    "20"  => "User-Ends-Session",
                    "21"  => "Idle-Timeout",
                    "22"  => "Exit-Telnet-Session",
                    "23"  => "No-Remote-IP-Addr",
                    "24"  => "Exit-Raw-TCP",
                    "25"  => "Password-Fail",
                    "26"  => "Raw-TCP-Disabled",
                    "27"  => "Control-C-Detected",
                    "28"  => "EXEC-Program-Destroyed",
                    "29"  => "Close-Virtual-Connection",
                    "30"  => "End-Virtual-Connection",
                    "31"  => "Exit-Rlogin",
                    "32"  => "Invalid-Rlogin-Option",
                    "33"  => "Insufficient-Resources",
                    "40"  => "Timeout-PPP-LCP",
                    "41"  => "Failed-PPP-LCP-Negotiation",
                    "42"  => "Failed-PPP-PAP-Auth-Fail",
                    "43"  => "Failed-PPP-CHAP-Auth",
                    "44"  => "Failed-PPP-Remote-Auth",
                    "45"  => "PPP-Remote-Terminate",
                    "46"  => "PPP-Closed-Event",
                    "47"  => "NCP-Closed-PPP",
                    "48"  => "MP-Error-PPP",
                    "49"  => "PPP-Maximum-Channels",
                    "50"  => "Tables-Full",
                    "51"  => "Resources-Full",
                    "52"  => "Invalid-IP-Address",
                    "53"  => "Bad-Hostname",
                    "54"  => "Bad-Port",
                    "60"  => "Reset-TCP",
                    "61"  => "TCP-Connection-Refused",
                    "62"  => "Timeout-TCP",
                    "63"  => "Foreign-Host-Close-TCP",
                    "64"  => "TCP-Network-Unreachable",
                    "65"  => "TCP-Host-Unreachable",
                    "66"  => "TCP-Network-Admin-Unreachable",
                    "67"  => "TCP-Port-Unreachable",
                    "100" => "Session-Timeout",
                    "101" => "Session-Failed-Security",
                    "102" => "Session-End-Callback",
                    "120" => "Invalid-Protocol",
                    "150" => "RADIUS-Disconnect",
                    "151" => "Local-Admin-Disconnect",
                    "152" => "SNMP-Disconnect",
                    "160" => "V110-Retries",
                    "170" => "PPP-Authentication-Timeout",
                    "180" => "Local-Hangup",
                    "185" => "Remote-Hangup",
                    "190" => "T1-Quiesced",
                    "195" => "Call-Duration",
                    "600" => "VPN-User-Disconnect",
                    "601" => "VPN-Carrier-Loss",
                    "602" => "VPN-No-Resources",
                    "603" => "VPN-Bad-Control-Packet",
                    "604" => "VPN-Admin-Disconnect",
                    "605" => "VPN-Tunnel-Shut",
                    "606" => "VPN-Local-Disconnect",
                    "607" => "VPN-Session-Limit",
                    "608" => "VPN-Call-Redirect",
                },
            },
            11 => {
                3  => { "0" => "Permit-List", "1" => "Deny-List" },
                13 => { 1   => "Port-Based",  2   => "User-Based" },
                26 => { 5   => "HTTP",        6   => "HTTPS" },
            },
            43 => {
                1 => {
                    "0" => "3Com-Visitor",
                    "1" => "3Com-Monitor",
                    "2" => "3Com-Manager",
                    "3" => "3Com-Administrator",
                },
            },
            52 => {
                201 => {
                    1 => "IP-Enable",
                    2 => "Bridge-Enable",
                    3 => "IP-BR-Enable",
                    6 => "BR-IPX-Enable",
                    7 => "IP-BR-IPX-Enable",
                },
                202 => {
                    1 => "IP-Callable",
                    2 => "Bridge-Callable",
                    3 => "IP-BR-Callable",
                    6 => "BR-IPX-Callable",
                    7 => "IP-BR-IPX-Callable",
                },
            },
            64 => {
                1 => {
                    1 => "Disabled",
                    2 => "Called-Only",
                    3 => "Calling-Called",
                    4 => "Calling-Only",
                },
                2 => { 1 => "Disabled", 2 => "Enabled" },
                3 => {
                    1 => "Unrestricted-64K",
                    2 => "Digital-56K",
                    3 => "3100Hz-Audio"
                },
                6 => {
                    1 => "CHAP",
                    2 => "PAP",
                    3 => "PAP-Sending-on-Incoming-Calls"
                },
                7  => { 2 => "BCP",      3 => "IPCP" },
                8  => { 1 => "Disabled", 2 => "Enabled" },
                9  => { 1 => "Disabled", 2 => "Enabled" },
                10 => { 1 => "Disabled", 2 => "Enabled" },
                11 => { 1 => "Disabled", 2 => "Enabled" },
                12 => { 1 => "Disabled", 2 => "Enabled" },
                13 => { 1 => "Disabled", 2 => "Enabled" },
                23 => {
                    1 => "Forward",
                    2 => "Spoof",
                    3 => "Filter-all-outgoing-RIP-SAP"
                },
                24 => { 1 => "Disabled", 2 => "Enabled" },
                31 => { 1 => "Disabled", 2 => "Enabled" },
                32 => { 1 => "Disabled", 2 => "Enabled" },
                33 => { 1 => "Disabled", 2 => "Enabled" },
            },
            161 => {
                5  => { "0" => "Disable", "1" => "Enable" },
                14 => { "0" => "Disable", "1" => "Enable" },
                15 => { "0" => "All",     "1" => "Tagged", "2" => "Untagged" },
                23 => { "0" => "Disable", "1" => "Enable" },
                50 => { 1   => "TECH",    2   => "INSTALL", 3 => "ADMIN" },
            },
            166 => {
                30 => {
                    "0" => "None",
                    "1" => "Negotiate",
                    "2" => "Spider",
                    "3" => "Predictor",
                    "4" => "STAC",
                },
                61 => {
                    1 => "Primary",
                    2 => "Secondary-Backup",
                    3 => "Secondary-Augment",
                    4 => "Secondary-Switch",
                    5 => "Listener",
                    6 => "RADIUS",
                },
                93 => {
                    1 => "Analog",
                    2 => "Digitized-Analog",
                    3 => "Digital",
                    4 => "Digital-V110",
                    5 => "Digital-V120",
                    6 => "Digital-Leased-Line",
                },
                97 => {
                    1 => "HDLC",
                    2 => "ARAV1",
                    3 => "ARAV2",
                    4 => "SHELL",
                    5 => "AALAP",
                    6 => "SLIP"
                },
                100 => {
                    1  => "Remote",
                    2  => "Error",
                    3  => "Idle-Timeout",
                    4  => "Session-Timeout",
                    5  => "Admin-Disconnect",
                    6  => "Dialback",
                    7  => "Virtual-Connection",
                    8  => "Bandwidth-On-Demand",
                    9  => "Failed-Authentication",
                    10 => "Preempted",
                    11 => "Blocked",
                    12 => "Tariff-Management",
                    13 => "Backup",
                },
                103 => {
                    "0" => "Unknown",
                    "1" => "Dialin",
                    "2" => "Dialout",
                    "3" => "Lan-To-Lan"
                },
                104 => {
                    1 => "Remote",
                    2 => "Dialback",
                    3 => "Virtual-Connection",
                    4 => "Bandwidth-On-Demand",
                },
            },
            171 => {
                1 => {
                    1  => "User-Legacy",
                    3  => "User",
                    4  => "Operator",
                    5  => "Admin",
                    6  => "Power-User",
                    15 => "Admin-Legacy",
                },
            },
            307 => {
                9 => {
                    1 => "SA-Success-On",
                    2 => "SA-Failure-On",
                    3 => "Console-On",
                    4 => "Syslog-On",
                    5 => "SA-Success-Off",
                    6 => "SA-Failure-Off",
                    7 => "Console-Off",
                    8 => "Syslog-Off",
                },
                10 => { 1 => "Drop", 2 => "ICMP-Reject", 3 => "Pass-Through" },
                16 => {
                    1 => "Session-Success-On",
                    2 => "Session-Failure-On",
                    3 => "Console-On",
                    4 => "Syslog-On",
                    5 => "Success-Off",
                    6 => "Failure-Off",
                    7 => "Console-Off",
                    8 => "Syslog-Off",
                },
                17 => { 1 => "Drop", 2 => "ICMP-Reject", 3 => "Pass-Through" },
                23 => { 1 => "On" },
            },
            311 => {
                7 => { 1 => "Encryption-Allowed", 2 => "Encryption-Required" },
                8 => {
                    1 => "RC4-40bit-Allowed",
                    2 => "RC4-128bit-Allowed",
                    6 => "RC4-40or128-bit-Allowed",
                },
                13 =>
                  { "0" => "Not-Allowed", "1" => "Allowed", "2" => "Required" },
                21 => {
                    1 => "Just-Change-Password",
                    2 => "Expired-Password",
                    3 => "Admin-Requires-Password-Change",
                    4 => "Password-Too-Short",
                },
                23 => {
                    1 => "PAP",
                    2 => "CHAP",
                    3 => "MS-CHAP-1",
                    4 => "MS-CHAP-2",
                    5 => "EAP"
                },
                24 => {
                    4  => "MD5",
                    5  => "OTP",
                    6  => "Generic-Token-Card",
                    13 => "TLS"
                },
                41 => {
                    1 => "Machine-Health-Check",
                    2 => "Ignore-User-Lookup-Failure"
                },
                45 => {
                    "0" => "Full-Access",
                    "1" => "Quarantine",
                    "2" => "Probation"
                },
                47 => {
                    "0" => "Unspecified",
                    "1" => "Terminal-Server-Gateway",
                    "2" => "Remote-Access-Server",
                    "3" => "DHCP-Server",
                    "4" => "Wireless-Access-Point",
                    "5" => "HRA",
                    "6" => "HCAP-Server",
                },
                48 => {
                    1 => "MS-AFW-Zone-Boundary-Policy",
                    2 => "MS-AFW-Zone-Unprotected-Policy",
                    3 => "MS-AFW-Zone-Protected-Policy",
                },
                49 => {
                    1 => "HECP-Response-Sign-Only",
                    2 => "HECP-Response-Sign-And-Encrypt",
                },
                54 => { "0" => "SoH-Sent", "1" => "SoH-Not-Sent" },
                57 => {
                    1 => "Transition",
                    2 => "Infected",
                    3 => "Unknown",
                    4 => "No-Data"
                },
            },
            318 => {
                1 => {
                    1 => "Admin",
                    2 => "Device",
                    3 => "ReadOnly",
                    4 => "Outlet",
                    5 => "Card",
                    6 => "NetworkOnly",
                },
            },
            388 => {
                1 => {
                    1     => "Monitor",
                    2     => "Helpdesk",
                    4     => "NetworkAdmin",
                    8     => "SysAdmin",
                    16    => "WebAdmin",
                    32    => "Security",
                    32768 => "SuperUser",
                },
                5 => {
                    1 => "BestEffort",
                    2 => "Background",
                    3 => "Video",
                    4 => "Voice"
                },
                100 => {
                    16  => "HTTP",
                    32  => "SSH",
                    64  => "Telnet",
                    128 => "Console",
                    240 => "All"
                },
            },
            429 => {
                94 => {
                    1  => "110-BPS",
                    2  => "300-BPS",
                    3  => "600-BPS",
                    4  => "1200-BPS",
                    5  => "2400-BPS",
                    6  => "4800-BPS",
                    7  => "7200-BPS",
                    8  => "9600-BPS",
                    9  => "12K-BPS",
                    10 => "14.4K-BPS",
                    11 => "16.8-BPS",
                    12 => "19.2K-BPS",
                    13 => "38.4K-BPS",
                    14 => "75-BPS",
                    15 => "450-BPS",
                    16 => "UNKNOWN-BPS",
                    17 => "57.6K-BPS",
                    18 => "21.6K-BPS",
                    19 => "24K-BPS",
                    20 => "26K-BPS",
                    21 => "28K-BPS",
                    22 => "115K-BPS",
                },
                103 => { 1 => "Asynchronous", 2 => "Synchronous" },
                104 => {
                    1 => "Originate_in_Originate_Mode",
                    2 => "Originate_in_Answer_Mode",
                    3 => "Answer_in_Originate_Mode",
                    4 => "Answer_in_Answer_Mode",
                },
                105 => {
                    1  => "dtrDrop",
                    2  => "escapeSequence",
                    3  => "athCommand",
                    4  => "carrierLoss",
                    5  => "inactivityTimout",
                    6  => "mnpIncompatible",
                    7  => "undefined",
                    8  => "remotePassword",
                    9  => "linkPassword",
                    10 => "retransmitLimit",
                    11 => "linkDisconnectMsgRec",
                    12 => "noLoopCurrent",
                    13 => "invalidSpeed",
                    14 => "unableToRetrain",
                    15 => "managementCommand",
                    16 => "noDialTone",
                    17 => "keyAbort",
                    18 => "lineBusy",
                    19 => "noAnswer",
                    20 => "voice",
                    21 => "noAnswerTone",
                    22 => "noCarrier",
                    23 => "undetermined",
                    24 => "v42SabmeTimeout",
                    25 => "v42BreakTimeout",
                    26 => "v42DisconnectCmd",
                    27 => "v42IdExchangeFail",
                    28 => "v42BadSetup",
                    29 => "v42InvalidCodeWord",
                    30 => "v42StringToLong",
                    31 => "v42InvalidCommand",
                    32 => "none",
                    33 => "v32Cleardown",
                    34 => "dialSecurity",
                    35 => "remoteAccessDenied",
                    36 => "loopLoss",
                    37 => "ds0Teardown",
                    38 => "promptNotEnabled",
                    39 => "noPromptingInSync",
                    40 => "nonArqMode",
                    41 => "modeIncompatible",
                    42 => "noPromptInNonARQ",
                    43 => "dialBackLink",
                    44 => "linkAbort",
                    45 => "autopassFailed",
                    46 => "pbGenericError",
                    47 => "pbLinkErrTxPreAck",
                    48 => "pbLinkErrTxTardyACK",
                    49 => "pbTransmitBusTimeout",
                    50 => "pbReceiveBusTimeout",
                    51 => "pbLinkErrTxTAL",
                    52 => "pbLinkErrRxTAL",
                    53 => "pbTransmitMasterTimeout",
                    54 => "pbClockMissing",
                    55 => "pbReceivedLsWhileLinkUp",
                    56 => "pbOutOfSequenceFrame",
                    57 => "pbBadFrame",
                    58 => "pbAckWaitTimeout",
                    59 => "pbReceivedAckSeqErr",
                    60 => "pbReceiveOvrflwRNRFail",
                    61 => "pbReceiveMsgBufOvrflw",
                    62 => "rcvdGatewayDiscCmd",
                    63 => "tokenPassingTimeout",
                    64 => "dspInterruptTimeout",
                    65 => "mnpProtocolViolation",
                    66 => "class2FaxHangupCmd",
                    67 => "hstSpeedSwitchTimeout",
                    68 => "tooManyUnacked",
                    69 => "timerExpired",
                    70 => "t1Glare",
                    71 => "priDialoutRqTimeout",
                    72 => "abortAnlgDstOvrIsdn",
                    73 => "normalUserCallClear",
                    74 => "normalUnspecified",
                    75 => "bearerIncompatibility",
                    76 => "protocolErrorEvent",
                    77 => "abnormalDisconnect",
                    78 => "invalidCauseValue",
                    79 => "resourceUnavailable",
                    80 => "remoteHungUpDuringTraining",
                    81 => "trainingTimeout",
                    82 => "incomingModemNotAvailable",
                    83 => "incomingInvalidBearerCap",
                    84 => "incomingInvalidChannelID",
                    85 => "incomingInvalidProgInd",
                    86 => "incomingInvalidCallingPty",
                    87 => "incomingInvalidCalledPty",
                    88 => "incomingCallBlock",
                    89 => "incomingLoopStNoRingOff",
                    90 => "outgoingTelcoDisconnect",
                    91 => "outgoingEMWinkTimeout",
                    92 => "outgoingEMWinkTooShort",
                    93 => "outgoingNoChannelAvail",
                    94 => "dspReboot",
                    95 => "noDSPRespToKA",
                    96 => "noDSPRespToDisc",
                    97 => "dspTailPtrInvalid",
                    98 => "dspHeadPtrInvalid",
                },
                106 => {
                    1  => "110-BPS",
                    2  => "300-BPS",
                    3  => "600-BPS",
                    4  => "1200-BPS",
                    5  => "2400-BPS",
                    6  => "4800-BPS",
                    7  => "7200-BPS",
                    8  => "9600-BPS",
                    9  => "12000-BPS",
                    10 => "14400-BPS",
                    11 => "16800-BPS",
                    12 => "19200-BPS",
                    13 => "38400-BPS",
                    14 => "75-BPS",
                    15 => "450-BPS",
                    16 => "UNKNOWN-BPS",
                    17 => "57600-BPS",
                    18 => "21600-BPS",
                    19 => "24000-BPS",
                    20 => "26400-BPS",
                    21 => "28800-BPS",
                    22 => "115200-BPS",
                    23 => "31200-BPS",
                    24 => "33600-BPS",
                    25 => "25333-BPS",
                    26 => "26666-BPS",
                    27 => "28000-BPS",
                    28 => "29333-BPS",
                    29 => "30666-BPS",
                    30 => "32000-BPS",
                    31 => "33333-BPS",
                    32 => "34666-BPS",
                    33 => "36000-BPS",
                    34 => "37333-BPS",
                    35 => "38666-BPS",
                    36 => "40000-BPS",
                    37 => "41333-BPS",
                    38 => "42666-BPS",
                    39 => "44000-BPS",
                    40 => "45333-BPS",
                    41 => "46666-BPS",
                    42 => "48000-BPS",
                    43 => "49333-BPS",
                    44 => "50666-BPS",
                    45 => "52000-BPS",
                    46 => "53333-BPS",
                    47 => "54666-BPS",
                    48 => "56000-BPS",
                    49 => "57333-BPS",
                    50 => "58666-BPS",
                    51 => "60000-BPS",
                    52 => "61333-BPS",
                    53 => "62666-BPS",
                    54 => "64000-BPS",
                },
                107 => {
                    1  => "110-BPS",
                    2  => "300-BPS",
                    3  => "600-BPS",
                    4  => "1200-BPS",
                    5  => "2400-BPS",
                    6  => "4800-BPS",
                    7  => "7200-BPS",
                    8  => "9600-BPS",
                    9  => "12000-BPS",
                    10 => "14400-BPS",
                    11 => "16800-BPS",
                    12 => "19200-BPS",
                    13 => "38400-BPS",
                    14 => "75-BPS",
                    15 => "450-BPS",
                    16 => "UNKNOWN-BPS",
                    17 => "57600-BPS",
                    18 => "21600-BPS",
                    19 => "24000-BPS",
                    20 => "26400-BPS",
                    21 => "28800-BPS",
                    22 => "115200-BPS",
                    23 => "31200-BPS",
                    24 => "33600-BPS",
                    25 => "25333-BPS",
                    26 => "26666-BPS",
                    27 => "28000-BPS",
                    28 => "29333-BPS",
                    29 => "30666-BPS",
                    30 => "32000-BPS",
                    31 => "33333-BPS",
                    32 => "34666-BPS",
                    33 => "36000-BPS",
                    34 => "37333-BPS",
                    35 => "38666-BPS",
                    36 => "40000-BPS",
                    37 => "41333-BPS",
                    38 => "42666-BPS",
                    39 => "44000-BPS",
                    40 => "45333-BPS",
                    41 => "46666-BPS",
                    42 => "48000-BPS",
                    43 => "49333-BPS",
                    44 => "50666-BPS",
                    45 => "52000-BPS",
                    46 => "53333-BPS",
                    47 => "54666-BPS",
                    48 => "56000-BPS",
                    49 => "57333-BPS",
                    50 => "58666-BPS",
                    51 => "60000-BPS",
                    52 => "61333-BPS",
                    53 => "62666-BPS",
                    54 => "64000-BPS",
                },
                108 => {
                    1  => "usRoboticsHST",
                    2  => "ccittV32",
                    3  => "ccittV22bis",
                    4  => "bell103",
                    5  => "ccittV21",
                    6  => "bell212",
                    7  => "ccittV32bis",
                    8  => "ccittV23",
                    9  => "negotiationFailed",
                    10 => "bell208b",
                    11 => "v21FaxClass1",
                    12 => "v27FaxClass1",
                    13 => "v29FaxClass1",
                    14 => "v17FaxClass1",
                    15 => "v21FaxClass2",
                    16 => "v27FaxClass2",
                    17 => "v29FaxClass2",
                    18 => "v17FaxClass2",
                    19 => "v32Terbo",
                    20 => "v34",
                    21 => "vFC",
                    22 => "v34plus",
                    23 => "x2",
                    24 => "v110",
                    25 => "v120",
                    26 => "x75",
                    27 => "asyncSyncPPP",
                    28 => "clearChannel",
                    29 => "x2client",
                    30 => "x2symmetric",
                    31 => "piafs",
                    32 => "x2version2",
                    33 => "v90Analog",
                    34 => "v90Digital",
                    35 => "v90AllDigital",
                },
                111 => { 1 => "Long",     2 => "Short" },
                112 => { 1 => "Disabled", 2 => "Enabled" },
                124 => { 1 => "450BPS",   2 => "300BPS", 3 => "None" },
                153 => {
                    1  => "none",
                    2  => "mnpLevel3",
                    3  => "mnpLevel4",
                    4  => "ccittV42",
                    5  => "usRoboticsHST",
                    6  => "synchronousNone",
                    7  => "mnpLevel2",
                    8  => "mnp10",
                    9  => "v42Etc",
                    10 => "mnp10Etc",
                    11 => "lapmEtc",
                    12 => "v42Etc2",
                    13 => "v42SRej",
                    14 => "piafs",
                },
                155 => {
                    1  => "dtrDrop",
                    2  => "escapeSequence",
                    3  => "athCommand",
                    4  => "carrierLoss",
                    5  => "inactivityTimout",
                    6  => "mnpIncompatible",
                    7  => "undefined",
                    8  => "remotePassword",
                    9  => "linkPassword",
                    10 => "retransmitLimit",
                    11 => "linkDisconnectMsgReceived",
                    12 => "noLoopCurrent",
                    13 => "invalidSpeed",
                    14 => "unableToRetrain",
                    15 => "managementCommand",
                    16 => "noDialTone",
                    17 => "keyAbort",
                    18 => "lineBusy",
                    19 => "noAnswer",
                    20 => "voice",
                    21 => "noAnswerTone",
                    22 => "noCarrier",
                    23 => "undetermined",
                    24 => "v42SabmeTimeout",
                    25 => "v42BreakTimeout",
                    26 => "v42DisconnectCmd",
                    27 => "v42IdExchangeFail",
                    28 => "v42BadSetup",
                    29 => "v42InvalidCodeWord",
                    30 => "v42StringToLong",
                    31 => "v42InvalidCommand",
                    32 => "none",
                    33 => "v32Cleardown",
                    34 => "dialSecurity",
                    35 => "remoteAccessDenied",
                    36 => "loopLoss",
                    37 => "ds0Teardown",
                    38 => "promptNotEnabled",
                    39 => "noPromptingInSync",
                    40 => "nonArqMode",
                    41 => "modeIncompatible",
                    42 => "noPromptInNonARQ",
                    43 => "dialBackLink",
                    44 => "linkAbort",
                    45 => "autopassFailed",
                    46 => "pbGenericError",
                    47 => "pbLinkErrTxPreAck",
                    48 => "pbLinkErrTxTardyACK",
                    49 => "pbTransmitBusTimeout",
                    50 => "pbReceiveBusTimeout",
                    51 => "pbLinkErrTxTAL",
                    52 => "pbLinkErrRxTAL",
                    53 => "pbTransmitMasterTimeout",
                    54 => "pbClockMissing",
                    55 => "pbReceivedLsWhileLinkUp",
                    56 => "pbOutOfSequenceFrame",
                    57 => "pbBadFrame",
                    58 => "pbAckWaitTimeout",
                    59 => "pbReceivedAckSeqErr",
                    60 => "pbReceiveOvrflwRNRFail",
                    61 => "pbReceiveMsgBufOvrflw",
                    62 => "rcvdGatewayDiscCmd",
                    63 => "tokenPassingTimeout",
                    64 => "dspInterruptTimeout",
                    65 => "mnpProtocolViolation",
                    66 => "class2FaxHangupCmd",
                    67 => "hstSpeedSwitchTimeout",
                    68 => "tooManyUnacked",
                    69 => "timerExpired",
                    70 => "t1Glare",
                    71 => "priDialoutRqTimeout",
                    72 => "abortAnlgDstOvrIsdn",
                    73 => "normalUserCallClear",
                    74 => "normalUnspecified",
                    75 => "bearerIncompatibility",
                    76 => "protocolErrorEvent",
                    77 => "abnormalDisconnect",
                    78 => "invalidCauseValue",
                    79 => "resourceUnavailable",
                    80 => "remoteHungUpDuringTraining",
                    81 => "trainingTimeout",
                    82 => "incomingModemNotAvailable",
                    83 => "incomingInvalidBearerCap",
                    84 => "incomingInvalidChannelID",
                    85 => "incomingInvalidProgInd",
                    86 => "incomingInvalidCallingPty",
                    87 => "incomingInvalidCalledPty",
                    88 => "incomingCallBlock",
                    89 => "incomingLoopStNoRingOff",
                    90 => "outgoingTelcoDisconnect",
                    91 => "outgoingEMWinkTimeout",
                    92 => "outgoingEMWinkTooShort",
                    93 => "outgoingNoChannelAvail",
                    94 => "dspReboot",
                    95 => "noDSPRespToKA",
                    96 => "noDSPRespToDisc",
                    97 => "dspTailPtrInvalid",
                    98 => "dspHeadPtrInvalid",
                },
                199 => { 1 => "none", 2 => "ccittV42bis", 3 => "mnpLevel5" },
                461 => {
                    1 => "notEnabledInLocalModem",
                    2 => "notDetectedInRemoteModem",
                    3 => "ok",
                },
                2305 => {
                    1 => "none",
                    2 => "initialConnection",
                    3 => "retrain",
                    4 => "speedShift",
                    5 => "plannedDisconnect",
                },
                2313 => {
                    1  => "notOperational",
                    2  => "operational",
                    3  => "x2Disabled",
                    4  => "v8Disabled",
                    5  => "remote3200Disabled",
                    6  => "invalidSpeedSetting",
                    7  => "v8NotDetected",
                    8  => "x2NotDetected",
                    9  => "incompatibleVersion",
                    10 => "incompatibleModes",
                    11 => "local3200Disabled",
                    12 => "excessHighFrequencyAtten",
                    13 => "connectNotSupport3200",
                    14 => "retrainBeforeConnection",
                },
                2314 => {
                    1  => "none",
                    2  => "dteNotReady",
                    3  => "dteInterfaceError",
                    4  => "dteRequest",
                    5  => "escapeToOnlineCommandMode",
                    6  => "athCommand",
                    7  => "inactivityTimeout",
                    8  => "arqProtocolError",
                    9  => "arqProtocolRetransmitLim",
                    10 => "invalidComprDataCodeword",
                    11 => "invalidComprDataStringLen",
                    12 => "invalidComprDataCommand",
                },
                2339 => {
                    1  => "usRoboticsHST",
                    2  => "ccittV32",
                    3  => "ccittV22bis",
                    4  => "bell103",
                    5  => "ccittV21",
                    6  => "bell212",
                    7  => "ccittV32bis",
                    8  => "ccittV23",
                    9  => "negotiationFailed",
                    10 => "bell208b",
                    11 => "v21FaxClass1",
                    12 => "v27FaxClass1",
                    13 => "v29FaxClass1",
                    14 => "v17FaxClass1",
                    15 => "v21FaxClass2",
                    16 => "v27FaxClass2",
                    17 => "v29FaxClass2",
                    18 => "v17FaxClass2",
                    19 => "v32Terbo",
                    20 => "v34",
                    21 => "vFC",
                    22 => "v34plus",
                    23 => "x2",
                    24 => "v110",
                    25 => "v120",
                    26 => "x75",
                    27 => "asyncSyncPPP",
                    28 => "clearChannel",
                    29 => "x2client",
                    30 => "x2symmetric",
                    31 => "piafs",
                    32 => "x2version2",
                    33 => "v90Analogue",
                    34 => "v90Digital",
                    35 => "v90AllDigital",
                },
                32770 => {
                    "0" => "COMS-UNKNOWN-ACCT-TYPE",
                    "1" => "COMS-PREPAID-ACCT",
                    "2" => "COMS-NEW-ACCT",
                    "3" => "COMS-SUSPENDED-ACCT",
                    "4" => "COMS-ADMINISTRATIVE-ACCT",
                },
                32774 => {
                    "0"   => "COMS-UNKNOWN-SOURCE",
                    "257" => "COMS-INGRESS-OPEN",
                    "258" => "COMS-EGRESS-OPEN",
                    "259" => "COMS-GTKPR-GEN-INGR-OPEN",
                    "260" => "COMS-GTKPR-GEN-EGR-OPEN",
                    "513" => "COMS-INGRESS-CLOSE",
                    "514" => "COMS-EGRESS-CLOSE",
                    "515" => "COMS-GTKPR-GEN-INGR-CLOSE",
                    "516" => "COMS-GTKPR-GEN-EGR-CLOSE",
                },
                32778 => { "0" => "NOT-THE-LAST-CALL", "1" => "LAST-CALL" },
                32780 => {
                    1 => "comsUnknown",
                    2 => "comsInternationalNumber",
                    3 => "comsNationalNumber",
                    4 => "comsNetworkSpecificNumber",
                    5 => "comsSubscriberNumber",
                    6 => "comsAbbreviatedNumber",
                    7 => "comsReserved",
                },
                32782 => { 1 => "TCP", 2 => "UDP", 3 => "SCTP" },
                32786 => {
                    1 => "comsUnknown",
                    2 => "comsInternationalNumber",
                    3 => "comsNationalNumber",
                    4 => "comsNetworkSpecificNumber",
                    5 => "comsSubscriberNumber",
                    6 => "comsAbbreviatedNumber",
                    7 => "comsReserved",
                },
                32788 => { 1 => "TCP", 2 => "UDP", 3 => "SCTP" },
                32794 => {
                    1 => "comsUnknown",
                    2 => "comsInternationalNumber",
                    3 => "comsNationalNumber",
                    4 => "comsNetworkSpecificNumber",
                    5 => "comsSubscriberNumber",
                    6 => "comsAbbreviatedNumber",
                    7 => "comsReserved",
                },
                32796 => { 1 => "TCP", 2 => "UDP", 3 => "SCTP" },
                32800 => { 1 => "TCP", 2 => "UDP", 3 => "SCTP" },
                32804 => { 1 => "TCP", 2 => "UDP", 3 => "SCTP" },
                32808 => { 1 => "TCP", 2 => "UDP", 3 => "SCTP" },
                32813 => {
                    "0" => "COMS-UNKNOWN-CALLTYPE",
                    "1" => "COMS-PHONE-TO-PHONE",
                    "2" => "COMS-PHONE-TO-PC",
                    "3" => "COMS-PC-TO-PHONE",
                    "4" => "COMS-PC-TO-PC",
                },
                32821 => {
                    "0"   => "COMS-UNDEFINED-CODEC",
                    "1"   => "COMS-G723-1",
                    "2"   => "COMS-G729-A",
                    "3"   => "COMS-G710-ALaw",
                    "4"   => "COMS-G711-MuLaw",
                    "255" => "COMS-FAX-MODULATION",
                },
                32822 => {
                    "0"  => "CAUSE-UNKNOWN",
                    "1"  => "CAUSE-CLD-PARTY-TERMINATE",
                    "2"  => "CAUSE-CLG-PARTY-TERMINATE",
                    "3"  => "CAUSE-ACCT-BAL-DEPLETED",
                    "4"  => "CAUSE-NO-EGR-PORTS-AVAIL",
                    "5"  => "CAUSE-H225-UNABLE-TO-CON",
                    "6"  => "CAUSE-H245-UNABLE-TO-CON",
                    "7"  => "CAUSE-INGR-FACILITY-DISC",
                    "8"  => "CAUSE-EGR-FACILITY-DISC",
                    "9"  => "CAUSE-DIR-SERVER-DOWN",
                    "10" => "CAUSE-RATING-SERVER-DOWN",
                    "11" => "CAUSE-GATEWAY-SHUTDOWN",
                    "12" => "CAUSE-GTKPR-TERMINATE",
                    "13" => "CAUSE-GTKPR-SHUTDOWN-GTWAY",
                    "14" => "CAUSE-BUSY",
                    "15" => "CAUSE-ABANDON",
                    "16" => "CAUSE-INVALID-LOGIN-LIMIT",
                    "17" => "CAUSE-NOACCTNUMBER-ENTRY",
                    "18" => "CAUSE-SUSPENDED-ACCT-LOGIN",
                    "19" => "CAUSE-AUTHENT-SERVER-DOWN",
                    "20" => "CAUSE-GATEKEEPER-TIMEOUT",
                    "21" => "CAUSE-GATEWAY-NO-RESOURCES",
                    "22" => "CAUSE-ACCT-INUSE",
                    "23" => "CAUSE-DEBIT-ACCT-BAL-ZERO",
                    "24" => "CAUSE-DEBIT-ACCTBAL-INSUFF",
                    "25" => "CAUSE-INVALID-DESTNUMBER-THRESH",
                    "26" => "CAUSE-NO-DESTNUMBER-ENTRY",
                    "27" => "CAUSE-SEQUENCE-DIALING-THRESH",
                },
                32845 =>
                  { "0" => "SIG-UNKNOWN", "1" => "SIG-SIP", "2" => "SIG-H323" },
                32846 => { 1 => "TCP", 2 => "UDP", 3 => "SCTP" },
                32847 => { 1 => "TCP", 2 => "UDP", 3 => "SCTP" },
                32851 => { 1 => "TCP", 2 => "UDP", 3 => "SCTP" },
                32855 => { 1 => "TCP", 2 => "UDP", 3 => "SCTP" },
                32859 => { 1 => "TCP", 2 => "UDP", 3 => "SCTP" },
                32865 => {
                    1 => "Unknown",
                    2 => "International-Number",
                    3 => "National-Number",
                    4 => "Network-Specific-Number",
                    5 => "Subscriber-Number",
                    6 => "Abbreviated-Number",
                    7 => "Reserved",
                },
                36883 => {
                    "0"          => "Off",
                    "1"          => "On-Raw",
                    "2"          => "On-Framed",
                    "4294967295" => "Unknown",
                },
                36897 => { 1 => "NONE", 2 => "Stac", 3 => "MS", 4 => "Any" },
                36899 => {
                    1  => "NONE",
                    2  => "300-BPS",
                    3  => "1200-BPS",
                    4  => "2400-BPS",
                    5  => "4800-BPS",
                    6  => "7200-BPS",
                    7  => "9600-BPS",
                    8  => "12000-BPS",
                    9  => "14400-BPS",
                    10 => "16800-BPS",
                    11 => "19200-BPS",
                    12 => "21600-BPS",
                    13 => "28800-BPS",
                    14 => "38400-BPS",
                    15 => "57600-BPS",
                    16 => "115200-BPS",
                    17 => "288000-BPS",
                    18 => "75-1200-BPS",
                    19 => "1200-75-BPS",
                    20 => "24000-BPS",
                    21 => "26400-BPS",
                    22 => "31200-BPS",
                    23 => "33600-BPS",
                    24 => "33333-BPS",
                    25 => "37333-BPS",
                    26 => "41333-BPS",
                    27 => "42666-BPS",
                    28 => "44000-BPS",
                    29 => "45333-BPS",
                    30 => "46666-BPS",
                    31 => "48000-BPS",
                    32 => "49333-BPS",
                    33 => "50666-BPS",
                    34 => "52000-BPS",
                    35 => "53333-BPS",
                    36 => "54666-BPS",
                    37 => "56000-BPS",
                    38 => "57333-BPS",
                    39 => "64000-BPS",
                    40 => "25333-BPS",
                    41 => "26666-BPS",
                    42 => "28000-BPS",
                    43 => "29333-BPS",
                    44 => "30666-BPS",
                    45 => "32000-BPS",
                    46 => "34666-BPS",
                    47 => "36000-BPS",
                    48 => "38666-BPS",
                    49 => "40000-BPS",
                    50 => "58666-BPS",
                    51 => "60000-BPS",
                    52 => "61333-BPS",
                    53 => "62666-BPS",
                },
                38913 =>
                  { "0" => "Auto", "1" => 56, "2" => 64, "3" => "Voice" },
                38917 => { 1 => "Constant", 2 => "Linear" },
                38918 => {
                    "0" => "None",
                    "1" => "Stac",
                    "2" => "Ascend",
                    "3" => "Microsoft",
                    "4" => "Auto",
                },
                38922 => {
                    "0" => "Auto",
                    "1" => "Reset-Every-Packet",
                    "2" => "Reset-On-Error"
                },
                38926 => { 1 => "enabled", 2 => "disabled" },
                38927 => { 1 => "enabled", 2 => "disabled" },
                38928 => { 1 => "enabled", 2 => "disabled" },
                38929 => { 1 => "enabled", 2 => "disabled" },
                38950 => { 1 => "Rip1",    2 => "Rip2" },
                38952 => {
                    "0" => "none",
                    "1" => "send",
                    "2" => "listen",
                    "3" => "respond",
                    "4" => "all"
                },
                38953 => { 1 => "enabled", 2 => "disabled" },
                38954 => {
                    "0"          => "SendDefault",
                    "2"          => "SendRoutes",
                    "4"          => "SendSubnets",
                    "8"          => "AcceptDefault",
                    "16"         => "SplitHorizon",
                    "32"         => "PoisonReserve",
                    "64"         => "FlashUpdate",
                    "128"        => "SimpleAuth",
                    "256"        => "V1Send",
                    "512"        => "V1Receive",
                    "1024"       => "V2Receive",
                    "2147483648" => "Silent",
                },
                38976 => { 1 => "enabled", 2 => "disabled" },
                38980 => {
                    "0" => "None",
                    "1" => "Control-Only",
                    "2" => "Data-Only",
                    "3" => "Both-Data-and-Control",
                },
                39018 =>
                  { 1 => "Normal", 2 => "ANI", 3 => "Static", 4 => "Dynamic" },
                39030 => { 1 => "FA", 2 => "HA" },
                39051 => {
                    "0"  => "No-Error",
                    "1"  => "No-Carrier",
                    "2"  => "No-DSR",
                    "3"  => "Timeout",
                    "4"  => "Reset",
                    "5"  => "Call-Drop-Req",
                    "6"  => "Idle-Timeout",
                    "7"  => "Session-Timeout",
                    "8"  => "User-Req-Drop",
                    "9"  => "Host-Req-Drop",
                    "10" => "Service-Interruption",
                    "11" => "Service-Unavailable",
                    "12" => "User-Input-Error",
                    "13" => "NAS-Drop-For-Callback",
                    "14" => "NAS-Drop-Misc-Non-Error",
                    "15" => "NAS-Internal-Error",
                    "16" => "Line-Busy",
                    "19" => "Tunnel-Term-Unreach",
                    "20" => "Tunnel-Refused",
                    "21" => "Tunnel-Auth-Failed",
                    "22" => "Tunnel-Session-Timeout",
                    "23" => "Tunnel-Timeout",
                    "25" => "Radius-Res-Reclaim",
                    "26" => "DNIS-Auth-Failed",
                    "27" => "PAP-Auth-Failure",
                    "28" => "CHAP-Auth-Failure",
                    "29" => "PPP-LCP-Failed",
                    "30" => "PPP-NCP-Failed",
                    "31" => "Radius-Timeout",
                },
                48735 => { 1 => "None", 2 => "isdnGateway", 3 => "quadModem" },
                48738 => {
                    1  => "notSupported",
                    2  => "setup",
                    3  => "usrSetup",
                    4  => "telcoDisconnect",
                    5  => "usrDisconnect",
                    6  => "noFreeModem",
                    7  => "modemsNotAllowed",
                    8  => "modemsRejectCall",
                    9  => "modemSetupTimeout",
                    10 => "noFreeIGW",
                    11 => "igwRejectCall",
                    12 => "igwSetupTimeout",
                    13 => "noFreeTdmts",
                    14 => "bcReject",
                    15 => "ieReject",
                    16 => "chidReject",
                    17 => "progReject",
                    18 => "callingPartyReject",
                    19 => "calledPartyReject",
                    20 => "blocked",
                    21 => "analogBlocked",
                    22 => "digitalBlocked",
                    23 => "outOfService",
                    24 => "busy",
                    25 => "congestion",
                    26 => "protocolError",
                    27 => "noFreeBchannel",
                    28 => "inOutCallCollision",
                    29 => "inCallArrival",
                    30 => "outCallArrival",
                    31 => "inCallConnect",
                    32 => "outCallConnect",
                },
                48773 => {
                    1    => "SlotEmpty",
                    2    => "SlotUnknown",
                    3    => "NetwMgtCard",
                    4    => "DualT1NAC",
                    5    => "DualModemNAC",
                    6    => "QuadModemNAC",
                    7    => "TrGatewayNAC",
                    8    => "X25GatewayNAC",
                    9    => "DualV34ModemNAC",
                    10   => "QuadV32DigitalModemNAC",
                    11   => "QuadV32AnalogModemNAC",
                    12   => "QuadV32DigAnlModemNAC",
                    13   => "QuadV34DigModemNAC",
                    14   => "QuadV34AnlModemNAC",
                    15   => "QuadV34DigAnlModemNAC",
                    16   => "SingleT1NAC",
                    17   => "EthernetGatewayNAC",
                    18   => "AccessServer",
                    19   => "486TrGatewayNAC",
                    20   => "486EthernetGatewayNAC",
                    22   => "DualRS232NAC",
                    23   => "486X25GatewayNAC",
                    25   => "ApplicationServerNAC",
                    26   => "ISDNGatewayNAC",
                    27   => "ISDNpriT1NAC",
                    28   => "ClkedNetMgtCard",
                    29   => "ModemPoolManagementNAC",
                    30   => "ModemPoolNetserverNAC",
                    31   => "ModemPoolV34ModemNAC",
                    32   => "ModemPoolISDNNAC",
                    33   => "NTServerNAC",
                    34   => "QuadV34DigitalG2NAC",
                    35   => "QuadV34AnalogG2NAC",
                    36   => "QuadV34DigAnlgG2NAC",
                    37   => "NETServerFrameRelayNAC",
                    38   => "NETServerTokenRingNAC",
                    39   => "X2524ChannelNAC",
                    42   => "WirelessGatewayNac",
                    44   => "EnhancedAccessServer",
                    45   => "EnhancedISDNGatewayNAC",
                    1001 => "DualT1NIC",
                    1002 => "DualAlogMdmNIC",
                    1003 => "QuadDgtlMdmNIC",
                    1004 => "QuadAlogDgtlMdmNIC",
                    1005 => "TokenRingNIC",
                    1006 => "SingleT1NIC",
                    1007 => "EthernetNIC",
                    1008 => "ShortHaulDualT1NIC",
                    1009 => "DualAlogMgdIntlMdmNIC",
                    1010 => "X25NIC",
                    1011 => "QuadAlogNonMgdMdmNIC",
                    1012 => "QuadAlogMgdIntlMdmNIC",
                    1013 => "QuadAlogNonMgdIntlMdmNIC",
                    1014 => "QuadLsdLiMgdMdmNIC",
                    1015 => "QuadLsdLiNonMgdMdmNIC",
                    1016 => "QuadLsdLiMgdIntlMdmNIC",
                    1017 => "QuadLsdLiNonMgdIntlMdmNIC",
                    1018 => "HSEthernetWithV35NIC",
                    1019 => "HSEthernetWithoutV35NIC",
                    1020 => "DualHighSpeedV35NIC",
                    1021 => "QuadV35RS232LowSpeedNIC",
                    1022 => "DualE1NIC",
                    1023 => "ShortHaulDualE1NIC",
                    1025 => "BellcoreLongHaulDualT1NIC",
                    1026 => "BellcoreShrtHaulDualT1NIC",
                    1027 => "SCSIEdgeServerNIC",
                },
                48940 => {
                    1  => "110-BPS",
                    2  => "300-BPS",
                    3  => "600-BPS",
                    4  => "1200-BPS",
                    5  => "2400-BPS",
                    6  => "4800-BPS",
                    7  => "7200-BPS",
                    8  => "9600-BPS",
                    9  => "12000-BPS",
                    10 => "14400-BPS",
                    11 => "16800-BPS",
                    12 => "19200-BPS",
                    13 => "38400-BPS",
                    14 => "75-BPS",
                    15 => "450-BPS",
                    16 => "UNKNOWN-BPS",
                    17 => "57600-BPS",
                    18 => "21600-BPS",
                    19 => "24000-BPS",
                    20 => "26400-BPS",
                    21 => "28800-BPS",
                    22 => "115200-BPS",
                    23 => "31200-BPS",
                    24 => "33600-BPS",
                    25 => "25333-BPS",
                    26 => "26666-BPS",
                    27 => "28000-BPS",
                    28 => "29333-BPS",
                    29 => "30666-BPS",
                    30 => "32000-BPS",
                    31 => "33333-BPS",
                    32 => "34666-BPS",
                    33 => "36000-BPS",
                    34 => "37333-BPS",
                    35 => "38666-BPS",
                    36 => "40000-BPS",
                    37 => "41333-BPS",
                    38 => "42666-BPS",
                    39 => "44000-BPS",
                    40 => "45333-BPS",
                    41 => "46666-BPS",
                    42 => "48000-BPS",
                    43 => "49333-BPS",
                    44 => "50666-BPS",
                    45 => "52000-BPS",
                    46 => "53333-BPS",
                    47 => "54666-BPS",
                    48 => "56000-BPS",
                    49 => "57333-BPS",
                    50 => "58666-BPS",
                    51 => "60000-BPS",
                    52 => "61333-BPS",
                    53 => "62666-BPS",
                    54 => "64000-BPS",
                },
                48941 => {
                    1  => "110-BPS",
                    2  => "300-BPS",
                    3  => "600-BPS",
                    4  => "1200-BPS",
                    5  => "2400-BPS",
                    6  => "4800-BPS",
                    7  => "7200-BPS",
                    8  => "9600-BPS",
                    9  => "12000-BPS",
                    10 => "14400-BPS",
                    11 => "16800-BPS",
                    12 => "19200-BPS",
                    13 => "38400-BPS",
                    14 => "75-BPS",
                    15 => "450-BPS",
                    16 => "UNKNOWN-BPS",
                    17 => "57600-BPS",
                    18 => "21600-BPS",
                    19 => "24000-BPS",
                    20 => "26400-BPS",
                    21 => "28800-BPS",
                    22 => "115200-BPS",
                    23 => "31200-BPS",
                    24 => "33600-BPS",
                    25 => "25333-BPS",
                    26 => "26666-BPS",
                    27 => "28000-BPS",
                    28 => "29333-BPS",
                    29 => "30666-BPS",
                    30 => "32000-BPS",
                    31 => "33333-BPS",
                    32 => "34666-BPS",
                    33 => "36000-BPS",
                    34 => "37333-BPS",
                    35 => "38666-BPS",
                    36 => "40000-BPS",
                    37 => "41333-BPS",
                    38 => "42666-BPS",
                    39 => "44000-BPS",
                    40 => "45333-BPS",
                    41 => "46666-BPS",
                    42 => "48000-BPS",
                    43 => "49333-BPS",
                    44 => "50666-BPS",
                    45 => "52000-BPS",
                    46 => "53333-BPS",
                    47 => "54666-BPS",
                    48 => "56000-BPS",
                    49 => "57333-BPS",
                    50 => "58666-BPS",
                    51 => "60000-BPS",
                    52 => "61333-BPS",
                    53 => "62666-BPS",
                    54 => "64000-BPS",
                },
                49086 => {
                    6   => "Module-Inserted",
                    7   => "Module-Removed",
                    8   => "PSU-Voltage-Alarm",
                    9   => "PSU-Failed",
                    10  => "HUB-Temp-Out-of-Range",
                    11  => "Fan-Failed",
                    12  => "Watchdog-Timeout",
                    13  => "Mgmt-Bus-Failure",
                    14  => "In-Connection-Est",
                    15  => "Out-Connection-Est",
                    16  => "In-Connection-Term",
                    17  => "Out-Connection-Term",
                    18  => "Connection-Failed",
                    19  => "Connection-Timeout",
                    20  => "DTE-Transmit-Idle",
                    21  => "DTR-True",
                    22  => "DTR-False",
                    23  => "Block-Error-at-Threshold",
                    24  => "Fallbacks-at-Threshold",
                    25  => "No-Dial-Tone-Detected",
                    26  => "No-Loop-Current-Detected",
                    27  => "Yellow-Alarm",
                    28  => "Red-Alarm",
                    29  => "Loss-Of-Signal",
                    30  => "Rcv-Alrm-Ind-Signal",
                    31  => "Timing-Source-Switch",
                    32  => "Modem-Reset-by-DTE",
                    33  => "Modem-Ring-No-Answer",
                    34  => "DTE-Ring-No-Answer",
                    35  => "Pkt-Bus-Session-Active",
                    36  => "Pkt-Bus-Session-Congestion",
                    37  => "Pkt-Bus-Session-Lost",
                    38  => "Pkt-Bus-Session-Inactive",
                    39  => "User-Interface-Reset",
                    40  => "Gateway-Port-Out-of-Service",
                    41  => "Gateway-Port-Link-Active",
                    42  => "Dial-Out-Login-Failure",
                    43  => "Dial-In-Login-Failure",
                    44  => "Dial-Out-Restricted-Number",
                    45  => "Dial-Back-Restricted-Number",
                    46  => "User-Blacklisted",
                    47  => "Attempted-Login-Blacklisted",
                    48  => "Response-Attempt-Limit-Exceeded",
                    49  => "Login-Attempt-Limit-Exceeded",
                    50  => "Dial-Out-Call-Duration",
                    51  => "Dial-In-Call-Duration",
                    52  => "Pkt-Bus-Session-Err-Status",
                    53  => "NMC-AutoRespnse-Trap",
                    54  => "Acct-Server-Contact-Loss",
                    55  => "Yellow-Alarm-Clear",
                    56  => "Red-Alarm-Clear",
                    57  => "Loss-Of-Signal-Clear",
                    58  => "Rcv-Alrm-Ind-Signal-Clear",
                    59  => "Incoming-Connection-Established",
                    60  => "Outgoing-Connection-Established",
                    61  => "Incoming-Connection-Terminated",
                    62  => "Outgoing-Connection-Terminated",
                    63  => "Connection-Attempt-Failure",
                    64  => "Continuous-CRC-Alarm",
                    65  => "Continuous-CRC-Alarm-Clear",
                    66  => "Physical-State-Change",
                    71  => "Gateway-Network-Failed",
                    72  => "Gateway-Network-Restored",
                    73  => "Packet-Bus-Clock-Lost",
                    74  => "Packet-Bus-Clock-Restored",
                    75  => "D-Channel-In-Service",
                    76  => "D-Channel-Out-of-Service",
                    77  => "DS0s-In-Service",
                    78  => "DS0s-Out-of-Service",
                    79  => "T1/T1PRI/E1PRI-Call-Event",
                    80  => "Psu-Incompatible",
                    81  => "T1,T1-E1/PRI-Call-Arrive-Event",
                    82  => "T1,T1-E1/PRI-Call-Connect-Event",
                    83  => "T1,T1-E1/PRI-Call-Termina-Event",
                    84  => "T1,T1-E1/PRI-Call-Failed-Event",
                    85  => "DNS-Contact-Lost",
                    86  => "NTP-Contact-Lost",
                    87  => "NTP-Contact-Restored",
                    88  => "IPGW-Link-Up",
                    89  => "IPGW-Link-Down",
                    90  => "NTP-Contact-Degraded",
                    91  => "In-Connection-Failed",
                    92  => "Out-Connection-Failed",
                    93  => "Application-ProcessorReset",
                    94  => "DSP-Reset",
                    95  => "Changed-to-Maint-Srvs-State",
                    96  => "Loop-Back-cleared-on-channel",
                    97  => "Loop-Back-on-channel",
                    98  => "Telco-Abnormal-Response",
                    99  => "DNS-Contact-Restored",
                    100 => "DNS-Contact-Degraded",
                    101 => "RADIUS-Accounting-Restored",
                    102 => "RADIUS-Accounting-Group-Restore",
                    103 => "RADIUS-Accounting-Group-Degrade",
                    104 => "RADIUS-Accounting-Group-NonOper",
                    119 => "T1/T1-E1/PRI-InCall-Fail-Event",
                    120 => "T1/T1-E1/PRI-OutCall-Fail-Event",
                    121 => "RMMIE-Retrain-Event",
                    122 => "RMMIE-Speed-Shift-Event",
                    191 => "CDMA-Call-Start",
                    192 => "CDMA-Call-End",
                },
                61441 => {
                    1   => "Access-Request",
                    2   => "Access-Accept",
                    3   => "Access-Reject",
                    4   => "Accounting-Request",
                    5   => "Accounting-Response",
                    7   => "Access-Password-Change",
                    8   => "Access-Password-Ack",
                    9   => "Access-Password-Reject",
                    11  => "Access-Challenge",
                    12  => "Status-Server",
                    13  => "Status-Client",
                    21  => "Resource-Free-Request",
                    22  => "Resource-Free-Response",
                    23  => "Resource-Query-Request",
                    24  => "Resource-Query-Response",
                    25  => "Disconnect-User",
                    26  => "NAS-Reboot-Request",
                    27  => "NAS-Reboot-Response",
                    253 => "Tacacs-Message",
                    255 => "Reserved",
                },
                61442 => {
                    "0" => "3Com-NMC",
                    "1" => "3Com-NETServer",
                    "2" => "3Com-HiPerArc",
                    "3" => "TACACS+-Server",
                    "4" => "3Com-SA-Server",
                    "5" => "Ascend",
                    "6" => "Generic-RADIUS",
                    "7" => "3Com-NETBuilder-II",
                },
                61443 => {
                    "0" => "Auth-3Com",
                    "1" => "Auth-Ace",
                    "2" => "Auth-Safeword",
                    "3" => "Auth-UNIX-PW",
                    "4" => "Auth-Defender",
                    "5" => "Auth-TACACSP",
                    "6" => "Auth-Netware",
                    "7" => "Auth-Skey",
                    "8" => "Auth-EAP-Proxy",
                    "9" => "Auth-UNIX-Crypt",
                },
            },
            529 => {
                13 => {
                    "0" => "Unknown",
                    "1" => "2_4_6_4",
                    "2" => "2_4_5_5",
                    "3" => "1_2_2"
                },
                14 => {
                    "0" => "VC-No-Loopback",
                    "1" => "VC-Segment-Loopback",
                    "2" => "VC-End-To-End-Loopback",
                },
                16 => { "0" => "Ascend-PVC", "1" => "Ascend-SVC" },
                17 => {
                    "0" => "Ascend-SVC-Enabled-No",
                    "1" => "Ascend-SVC-Enabled-Yes"
                },
                18 => {
                    "0" => "Ascend-Session-Unused",
                    "1" => "Ascend-Session-Unknown",
                    "2" => "Ascend-Session-G711-Ulaw",
                    "3" => "Ascend-Session-G711-Alaw",
                    "4" => "Ascend-Session-G723",
                    "5" => "Ascend-Session-G729",
                    "6" => "Ascend-Session-G723-64KPS",
                    "7" => "Ascend-Session-G728",
                    "8" => "Ascend-Session-RT24",
                },
                29 => {
                    "0"  => "CRT",
                    "1"  => "INFONET",
                    "2"  => "DEFAULT",
                    "3"  => "SCEN",
                    "4"  => "CC_SSP",
                    "5"  => "CC_TSP",
                    "6"  => "HARDCOPY",
                    "7"  => "HDX",
                    "8"  => "SHARK",
                    "9"  => "POS",
                    "10" => "NULL",
                    "11" => "CUSTOM",
                },
                32 => {
                    "0" => "Reverse-Charging-No",
                    "1" => "Reverse-Charging-Yes"
                },
                46 => {
                    "0" => "Bi-Directional-Auth-None",
                    "1" => "Bi-Directional-Auth-Allowed",
                    "2" => "Bi-Directional-Auth-Required",
                },
                48 => {
                    "0" => "Ascend-Call-Direction-Incoming",
                    "1" => "Ascend-Call-Direction-Outgoing",
                },
                49 => {
                    "0"  => "Ascend-Service-Type-NotUsed",
                    "1"  => "Ascend-Service-Type-None",
                    "2"  => "Ascend-Service-Type-Other",
                    "3"  => "Ascend-Service-Type-PPP",
                    "4"  => "Ascend-Service-Type-Slip",
                    "5"  => "Ascend-Service-Type-MPP",
                    "6"  => "Ascend-Service-Type-X25",
                    "7"  => "Ascend-Service-Type-Combinet",
                    "8"  => "Ascend-Service-Type-FR",
                    "9"  => "Ascend-Service-Type-EuRaw",
                    "10" => "Ascend-Service-Type-EuUi",
                    "11" => "Ascend-Service-Type-Telnet",
                    "12" => "Ascend-Service-Type-TelnetBin",
                    "13" => "Ascend-Service-Type-RawTcp",
                    "14" => "Ascend-Service-Type-TermServer",
                    "15" => "Ascend-Service-Type-MP",
                    "16" => "Ascend-Service-Type-VirtualConn",
                    "17" => "Ascend-Service-Type-X25DChan",
                    "18" => "Ascend-Service-Type-PseuTunPPP",
                    "19" => "Ascend-Service-Type-IpFax",
                    "20" => "Ascend-Service-Type-ATM",
                    "21" => "Ascend-Service-Type-HdlcNrm",
                    "22" => "Ascend-Service-Type-VoIp",
                    "23" => "Ascend-Service-Type-Visa2",
                    "25" => "Ascend-Service-Type-NetToNet",
                },
                50 => { "0" => "Required-No", "1" => "Required-Yes" },
                55 => { "0" => "Required-No", "1" => "Required-Yes" },
                56 => { "0" => "Refresh-No",  "1" => "Refresh-Yes" },
                65 => {
                    "0" => "IPX-Header-Compression-No",
                    "1" => "IPX-Header-Compression-Yes",
                },
                66 => {
                    "0" => "Unknown",
                    "1" => "International-Number",
                    "2" => "National-Number",
                    "3" => "Network-Specific",
                    "4" => "Subscriber-Number",
                    "6" => "Abbreviated-Number",
                },
                67 => {
                    "0" => "Unknown",
                    "1" => "ISDN-Telephony",
                    "3" => "Data",
                    "4" => "Telex",
                    "8" => "National",
                    "9" => "Private",
                },
                68 => {
                    "0" => "Allowed",
                    "1" => "Restricted",
                    "2" => "Number-Not-Available"
                },
                69 => {
                    "0" => "User-Not-Screened",
                    "1" => "User-Provided-Passed",
                    "2" => "User-Provided-Failed",
                    "3" => "Network-Provided",
                },
                70 => { "0" => "BIR-Enable-No", "1" => "BIR-Enable-Yes" },
                71 => { "0" => "BIR-Proxy-No",  "1" => "BIR-Proxy-Yes" },
                74 => { "0" => "PPPoE-No",      "1" => "PPPoE-Yes" },
                75 => {
                    "0" => "Bridge-Non-PPPoE-No",
                    "1" => "Bridge-Non-PPPoE-Yes"
                },
                76 => { "0" => "ATM-Direct-No",  "1" => "ATM-Direct-Yes" },
                80 => { "0" => "WINS-Assign-No", "1" => "WINS-Assign-Yes" },
                81 => {
                    "0" => "Auth-None",
                    "1" => "Auth-Default",
                    "2" => "Auth-Any",
                    "3" => "Auth-PAP",
                    "4" => "Auth-CHAP",
                    "5" => "Auth-MS-CHAP",
                },
                82 => { 6 => "Ascend-Proto-TCP", 17 => "Ascend-Proto-UDP" },
                85 => {
                    "0" => "IP-Pool-Chaining-No",
                    "1" => "IP-Pool-Chaining-Yes"
                },
                87 => {
                    "0"  => "IP-TOS-Normal",
                    "1"  => "IP-TOS-Disabled",
                    "2"  => "IP-TOS-Cost",
                    "4"  => "IP-TOS-Reliability",
                    "8"  => "IP-TOS-Throughput",
                    "16" => "IP-TOS-Latency",
                },
                88 => {
                    "0"   => "IP-TOS-Precedence-Pri-Normal",
                    "32"  => "IP-TOS-Precedence-Pri-One",
                    "64"  => "IP-TOS-Precedence-Pri-Two",
                    "96"  => "IP-TOS-Precedence-Pri-Three",
                    "128" => "IP-TOS-Precedence-Pri-Four",
                    "160" => "IP-TOS-Precedence-Pri-Five",
                    "192" => "IP-TOS-Precedence-Pri-Six",
                    "224" => "IP-TOS-Precedence-Pri-Seven",
                },
                89 => {
                    1024 => "IP-TOS-Apply-To-Incoming",
                    2048 => "IP-TOS-Apply-To-Outgoing",
                    3072 => "IP-TOS-Apply-To-Both",
                },
                92 => {
                    "0" => "Rate-Type-Disabled",
                    "1" => "Rate-Type-Sdsl",
                    "2" => "Rate-Type-AdslCap",
                    "3" => "Rate-Type-AdslDmtCell",
                    "4" => "Rate-Type-AdslDmt",
                },
                96 =>
                  { "0" => "Source-IP-Check-No", "1" => "Source-IP-Check-Yes" },
                97 => { 1 => "Rate-Mode-AutoBaud", 2 => "Rate-Mode-Single" },
                98 => {
                    "0"   => "sdsl-144000",
                    "1"   => "sdsl-272000",
                    "2"   => "sdsl-400000",
                    "3"   => "sdsl-528000",
                    "4"   => "sdsl-784000",
                    "5"   => "sdsl-1168000",
                    "6"   => "sdsl-1552000",
                    "7"   => "sdsl-2320000",
                    "50"  => "adslcap-up-1088000",
                    "51"  => "adslcap-up-952000",
                    "52"  => "adslcap-up-816000",
                    "53"  => "adslcap-up-680000",
                    "54"  => "adslcap-up-544000",
                    "55"  => "adslcap-up-408000",
                    "56"  => "adslcap-up-272000",
                    "150" => "adsldmt-up-auto",
                    "151" => "adsldmt-up-1088000",
                    "152" => "adsldmt-up-928000",
                    "153" => "adsldmt-up-896000",
                    "154" => "adsldmt-up-800000",
                    "155" => "adsldmt-up-768000",
                    "156" => "adsldmt-up-640000",
                    "157" => "adsldmt-up-512000",
                    "158" => "adsldmt-up-384000",
                    "159" => "adsldmt-up-256000",
                    "160" => "adsldmt-up-128000",
                },
                99 => {
                    "0"   => "adslcap-dn-7168000",
                    "1"   => "adslcap-dn-6272000",
                    "2"   => "adslcap-dn-5120000",
                    "3"   => "adslcap-dn-4480000",
                    "4"   => "adslcap-dn-3200000",
                    "5"   => "adslcap-dn-2688000",
                    "6"   => "adslcap-dn-2560000",
                    "7"   => "adslcap-dn-2240000",
                    "8"   => "adslcap-dn-1920000",
                    "9"   => "adslcap-dn-1600000",
                    "10"  => "adslcap-dn-1280000",
                    "11"  => "adslcap-dn-960000",
                    "12"  => "adslcap-dn-640000",
                    "100" => "adsldmt-dn-auto",
                    "101" => "adsldmt-dn-9504000",
                    "102" => "adsldmt-dn-8960000",
                    "103" => "adsldmt-dn-8000000",
                    "104" => "adsldmt-dn-7168000",
                    "105" => "adsldmt-dn-6272000",
                    "106" => "adsldmt-dn-5120000",
                    "107" => "adsldmt-dn-4480000",
                    "108" => "adsldmt-dn-3200000",
                    "109" => "adsldmt-dn-2688000",
                    "110" => "adsldmt-dn-2560000",
                    "111" => "adsldmt-dn-2240000",
                    "112" => "adsldmt-dn-1920000",
                    "113" => "adsldmt-dn-1600000",
                    "114" => "adsldmt-dn-1280000",
                    "115" => "adsldmt-dn-960000",
                    "116" => "adsldmt-dn-768000",
                    "117" => "adsldmt-dn-640000",
                    "118" => "adsldmt-dn-512000",
                    "119" => "adsldmt-dn-384000",
                    "120" => "adsldmt-dn-256000",
                    "121" => "adsldmt-dn-128000",
                },
                105 => {
                    "0" => "Unknown-Numbering-Plan",
                    "1" => "ISDN-Numbering-Plan",
                    "9" => "Private-Numbering-Plan",
                },
                106 => {
                    "0"    => "Ascend-FR-LMI-Dlci-0",
                    "1023" => "Ascend-FR-LMI-Dlci-1023"
                },
                112 => { "0" => "CBCP-Not-Enabled", "1" => "CBCP-Enabled" },
                113 => {
                    1 => "CBCP-No-Callback",
                    2 => "CBCP-User-Callback",
                    3 => "CBCP-Profile-Callback",
                    7 => "CBCP-Any-Or-No",
                    8 => "CBCP-Off",
                },
                117 => {
                    "0" => "Appletalk-Peer-Router",
                    "1" => "Appletalk-Peer-Dialin"
                },
                118 =>
                  { "0" => "Route-Appletalk-No", "1" => "Route-Appletalk-Yes" },
                126 => { "0" => "Temp-Rtes-No", "1" => "Temp-Rtes-Yes" },
                127 => { "0" => "ATMP-Tunnel",  "1" => "VTP-Tunnel" },
                128 =>
                  { "0" => "Shared-Profile-No", "1" => "Shared-Profile-Yes" },
                131 =>
                  { "0" => "Dialout-Not-Allowed", "1" => "Dialout-Allowed" },
                133 => { "0" => "BACP-No",       "1" => "BACP-Yes" },
                137 => { "0" => "DNS-Assign-No", "1" => "DNS-Assign-Yes" },
                138 => {
                    "0" => "Ascend-User-Acct-None",
                    "1" => "Ascend-User-Acct-User",
                    "2" => "Ascend-User-Acct-User-Default",
                },
                142 => { "0" => "Base-10",       "1" => "Base-16" },
                147 => { "0" => "DHCP-Reply-No", "1" => "DHCP-Reply-Yes" },
                149 =>
                  { "0" => "Expect-Callback-No", "1" => "Expect-Callback-Yes" },
                150 => { 1 => "Ascend-ColdStart", 2 => "Ascend-Session-Event" },
                155 => { "0" => "Multicast-No",   "1" => "Multicast-Yes" },
                157 => {
                    "0" => "Ascend-LinkUp-Default",
                    "1" => "Ascend-LinkUp-AlwaysUp"
                },
                159 => {
                    "0" => "Ascend-FR-DTE",
                    "1" => "Ascend-FR-DCE",
                    "2" => "Ascend-FR-NNI"
                },
                160 => {
                    "0" => "Ascend-FR-No-Link-Mgt",
                    "1" => "Ascend-FR-T1-617D",
                    "2" => "Ascend-FR-Q-933A",
                },
                170 => {
                    "0" => "TS-Idle-None",
                    "1" => "TS-Idle-Input",
                    "2" => "TS-Idle-Input-Output",
                },
                171 => {
                    "0" => "DBA-Transmit",
                    "1" => "DBA-Transmit-Recv",
                    "2" => "DBA-None"
                },
                175 => { "0" => "FT1-No", "1" => "FT1-Yes" },
                177 => {
                    "0" => "Switched",
                    "1" => "Nailed",
                    "2" => "Nailed/Mpp",
                    "3" => "Perm/Switched",
                    "6" => "AO/DI",
                    "7" => "MegaMax",
                },
                195 => {
                    "0"   => "No-Reason",
                    "1"   => "Not-Applicable",
                    "2"   => "Unknown",
                    "3"   => "Call-Disconnected",
                    "4"   => "CLID-Authentication-Failed",
                    "5"   => "CLID-RADIUS-Timeout",
                    "10"  => "Modem-No-DCD",
                    "11"  => "DCD-Detected-Then-Inactive",
                    "12"  => "Modem-Invalid-Result-Codes",
                    "20"  => "TermSrv-User-Quit",
                    "21"  => "TermSrv-Idle-Timeout",
                    "22"  => "TermSrv-Exit-Telnet",
                    "23"  => "TermSrv-No-IPaddr",
                    "24"  => "TermSrv-Exit-Raw-TCP",
                    "25"  => "TermSrv-Exit-Login-Failed",
                    "26"  => "TermSrv-Exit-Raw-TCP-Disabled",
                    "27"  => "TermSrv-CTRL-C-In-Login",
                    "28"  => "TermSrv-Destroyed",
                    "29"  => "TermSrv-User-Closed-VCon",
                    "30"  => "TermSrv-VCon-Destroyed",
                    "31"  => "TermSrv-Exit-Rlogin",
                    "32"  => "TermSrv-Bad-Rlogin-Option",
                    "33"  => "TermSrv-Not-Enough-Resources",
                    "35"  => "MPP-No-NULL-Msg-Timeout",
                    "40"  => "PPP-LCP-Timeout",
                    "41"  => "PPP-LCP-Negotion-Failed",
                    "42"  => "PPP-PAP-Auth-Failed",
                    "43"  => "PPP-CHAP-Auth-Failed",
                    "44"  => "PPP-Rmt-Auth-Failed",
                    "45"  => "PPP-Rcv-Terminate-Req",
                    "46"  => "PPP-Rcv-Close-Event",
                    "47"  => "PPP-No-NCPs-Open",
                    "48"  => "PPP-MP-Bundle-Unknown",
                    "49"  => "PPP-LCP-Close-MP-Add-Fail",
                    "50"  => "Session-Table-Full",
                    "51"  => "Out-Of-Resources",
                    "52"  => "Invalid-IP-Address",
                    "53"  => "Hostname-Resolution-Failed",
                    "54"  => "Bad-Or-Missing-Port-Number",
                    "60"  => "Host-Reset",
                    "61"  => "Connection-Refused",
                    "62"  => "Connection-Timeout",
                    "63"  => "Connection-Closed",
                    "64"  => "Network-Unreachable",
                    "65"  => "Host-Unreachable",
                    "66"  => "Network-Unreachable-Admin",
                    "67"  => "Host-Unreachable-Admin",
                    "68"  => "Port-Unreachable",
                    "100" => "Session-Timeout",
                    "101" => "Invalid-Incoming-User",
                    "102" => "Disconnect-Due-To-Callback",
                    "120" => "Proto-Disabled-Or-Unsupported",
                    "150" => "Disconnect-Req-By-RADIUS",
                    "151" => "Disconnect-Req-By-Local-Admin",
                    "160" => "V110-Timeout-Sync-Retry-Exceed",
                    "170" => "PPP-Auth-Timeout-Exceeded",
                    "180" => "User-Executed-Do-Hangup",
                    "185" => "Remote-End-Hung-Up",
                    "190" => "Resource-Has-Been-Quiesced",
                    "195" => "Max-Call-Duration-Reached",
                },
                196 => {
                    "0"  => "No-Progress",
                    "10" => "Call-Up",
                    "30" => "Modem-Up",
                    "31" => "Modem-Awaiting-DCD",
                    "32" => "Modem-Awaiting-Codes",
                    "40" => "TermSrv-Started",
                    "41" => "TermSrv-Raw-TCP-Started",
                    "42" => "TermSrv-Telnet-Started",
                    "43" => "TermSrv-Raw-TCP-Connected",
                    "44" => "TermSrv-Telnet-Connected",
                    "45" => "TermSrv-Rlogin-Started",
                    "46" => "TermSrv-Rlogin-Connected",
                    "50" => "Modem-Outdial-Call-Up",
                    "60" => "LAN-Session-Up",
                    "61" => "LCP-Opening",
                    "62" => "CCP-Opening",
                    "63" => "IPNCP-Opening",
                    "64" => "BNCP-Opening",
                    "65" => "LCP-Opened",
                    "66" => "CCP-Opened",
                    "67" => "IPNCP-Opened",
                    "68" => "BNCP-Opened",
                    "69" => "LCP-State-Initial",
                    "70" => "LCP-State-Starting",
                    "71" => "LCP-State-Closed",
                    "72" => "LCP-State-Stopped",
                    "73" => "LCP-State-Closing",
                    "74" => "LCP-State-Stopping",
                    "75" => "LCP-State-Request-Sent",
                    "76" => "LCP-State-Ack-Received",
                    "77" => "LCP-State-Ack-Sent",
                    "80" => "IPXNCP-Opened",
                    "81" => "ATNCP-Opened",
                    "82" => "BACP-Opening",
                    "83" => "BACP-Opened",
                    "90" => "V110-Up",
                    "91" => "V110-State-Opened",
                    "92" => "V110-State-Carrier",
                    "93" => "V110-State-Reset",
                    "94" => "V110-State-Closed",
                },
                200 => { "0" => "Tok-Imm-No",       "1" => "Tok-Imm-Yes" },
                201 => { "0" => "Not-Require-Auth", "1" => "Require-Auth" },
                207 => { "0" => "Days-Of-Warning" },
                208 => { "0" => "Lifetime-In-Days" },
                210 => { 1   => "VJ-Slot-Comp-No" },
                211 => { 1   => "PPP-VJ-1172" },
                216 => { "0" => "IPX-Peer-Router", "1" => "IPX-Peer-Dialin" },
                219 => { "0" => "FR-Direct-No",    "1" => "FR-Direct-Yes" },
                222 => {
                    "0" => "Handle-IPX-None",
                    "1" => "Handle-IPX-Client",
                    "2" => "Handle-IPX-Server",
                },
                226 => {
                    "0" => "Unknown-Number",
                    "1" => "Intl-Number",
                    "2" => "National-Number",
                    "3" => "Net-Specific-Number",
                    "4" => "Local-Number",
                    "5" => "Abbrev-Number",
                },
                228 => { "0" => "Route-IP-No",  "1" => "Route-IP-Yes" },
                229 => { "0" => "Route-IPX-No", "1" => "Route-IPX-Yes" },
                230 => { "0" => "Bridge-No",    "1" => "Bridge-Yes" },
                231 => {
                    "0" => "Send-Auth-None",
                    "1" => "Send-Auth-PAP",
                    "2" => "Send-Auth-CHAP",
                    "3" => "Send-Auth-MS-CHAP",
                },
                233 => {
                    "0" => "Link-Comp-None",
                    "1" => "Link-Comp-Stac",
                    "2" => "Link-Comp-Stac-Draft-9",
                    "3" => "Link-Comp-MS-Stac",
                },
                239 => {
                    "0" => "History-Constant",
                    "1" => "History-Linear",
                    "2" => "History-Quadratic",
                },
                246 => { "0" => "Callback-No", "1" => "Callback-Yes" },
                247 => {
                    "0"  => "Switched-Voice-Bearer",
                    "1"  => "Nailed-56KR",
                    "2"  => "Nailed-64K",
                    "3"  => "Switched-64KR",
                    "4"  => "Switched-56K",
                    "5"  => "Switched-384KR",
                    "6"  => "Switched-384K",
                    "7"  => "Switched-1536K",
                    "8"  => "Switched-1536KR",
                    "9"  => "Switched-128K",
                    "10" => "Switched-192K",
                    "11" => "Switched-256K",
                    "12" => "Switched-320K",
                    "13" => "Switched-384K-MR",
                    "14" => "Switched-448K",
                    "15" => "Switched-512K",
                    "16" => "Switched-576K",
                    "17" => "Switched-640K",
                    "18" => "Switched-704K",
                    "19" => "Switched-768K",
                    "20" => "Switched-832K",
                    "21" => "Switched-896K",
                    "22" => "Switched-960K",
                    "23" => "Switched-1024K",
                    "24" => "Switched-1088K",
                    "25" => "Switched-1152K",
                    "26" => "Switched-1216K",
                    "27" => "Switched-1280K",
                    "28" => "Switched-1344K",
                    "29" => "Switched-1408K",
                    "30" => "Switched-1472K",
                    "31" => "Switched-1600K",
                    "32" => "Switched-1664K",
                    "33" => "Switched-1728K",
                    "34" => "Switched-1792K",
                    "35" => "Switched-1856K",
                    "36" => "Switched-1920K",
                    "37" => "Switched-inherited",
                    "38" => "Switched-restricted-bearer-x30",
                    "39" => "Switched-clear-bearer-v110",
                    "40" => "Switched-restricted-64-x30",
                    "41" => "Switched-clear-56-v110",
                    "42" => "Switched-modem",
                    "43" => "Switched-atmodem",
                    "45" => "Switched-V110-24-56",
                    "46" => "Switched-V110-48-56",
                    "47" => "Switched-V110-96-56",
                    "48" => "Switched-V110-192-56",
                    "49" => "Switched-V110-384-56",
                    "50" => "Switched-V110-24-56R",
                    "51" => "Switched-V110-48-56R",
                    "52" => "Switched-V110-96-56R",
                    "53" => "Switched-V110-192-56R",
                    "54" => "Switched-V110-384-56R",
                    "55" => "Switched-V110-24-64",
                    "56" => "Switched-V110-48-64",
                    "57" => "Switched-V110-96-64",
                    "58" => "Switched-V110-192-64",
                    "59" => "Switched-V110-384-64",
                    "60" => "Switched-V110-24-64R",
                    "61" => "Switched-V110-48-64R",
                    "62" => "Switched-V110-96-64R",
                    "63" => "Switched-V110-192-64R",
                    "64" => "Switched-V110-384-64R",
                    "68" => "Switched-Pots",
                    "69" => "Switched-ATM",
                    "70" => "Switched-FR",
                },
                248 => { "0" => "Force-56-No", "1" => "Force-56-Yes" },
            },
            562 => {
                166 => {
                    "0"  => "VoiceMailAdmin",
                    "1"  => "ContactCenter",
                    "2"  => "SBAInstaller",
                    "3"  => "SBASystemCoord",
                    "4"  => "SBASystemCoordBasic",
                    "5"  => "SBABasic",
                    "6"  => "Security",
                    "7"  => "CTEApp",
                    "8"  => "SBA-IPSetRegistration",
                    "9"  => "Application-BCMMonitor",
                    "10" => "CDRApp",
                    "11" => "ModemLogin",
                    "12" => "GuestLogin",
                    "13" => "AdminDownload",
                    "14" => "ExclusiveAccess",
                    "15" => "Admin",
                    "16" => "DataAdmin",
                    "17" => "RemoteAccess",
                    "18" => "Guest",
                    "19" => "VoiceAdmin",
                    "20" => "BackupOperator",
                    "21" => "RemoteMonitoring",
                    "22" => "SoftwareUpgrade",
                    "24" => "AlarmViewer",
                    "26" => "OperationalLogs",
                    "27" => "DiagnosticLogs",
                    "28" => "ApplicationIVR",
                    "30" => "ISDN-Dial-in",
                    "32" => "WAN-Dial-in",
                    "36" => "System-SerialPort",
                },
                170 => { "0" => "No", "1" => "Yes" },
            },
            637 => {
                1536 => {
                    "0" => "Alcatel-No-Maint-Priv-Level",
                    "1" => "Alcatel-Maint-Priv-Level-1",
                    "2" => "Alcatel-Maint-Priv-Level-2",
                    "3" => "Alcatel-Maint-Priv-Level-3",
                    "4" => "Alcatel-Maint-Priv-Level-4",
                    "5" => "Alcatel-Maint-Priv-Level-5",
                    "6" => "Alcatel-Maint-Priv-Level-6",
                    "7" => "Alcatel-Maint-Priv-Level-7",
                },
                1537 => {
                    "0" => "Alcatel-No-Maint-Priv-Level",
                    "1" => "Alcatel-Maint-Priv-Level-1",
                    "2" => "Alcatel-Maint-Priv-Level-2",
                    "3" => "Alcatel-Maint-Priv-Level-3",
                    "4" => "Alcatel-Maint-Priv-Level-4",
                    "5" => "Alcatel-Maint-Priv-Level-5",
                    "6" => "Alcatel-Maint-Priv-Level-6",
                    "7" => "Alcatel-Maint-Priv-Level-7",
                },
                1539 => {
                    "0" => "Alcatel-No-Maint-Priv-Level",
                    "1" => "Alcatel-Maint-Priv-Level-1",
                    "2" => "Alcatel-Maint-Priv-Level-2",
                    "3" => "Alcatel-Maint-Priv-Level-3",
                    "4" => "Alcatel-Maint-Priv-Level-4",
                    "5" => "Alcatel-Maint-Priv-Level-5",
                    "6" => "Alcatel-Maint-Priv-Level-6",
                    "7" => "Alcatel-Maint-Priv-Level-7",
                },
                1796 => {
                    1  => "Unknown-VRF",
                    2  => "No-VRF",
                    3  => "Unknown-Vlan",
                    4  => "No-Vlan",
                    5  => "Unknown-Pool-Id",
                    6  => "Pool-Admin-Locked",
                    7  => "No-Pool-Id",
                    8  => "Pool-VRF-Inconsistent",
                    9  => "Unknown-QOS-Profile",
                    10 => "QOS-Params-Syntax-Err",
                    11 => "IP-Addr-In-Use",
                    12 => "No-IP-Addr-Available",
                    13 => "No-User-IP-Addr",
                    14 => "Missing-Attributes",
                },
                1801 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1802 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1803 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1804 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1805 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1806 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1807 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1808 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1809 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1810 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1811 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1812 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1813 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1814 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1815 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                    "4" => "Alcatel-Maint-Priv-Level-4",
                    "5" => "Alcatel-Maint-Priv-Level-5",
                    "6" => "Alcatel-Maint-Priv-Level-6",
                    "7" => "Alcatel-Maint-Priv-Level-7",
                },
                1816 => {
                    "0" => "Alcatel-No-Priv",
                    "1" => "Alcatel-Read-Priv",
                    "2" => "Alcatel-Write-Priv",
                    "3" => "Alcatel-RW-Priv",
                },
                1820 => {
                    1 => "SLOT-NUMBERING-TYPE",
                    2 => "SLOT-NUMBERING-POSITION",
                    3 => "SLOT-NUMBERING-LEGACY",
                },
            },
            762 => {
                152 => {
                    "0"    => "TxRate-Local",
                    "8"    => "TxRate-MaxSpeed",
                    "11"   => "TxRate-11k",
                    "12"   => "TxRate-12k",
                    "13"   => "TxRate-13k",
                    "14"   => "TxRate-14k",
                    "15"   => "TxRate-15k",
                    "16"   => "TxRate-16k",
                    "17"   => "TxRate-17k",
                    "18"   => "TxRate-18k",
                    "19"   => "TxRate-19k",
                    "20"   => "TxRate-20k",
                    "21"   => "TxRate-21k",
                    "22"   => "TxRate-22k",
                    "23"   => "TxRate-23k",
                    "24"   => "TxRate-24k",
                    "25"   => "TxRate-25k",
                    "26"   => "TxRate-26k",
                    "27"   => "TxRate-27k",
                    "28"   => "TxRate-28k",
                    "29"   => "TxRate-29k",
                    "30"   => "TxRate-30k",
                    "31"   => "TxRate-31k",
                    "32"   => "TxRate-32k",
                    "33"   => "TxRate-33k",
                    "34"   => "TxRate-34k",
                    "35"   => "TxRate-35k",
                    "36"   => "TxRate-36k",
                    "37"   => "TxRate-37k",
                    "38"   => "TxRate-38k",
                    "39"   => "TxRate-39k",
                    "40"   => "TxRate-40k",
                    "41"   => "TxRate-41k",
                    "42"   => "TxRate-42k",
                    "43"   => "TxRate-43k",
                    "44"   => "TxRate-44k",
                    "45"   => "TxRate-45k",
                    "46"   => "TxRate-46k",
                    "47"   => "TxRate-47k",
                    "48"   => "TxRate-48k",
                    "49"   => "TxRate-49k",
                    "50"   => "TxRate-50k",
                    "51"   => "TxRate-51k",
                    "52"   => "TxRate-52k",
                    "53"   => "TxRate-53k",
                    "54"   => "TxRate-54k",
                    "55"   => "TxRate-55k",
                    "56"   => "TxRate-56k",
                    "57"   => "TxRate-57k",
                    "58"   => "TxRate-58k",
                    "59"   => "TxRate-59k",
                    "60"   => "TxRate-60k",
                    "61"   => "TxRate-61k",
                    "62"   => "TxRate-62k",
                    "63"   => "TxRate-63k",
                    "64"   => "TxRate-64k",
                    "65"   => "TxRate-65k",
                    "66"   => "TxRate-66k",
                    "67"   => "TxRate-67k",
                    "68"   => "TxRate-68k",
                    "69"   => "TxRate-69k",
                    "70"   => "TxRate-70k",
                    "71"   => "TxRate-71k",
                    "72"   => "TxRate-72k",
                    "73"   => "TxRate-73k",
                    "74"   => "TxRate-74k",
                    "75"   => "TxRate-75k",
                    "76"   => "TxRate-76k",
                    "77"   => "TxRate-77k",
                    "78"   => "TxRate-78k",
                    "79"   => "TxRate-79k",
                    "80"   => "TxRate-80k",
                    "81"   => "TxRate-81k",
                    "82"   => "TxRate-82k",
                    "83"   => "TxRate-83k",
                    "84"   => "TxRate-84k",
                    "85"   => "TxRate-85k",
                    "86"   => "TxRate-86k",
                    "87"   => "TxRate-87k",
                    "88"   => "TxRate-88k",
                    "89"   => "TxRate-89k",
                    "90"   => "TxRate-90k",
                    "91"   => "TxRate-91k",
                    "92"   => "TxRate-92k",
                    "93"   => "TxRate-93k",
                    "94"   => "TxRate-94k",
                    "95"   => "TxRate-95k",
                    "96"   => "TxRate-96k",
                    "97"   => "TxRate-97k",
                    "98"   => "TxRate-98k",
                    "99"   => "TxRate-99k",
                    "100"  => "TxRate-100k",
                    "101"  => "TxRate-101k",
                    "102"  => "TxRate-102k",
                    "103"  => "TxRate-103k",
                    "104"  => "TxRate-104k",
                    "105"  => "TxRate-105k",
                    "106"  => "TxRate-106k",
                    "107"  => "TxRate-107k",
                    "108"  => "TxRate-108k",
                    "109"  => "TxRate-109k",
                    "110"  => "TxRate-110k",
                    "111"  => "TxRate-111k",
                    "112"  => "TxRate-112k",
                    "113"  => "TxRate-113k",
                    "114"  => "TxRate-114k",
                    "115"  => "TxRate-115k",
                    "116"  => "TxRate-116k",
                    "117"  => "TxRate-117k",
                    "118"  => "TxRate-118k",
                    "119"  => "TxRate-119k",
                    "120"  => "TxRate-120k",
                    "121"  => "TxRate-121k",
                    "122"  => "TxRate-122k",
                    "123"  => "TxRate-123k",
                    "124"  => "TxRate-124k",
                    "125"  => "TxRate-125k",
                    "126"  => "TxRate-126k",
                    "127"  => "TxRate-127k",
                    "128"  => "TxRate-128k",
                    "129"  => "TxRate-129k",
                    "130"  => "TxRate-130k",
                    "131"  => "TxRate-131k",
                    "132"  => "TxRate-132k",
                    "133"  => "TxRate-133k",
                    "134"  => "TxRate-134k",
                    "135"  => "TxRate-135k",
                    "136"  => "TxRate-136k",
                    "137"  => "TxRate-137k",
                    "138"  => "TxRate-138k",
                    "139"  => "TxRate-139k",
                    "140"  => "TxRate-140k",
                    "141"  => "TxRate-141k",
                    "142"  => "TxRate-142k",
                    "143"  => "TxRate-143k",
                    "144"  => "TxRate-144k",
                    "145"  => "TxRate-145k",
                    "146"  => "TxRate-146k",
                    "147"  => "TxRate-147k",
                    "148"  => "TxRate-148k",
                    "149"  => "TxRate-149k",
                    "150"  => "TxRate-150k",
                    "151"  => "TxRate-151k",
                    "152"  => "TxRate-152k",
                    "153"  => "TxRate-153k",
                    "154"  => "TxRate-154k",
                    "155"  => "TxRate-155k",
                    "156"  => "TxRate-156k",
                    "157"  => "TxRate-157k",
                    "158"  => "TxRate-158k",
                    "159"  => "TxRate-159k",
                    "160"  => "TxRate-160k",
                    "161"  => "TxRate-161k",
                    "162"  => "TxRate-162k",
                    "163"  => "TxRate-163k",
                    "164"  => "TxRate-164k",
                    "165"  => "TxRate-165k",
                    "166"  => "TxRate-166k",
                    "167"  => "TxRate-167k",
                    "168"  => "TxRate-168k",
                    "169"  => "TxRate-169k",
                    "170"  => "TxRate-170k",
                    "171"  => "TxRate-171k",
                    "172"  => "TxRate-172k",
                    "173"  => "TxRate-173k",
                    "174"  => "TxRate-174k",
                    "175"  => "TxRate-175k",
                    "176"  => "TxRate-176k",
                    "177"  => "TxRate-177k",
                    "178"  => "TxRate-178k",
                    "179"  => "TxRate-179k",
                    "180"  => "TxRate-180k",
                    "181"  => "TxRate-181k",
                    "182"  => "TxRate-182k",
                    "183"  => "TxRate-183k",
                    "184"  => "TxRate-184k",
                    "185"  => "TxRate-185k",
                    "186"  => "TxRate-186k",
                    "187"  => "TxRate-187k",
                    "188"  => "TxRate-188k",
                    "189"  => "TxRate-189k",
                    "190"  => "TxRate-190k",
                    "191"  => "TxRate-191k",
                    "192"  => "TxRate-192k",
                    "193"  => "TxRate-193k",
                    "194"  => "TxRate-194k",
                    "195"  => "TxRate-195k",
                    "196"  => "TxRate-196k",
                    "197"  => "TxRate-197k",
                    "198"  => "TxRate-198k",
                    "199"  => "TxRate-199k",
                    "200"  => "TxRate-200k",
                    "201"  => "TxRate-201k",
                    "202"  => "TxRate-202k",
                    "203"  => "TxRate-203k",
                    "204"  => "TxRate-204k",
                    "205"  => "TxRate-205k",
                    "206"  => "TxRate-206k",
                    "207"  => "TxRate-207k",
                    "208"  => "TxRate-208k",
                    "209"  => "TxRate-209k",
                    "210"  => "TxRate-210k",
                    "211"  => "TxRate-211k",
                    "212"  => "TxRate-212k",
                    "213"  => "TxRate-213k",
                    "214"  => "TxRate-214k",
                    "215"  => "TxRate-215k",
                    "216"  => "TxRate-216k",
                    "217"  => "TxRate-217k",
                    "218"  => "TxRate-218k",
                    "219"  => "TxRate-219k",
                    "220"  => "TxRate-220k",
                    "221"  => "TxRate-221k",
                    "222"  => "TxRate-222k",
                    "223"  => "TxRate-223k",
                    "224"  => "TxRate-224k",
                    "225"  => "TxRate-225k",
                    "226"  => "TxRate-226k",
                    "227"  => "TxRate-227k",
                    "228"  => "TxRate-228k",
                    "229"  => "TxRate-229k",
                    "230"  => "TxRate-230k",
                    "231"  => "TxRate-231k",
                    "232"  => "TxRate-232k",
                    "233"  => "TxRate-233k",
                    "234"  => "TxRate-234k",
                    "235"  => "TxRate-235k",
                    "236"  => "TxRate-236k",
                    "237"  => "TxRate-237k",
                    "238"  => "TxRate-238k",
                    "239"  => "TxRate-239k",
                    "240"  => "TxRate-240k",
                    "241"  => "TxRate-241k",
                    "242"  => "TxRate-242k",
                    "243"  => "TxRate-243k",
                    "244"  => "TxRate-244k",
                    "245"  => "TxRate-245k",
                    "246"  => "TxRate-246k",
                    "247"  => "TxRate-247k",
                    "248"  => "TxRate-248k",
                    "249"  => "TxRate-249k",
                    "250"  => "TxRate-250k",
                    "251"  => "TxRate-251k",
                    "252"  => "TxRate-252k",
                    "253"  => "TxRate-253k",
                    "254"  => "TxRate-254k",
                    "255"  => "TxRate-255k",
                    "256"  => "TxRate-256k",
                    "257"  => "TxRate-257k",
                    "258"  => "TxRate-258k",
                    "259"  => "TxRate-259k",
                    "260"  => "TxRate-260k",
                    "261"  => "TxRate-261k",
                    "262"  => "TxRate-262k",
                    "263"  => "TxRate-263k",
                    "264"  => "TxRate-264k",
                    "265"  => "TxRate-265k",
                    "266"  => "TxRate-266k",
                    "267"  => "TxRate-267k",
                    "268"  => "TxRate-268k",
                    "269"  => "TxRate-269k",
                    "270"  => "TxRate-270k",
                    "271"  => "TxRate-271k",
                    "272"  => "TxRate-272k",
                    "273"  => "TxRate-273k",
                    "274"  => "TxRate-274k",
                    "275"  => "TxRate-275k",
                    "276"  => "TxRate-276k",
                    "277"  => "TxRate-277k",
                    "278"  => "TxRate-278k",
                    "279"  => "TxRate-279k",
                    "280"  => "TxRate-280k",
                    "281"  => "TxRate-281k",
                    "282"  => "TxRate-282k",
                    "283"  => "TxRate-283k",
                    "284"  => "TxRate-284k",
                    "285"  => "TxRate-285k",
                    "286"  => "TxRate-286k",
                    "287"  => "TxRate-287k",
                    "288"  => "TxRate-288k",
                    "289"  => "TxRate-289k",
                    "290"  => "TxRate-290k",
                    "291"  => "TxRate-291k",
                    "292"  => "TxRate-292k",
                    "293"  => "TxRate-293k",
                    "294"  => "TxRate-294k",
                    "295"  => "TxRate-295k",
                    "296"  => "TxRate-296k",
                    "297"  => "TxRate-297k",
                    "298"  => "TxRate-298k",
                    "299"  => "TxRate-299k",
                    "300"  => "TxRate-300k",
                    "301"  => "TxRate-301k",
                    "302"  => "TxRate-302k",
                    "303"  => "TxRate-303k",
                    "304"  => "TxRate-304k",
                    "305"  => "TxRate-305k",
                    "306"  => "TxRate-306k",
                    "307"  => "TxRate-307k",
                    "308"  => "TxRate-308k",
                    "309"  => "TxRate-309k",
                    "310"  => "TxRate-310k",
                    "311"  => "TxRate-311k",
                    "312"  => "TxRate-312k",
                    "313"  => "TxRate-313k",
                    "314"  => "TxRate-314k",
                    "315"  => "TxRate-315k",
                    "316"  => "TxRate-316k",
                    "317"  => "TxRate-317k",
                    "318"  => "TxRate-318k",
                    "319"  => "TxRate-319k",
                    "320"  => "TxRate-320k",
                    "321"  => "TxRate-321k",
                    "322"  => "TxRate-322k",
                    "323"  => "TxRate-323k",
                    "324"  => "TxRate-324k",
                    "325"  => "TxRate-325k",
                    "326"  => "TxRate-326k",
                    "327"  => "TxRate-327k",
                    "328"  => "TxRate-328k",
                    "329"  => "TxRate-329k",
                    "330"  => "TxRate-330k",
                    "331"  => "TxRate-331k",
                    "332"  => "TxRate-332k",
                    "333"  => "TxRate-333k",
                    "334"  => "TxRate-334k",
                    "335"  => "TxRate-335k",
                    "336"  => "TxRate-336k",
                    "337"  => "TxRate-337k",
                    "338"  => "TxRate-338k",
                    "339"  => "TxRate-339k",
                    "340"  => "TxRate-340k",
                    "341"  => "TxRate-341k",
                    "342"  => "TxRate-342k",
                    "343"  => "TxRate-343k",
                    "344"  => "TxRate-344k",
                    "345"  => "TxRate-345k",
                    "346"  => "TxRate-346k",
                    "347"  => "TxRate-347k",
                    "348"  => "TxRate-348k",
                    "349"  => "TxRate-349k",
                    "350"  => "TxRate-350k",
                    "351"  => "TxRate-351k",
                    "352"  => "TxRate-352k",
                    "353"  => "TxRate-353k",
                    "354"  => "TxRate-354k",
                    "355"  => "TxRate-355k",
                    "356"  => "TxRate-356k",
                    "357"  => "TxRate-357k",
                    "358"  => "TxRate-358k",
                    "359"  => "TxRate-359k",
                    "360"  => "TxRate-360k",
                    "361"  => "TxRate-361k",
                    "362"  => "TxRate-362k",
                    "363"  => "TxRate-363k",
                    "364"  => "TxRate-364k",
                    "365"  => "TxRate-365k",
                    "366"  => "TxRate-366k",
                    "367"  => "TxRate-367k",
                    "368"  => "TxRate-368k",
                    "369"  => "TxRate-369k",
                    "370"  => "TxRate-370k",
                    "371"  => "TxRate-371k",
                    "372"  => "TxRate-372k",
                    "373"  => "TxRate-373k",
                    "374"  => "TxRate-374k",
                    "375"  => "TxRate-375k",
                    "376"  => "TxRate-376k",
                    "377"  => "TxRate-377k",
                    "378"  => "TxRate-378k",
                    "379"  => "TxRate-379k",
                    "380"  => "TxRate-380k",
                    "381"  => "TxRate-381k",
                    "382"  => "TxRate-382k",
                    "383"  => "TxRate-383k",
                    "384"  => "TxRate-384k",
                    "385"  => "TxRate-385k",
                    "386"  => "TxRate-386k",
                    "387"  => "TxRate-387k",
                    "388"  => "TxRate-388k",
                    "389"  => "TxRate-389k",
                    "390"  => "TxRate-390k",
                    "391"  => "TxRate-391k",
                    "392"  => "TxRate-392k",
                    "393"  => "TxRate-393k",
                    "394"  => "TxRate-394k",
                    "395"  => "TxRate-395k",
                    "396"  => "TxRate-396k",
                    "397"  => "TxRate-397k",
                    "398"  => "TxRate-398k",
                    "399"  => "TxRate-399k",
                    "400"  => "TxRate-400k",
                    "401"  => "TxRate-401k",
                    "402"  => "TxRate-402k",
                    "403"  => "TxRate-403k",
                    "404"  => "TxRate-404k",
                    "405"  => "TxRate-405k",
                    "406"  => "TxRate-406k",
                    "407"  => "TxRate-407k",
                    "408"  => "TxRate-408k",
                    "409"  => "TxRate-409k",
                    "410"  => "TxRate-410k",
                    "411"  => "TxRate-411k",
                    "412"  => "TxRate-412k",
                    "413"  => "TxRate-413k",
                    "414"  => "TxRate-414k",
                    "415"  => "TxRate-415k",
                    "416"  => "TxRate-416k",
                    "417"  => "TxRate-417k",
                    "418"  => "TxRate-418k",
                    "419"  => "TxRate-419k",
                    "420"  => "TxRate-420k",
                    "421"  => "TxRate-421k",
                    "422"  => "TxRate-422k",
                    "423"  => "TxRate-423k",
                    "424"  => "TxRate-424k",
                    "425"  => "TxRate-425k",
                    "426"  => "TxRate-426k",
                    "427"  => "TxRate-427k",
                    "428"  => "TxRate-428k",
                    "429"  => "TxRate-429k",
                    "430"  => "TxRate-430k",
                    "431"  => "TxRate-431k",
                    "432"  => "TxRate-432k",
                    "433"  => "TxRate-433k",
                    "434"  => "TxRate-434k",
                    "435"  => "TxRate-435k",
                    "436"  => "TxRate-436k",
                    "437"  => "TxRate-437k",
                    "438"  => "TxRate-438k",
                    "439"  => "TxRate-439k",
                    "440"  => "TxRate-440k",
                    "441"  => "TxRate-441k",
                    "442"  => "TxRate-442k",
                    "443"  => "TxRate-443k",
                    "444"  => "TxRate-444k",
                    "445"  => "TxRate-445k",
                    "446"  => "TxRate-446k",
                    "447"  => "TxRate-447k",
                    "448"  => "TxRate-448k",
                    "449"  => "TxRate-449k",
                    "450"  => "TxRate-450k",
                    "451"  => "TxRate-451k",
                    "452"  => "TxRate-452k",
                    "453"  => "TxRate-453k",
                    "454"  => "TxRate-454k",
                    "455"  => "TxRate-455k",
                    "456"  => "TxRate-456k",
                    "457"  => "TxRate-457k",
                    "458"  => "TxRate-458k",
                    "459"  => "TxRate-459k",
                    "460"  => "TxRate-460k",
                    "461"  => "TxRate-461k",
                    "462"  => "TxRate-462k",
                    "463"  => "TxRate-463k",
                    "464"  => "TxRate-464k",
                    "465"  => "TxRate-465k",
                    "466"  => "TxRate-466k",
                    "467"  => "TxRate-467k",
                    "468"  => "TxRate-468k",
                    "469"  => "TxRate-469k",
                    "470"  => "TxRate-470k",
                    "471"  => "TxRate-471k",
                    "472"  => "TxRate-472k",
                    "473"  => "TxRate-473k",
                    "474"  => "TxRate-474k",
                    "475"  => "TxRate-475k",
                    "476"  => "TxRate-476k",
                    "477"  => "TxRate-477k",
                    "478"  => "TxRate-478k",
                    "479"  => "TxRate-479k",
                    "480"  => "TxRate-480k",
                    "481"  => "TxRate-481k",
                    "482"  => "TxRate-482k",
                    "483"  => "TxRate-483k",
                    "484"  => "TxRate-484k",
                    "485"  => "TxRate-485k",
                    "486"  => "TxRate-486k",
                    "487"  => "TxRate-487k",
                    "488"  => "TxRate-488k",
                    "489"  => "TxRate-489k",
                    "490"  => "TxRate-490k",
                    "491"  => "TxRate-491k",
                    "492"  => "TxRate-492k",
                    "493"  => "TxRate-493k",
                    "494"  => "TxRate-494k",
                    "495"  => "TxRate-495k",
                    "496"  => "TxRate-496k",
                    "497"  => "TxRate-497k",
                    "498"  => "TxRate-498k",
                    "499"  => "TxRate-499k",
                    "500"  => "TxRate-500k",
                    "501"  => "TxRate-501k",
                    "502"  => "TxRate-502k",
                    "503"  => "TxRate-503k",
                    "504"  => "TxRate-504k",
                    "505"  => "TxRate-505k",
                    "506"  => "TxRate-506k",
                    "507"  => "TxRate-507k",
                    "508"  => "TxRate-508k",
                    "509"  => "TxRate-509k",
                    "510"  => "TxRate-510k",
                    "511"  => "TxRate-511k",
                    "512"  => "TxRate-512k",
                    "513"  => "TxRate-513k",
                    "514"  => "TxRate-514k",
                    "515"  => "TxRate-515k",
                    "516"  => "TxRate-516k",
                    "517"  => "TxRate-517k",
                    "518"  => "TxRate-518k",
                    "519"  => "TxRate-519k",
                    "520"  => "TxRate-520k",
                    "521"  => "TxRate-521k",
                    "522"  => "TxRate-522k",
                    "523"  => "TxRate-523k",
                    "524"  => "TxRate-524k",
                    "525"  => "TxRate-525k",
                    "526"  => "TxRate-526k",
                    "527"  => "TxRate-527k",
                    "528"  => "TxRate-528k",
                    "529"  => "TxRate-529k",
                    "530"  => "TxRate-530k",
                    "531"  => "TxRate-531k",
                    "532"  => "TxRate-532k",
                    "533"  => "TxRate-533k",
                    "534"  => "TxRate-534k",
                    "535"  => "TxRate-535k",
                    "536"  => "TxRate-536k",
                    "537"  => "TxRate-537k",
                    "538"  => "TxRate-538k",
                    "539"  => "TxRate-539k",
                    "540"  => "TxRate-540k",
                    "541"  => "TxRate-541k",
                    "542"  => "TxRate-542k",
                    "543"  => "TxRate-543k",
                    "544"  => "TxRate-544k",
                    "545"  => "TxRate-545k",
                    "546"  => "TxRate-546k",
                    "547"  => "TxRate-547k",
                    "548"  => "TxRate-548k",
                    "549"  => "TxRate-549k",
                    "550"  => "TxRate-550k",
                    "551"  => "TxRate-551k",
                    "552"  => "TxRate-552k",
                    "553"  => "TxRate-553k",
                    "554"  => "TxRate-554k",
                    "555"  => "TxRate-555k",
                    "556"  => "TxRate-556k",
                    "557"  => "TxRate-557k",
                    "558"  => "TxRate-558k",
                    "559"  => "TxRate-559k",
                    "560"  => "TxRate-560k",
                    "561"  => "TxRate-561k",
                    "562"  => "TxRate-562k",
                    "563"  => "TxRate-563k",
                    "564"  => "TxRate-564k",
                    "565"  => "TxRate-565k",
                    "566"  => "TxRate-566k",
                    "567"  => "TxRate-567k",
                    "568"  => "TxRate-568k",
                    "569"  => "TxRate-569k",
                    "570"  => "TxRate-570k",
                    "571"  => "TxRate-571k",
                    "572"  => "TxRate-572k",
                    "573"  => "TxRate-573k",
                    "574"  => "TxRate-574k",
                    "575"  => "TxRate-575k",
                    "576"  => "TxRate-576k",
                    "577"  => "TxRate-577k",
                    "578"  => "TxRate-578k",
                    "579"  => "TxRate-579k",
                    "580"  => "TxRate-580k",
                    "581"  => "TxRate-581k",
                    "582"  => "TxRate-582k",
                    "583"  => "TxRate-583k",
                    "584"  => "TxRate-584k",
                    "585"  => "TxRate-585k",
                    "586"  => "TxRate-586k",
                    "587"  => "TxRate-587k",
                    "588"  => "TxRate-588k",
                    "589"  => "TxRate-589k",
                    "590"  => "TxRate-590k",
                    "591"  => "TxRate-591k",
                    "592"  => "TxRate-592k",
                    "593"  => "TxRate-593k",
                    "594"  => "TxRate-594k",
                    "595"  => "TxRate-595k",
                    "596"  => "TxRate-596k",
                    "597"  => "TxRate-597k",
                    "598"  => "TxRate-598k",
                    "599"  => "TxRate-599k",
                    "600"  => "TxRate-600k",
                    "601"  => "TxRate-601k",
                    "602"  => "TxRate-602k",
                    "603"  => "TxRate-603k",
                    "604"  => "TxRate-604k",
                    "605"  => "TxRate-605k",
                    "606"  => "TxRate-606k",
                    "607"  => "TxRate-607k",
                    "608"  => "TxRate-608k",
                    "609"  => "TxRate-609k",
                    "610"  => "TxRate-610k",
                    "611"  => "TxRate-611k",
                    "612"  => "TxRate-612k",
                    "613"  => "TxRate-613k",
                    "614"  => "TxRate-614k",
                    "615"  => "TxRate-615k",
                    "616"  => "TxRate-616k",
                    "617"  => "TxRate-617k",
                    "618"  => "TxRate-618k",
                    "619"  => "TxRate-619k",
                    "620"  => "TxRate-620k",
                    "621"  => "TxRate-621k",
                    "622"  => "TxRate-622k",
                    "623"  => "TxRate-623k",
                    "624"  => "TxRate-624k",
                    "625"  => "TxRate-625k",
                    "626"  => "TxRate-626k",
                    "627"  => "TxRate-627k",
                    "628"  => "TxRate-628k",
                    "629"  => "TxRate-629k",
                    "630"  => "TxRate-630k",
                    "631"  => "TxRate-631k",
                    "632"  => "TxRate-632k",
                    "633"  => "TxRate-633k",
                    "634"  => "TxRate-634k",
                    "635"  => "TxRate-635k",
                    "636"  => "TxRate-636k",
                    "637"  => "TxRate-637k",
                    "638"  => "TxRate-638k",
                    "639"  => "TxRate-639k",
                    "640"  => "TxRate-640k",
                    "641"  => "TxRate-641k",
                    "642"  => "TxRate-642k",
                    "643"  => "TxRate-643k",
                    "644"  => "TxRate-644k",
                    "645"  => "TxRate-645k",
                    "646"  => "TxRate-646k",
                    "647"  => "TxRate-647k",
                    "648"  => "TxRate-648k",
                    "649"  => "TxRate-649k",
                    "650"  => "TxRate-650k",
                    "651"  => "TxRate-651k",
                    "652"  => "TxRate-652k",
                    "653"  => "TxRate-653k",
                    "654"  => "TxRate-654k",
                    "655"  => "TxRate-655k",
                    "656"  => "TxRate-656k",
                    "657"  => "TxRate-657k",
                    "658"  => "TxRate-658k",
                    "659"  => "TxRate-659k",
                    "660"  => "TxRate-660k",
                    "661"  => "TxRate-661k",
                    "662"  => "TxRate-662k",
                    "663"  => "TxRate-663k",
                    "664"  => "TxRate-664k",
                    "665"  => "TxRate-665k",
                    "666"  => "TxRate-666k",
                    "667"  => "TxRate-667k",
                    "668"  => "TxRate-668k",
                    "669"  => "TxRate-669k",
                    "670"  => "TxRate-670k",
                    "671"  => "TxRate-671k",
                    "672"  => "TxRate-672k",
                    "673"  => "TxRate-673k",
                    "674"  => "TxRate-674k",
                    "675"  => "TxRate-675k",
                    "676"  => "TxRate-676k",
                    "677"  => "TxRate-677k",
                    "678"  => "TxRate-678k",
                    "679"  => "TxRate-679k",
                    "680"  => "TxRate-680k",
                    "681"  => "TxRate-681k",
                    "682"  => "TxRate-682k",
                    "683"  => "TxRate-683k",
                    "684"  => "TxRate-684k",
                    "685"  => "TxRate-685k",
                    "686"  => "TxRate-686k",
                    "687"  => "TxRate-687k",
                    "688"  => "TxRate-688k",
                    "689"  => "TxRate-689k",
                    "690"  => "TxRate-690k",
                    "691"  => "TxRate-691k",
                    "692"  => "TxRate-692k",
                    "693"  => "TxRate-693k",
                    "694"  => "TxRate-694k",
                    "695"  => "TxRate-695k",
                    "696"  => "TxRate-696k",
                    "697"  => "TxRate-697k",
                    "698"  => "TxRate-698k",
                    "699"  => "TxRate-699k",
                    "700"  => "TxRate-700k",
                    "701"  => "TxRate-701k",
                    "702"  => "TxRate-702k",
                    "703"  => "TxRate-703k",
                    "704"  => "TxRate-704k",
                    "705"  => "TxRate-705k",
                    "706"  => "TxRate-706k",
                    "707"  => "TxRate-707k",
                    "708"  => "TxRate-708k",
                    "709"  => "TxRate-709k",
                    "710"  => "TxRate-710k",
                    "711"  => "TxRate-711k",
                    "712"  => "TxRate-712k",
                    "713"  => "TxRate-713k",
                    "714"  => "TxRate-714k",
                    "715"  => "TxRate-715k",
                    "716"  => "TxRate-716k",
                    "717"  => "TxRate-717k",
                    "718"  => "TxRate-718k",
                    "719"  => "TxRate-719k",
                    "720"  => "TxRate-720k",
                    "721"  => "TxRate-721k",
                    "722"  => "TxRate-722k",
                    "723"  => "TxRate-723k",
                    "724"  => "TxRate-724k",
                    "725"  => "TxRate-725k",
                    "726"  => "TxRate-726k",
                    "727"  => "TxRate-727k",
                    "728"  => "TxRate-728k",
                    "729"  => "TxRate-729k",
                    "730"  => "TxRate-730k",
                    "731"  => "TxRate-731k",
                    "732"  => "TxRate-732k",
                    "733"  => "TxRate-733k",
                    "734"  => "TxRate-734k",
                    "735"  => "TxRate-735k",
                    "736"  => "TxRate-736k",
                    "737"  => "TxRate-737k",
                    "738"  => "TxRate-738k",
                    "739"  => "TxRate-739k",
                    "740"  => "TxRate-740k",
                    "741"  => "TxRate-741k",
                    "742"  => "TxRate-742k",
                    "743"  => "TxRate-743k",
                    "744"  => "TxRate-744k",
                    "745"  => "TxRate-745k",
                    "746"  => "TxRate-746k",
                    "747"  => "TxRate-747k",
                    "748"  => "TxRate-748k",
                    "749"  => "TxRate-749k",
                    "750"  => "TxRate-750k",
                    "751"  => "TxRate-751k",
                    "752"  => "TxRate-752k",
                    "753"  => "TxRate-753k",
                    "754"  => "TxRate-754k",
                    "755"  => "TxRate-755k",
                    "756"  => "TxRate-756k",
                    "757"  => "TxRate-757k",
                    "758"  => "TxRate-758k",
                    "759"  => "TxRate-759k",
                    "760"  => "TxRate-760k",
                    "761"  => "TxRate-761k",
                    "762"  => "TxRate-762k",
                    "763"  => "TxRate-763k",
                    "764"  => "TxRate-764k",
                    "765"  => "TxRate-765k",
                    "766"  => "TxRate-766k",
                    "767"  => "TxRate-767k",
                    "768"  => "TxRate-768k",
                    "769"  => "TxRate-769k",
                    "770"  => "TxRate-770k",
                    "771"  => "TxRate-771k",
                    "772"  => "TxRate-772k",
                    "773"  => "TxRate-773k",
                    "774"  => "TxRate-774k",
                    "775"  => "TxRate-775k",
                    "776"  => "TxRate-776k",
                    "777"  => "TxRate-777k",
                    "778"  => "TxRate-778k",
                    "779"  => "TxRate-779k",
                    "780"  => "TxRate-780k",
                    "781"  => "TxRate-781k",
                    "782"  => "TxRate-782k",
                    "783"  => "TxRate-783k",
                    "784"  => "TxRate-784k",
                    "785"  => "TxRate-785k",
                    "786"  => "TxRate-786k",
                    "787"  => "TxRate-787k",
                    "788"  => "TxRate-788k",
                    "789"  => "TxRate-789k",
                    "790"  => "TxRate-790k",
                    "791"  => "TxRate-791k",
                    "792"  => "TxRate-792k",
                    "793"  => "TxRate-793k",
                    "794"  => "TxRate-794k",
                    "795"  => "TxRate-795k",
                    "796"  => "TxRate-796k",
                    "797"  => "TxRate-797k",
                    "798"  => "TxRate-798k",
                    "799"  => "TxRate-799k",
                    "800"  => "TxRate-800k",
                    "801"  => "TxRate-801k",
                    "802"  => "TxRate-802k",
                    "803"  => "TxRate-803k",
                    "804"  => "TxRate-804k",
                    "805"  => "TxRate-805k",
                    "806"  => "TxRate-806k",
                    "807"  => "TxRate-807k",
                    "808"  => "TxRate-808k",
                    "809"  => "TxRate-809k",
                    "810"  => "TxRate-810k",
                    "811"  => "TxRate-811k",
                    "812"  => "TxRate-812k",
                    "813"  => "TxRate-813k",
                    "814"  => "TxRate-814k",
                    "815"  => "TxRate-815k",
                    "816"  => "TxRate-816k",
                    "817"  => "TxRate-817k",
                    "818"  => "TxRate-818k",
                    "819"  => "TxRate-819k",
                    "820"  => "TxRate-820k",
                    "821"  => "TxRate-821k",
                    "822"  => "TxRate-822k",
                    "823"  => "TxRate-823k",
                    "824"  => "TxRate-824k",
                    "825"  => "TxRate-825k",
                    "826"  => "TxRate-826k",
                    "827"  => "TxRate-827k",
                    "828"  => "TxRate-828k",
                    "829"  => "TxRate-829k",
                    "830"  => "TxRate-830k",
                    "831"  => "TxRate-831k",
                    "832"  => "TxRate-832k",
                    "833"  => "TxRate-833k",
                    "834"  => "TxRate-834k",
                    "835"  => "TxRate-835k",
                    "836"  => "TxRate-836k",
                    "837"  => "TxRate-837k",
                    "838"  => "TxRate-838k",
                    "839"  => "TxRate-839k",
                    "840"  => "TxRate-840k",
                    "841"  => "TxRate-841k",
                    "842"  => "TxRate-842k",
                    "843"  => "TxRate-843k",
                    "844"  => "TxRate-844k",
                    "845"  => "TxRate-845k",
                    "846"  => "TxRate-846k",
                    "847"  => "TxRate-847k",
                    "848"  => "TxRate-848k",
                    "849"  => "TxRate-849k",
                    "850"  => "TxRate-850k",
                    "851"  => "TxRate-851k",
                    "852"  => "TxRate-852k",
                    "853"  => "TxRate-853k",
                    "854"  => "TxRate-854k",
                    "855"  => "TxRate-855k",
                    "856"  => "TxRate-856k",
                    "857"  => "TxRate-857k",
                    "858"  => "TxRate-858k",
                    "859"  => "TxRate-859k",
                    "860"  => "TxRate-860k",
                    "861"  => "TxRate-861k",
                    "862"  => "TxRate-862k",
                    "863"  => "TxRate-863k",
                    "864"  => "TxRate-864k",
                    "865"  => "TxRate-865k",
                    "866"  => "TxRate-866k",
                    "867"  => "TxRate-867k",
                    "868"  => "TxRate-868k",
                    "869"  => "TxRate-869k",
                    "870"  => "TxRate-870k",
                    "871"  => "TxRate-871k",
                    "872"  => "TxRate-872k",
                    "873"  => "TxRate-873k",
                    "874"  => "TxRate-874k",
                    "875"  => "TxRate-875k",
                    "876"  => "TxRate-876k",
                    "877"  => "TxRate-877k",
                    "878"  => "TxRate-878k",
                    "879"  => "TxRate-879k",
                    "880"  => "TxRate-880k",
                    "881"  => "TxRate-881k",
                    "882"  => "TxRate-882k",
                    "883"  => "TxRate-883k",
                    "884"  => "TxRate-884k",
                    "885"  => "TxRate-885k",
                    "886"  => "TxRate-886k",
                    "887"  => "TxRate-887k",
                    "888"  => "TxRate-888k",
                    "889"  => "TxRate-889k",
                    "890"  => "TxRate-890k",
                    "891"  => "TxRate-891k",
                    "892"  => "TxRate-892k",
                    "893"  => "TxRate-893k",
                    "894"  => "TxRate-894k",
                    "895"  => "TxRate-895k",
                    "896"  => "TxRate-896k",
                    "897"  => "TxRate-897k",
                    "898"  => "TxRate-898k",
                    "899"  => "TxRate-899k",
                    "900"  => "TxRate-900k",
                    "901"  => "TxRate-901k",
                    "902"  => "TxRate-902k",
                    "903"  => "TxRate-903k",
                    "904"  => "TxRate-904k",
                    "905"  => "TxRate-905k",
                    "906"  => "TxRate-906k",
                    "907"  => "TxRate-907k",
                    "908"  => "TxRate-908k",
                    "909"  => "TxRate-909k",
                    "910"  => "TxRate-910k",
                    "911"  => "TxRate-911k",
                    "912"  => "TxRate-912k",
                    "913"  => "TxRate-913k",
                    "914"  => "TxRate-914k",
                    "915"  => "TxRate-915k",
                    "916"  => "TxRate-916k",
                    "917"  => "TxRate-917k",
                    "918"  => "TxRate-918k",
                    "919"  => "TxRate-919k",
                    "920"  => "TxRate-920k",
                    "921"  => "TxRate-921k",
                    "922"  => "TxRate-922k",
                    "923"  => "TxRate-923k",
                    "924"  => "TxRate-924k",
                    "925"  => "TxRate-925k",
                    "926"  => "TxRate-926k",
                    "927"  => "TxRate-927k",
                    "928"  => "TxRate-928k",
                    "929"  => "TxRate-929k",
                    "930"  => "TxRate-930k",
                    "931"  => "TxRate-931k",
                    "932"  => "TxRate-932k",
                    "933"  => "TxRate-933k",
                    "934"  => "TxRate-934k",
                    "935"  => "TxRate-935k",
                    "936"  => "TxRate-936k",
                    "937"  => "TxRate-937k",
                    "938"  => "TxRate-938k",
                    "939"  => "TxRate-939k",
                    "940"  => "TxRate-940k",
                    "941"  => "TxRate-941k",
                    "942"  => "TxRate-942k",
                    "943"  => "TxRate-943k",
                    "944"  => "TxRate-944k",
                    "945"  => "TxRate-945k",
                    "946"  => "TxRate-946k",
                    "947"  => "TxRate-947k",
                    "948"  => "TxRate-948k",
                    "949"  => "TxRate-949k",
                    "950"  => "TxRate-950k",
                    "951"  => "TxRate-951k",
                    "952"  => "TxRate-952k",
                    "953"  => "TxRate-953k",
                    "954"  => "TxRate-954k",
                    "955"  => "TxRate-955k",
                    "956"  => "TxRate-956k",
                    "957"  => "TxRate-957k",
                    "958"  => "TxRate-958k",
                    "959"  => "TxRate-959k",
                    "960"  => "TxRate-960k",
                    "961"  => "TxRate-961k",
                    "962"  => "TxRate-962k",
                    "963"  => "TxRate-963k",
                    "964"  => "TxRate-964k",
                    "965"  => "TxRate-965k",
                    "966"  => "TxRate-966k",
                    "967"  => "TxRate-967k",
                    "968"  => "TxRate-968k",
                    "969"  => "TxRate-969k",
                    "970"  => "TxRate-970k",
                    "971"  => "TxRate-971k",
                    "972"  => "TxRate-972k",
                    "973"  => "TxRate-973k",
                    "974"  => "TxRate-974k",
                    "975"  => "TxRate-975k",
                    "976"  => "TxRate-976k",
                    "977"  => "TxRate-977k",
                    "978"  => "TxRate-978k",
                    "979"  => "TxRate-979k",
                    "980"  => "TxRate-980k",
                    "981"  => "TxRate-981k",
                    "982"  => "TxRate-982k",
                    "983"  => "TxRate-983k",
                    "984"  => "TxRate-984k",
                    "985"  => "TxRate-985k",
                    "986"  => "TxRate-986k",
                    "987"  => "TxRate-987k",
                    "988"  => "TxRate-988k",
                    "989"  => "TxRate-989k",
                    "990"  => "TxRate-990k",
                    "991"  => "TxRate-991k",
                    "992"  => "TxRate-992k",
                    "993"  => "TxRate-993k",
                    "994"  => "TxRate-994k",
                    "995"  => "TxRate-995k",
                    "996"  => "TxRate-996k",
                    "997"  => "TxRate-997k",
                    "998"  => "TxRate-998k",
                    "999"  => "TxRate-999k",
                    "1000" => "TxRate-1000k",
                    "1001" => "TxRate-1001k",
                    "1002" => "TxRate-1002k",
                    "1003" => "TxRate-1003k",
                    "1004" => "TxRate-1004k",
                    "1005" => "TxRate-1005k",
                    "1006" => "TxRate-1006k",
                    "1007" => "TxRate-1007k",
                    "1008" => "TxRate-1008k",
                    "1009" => "TxRate-1009k",
                    "1010" => "TxRate-1010k",
                    "1011" => "TxRate-1011k",
                    "1012" => "TxRate-1012k",
                    "1013" => "TxRate-1013k",
                    "1014" => "TxRate-1014k",
                    "1015" => "TxRate-1015k",
                    "1016" => "TxRate-1016k",
                    "1017" => "TxRate-1017k",
                    "1018" => "TxRate-1018k",
                    "1019" => "TxRate-1019k",
                    "1020" => "TxRate-1020k",
                    "1021" => "TxRate-1021k",
                    "1022" => "TxRate-1022k",
                    "1023" => "TxRate-1023k",
                    "1024" => "TxRate-1024k",
                    "1025" => "TxRate-1152k",
                    "1026" => "TxRate-1280k",
                    "1027" => "TxRate-1408k",
                    "1028" => "TxRate-1536k",
                    "1029" => "TxRate-1664k",
                    "1030" => "TxRate-1792k",
                    "1031" => "TxRate-1920k",
                    "1032" => "TxRate-2048k",
                    "1033" => "TxRate-2176k",
                    "1034" => "TxRate-2304k",
                    "1035" => "TxRate-2432k",
                    "1036" => "TxRate-2560k",
                    "1037" => "TxRate-2688k",
                    "1038" => "TxRate-2816k",
                    "1039" => "TxRate-2944k",
                    "1040" => "TxRate-3072k",
                    "1041" => "TxRate-3200k",
                    "1042" => "TxRate-3328k",
                    "1043" => "TxRate-3456k",
                    "1044" => "TxRate-3584k",
                    "1045" => "TxRate-3712k",
                    "1046" => "TxRate-3840k",
                    "1047" => "TxRate-3968k",
                    "1048" => "TxRate-4096k",
                    "1049" => "TxRate-4224k",
                    "1050" => "TxRate-4352k",
                    "1051" => "TxRate-4480k",
                    "1052" => "TxRate-4608k",
                    "1053" => "TxRate-4736k",
                    "1054" => "TxRate-4864k",
                    "1055" => "TxRate-4992k",
                    "1056" => "TxRate-5120k",
                    "1057" => "TxRate-5248k",
                    "1058" => "TxRate-5376k",
                    "1059" => "TxRate-5504k",
                    "1060" => "TxRate-5632k",
                    "1061" => "TxRate-5760k",
                    "1062" => "TxRate-5888k",
                    "1063" => "TxRate-6016k",
                    "1064" => "TxRate-6144k",
                    "1065" => "TxRate-6272k",
                    "1066" => "TxRate-6400k",
                    "1067" => "TxRate-6528k",
                    "1068" => "TxRate-6656k",
                    "1069" => "TxRate-6784k",
                    "1070" => "TxRate-6912k",
                    "1071" => "TxRate-7040k",
                    "1072" => "TxRate-7168k",
                    "1073" => "TxRate-7296k",
                    "1074" => "TxRate-7424k",
                    "1075" => "TxRate-7552k",
                    "1076" => "TxRate-7680k",
                    "1077" => "TxRate-7808k",
                    "1078" => "TxRate-7936k",
                    "1079" => "TxRate-8064k",
                    "1080" => "TxRate-8192k",
                    "1081" => "TxRate-8320k",
                    "1082" => "TxRate-8448k",
                    "1083" => "TxRate-8576k",
                    "1084" => "TxRate-8704k",
                    "1085" => "TxRate-8832k",
                    "1086" => "TxRate-8960k",
                    "1087" => "TxRate-9088k",
                    "1088" => "TxRate-9216k",
                    "1089" => "TxRate-9344k",
                    "1090" => "TxRate-9472k",
                    "1091" => "TxRate-9600k",
                    "1092" => "TxRate-9728k",
                    "1093" => "TxRate-9856k",
                    "1094" => "TxRate-9984k",
                    "1095" => "TxRate-10112k",
                    "1096" => "TxRate-10240k",
                    "1097" => "TxRate-10368k",
                    "1098" => "TxRate-10496k",
                    "1099" => "TxRate-10624k",
                    "1100" => "TxRate-10752k",
                    "1101" => "TxRate-10880k",
                    "1102" => "TxRate-11008k",
                    "1103" => "TxRate-11136k",
                    "1104" => "TxRate-11264k",
                    "1105" => "TxRate-11392k",
                    "1106" => "TxRate-11520k",
                    "1107" => "TxRate-11648k",
                    "1108" => "TxRate-11776k",
                    "1109" => "TxRate-11904k",
                    "1110" => "TxRate-12032k",
                    "1111" => "TxRate-12160k",
                    "1112" => "TxRate-12288k",
                    "1113" => "TxRate-12416k",
                    "1114" => "TxRate-12544k",
                    "1115" => "TxRate-12672k",
                    "1116" => "TxRate-12800k",
                    "1117" => "TxRate-12928k",
                    "1118" => "TxRate-13056k",
                    "1119" => "TxRate-13184k",
                    "1120" => "TxRate-13312k",
                    "1121" => "TxRate-13440k",
                    "1122" => "TxRate-13568k",
                    "1123" => "TxRate-13696k",
                    "1124" => "TxRate-13824k",
                    "1125" => "TxRate-13952k",
                    "1126" => "TxRate-14080k",
                    "1127" => "TxRate-14208k",
                    "1128" => "TxRate-14336k",
                    "1129" => "TxRate-14464k",
                    "1130" => "TxRate-14592k",
                    "1131" => "TxRate-14720k",
                    "1132" => "TxRate-14848k",
                    "1133" => "TxRate-14976k",
                    "1134" => "TxRate-15104k",
                    "1135" => "TxRate-15232k",
                    "1136" => "TxRate-15360k",
                    "1137" => "TxRate-15488k",
                    "1138" => "TxRate-15616k",
                    "1139" => "TxRate-15744k",
                    "1140" => "TxRate-15872k",
                    "1141" => "TxRate-16000k",
                    "1142" => "TxRate-16128k",
                    "1143" => "TxRate-16256k",
                    "1144" => "TxRate-16384k",
                    "1145" => "TxRate-16512k",
                    "1146" => "TxRate-16640k",
                    "1147" => "TxRate-16768k",
                    "1148" => "TxRate-16896k",
                    "1149" => "TxRate-17024k",
                    "1150" => "TxRate-17152k",
                    "1151" => "TxRate-17280k",
                    "1152" => "TxRate-17408k",
                    "1153" => "TxRate-17536k",
                    "1154" => "TxRate-17664k",
                    "1155" => "TxRate-17792k",
                    "1156" => "TxRate-17920k",
                    "1157" => "TxRate-18048k",
                    "1158" => "TxRate-18176k",
                    "1159" => "TxRate-18304k",
                    "1160" => "TxRate-18432k",
                    "1161" => "TxRate-18560k",
                    "1162" => "TxRate-18688k",
                    "1163" => "TxRate-18816k",
                    "1164" => "TxRate-18944k",
                    "1165" => "TxRate-19072k",
                    "1166" => "TxRate-19200k",
                    "1167" => "TxRate-19328k",
                    "1168" => "TxRate-19456k",
                    "1169" => "TxRate-19584k",
                    "1170" => "TxRate-19712k",
                    "1171" => "TxRate-19840k",
                    "1172" => "TxRate-19968k",
                    "1173" => "TxRate-20096k",
                    "1174" => "TxRate-20224k",
                    "1175" => "TxRate-20352k",
                    "1176" => "TxRate-20480k",
                    "1177" => "TxRate-20608k",
                    "1178" => "TxRate-20736k",
                    "1179" => "TxRate-20864k",
                    "1180" => "TxRate-20992k",
                    "1181" => "TxRate-21120k",
                    "1182" => "TxRate-21248k",
                    "1183" => "TxRate-21376k",
                    "1184" => "TxRate-21504k",
                    "1185" => "TxRate-21632k",
                    "1186" => "TxRate-21760k",
                    "1187" => "TxRate-21888k",
                    "1188" => "TxRate-22016k",
                    "1189" => "TxRate-22144k",
                    "1190" => "TxRate-22272k",
                    "1191" => "TxRate-22400k",
                    "1192" => "TxRate-22528k",
                    "1193" => "TxRate-22656k",
                    "1194" => "TxRate-22784k",
                    "1195" => "TxRate-22912k",
                    "1196" => "TxRate-23040k",
                    "1197" => "TxRate-23168k",
                    "1198" => "TxRate-23296k",
                    "1199" => "TxRate-23424k",
                    "1200" => "TxRate-23552k",
                    "1201" => "TxRate-23680k",
                    "1202" => "TxRate-23808k",
                    "1203" => "TxRate-23936k",
                    "1204" => "TxRate-24064k",
                    "1205" => "TxRate-24192k",
                    "1206" => "TxRate-24320k",
                    "1207" => "TxRate-24448k",
                    "1208" => "TxRate-24576k",
                    "1209" => "TxRate-24704k",
                    "1210" => "TxRate-24832k",
                    "1211" => "TxRate-24960k",
                    "1212" => "TxRate-25088k",
                    "1213" => "TxRate-25216k",
                    "1214" => "TxRate-25344k",
                    "1215" => "TxRate-25472k",
                    "1216" => "TxRate-25600k",
                    "1217" => "TxRate-25728k",
                    "1218" => "TxRate-25856k",
                    "1219" => "TxRate-25984k",
                    "1220" => "TxRate-26112k",
                    "1221" => "TxRate-26240k",
                    "1222" => "TxRate-26368k",
                    "1223" => "TxRate-26496k",
                    "1224" => "TxRate-26624k",
                    "1225" => "TxRate-26752k",
                    "1226" => "TxRate-26880k",
                    "1227" => "TxRate-27008k",
                    "1228" => "TxRate-27136k",
                    "1229" => "TxRate-27264k",
                    "1230" => "TxRate-27392k",
                    "1231" => "TxRate-27520k",
                    "1232" => "TxRate-27648k",
                    "1233" => "TxRate-27776k",
                    "1234" => "TxRate-27904k",
                    "1235" => "TxRate-28032k",
                    "1236" => "TxRate-28160k",
                    "1237" => "TxRate-28288k",
                    "1238" => "TxRate-28416k",
                    "1239" => "TxRate-28544k",
                    "1240" => "TxRate-28672k",
                    "1241" => "TxRate-28800k",
                    "1242" => "TxRate-28928k",
                    "1243" => "TxRate-29056k",
                    "1244" => "TxRate-29184k",
                    "1245" => "TxRate-29312k",
                    "1246" => "TxRate-29440k",
                    "1247" => "TxRate-29568k",
                    "1248" => "TxRate-29696k",
                    "1249" => "TxRate-29824k",
                    "1250" => "TxRate-29952k",
                    "1251" => "TxRate-30080k",
                    "1252" => "TxRate-30208k",
                    "1253" => "TxRate-30336k",
                    "1254" => "TxRate-30464k",
                    "1255" => "TxRate-30592k",
                    "1256" => "TxRate-30720k",
                    "1257" => "TxRate-30848k",
                    "1258" => "TxRate-30976k",
                    "1259" => "TxRate-31104k",
                    "1260" => "TxRate-31232k",
                    "1261" => "TxRate-31360k",
                    "1262" => "TxRate-31488k",
                    "1263" => "TxRate-31616k",
                    "1264" => "TxRate-31744k",
                    "1265" => "TxRate-31872k",
                    "1266" => "TxRate-32000k",
                    "1267" => "TxRate-32128k",
                    "1268" => "TxRate-32256k",
                    "1269" => "TxRate-32384k",
                    "1270" => "TxRate-32512k",
                    "1271" => "TxRate-32640k",
                    "1272" => "TxRate-32768k",
                    "1273" => "TxRate-32896k",
                    "1274" => "TxRate-33024k",
                    "1275" => "TxRate-33152k",
                    "1276" => "TxRate-33280k",
                    "1277" => "TxRate-33408k",
                    "1278" => "TxRate-33536k",
                    "1279" => "TxRate-33664k",
                    "1280" => "TxRate-33792k",
                    "1281" => "TxRate-33920k",
                    "1282" => "TxRate-34048k",
                    "1283" => "TxRate-34176k",
                    "1284" => "TxRate-34304k",
                    "1285" => "TxRate-34432k",
                    "1286" => "TxRate-34560k",
                    "1287" => "TxRate-34688k",
                    "1288" => "TxRate-34816k",
                    "1289" => "TxRate-34944k",
                    "1290" => "TxRate-35072k",
                    "1291" => "TxRate-35200k",
                    "1292" => "TxRate-35328k",
                    "1293" => "TxRate-35456k",
                    "1294" => "TxRate-35584k",
                    "1295" => "TxRate-35712k",
                    "1296" => "TxRate-35840k",
                    "1297" => "TxRate-35968k",
                    "1298" => "TxRate-36096k",
                    "1299" => "TxRate-36224k",
                    "1300" => "TxRate-36352k",
                    "1301" => "TxRate-36480k",
                    "1302" => "TxRate-36608k",
                    "1303" => "TxRate-36736k",
                    "1304" => "TxRate-36864k",
                    "1305" => "TxRate-36992k",
                    "1306" => "TxRate-37120k",
                    "1307" => "TxRate-37248k",
                    "1308" => "TxRate-37376k",
                    "1309" => "TxRate-37504k",
                    "1310" => "TxRate-37632k",
                    "1311" => "TxRate-37760k",
                    "1312" => "TxRate-37888k",
                    "1313" => "TxRate-38016k",
                    "1314" => "TxRate-38144k",
                    "1315" => "TxRate-38272k",
                    "1316" => "TxRate-38400k",
                    "1317" => "TxRate-38528k",
                    "1318" => "TxRate-38656k",
                    "1319" => "TxRate-38784k",
                    "1320" => "TxRate-38912k",
                    "1321" => "TxRate-39040k",
                    "1322" => "TxRate-39168k",
                    "1323" => "TxRate-39296k",
                    "1324" => "TxRate-39424k",
                    "1325" => "TxRate-39552k",
                    "1326" => "TxRate-39680k",
                    "1327" => "TxRate-39808k",
                    "1328" => "TxRate-39936k",
                    "1329" => "TxRate-40064k",
                    "1330" => "TxRate-40192k",
                    "1331" => "TxRate-40320k",
                    "1332" => "TxRate-40448k",
                    "1333" => "TxRate-40576k",
                    "1334" => "TxRate-40704k",
                    "1335" => "TxRate-40832k",
                    "1336" => "TxRate-40960k",
                    "1337" => "TxRate-41088k",
                    "1338" => "TxRate-41216k",
                    "1339" => "TxRate-41344k",
                    "1340" => "TxRate-41472k",
                    "1341" => "TxRate-41600k",
                    "1342" => "TxRate-41728k",
                    "1343" => "TxRate-41856k",
                    "1344" => "TxRate-41984k",
                    "1345" => "TxRate-42112k",
                    "1346" => "TxRate-42240k",
                    "1347" => "TxRate-42368k",
                    "1348" => "TxRate-42496k",
                    "1349" => "TxRate-42624k",
                    "1350" => "TxRate-42752k",
                    "1351" => "TxRate-42880k",
                    "1352" => "TxRate-43008k",
                    "1353" => "TxRate-43136k",
                    "1354" => "TxRate-43264k",
                    "1355" => "TxRate-43392k",
                    "1356" => "TxRate-43520k",
                    "1357" => "TxRate-43648k",
                    "1358" => "TxRate-43776k",
                    "1359" => "TxRate-43904k",
                    "1360" => "TxRate-44032k",
                    "1361" => "TxRate-44160k",
                    "1362" => "TxRate-44288k",
                    "1363" => "TxRate-44416k",
                    "1364" => "TxRate-44544k",
                    "1365" => "TxRate-44672k",
                    "1366" => "TxRate-44800k",
                    "1367" => "TxRate-44928k",
                    "1368" => "TxRate-45056k",
                    "1369" => "TxRate-45184k",
                    "1370" => "TxRate-45312k",
                    "1371" => "TxRate-45440k",
                    "1372" => "TxRate-45568k",
                    "1373" => "TxRate-45696k",
                    "1374" => "TxRate-45824k",
                    "1375" => "TxRate-45952k",
                    "1376" => "TxRate-46080k",
                    "1377" => "TxRate-46208k",
                    "1378" => "TxRate-46336k",
                    "1379" => "TxRate-46464k",
                    "1380" => "TxRate-46592k",
                    "1381" => "TxRate-46720k",
                    "1382" => "TxRate-46848k",
                    "1383" => "TxRate-46976k",
                    "1384" => "TxRate-47104k",
                    "1385" => "TxRate-47232k",
                    "1386" => "TxRate-47360k",
                    "1387" => "TxRate-47488k",
                    "1388" => "TxRate-47616k",
                    "1389" => "TxRate-47744k",
                    "1390" => "TxRate-47872k",
                    "1391" => "TxRate-48000k",
                    "1392" => "TxRate-48128k",
                    "1393" => "TxRate-48256k",
                    "1394" => "TxRate-48384k",
                    "1395" => "TxRate-48512k",
                    "1396" => "TxRate-48640k",
                    "1397" => "TxRate-48768k",
                    "1398" => "TxRate-48896k",
                    "1399" => "TxRate-49024k",
                    "1400" => "TxRate-49152k",
                    "1401" => "TxRate-49280k",
                    "1402" => "TxRate-49408k",
                    "1403" => "TxRate-49536k",
                    "1404" => "TxRate-49664k",
                    "1405" => "TxRate-49792k",
                    "1406" => "TxRate-49920k",
                    "1407" => "TxRate-50048k",
                    "1408" => "TxRate-50176k",
                    "1409" => "TxRate-50304k",
                    "1410" => "TxRate-50432k",
                    "1411" => "TxRate-50560k",
                    "1412" => "TxRate-50688k",
                    "1413" => "TxRate-50816k",
                    "1414" => "TxRate-50944k",
                    "1415" => "TxRate-51072k",
                    "1416" => "TxRate-51200k",
                    "1417" => "TxRate-51328k",
                    "1418" => "TxRate-51456k",
                    "1419" => "TxRate-51584k",
                    "1420" => "TxRate-51712k",
                    "1421" => "TxRate-51840k",
                    "1422" => "TxRate-51968k",
                    "1423" => "TxRate-52096k",
                    "1424" => "TxRate-52224k",
                    "1425" => "TxRate-52352k",
                    "1426" => "TxRate-52480k",
                    "1427" => "TxRate-52608k",
                    "1428" => "TxRate-52736k",
                    "1429" => "TxRate-52864k",
                    "1430" => "TxRate-52992k",
                    "1431" => "TxRate-53120k",
                    "1432" => "TxRate-53248k",
                    "1433" => "TxRate-53376k",
                    "1434" => "TxRate-53504k",
                    "1435" => "TxRate-53632k",
                    "1436" => "TxRate-53760k",
                    "1437" => "TxRate-53888k",
                    "1438" => "TxRate-54016k",
                    "1439" => "TxRate-54144k",
                    "1440" => "TxRate-54272k",
                    "1441" => "TxRate-54400k",
                    "1442" => "TxRate-54528k",
                    "1443" => "TxRate-54656k",
                    "1444" => "TxRate-54784k",
                    "1445" => "TxRate-54912k",
                    "1446" => "TxRate-55040k",
                    "1447" => "TxRate-55168k",
                    "1448" => "TxRate-55296k",
                    "1449" => "TxRate-55424k",
                    "1450" => "TxRate-55552k",
                    "1451" => "TxRate-55680k",
                    "1452" => "TxRate-55808k",
                    "1453" => "TxRate-55936k",
                    "1454" => "TxRate-56064k",
                    "1455" => "TxRate-56192k",
                    "1456" => "TxRate-56320k",
                    "1457" => "TxRate-56448k",
                    "1458" => "TxRate-56576k",
                    "1459" => "TxRate-56704k",
                    "1460" => "TxRate-56832k",
                    "1461" => "TxRate-56960k",
                    "1462" => "TxRate-57088k",
                    "1463" => "TxRate-57216k",
                    "1464" => "TxRate-57344k",
                    "1465" => "TxRate-57472k",
                    "1466" => "TxRate-57600k",
                    "1467" => "TxRate-57728k",
                    "1468" => "TxRate-57856k",
                    "1469" => "TxRate-57984k",
                    "1470" => "TxRate-58112k",
                    "1471" => "TxRate-58240k",
                    "1472" => "TxRate-58368k",
                    "1473" => "TxRate-58496k",
                    "1474" => "TxRate-58624k",
                    "1475" => "TxRate-58752k",
                    "1476" => "TxRate-58880k",
                    "1477" => "TxRate-59008k",
                    "1478" => "TxRate-59136k",
                    "1479" => "TxRate-59264k",
                    "1480" => "TxRate-59392k",
                    "1481" => "TxRate-59520k",
                    "1482" => "TxRate-59648k",
                    "1483" => "TxRate-59776k",
                    "1484" => "TxRate-59904k",
                    "1485" => "TxRate-60032k",
                    "1486" => "TxRate-60160k",
                    "1487" => "TxRate-60288k",
                    "1488" => "TxRate-60416k",
                    "1489" => "TxRate-60544k",
                    "1490" => "TxRate-60672k",
                    "1491" => "TxRate-60800k",
                    "1492" => "TxRate-60928k",
                    "1493" => "TxRate-61056k",
                    "1494" => "TxRate-61184k",
                    "1495" => "TxRate-61312k",
                    "1496" => "TxRate-61440k",
                    "1497" => "TxRate-61568k",
                    "1498" => "TxRate-61696k",
                    "1499" => "TxRate-61824k",
                    "1500" => "TxRate-61952k",
                    "1501" => "TxRate-62080k",
                    "1502" => "TxRate-62208k",
                    "1503" => "TxRate-62336k",
                    "1504" => "TxRate-62464k",
                    "1505" => "TxRate-62592k",
                    "1506" => "TxRate-62720k",
                    "1507" => "TxRate-62848k",
                    "1508" => "TxRate-62976k",
                    "1509" => "TxRate-63104k",
                    "1510" => "TxRate-63232k",
                    "1511" => "TxRate-63360k",
                    "1512" => "TxRate-63488k",
                    "1513" => "TxRate-63616k",
                    "1514" => "TxRate-63744k",
                    "1515" => "TxRate-63872k",
                    "1516" => "TxRate-64000k",
                    "1517" => "TxRate-64128k",
                    "1518" => "TxRate-64256k",
                    "1519" => "TxRate-64384k",
                    "1520" => "TxRate-64512k",
                    "1521" => "TxRate-64640k",
                    "1522" => "TxRate-64768k",
                    "1523" => "TxRate-64896k",
                    "1524" => "TxRate-65024k",
                    "1525" => "TxRate-65152k",
                    "1526" => "TxRate-65280k",
                    "1527" => "TxRate-65408k",
                    "1528" => "TxRate-65536k",
                    "1529" => "TxRate-65664k",
                    "1530" => "TxRate-65792k",
                    "1531" => "TxRate-65920k",
                    "1532" => "TxRate-66048k",
                    "1533" => "TxRate-66176k",
                    "1534" => "TxRate-66304k",
                    "1535" => "TxRate-66432k",
                    "1536" => "TxRate-66560k",
                    "1537" => "TxRate-66688k",
                    "1538" => "TxRate-66816k",
                    "1539" => "TxRate-66944k",
                    "1540" => "TxRate-67072k",
                    "1541" => "TxRate-67200k",
                    "1542" => "TxRate-67328k",
                    "1543" => "TxRate-67456k",
                    "1544" => "TxRate-67584k",
                    "1545" => "TxRate-67712k",
                    "1546" => "TxRate-67840k",
                    "1547" => "TxRate-67968k",
                    "1548" => "TxRate-68096k",
                    "1549" => "TxRate-68224k",
                    "1550" => "TxRate-68352k",
                    "1551" => "TxRate-68480k",
                    "1552" => "TxRate-68608k",
                    "1553" => "TxRate-68736k",
                    "1554" => "TxRate-68864k",
                    "1555" => "TxRate-68992k",
                    "1556" => "TxRate-69120k",
                    "1557" => "TxRate-69248k",
                    "1558" => "TxRate-69376k",
                    "1559" => "TxRate-69504k",
                    "1560" => "TxRate-69632k",
                    "1561" => "TxRate-69760k",
                    "1562" => "TxRate-69888k",
                    "1563" => "TxRate-70016k",
                    "1564" => "TxRate-70144k",
                    "1565" => "TxRate-70272k",
                    "1566" => "TxRate-70400k",
                    "1567" => "TxRate-70528k",
                    "1568" => "TxRate-70656k",
                    "1569" => "TxRate-70784k",
                    "1570" => "TxRate-70912k",
                    "1571" => "TxRate-71040k",
                    "1572" => "TxRate-71168k",
                    "1573" => "TxRate-71296k",
                    "1574" => "TxRate-71424k",
                    "1575" => "TxRate-71552k",
                    "1576" => "TxRate-71680k",
                    "1577" => "TxRate-71808k",
                    "1578" => "TxRate-71936k",
                    "1579" => "TxRate-72064k",
                    "1580" => "TxRate-72192k",
                    "1581" => "TxRate-72320k",
                    "1582" => "TxRate-72448k",
                    "1583" => "TxRate-72576k",
                    "1584" => "TxRate-72704k",
                    "1585" => "TxRate-72832k",
                    "1586" => "TxRate-72960k",
                    "1587" => "TxRate-73088k",
                    "1588" => "TxRate-73216k",
                    "1589" => "TxRate-73344k",
                    "1590" => "TxRate-73472k",
                    "1591" => "TxRate-73600k",
                    "1592" => "TxRate-73728k",
                    "1593" => "TxRate-73856k",
                    "1594" => "TxRate-73984k",
                    "1595" => "TxRate-74112k",
                    "1596" => "TxRate-74240k",
                    "1597" => "TxRate-74368k",
                    "1598" => "TxRate-74496k",
                    "1599" => "TxRate-74624k",
                    "1600" => "TxRate-74752k",
                    "1601" => "TxRate-74880k",
                    "1602" => "TxRate-75008k",
                    "1603" => "TxRate-75136k",
                    "1604" => "TxRate-75264k",
                    "1605" => "TxRate-75392k",
                    "1606" => "TxRate-75520k",
                    "1607" => "TxRate-75648k",
                    "1608" => "TxRate-75776k",
                    "1609" => "TxRate-75904k",
                    "1610" => "TxRate-76032k",
                    "1611" => "TxRate-76160k",
                    "1612" => "TxRate-76288k",
                    "1613" => "TxRate-76416k",
                    "1614" => "TxRate-76544k",
                    "1615" => "TxRate-76672k",
                    "1616" => "TxRate-76800k",
                    "1617" => "TxRate-76928k",
                    "1618" => "TxRate-77056k",
                    "1619" => "TxRate-77184k",
                    "1620" => "TxRate-77312k",
                    "1621" => "TxRate-77440k",
                    "1622" => "TxRate-77568k",
                    "1623" => "TxRate-77696k",
                    "1624" => "TxRate-77824k",
                    "1625" => "TxRate-77952k",
                    "1626" => "TxRate-78080k",
                    "1627" => "TxRate-78208k",
                    "1628" => "TxRate-78336k",
                    "1629" => "TxRate-78464k",
                    "1630" => "TxRate-78592k",
                    "1631" => "TxRate-78720k",
                    "1632" => "TxRate-78848k",
                    "1633" => "TxRate-78976k",
                    "1634" => "TxRate-79104k",
                    "1635" => "TxRate-79232k",
                    "1636" => "TxRate-79360k",
                    "1637" => "TxRate-79488k",
                    "1638" => "TxRate-79616k",
                    "1639" => "TxRate-79744k",
                    "1640" => "TxRate-79872k",
                    "1641" => "TxRate-80000k",
                    "1642" => "TxRate-80128k",
                    "1643" => "TxRate-80256k",
                    "1644" => "TxRate-80384k",
                    "1645" => "TxRate-80512k",
                    "1646" => "TxRate-80640k",
                    "1647" => "TxRate-80768k",
                    "1648" => "TxRate-80896k",
                    "1649" => "TxRate-81024k",
                    "1650" => "TxRate-81152k",
                    "1651" => "TxRate-81280k",
                    "1652" => "TxRate-81408k",
                    "1653" => "TxRate-81536k",
                    "1654" => "TxRate-81664k",
                    "1655" => "TxRate-81792k",
                    "1656" => "TxRate-81920k",
                    "1657" => "TxRate-82048k",
                    "1658" => "TxRate-82176k",
                    "1659" => "TxRate-82304k",
                    "1660" => "TxRate-82432k",
                    "1661" => "TxRate-82560k",
                    "1662" => "TxRate-82688k",
                    "1663" => "TxRate-82816k",
                    "1664" => "TxRate-82944k",
                    "1665" => "TxRate-83072k",
                    "1666" => "TxRate-83200k",
                    "1667" => "TxRate-83328k",
                    "1668" => "TxRate-83456k",
                    "1669" => "TxRate-83584k",
                    "1670" => "TxRate-83712k",
                    "1671" => "TxRate-83840k",
                    "1672" => "TxRate-83968k",
                    "1673" => "TxRate-84096k",
                    "1674" => "TxRate-84224k",
                    "1675" => "TxRate-84352k",
                    "1676" => "TxRate-84480k",
                    "1677" => "TxRate-84608k",
                    "1678" => "TxRate-84736k",
                    "1679" => "TxRate-84864k",
                    "1680" => "TxRate-84992k",
                    "1681" => "TxRate-85120k",
                    "1682" => "TxRate-85248k",
                    "1683" => "TxRate-85376k",
                    "1684" => "TxRate-85504k",
                    "1685" => "TxRate-85632k",
                    "1686" => "TxRate-85760k",
                    "1687" => "TxRate-85888k",
                    "1688" => "TxRate-86016k",
                    "1689" => "TxRate-86144k",
                    "1690" => "TxRate-86272k",
                    "1691" => "TxRate-86400k",
                    "1692" => "TxRate-86528k",
                    "1693" => "TxRate-86656k",
                    "1694" => "TxRate-86784k",
                    "1695" => "TxRate-86912k",
                    "1696" => "TxRate-87040k",
                    "1697" => "TxRate-87168k",
                    "1698" => "TxRate-87296k",
                    "1699" => "TxRate-87424k",
                    "1700" => "TxRate-87552k",
                    "1701" => "TxRate-87680k",
                    "1702" => "TxRate-87808k",
                    "1703" => "TxRate-87936k",
                    "1704" => "TxRate-88064k",
                    "1705" => "TxRate-88192k",
                    "1706" => "TxRate-88320k",
                    "1707" => "TxRate-88448k",
                    "1708" => "TxRate-88576k",
                    "1709" => "TxRate-88704k",
                    "1710" => "TxRate-88832k",
                    "1711" => "TxRate-88960k",
                    "1712" => "TxRate-89088k",
                    "1713" => "TxRate-89216k",
                    "1714" => "TxRate-89344k",
                    "1715" => "TxRate-89472k",
                    "1716" => "TxRate-89600k",
                    "1717" => "TxRate-89728k",
                    "1718" => "TxRate-89856k",
                    "1719" => "TxRate-89984k",
                    "1720" => "TxRate-90112k",
                    "1721" => "TxRate-90240k",
                    "1722" => "TxRate-90368k",
                    "1723" => "TxRate-90496k",
                    "1724" => "TxRate-90624k",
                    "1725" => "TxRate-90752k",
                    "1726" => "TxRate-90880k",
                    "1727" => "TxRate-91008k",
                    "1728" => "TxRate-91136k",
                    "1729" => "TxRate-91264k",
                    "1730" => "TxRate-91392k",
                    "1731" => "TxRate-91520k",
                    "1732" => "TxRate-91648k",
                    "1733" => "TxRate-91776k",
                    "1734" => "TxRate-91904k",
                    "1735" => "TxRate-92032k",
                    "1736" => "TxRate-92160k",
                    "1737" => "TxRate-92288k",
                    "1738" => "TxRate-92416k",
                    "1739" => "TxRate-92544k",
                    "1740" => "TxRate-92672k",
                    "1741" => "TxRate-92800k",
                    "1742" => "TxRate-92928k",
                    "1743" => "TxRate-93056k",
                    "1744" => "TxRate-93184k",
                    "1745" => "TxRate-93312k",
                    "1746" => "TxRate-93440k",
                    "1747" => "TxRate-93568k",
                    "1748" => "TxRate-93696k",
                    "1749" => "TxRate-93824k",
                    "1750" => "TxRate-93952k",
                    "1751" => "TxRate-94080k",
                    "1752" => "TxRate-94208k",
                    "1753" => "TxRate-94336k",
                    "1754" => "TxRate-94464k",
                    "1755" => "TxRate-94592k",
                    "1756" => "TxRate-94720k",
                    "1757" => "TxRate-94848k",
                    "1758" => "TxRate-94976k",
                    "1759" => "TxRate-95104k",
                    "1760" => "TxRate-95232k",
                    "1761" => "TxRate-95360k",
                    "1762" => "TxRate-95488k",
                    "1763" => "TxRate-95616k",
                    "1764" => "TxRate-95744k",
                    "1765" => "TxRate-95872k",
                    "1766" => "TxRate-96000k",
                    "1767" => "TxRate-96128k",
                    "1768" => "TxRate-96256k",
                    "1769" => "TxRate-96384k",
                    "1770" => "TxRate-96512k",
                    "1771" => "TxRate-96640k",
                    "1772" => "TxRate-96768k",
                    "1773" => "TxRate-96896k",
                    "1774" => "TxRate-97024k",
                    "1775" => "TxRate-97152k",
                    "1776" => "TxRate-97280k",
                    "1777" => "TxRate-97408k",
                    "1778" => "TxRate-97536k",
                    "1779" => "TxRate-97664k",
                    "1780" => "TxRate-97792k",
                    "1781" => "TxRate-97920k",
                    "1782" => "TxRate-98048k",
                    "1783" => "TxRate-98176k",
                    "1784" => "TxRate-98304k",
                    "1785" => "TxRate-98432k",
                    "1786" => "TxRate-98560k",
                    "1787" => "TxRate-98688k",
                    "1788" => "TxRate-98816k",
                    "1789" => "TxRate-98944k",
                    "1790" => "TxRate-99072k",
                    "1791" => "TxRate-99200k",
                    "1792" => "TxRate-99328k",
                    "1793" => "TxRate-99456k",
                    "1794" => "TxRate-99584k",
                    "1795" => "TxRate-99712k",
                    "1796" => "TxRate-99840k",
                    "1797" => "TxRate-99968k",
                    "1798" => "TxRate-100096k",
                    "1799" => "TxRate-100224k",
                    "1800" => "TxRate-100352k",
                    "1801" => "TxRate-100480k",
                    "1802" => "TxRate-100608k",
                    "1803" => "TxRate-100736k",
                    "1804" => "TxRate-100864k",
                    "1805" => "TxRate-100992k",
                    "1806" => "TxRate-101120k",
                    "1807" => "TxRate-101248k",
                    "1808" => "TxRate-101376k",
                    "1809" => "TxRate-101504k",
                    "1810" => "TxRate-101632k",
                    "1811" => "TxRate-101760k",
                    "1812" => "TxRate-101888k",
                    "1813" => "TxRate-102016k",
                    "1814" => "TxRate-102144k",
                    "1815" => "TxRate-102272k",
                    "1816" => "TxRate-102400k",
                    "1817" => "TxRate-102528k",
                    "1818" => "TxRate-102656k",
                    "1819" => "TxRate-102784k",
                    "1820" => "TxRate-102912k",
                    "1821" => "TxRate-103040k",
                    "1822" => "TxRate-103168k",
                    "1823" => "TxRate-103296k",
                    "1824" => "TxRate-103424k",
                    "1825" => "TxRate-103552k",
                    "1826" => "TxRate-103680k",
                    "1827" => "TxRate-103808k",
                    "1828" => "TxRate-103936k",
                    "1829" => "TxRate-104064k",
                    "1830" => "TxRate-104192k",
                    "1831" => "TxRate-104320k",
                    "1832" => "TxRate-104448k",
                    "1833" => "TxRate-104576k",
                    "1834" => "TxRate-104704k",
                    "1835" => "TxRate-104832k",
                    "1836" => "TxRate-104960k",
                    "1837" => "TxRate-105088k",
                    "1838" => "TxRate-105216k",
                    "1839" => "TxRate-105344k",
                    "1840" => "TxRate-105472k",
                    "1841" => "TxRate-105600k",
                    "1842" => "TxRate-105728k",
                    "1843" => "TxRate-105856k",
                    "1844" => "TxRate-105984k",
                    "1845" => "TxRate-106112k",
                    "1846" => "TxRate-106240k",
                    "1847" => "TxRate-106368k",
                    "1848" => "TxRate-106496k",
                    "1849" => "TxRate-106624k",
                    "1850" => "TxRate-106752k",
                    "1851" => "TxRate-106880k",
                    "1852" => "TxRate-107008k",
                    "1853" => "TxRate-107136k",
                    "1854" => "TxRate-107264k",
                    "1855" => "TxRate-107392k",
                    "1856" => "TxRate-107520k",
                    "1857" => "TxRate-107648k",
                    "1858" => "TxRate-107776k",
                    "1859" => "TxRate-107904k",
                    "1860" => "TxRate-108032k",
                    "1861" => "TxRate-108160k",
                    "1862" => "TxRate-108288k",
                    "1863" => "TxRate-108416k",
                    "1864" => "TxRate-108544k",
                    "1865" => "TxRate-108672k",
                    "1866" => "TxRate-108800k",
                    "1867" => "TxRate-108928k",
                    "1868" => "TxRate-109056k",
                    "1869" => "TxRate-109184k",
                    "1870" => "TxRate-109312k",
                    "1871" => "TxRate-109440k",
                    "1872" => "TxRate-109568k",
                    "1873" => "TxRate-109696k",
                    "1874" => "TxRate-109824k",
                    "1875" => "TxRate-109952k",
                    "1876" => "TxRate-110080k",
                    "1877" => "TxRate-110208k",
                    "1878" => "TxRate-110336k",
                    "1879" => "TxRate-110464k",
                    "1880" => "TxRate-110592k",
                    "1881" => "TxRate-110720k",
                    "1882" => "TxRate-110848k",
                    "1883" => "TxRate-110976k",
                    "1884" => "TxRate-111104k",
                    "1885" => "TxRate-111232k",
                    "1886" => "TxRate-111360k",
                    "1887" => "TxRate-111488k",
                    "1888" => "TxRate-111616k",
                    "1889" => "TxRate-111744k",
                    "1890" => "TxRate-111872k",
                    "1891" => "TxRate-112000k",
                    "1892" => "TxRate-112128k",
                    "1893" => "TxRate-112256k",
                    "1894" => "TxRate-112384k",
                    "1895" => "TxRate-112512k",
                    "1896" => "TxRate-112640k",
                    "1897" => "TxRate-112768k",
                    "1898" => "TxRate-112896k",
                    "1899" => "TxRate-113024k",
                    "1900" => "TxRate-113152k",
                    "1901" => "TxRate-113280k",
                    "1902" => "TxRate-113408k",
                    "1903" => "TxRate-113536k",
                    "1904" => "TxRate-113664k",
                    "1905" => "TxRate-113792k",
                    "1906" => "TxRate-113920k",
                    "1907" => "TxRate-114048k",
                    "1908" => "TxRate-114176k",
                    "1909" => "TxRate-114304k",
                    "1910" => "TxRate-114432k",
                    "1911" => "TxRate-114560k",
                    "1912" => "TxRate-114688k",
                    "1913" => "TxRate-114816k",
                    "1914" => "TxRate-114944k",
                    "1915" => "TxRate-115072k",
                    "1916" => "TxRate-115200k",
                    "1917" => "TxRate-115328k",
                    "1918" => "TxRate-115456k",
                    "1919" => "TxRate-115584k",
                    "1920" => "TxRate-115712k",
                    "1921" => "TxRate-115840k",
                    "1922" => "TxRate-115968k",
                    "1923" => "TxRate-116096k",
                    "1924" => "TxRate-116224k",
                    "1925" => "TxRate-116352k",
                    "1926" => "TxRate-116480k",
                    "1927" => "TxRate-116608k",
                    "1928" => "TxRate-116736k",
                    "1929" => "TxRate-116864k",
                    "1930" => "TxRate-116992k",
                    "1931" => "TxRate-117120k",
                    "1932" => "TxRate-117248k",
                    "1933" => "TxRate-117376k",
                    "1934" => "TxRate-117504k",
                    "1935" => "TxRate-117632k",
                    "1936" => "TxRate-117760k",
                    "1937" => "TxRate-117888k",
                    "1938" => "TxRate-118016k",
                    "1939" => "TxRate-118144k",
                    "1940" => "TxRate-118272k",
                    "1941" => "TxRate-118400k",
                    "1942" => "TxRate-118528k",
                    "1943" => "TxRate-118656k",
                    "1944" => "TxRate-118784k",
                    "1945" => "TxRate-118912k",
                    "1946" => "TxRate-119040k",
                    "1947" => "TxRate-119168k",
                    "1948" => "TxRate-119296k",
                    "1949" => "TxRate-119424k",
                    "1950" => "TxRate-119552k",
                    "1951" => "TxRate-119680k",
                    "1952" => "TxRate-119808k",
                    "1953" => "TxRate-119936k",
                    "1954" => "TxRate-120064k",
                    "1955" => "TxRate-120192k",
                    "1956" => "TxRate-120320k",
                    "1957" => "TxRate-120448k",
                    "1958" => "TxRate-120576k",
                    "1959" => "TxRate-120704k",
                    "1960" => "TxRate-120832k",
                    "1961" => "TxRate-120960k",
                    "1962" => "TxRate-121088k",
                    "1963" => "TxRate-121216k",
                    "1964" => "TxRate-121344k",
                    "1965" => "TxRate-121472k",
                    "1966" => "TxRate-121600k",
                    "1967" => "TxRate-121728k",
                    "1968" => "TxRate-121856k",
                    "1969" => "TxRate-121984k",
                    "1970" => "TxRate-122112k",
                    "1971" => "TxRate-122240k",
                    "1972" => "TxRate-122368k",
                    "1973" => "TxRate-122496k",
                    "1974" => "TxRate-122624k",
                    "1975" => "TxRate-122752k",
                    "1976" => "TxRate-122880k",
                    "1977" => "TxRate-123008k",
                    "1978" => "TxRate-123136k",
                    "1979" => "TxRate-123264k",
                    "1980" => "TxRate-123392k",
                    "1981" => "TxRate-123520k",
                    "1982" => "TxRate-123648k",
                    "1983" => "TxRate-123776k",
                    "1984" => "TxRate-123904k",
                    "1985" => "TxRate-124032k",
                    "1986" => "TxRate-124160k",
                    "1987" => "TxRate-124288k",
                    "1988" => "TxRate-124416k",
                    "1989" => "TxRate-124544k",
                    "1990" => "TxRate-124672k",
                    "1991" => "TxRate-124800k",
                    "1992" => "TxRate-124928k",
                    "1993" => "TxRate-125056k",
                    "1994" => "TxRate-125184k",
                    "1995" => "TxRate-125312k",
                    "1996" => "TxRate-125440k",
                    "1997" => "TxRate-125568k",
                    "1998" => "TxRate-125696k",
                    "1999" => "TxRate-125824k",
                    "2000" => "TxRate-125952k",
                    "2001" => "TxRate-126080k",
                    "2002" => "TxRate-126208k",
                    "2003" => "TxRate-126336k",
                    "2004" => "TxRate-126464k",
                    "2005" => "TxRate-126592k",
                    "2006" => "TxRate-126720k",
                    "2007" => "TxRate-126848k",
                    "2008" => "TxRate-126976k",
                    "2009" => "TxRate-127104k",
                    "2010" => "TxRate-127232k",
                    "2011" => "TxRate-127360k",
                    "2012" => "TxRate-127488k",
                    "2013" => "TxRate-127616k",
                    "2014" => "TxRate-127744k",
                    "2015" => "TxRate-127872k",
                    "2016" => "TxRate-128000k",
                    "2017" => "TxRate-128128k",
                    "2018" => "TxRate-128256k",
                    "2019" => "TxRate-128384k",
                    "2020" => "TxRate-128512k",
                    "2021" => "TxRate-128640k",
                    "2022" => "TxRate-128768k",
                    "2023" => "TxRate-128896k",
                    "2024" => "TxRate-129024k",
                    "2025" => "TxRate-129152k",
                    "2026" => "TxRate-129280k",
                    "2027" => "TxRate-129408k",
                    "2028" => "TxRate-129536k",
                    "2029" => "TxRate-129664k",
                    "2030" => "TxRate-129792k",
                    "2031" => "TxRate-129920k",
                    "2032" => "TxRate-130048k",
                    "2033" => "TxRate-130176k",
                    "2034" => "TxRate-130304k",
                    "2035" => "TxRate-130432k",
                    "2036" => "TxRate-130560k",
                    "2037" => "TxRate-130688k",
                    "2038" => "TxRate-130816k",
                    "2039" => "TxRate-130944k",
                    "2040" => "TxRate-131072k",
                    "2041" => "TxRate-131200k",
                    "2042" => "TxRate-131328k",
                    "2043" => "TxRate-131456k",
                    "2044" => "TxRate-131584k",
                    "2045" => "TxRate-131712k",
                    "2046" => "TxRate-131840k",
                    "2047" => "TxRate-131968k",
                },
                153 => { "0" => "Up", "1" => "Down" },
                154 => {
                    "0" => "Peer-to-Peer",
                    "1" => "Base",
                    "2" => "Base-Polling",
                    "3" => "Satellite-NT",
                },
            },
            800 => {
                16 => {
                    1 => "Xylan-Read-Priv",
                    2 => "Xylan-Write-Priv",
                    3 => "Xylan-Admin-Priv",
                },
            },
            831 => {
                14  => { 1   => "Ignore", 2   => "Disconnect" },
                210 => { "0" => "False",  "1" => "True" },
            },
            890 => {
                192 => { "0" => "None", "1" => "Optional", "2" => "Mandatory" },
                193 => { "0" => "Preconfigured", "1" => "User" },
            },
            969 => {
                13 => {
                    1   => "FTP",
                    2   => "WEB",
                    3   => "POP",
                    4   => "IMAP",
                    5   => "Windows-Logon",
                    6   => "Unix-Logon",
                    7   => "SMTP-Auth",
                    200 => "Other",
                },
                17 => { 1 => "Anonymous-User", 2 => "Admin-User" },
            },
            1271 => {
                1 => {
                    1 => "limited",
                    2 => "admin",
                    3 => "super-user",
                    4 => "diag"
                },
                10 => {
                    1 => "limited",
                    2 => "admin",
                    3 => "super-user",
                    4 => "diag"
                },
            },
            1584 => {
                38 => { "0" => "none",  "1" => "kmd5-128" },
                39 => { "0" => "none",  "1" => "prefix-suffix" },
                42 => { 1   => "local", 2   => "remote" },
                44 => {
                    "0"  => "Unknown",
                    "1"  => "Line-disconnected",
                    "2"  => "Dial-failed",
                    "3"  => "WAN-manager-error",
                    "4"  => "Disconnect-reset",
                    "5"  => "Error-from-adm_notify",
                    "6"  => "Modem-down-adm_notify",
                    "7"  => "PPP-protocol-disconnect",
                    "8"  => "Inactivity-timer",
                    "9"  => "CLI-Hangup-command",
                    "10" => "CLI-last-job",
                    "11" => "Session-timeout",
                    "12" => "Slave-termination",
                    "13" => "Abnormal-termination",
                    "14" => "DCD-wait-failed",
                    "15" => "CLI-inactivity",
                    "16" => "Admin-port-reset",
                    "17" => "CLI-auth-failed",
                    "18" => "Slave-auth-failed",
                    "19" => "PAP-auth-failed",
                    "20" => "CHAP-auth-failed",
                    "21" => "Local-modem-reset",
                    "22" => "Modem-dead",
                    "23" => "PPP-LCP-failure",
                    "24" => "PPP-IPCP-failure",
                    "25" => "PPP-IPXCP-failure",
                    "26" => "PPP-ATCP-failure",
                    "27" => "PPP-CCP-failure",
                    "28" => "PPP-MP-failure",
                    "29" => "PPP-IPCP-timeout",
                    "30" => "PPP-IPXCP-timeout",
                    "31" => "PPP-ATCP-timeout",
                    "32" => "PPP-CCP-timeout",
                    "33" => "PPP-MP-timeout",
                    "34" => "PPP-init-failure",
                    "35" => "PPP-Unknown",
                    "36" => "PPP-Dialback-failed",
                    "37" => "PPP-Address-In-Use",
                    "38" => "PPP-No-device",
                    "39" => "PPP-Modem-hangup-rcvd",
                    "40" => "PPP-Hangup-rcvd",
                    "41" => "PPP-Termination-rcvd",
                    "42" => "PPP-Kill-rcvd",
                    "43" => "PPP-Time-rcvd",
                    "44" => "PPP-No-memory",
                    "45" => "PPP-Connection-Abort",
                    "46" => "PPP-VPN-LCP-failure",
                    "47" => "PPP-VPN-Auth-failure",
                    "48" => "PPP-MP-invalid-port",
                    "49" => "PPP-Invalid-device",
                    "50" => "PPP-MMP-bundle-failure",
                    "51" => "DVS-Registration-failure",
                    "52" => "DVS-Home-agent-dereg",
                    "53" => "DVS-Tunnel-no-renew",
                    "54" => "DVS-Tunnel-expired",
                },
                45 => {
                    "0" => "Unknown",
                    "1" => "Local-disconnect",
                    "2" => "CD-Timer-Expired",
                    "4" => "Remote-protocol-disc",
                    "5" => "Clear-down",
                    "6" => "Long-Space-disconnect",
                    "7" => "Carrier-Lost",
                    "8" => "Modem-Retrain-Timeout",
                },
                47  => { "0" => "none",    "1" => "DHCP" },
                100 => { 2   => "Manager", 4   => "User", 8 => "Operator" },
                101 => { 2   => "Manager", 4   => "User", 8 => "Operator" },
                192 => {
                    "0" => "None-Access",
                    "1" => "Read-Only-Access",
                    "2" => "L1-Read-Write-Access",
                    "3" => "L2-Read-Write-Access",
                    "4" => "L3-Read-Write-Access",
                    "5" => "Read-Write-Access",
                    "6" => "Read-Write-All-Access",
                },
                194 => { "0" => "False", "1" => "True" },
            },
            1768 => {
                35 => {
                    "0" => "Valid-cause-code-not-yet-received",
                    "1" => "Unallocated-runassigned-number",
                    "2" => "No-route-to-specified-transit-network-WAN",
                    "3" => "No-route-to-destination",
                    "4" => "send-special-information-tone",
                    "5" => "misdialled-trunk-prefix",
                    "6" => "Channel-unacceptable",
                    "7" =>
"Call-awarded-and-being-delivered-in-an-established-channel",
                    "8"  => "Prefix-0-dialed-but-not-allowed",
                    "9"  => "Prefix-1-dialed-but-not-allowed",
                    "10" => "Prefix-1-dialed-but-not-required",
                    "11" =>
                      "More-digits-received-than-allowed-call-is-proceeding",
                    "16" => "Normal-call-clearing",
                    "17" => "User-busy",
                    "18" => "No-user-responding",
                    "19" => "no-answer-from-user",
                    "21" => "Call-rejected",
                    "22" => "Number-changed",
                    "23" => "Reverse-charging-rejected",
                    "24" => "Call-suspended",
                    "25" => "Call-resumed",
                    "26" => "Non-selected-user-clearing",
                    "27" => "Destination-out-of-order",
                    "28" => "Invalid-number-format-incomplete-number",
                    "29" => "Facility-rejected",
                    "30" => "Response-to-STATUS-ENQUIRY",
                    "31" => "Normal-unspecified",
                    "33" => "Circuit-out-of-order",
                    "34" => "No-circuit/channel-available",
                    "35" => "Destination-unattainable",
                    "37" => "Degraded-service",
                    "38" => "Network-WAN-out-of-order",
                    "39" => "Transit-delay-range-cannot-be-achieved",
                    "40" => "Throughput-range-cannot-be-achieved",
                    "41" => "Temporary-failure",
                    "42" => "Switching-equipment-congestion",
                    "43" => "Access-information-discarded",
                    "44" => "Requested-circuit-channel-not-available",
                    "45" => "Pre-empted",
                    "46" => "Precedence-call-blocked",
                    "47" => "Resource-unavailable-unspecified",
                    "49" => "Quality-of-service-unavailable",
                    "50" => "Requested-facility-not-subscribed",
                    "51" => "Reverse-charging-not-allowed",
                    "52" => "Outgoing-calls-barred",
                    "53" => "Outgoing-calls-barred-within-CUG",
                    "54" => "Incoming-calls-barred",
                    "55" => "Incoming-calls-barred-within-CUG",
                    "56" => "Call-waiting-not-subscribed",
                    "57" => "Bearer-capability-not-authorized",
                    "58" => "Bearer-capability-not-presently-available",
                    "63" => "Service-or-option-not-available-unspecified",
                    "65" => "Bearer-service-not-implemented",
                    "66" => "Channel-type-not-implemented",
                    "67" => "Transit-network-selection-not-implemented",
                    "68" => "Message-not-implemented",
                    "69" => "Requested-facility-not-implemented",
                    "70" =>
"Only-restricted-digital-information-bearer-capability-is-avail",
                    "79" => "Service-or-option-not-implemented-unspecified",
                    "81" => "Invalid-call-reference-value",
                    "82" => "Identified-channel-does-not-exist",
                    "83" =>
                      "A-suspended-call-exists-but-this-call-identity-does-not",
                    "84" => "Call-identity-in-use",
                    "85" => "No-call-suspended",
                    "86" =>
"Call-having-the-requested-call-identity-has-been-cleared",
                    "87" => "Called-user-not-member-of-CUG",
                    "88" => "Incompatible-destination",
                    "89" => "Non-existent-abbreviated-address-entry",
                    "90" =>
"Destination-address-missing-and-direct-call-not-subscribed",
                    "91" => "Invalid-transit-network-selection-national-use",
                    "92" => "Invalid-facility-parameter",
                    "93" => "Mandatory-information-element-is-missing",
                    "95" => "Invalid-message-unspecified",
                    "96" => "Mandatory-information-element-is-missing-2",
                    "97" => "Message-type-non-existent-or-not-implemented",
                    "98" => "Message-not-compatible-with-call-state",
                    "99" =>
                      "information-element-nonexistant-or-not-implemented",
                    "100" => "Invalid-information-element-contents",
                    "101" => "Message-not-compatible-with-call-state-2",
                    "102" => "Recovery-on-timer-expiry",
                    "103" =>
                      "parameter-non-existent-or-not-implemented-passed-on",
                    "111" => "Protocol-error-unspecified",
                    "127" => "Internetworking-unspecified",
                },
            },
            1872 => {
                26 => {
                    250 => "Alteon-L4admin",
                    251 => "Alteon-Slbadmin",
                    252 => "Alteon-Oper",
                    253 => "Alteon-L4oper",
                    254 => "Alteon-Slboper",
                    255 => "Alteon-User",
                },
            },
            1916 => {
                201 => { "0" => "Disabled", "1" => "Enabled" },
                206 => { "0" => "Disabled", "1" => "Enabled" },
            },
            1966 => {
                99  => { "0" => "Disabled", "1" => "Enabled" },
                100 => {
                    1 => "Admin",
                    2 => "Normal",
                    3 => "Restricted",
                    4 => "Menu"
                },
                101 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                102 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                103 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                104 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                105 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                106 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                107 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                108 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                109 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                110 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                111 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                112 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                113 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                114 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                115 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                116 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                117 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                118 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                119 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                120 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                121 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                122 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                123 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                124 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                125 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                126 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                127 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                128 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                129 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                130 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                131 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                132 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                133 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                134 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                135 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                136 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                137 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                138 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                139 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                140 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                141 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                142 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                143 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                144 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                145 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                146 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                147 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                148 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
                149 => {
                    "0" => "Disabled",
                    "1" => "Read-Write",
                    "2" => "Read-Input",
                    "3" => "Read-Input-Write",
                    "4" => "Read-Output",
                    "5" => "Read-Output-Write",
                    "6" => "Read-Output-Input",
                    "7" => "Read-Output-Input-Write",
                },
            },
            1991 => {
                4 => {
                    "0"  => "AAA_pri_0",
                    "1"  => "AAA_pri_1",
                    "2"  => "AAA_pri_2",
                    "3"  => "AAA_pri_3",
                    "4"  => "AAA_pri_4",
                    "5"  => "AAA_pri_5",
                    "6"  => "AAA_pri_6",
                    "7"  => "AAA_pri_7",
                    "8"  => "AAA_pri_8",
                    "9"  => "AAA_pri_9",
                    "10" => "AAA_pri_10",
                    "11" => "AAA_pri_11",
                    "12" => "AAA_pri_12",
                    "13" => "AAA_pri_13",
                    "14" => "AAA_pri_14",
                    "15" => "AAA_pri_15",
                },
                8 => {
                    "0" => "QoS_priority_0",
                    "1" => "QoS_priority_1",
                    "2" => "QoS_priority_2",
                    "3" => "QoS_priority_3",
                    "4" => "QoS_priority_4",
                    "5" => "QoS_priority_5",
                    "6" => "QoS_priority_6",
                    "7" => "QoS_priority_7",
                },
            },
            2011 => {
                25 => { "0" => "Succeeded" },
                85 => {
                    "0" => "PADM",
                    "1" => "Redirectional",
                    "2" => "Non-captive"
                },
                142 => {
                    "0" => "Original",
                    "1" => "L2TP-Inbound",
                    "2" => "L2TP-Outbound",
                    "3" => "L2TP",
                },
                168 => { "0" => "Safe", "1" => "Warning", "2" => "Danger" },
                180 => {
                    1  => "PPP",
                    2  => "Web",
                    3  => "Dot1x",
                    4  => "Fast",
                    5  => "Bind",
                    6  => "WLAN",
                    7  => "Administrative",
                    8  => "Tunnel",
                    9  => "MIP",
                    10 => "None",
                },
                183 => {
                    "0" => "Disable",
                    "1" => "Uplink-Enable",
                    "2" => "Downlink-Enable",
                    "3" => "Enable",
                },
                196 => { "0" => "Unsupported", "1" => "Supported" },
                215 => {
                    1 => "Fixed",
                    2 => "Nomadic",
                    3 => "Portable",
                    4 => "Simple-Mobile",
                    5 => "Full-Mobile",
                },
                218 => {
                    "0" => "Common",
                    "1" => "Copper",
                    "2" => "Silver",
                    "3" => "Gold"
                },
            },
            2167 => {
                1 => {
                    1 => "Cajun-Read-Only-User",
                    2 => "Cajun-Read-Write-User",
                    3 => "Cajun-Admin-User",
                },
                13 => {
                    "0" => "Type-0",
                    "1" => "Type-1",
                    "2" => "Type-2",
                    "3" => "Type-3",
                    "4" => "Type-4",
                    "5" => "Type-5",
                    "6" => "Type-6",
                    "7" => "Type-7",
                },
            },
            2180 => {
                1 => {
                    "0"  => "Normal-Hangup-No-Error-Occurred",
                    "3"  => "Call-Waiting-Caused-Disconnect",
                    "4"  => "Physical-Carrier-Loss",
                    "5"  => "No-err-correction-at-other-end",
                    "6"  => "No-resp-to-feature-negotiation",
                    "7"  => "1st-modem-async-only-2nd-sync",
                    "8"  => "No-framing-technique-in-common",
                    "9"  => "No-protocol-in-common",
                    "10" => "Bad-resp-to-feature-negotiation",
                    "11" => "No-sync-info-from-remote-modem",
                    "12" => "Normal-Hangup-by-Remote-modem",
                    "13" => "Retransmission-limit-reached",
                    "14" => "Protocol-violation-occurred",
                    "15" => "Lost-DTR",
                    "16" => "Received-GSTN-cleardown",
                    "17" => "Inactivity-timeout",
                    "18" => "Speed-not-supported",
                    "19" => "Long-space-disconnect",
                    "20" => "Key-abort-disconnect",
                    "21" => "Clears-previous-disc-reason",
                    "22" => "No-connection-established",
                    "23" => "Disconnect-after-three-retrains",
                },
            },
            2352 => {
                14 => { 1 => "Enabled",  2 => "Disabled" },
                15 => { 1 => "Enabled",  2 => "Disabled" },
                18 => { 1 => "LAC-Only", 2 => "LNS-Only", 3 => "LAC-LNS" },
                23 => { 1 => "CHAP",     2 => "PAP",      3 => "CHAP-PAP" },
                29 => { 1 => "Enabled",  2 => "Disabled" },
                31 => { 1 => "First",    2 => "Load-Balance", 3 => "WRR" },
                33 => { 1 => "NO-SEND",  2 => "SEND", 3 => "UNSOLICITED-SEND" },
                34 => { 1 => "NO-RECEIVE", 2 => "RECEIVE" },
                37 => { 1 => "DNIS", 2 => "DNIS-Only", 4 => "DNIS-Generate" },
                38 => {
                    11 => "DSL",
                    12 => "Cable",
                    13 => "Wireless",
                    14 => "Satellite"
                },
                39 => {
                    1  => "AAA-ENCAPS-ATM-RAW",
                    2  => "AAA-ENCAPS-ATM-ROUTE1483",
                    3  => "AAA-ENCAPS-ATM-AUTO1483",
                    4  => "AAA-ENCAPS-ATM-MULTI",
                    5  => "AAA-ENCAPS-ATM-BRIDGE1483",
                    6  => "AAA-ENCAPS-ATM-PPP",
                    7  => "AAA-ENCAPS-ATM-PPP-SERIAL",
                    8  => "AAA-ENCAPS-ATM-PPP-NLPID",
                    9  => "AAA-ENCAPS-ATM-PPP-AUTO",
                    10 => "AAA-ENCAPS-ATM-PPPOE",
                    11 => "AAA-ENCAPS-ATM-L2TP",
                    12 => "AAA-ENCAPS-ATM-PPP-LLC",
                    13 => "AAA-ENCAPS-FRAME-AUTO1490",
                    14 => "AAA-ENCAPS-FRAME-MULTI",
                    15 => "AAA-ENCAPS-FRAME-BRIDGE1490",
                    16 => "AAA-ENCAPS-FRAME-PPP",
                    17 => "AAA-ENCAPS-FRAME-PPP-AUTO",
                    18 => "AAA-ENCAPS-FRAME-PPPOE",
                    19 => "AAA-ENCAPS-FRAME-ROUTE1490",
                    20 => "AAA-ENCAPS-FRAME-L2TP",
                    21 => "AAA-ENCAPS-L2TP-VC-MUXED",
                    22 => "AAA-ENCAPS-ETH",
                    23 => "AAA-ENCAPS-ETH-PPPOE",
                    24 => "AAA-ENCAPS-ETH-MULTI",
                    25 => "AAA-ENCAPS-ETH-DOT1Q",
                    26 => "AAA-ENCAPS-ETH-DOT1Q-PPPOE",
                    27 => "AAA-ENCAPS-ATM-MULTI-PPPOE",
                    28 => "AAA-ENCAPS-ATM-MULTI-IPV6OE",
                    29 => "AAA-ENCAPS-ATM-MULTI-PPPOE-N-IPV6OE",
                    30 => "AAA-ENCAPS-ETH-DOT1Q-TUNNEL",
                    31 => "AAA-ENCAPS-ETH-DOT1Q-TUNNEL-PPPOE",
                },
                41 =>
                  { 1 => "AAA-CIRCUIT-PADDING", 2 => "AAA-CIRCUIT-NO-PADDING" },
                42 => {
                    1  => "AAA-AUTH-BIND",
                    2  => "AAA-BYPASS-BIND",
                    3  => "AAA-INTERFACE-BIND",
                    4  => "AAA-SUBSCRIBE-BIND",
                    5  => "AAA-TUNNEL-BIND",
                    6  => "AAA-SESSION-BIND",
                    7  => "AAA-Q8021-BIND",
                    8  => "AAA-MULTI-BIND",
                    9  => "AAA-DHCP-BIND",
                    10 => "AAA-MULTI-BIND-SUB",
                    11 => "AAA-BRIDGE-GROUP-BIND",
                    12 => "AAA-VLAN-BIND",
                    13 => "AAA-VLAN-GROUP-BIND",
                    14 => "AAA-AUTO-SUBSCRIBER-BIND",
                },
                43 => {
                    1 => "AAA-PPP-PAP",
                    2 => "AAA-PPP-CHAP",
                    3 => "AAA-PPP-CHAP-WAIT",
                    4 => "AAA-PPP-CHAP-PAP",
                    5 => "AAA-PPP-CHAP-WAIT-PAP",
                    6 => "AAA-PPP-EAP",
                    7 => "AAA-PPP-PAP-CHAP",
                    8 => "AAA-PPP-PAP-CHAP-WAIT",
                },
                61 => {
                    "0"  => "normal",
                    "1"  => "min-cost-only",
                    "2"  => "max-reliability-only",
                    "3"  => "max-reliability-plus-min-cost",
                    "4"  => "max-throughput-only",
                    "5"  => "max-throughput-plus-min-cost",
                    "6"  => "max-throughput-plus-max-reliability",
                    "7"  => "max-throughput-plus-max-reliability-plus-min-cost",
                    "8"  => "min-delay-only",
                    "9"  => "min-delay-plus-min-cost",
                    "10" => "min-delay-plus-max-reliability",
                    "11" => "min-delay-plus-max-reliability-plus-min-cost",
                    "12" => "min-delay-plus-max-throughput",
                    "13" => "min-delay-plus-max-throughput-plus-min-cost",
                    "14" =>
                      "min-delay-plus-max-throughput-plus-max-reliability",
                    "15" =>
"min-delay-plus-max-throughput-plus-max-reliability-plus-min-cost",
                },
                98 => {
                    1 => "SMS",
                    2 => "SmartEdge-800",
                    3 => "SE-400",
                    4 => "SE-100"
                },
                111 => { 27 => "ENCAPS-PPPOE" },
                139 => {
                    40 => "NAS-PORT-TYPE-10BT",
                    41 => "NAS-PORT-TYPE-100BT",
                    42 => "NAS-PORT-TYPE-DS3-FR",
                    43 => "NAS-PORT-TYPE-DS3-ATM",
                    44 => "NAS-PORT-TYPE-OC3",
                    45 => "NAS-PORT-TYPE-HSSI",
                    46 => "NAS-PORT-TYPE-EIA530",
                    47 => "NAS-PORT-TYPE-T1",
                    48 => "NAS-PORT-TYPE-CHAN-T3",
                    49 => "NAS-PORT-TYPE-DS1-FR",
                    50 => "NAS-PORT-TYPE-E3-ATM",
                    51 => "NAS-PORT-TYPE-IMA-ATM",
                    52 => "NAS-PORT-TYPE-DS3-ATM-2",
                    53 => "NAS-PORT-TYPE-OC3-ATM-2",
                    54 => "NAS-PORT-TYPE-1000BSX",
                    55 => "NAS-PORT-TYPE-E1-FR",
                    56 => "NAS-PORT-TYPE-E1-ATM",
                    57 => "NAS-PORT-TYPE-E3-FR",
                    58 => "NAS-PORT-TYPE-OC3-POS",
                    59 => "NAS-PORT-TYPE-OC12-POS",
                    60 => "NAS-PORT-TYPE-PPPOE",
                },
                140 => {
                    40 => "NAS-PORT-TYPE-10BT",
                    41 => "NAS-PORT-TYPE-100BT",
                    42 => "NAS-PORT-TYPE-DS3-FR",
                    43 => "NAS-PORT-TYPE-DS3-ATM",
                    44 => "NAS-PORT-TYPE-OC3",
                    45 => "NAS-PORT-TYPE-HSSI",
                    46 => "NAS-PORT-TYPE-EIA530",
                    47 => "NAS-PORT-TYPE-T1",
                    48 => "NAS-PORT-TYPE-CHAN-T3",
                    49 => "NAS-PORT-TYPE-DS1-FR",
                    50 => "NAS-PORT-TYPE-E3-ATM",
                    51 => "NAS-PORT-TYPE-IMA-ATM",
                    52 => "NAS-PORT-TYPE-DS3-ATM-2",
                    53 => "NAS-PORT-TYPE-OC3-ATM-2",
                    54 => "NAS-PORT-TYPE-1000BSX",
                    55 => "NAS-PORT-TYPE-E1-FR",
                    56 => "NAS-PORT-TYPE-E1-ATM",
                    57 => "NAS-PORT-TYPE-E3-FR",
                    58 => "NAS-PORT-TYPE-OC3-POS",
                    59 => "NAS-PORT-TYPE-OC12-POS",
                    60 => "NAS-PORT-TYPE-PPPOE",
                },
                144 => {
                    1  => "AAA-LOAD-ACCT-SESSION-UP",
                    2  => "AAA-LOAD-ACCT-SESSION-DOWN",
                    3  => "AAA-LOAD-ACCT-PERIODIC",
                    4  => "AAA-LOAD-ACCT-DYN-AC-ENT-START",
                    5  => "AAA-LOAD-ACCT-DYN-AC-ENT-STOP",
                    6  => "AAA-LOAD-ACCT-DYN-AC-ENT-TIMEOUT",
                    7  => "AAA-LOAD-ACCT-SUBSCRIBER-REAUTHOR",
                    8  => "AAA-LOAD-ACCT-PPP-IPCP-UP",
                    9  => "AAA-LOAD-ACCT-PPP-MP-LINK-UP",
                    10 => "AAA-LOAD-ACCT-DHCP-IP-ADDR-GRANTED",
                    11 => "AAA-LOAD-ACCT-DHCP-IP-ADDR-RELEASED",
                    12 => "AAA-LOAD-ACCT-ACL-TIMERED-ACTION",
                    13 => "AAA-LOAD-ACCT-ACL-ACTION",
                    14 => "AAA-LOAD-ACCT-CMD",
                    15 => "AAA-LOAD-ACCT-TEST",
                },
                180 => { 1 => "Showtime", 2 => "Idle", 3 => "Silent" },
                182 => {
                    1 => "ADSL1",
                    2 => "ADSL2",
                    3 => "ADSL2+",
                    4 => "VDSL1",
                    5 => "VDSL2",
                    6 => "SDSL",
                    7 => "UNKNOWN",
                },
                191 => {
                    "0" => "DE-ACTIVATE",
                    "1" => "ACTIVATE-WITH-ACCT",
                    "2" => "ACTIVATE-WITHOUT-ACCT",
                },
                193 => {
                    "0"   => "Service-success",
                    "401" => "Unsupported-attribute",
                    "402" => "Missing-attribute",
                    "404" => "Invalid-request",
                    "506" => "Resource-unavailable",
                    "550" => "Generic-service-error",
                    "551" => "Service-not-found",
                    "552" => "Service-already-active",
                    "553" => "Service-accounting-disabled",
                    "554" => "Service-duplicate-parameter",
                },
            },
            2454 => {
                10 => {
                    1 => "Disable",
                    2 => "Enable",
                    3 => "Lastpacket",
                    4 => "Enable-On-IP-Update",
                    5 => "Reset-Acct-Session-ID",
                },
                13 => {
                    1 => "Pre-Auth",
                    2 => "Service-Selection",
                    3 => "Web-Auth"
                },
                14 => {
                    1 => "Reject",
                    2 => "Echo",
                    3 => "Macantispoof",
                    4 => "User-Space-Overwrite",
                    5 => "User-Space-Overwrite-On-Next-Service",
                    6 => "L2Echo",
                },
                32  => { 1 => "Normal", 2 => "Update", 3 => "Pass-Through" },
                33  => { 1 => "Disconnect", 2 => "Update" },
                40  => { 1 => "MLP",        2 => "ROAM" },
                53  => { 1 => "Service",    2 => "User", 3 => "CLI" },
                56  => { 1 => "Off" },
                61  => { 1 => "Disable" },
                73  => { 1 => "RIPv2", 2 => "OSPF" },
                85  => { 1 => "PPP" },
                110 => { 1 => "Enable", 2 => "Disable" },
                120 => {
                    5      => "Idle",
                    4320   => "Reconnect-Disable",
                    262149 => "Idle-On-Session-Idle",
                    266464 => "Reconnect-Disable-On-Idle",
                },
                123 => {
                    "1"          => "Mobility",
                    "2"          => "Sleep",
                    "4"          => "Idle",
                    "4294967291" => "NoIdle",
                    "4294967293" => "NoSleep",
                    "4294967294" => "NoMobility",
                },
                124 => { "0" => "Enable", "1" => "Disable" },
                125 => { 1   => "Off",    2   => "On" },
            },
            2544 => {
                100 => {
                    "0" => "Retrieve",
                    "1" => "Reserved",
                    "2" => "Operate_Control",
                    "3" => "Provision",
                    "4" => "Admin",
                    "5" => "Super",
                },
                102 => {
                    "0" => "Monitor",
                    "1" => "Reserved",
                    "2" => "Operator",
                    "3" => "Provision",
                    "4" => "Admin",
                    "5" => "Root",
                },
            },
            2636 => {
                21 => {
                    1 => "Read_Only",
                    2 => "Admin",
                    3 => "Privileged_Admin",
                    4 => "Auditor"
                },
                22 =>
                  { 1 => "Net_View", 2 => "Net_Admin", 3 => "Global_Admin" },
                23 =>
                  { 1 => "Web_Manager", 2 => "System_Admin", 3 => "Auditor" },
            },
            2979 => {
                1 => { 1   => "be", 2 => "bronze", 3 => "silver", 4 => "gold" },
                2 => { "0" => "disabled", "1" => "enabled" },
                7 => {
                    1 => "auto",
                    2 => "nomadic",
                    3 => "f_9050",
                    4 => "f_9116",
                    5 => "f_9184",
                    6 => "f_9250",
                    7 => "f_9084",
                    8 => "f_9150",
                    9 => "f_9216",
                },
                15 => {
                    1  => "p_15",
                    2  => "p_16",
                    3  => "p_17",
                    4  => "p_18",
                    5  => "p_19",
                    6  => "p_20",
                    7  => "p_21",
                    8  => "p_22",
                    9  => "p_23",
                    10 => "p_24",
                    11 => "p_25",
                    12 => "p_26",
                },
            },
            3041 => {
                18 => { "0" => "No", "1" => "Yes" },
                22 => {
                    "0"  => "IP-TOS-Normal",
                    "1"  => "IP-TOS-Disabled",
                    "2"  => "IP-TOS-Cost",
                    "4"  => "IP-TOS-Reliability",
                    "8"  => "IP-TOS-Throughput",
                    "16" => "IP-TOS-Latency",
                },
                23 => {
                    "0"   => "IP-TOS-Precedence-Pri-Normal",
                    "32"  => "IP-TOS-Precedence-Pri-One",
                    "64"  => "IP-TOS-Precedence-Pri-Two",
                    "96"  => "IP-TOS-Precedence-Pri-Three",
                    "128" => "IP-TOS-Precedence-Pri-Four",
                    "160" => "IP-TOS-Precedence-Pri-Five",
                    "192" => "IP-TOS-Precedence-Pri-Six",
                    "224" => "IP-TOS-Precedence-Pri-Seven",
                },
                24 => {
                    1024 => "IP-TOS-Apply-To-Incoming",
                    2048 => "IP-TOS-Apply-To-Outgoing",
                    3072 => "IP-TOS-Apply-To-Both",
                },
                27 => { "0" => "Multicast-No",     "1" => "Multicast-Yes" },
                62 => { "0" => "Not-Require-Auth", "1" => "Require-Auth" },
                66 =>
                  { "0" => "Source-IP-Check-No", "1" => "Source-IP-Check-Yes" },
                68 => {
                    "0" => "AAT-Auth-None",
                    "1" => "AAT-Auth-Default",
                    "2" => "AAT-Auth-Any",
                    "3" => "AAT-Auth-PAP",
                    "4" => "AAT-Auth-CHAP",
                    "5" => "AAT-Auth-MS-CHAP",
                },
                72 => { "0" => "DNS-Assign-No", "1" => "DNS-Assign-Yes" },
            },
            3076 => {
                13 => {
                    "0" => "None",
                    "1" => "RADIUS",
                    "2" => "LDAP-Authorization-only",
                    "3" => "NT-Domain",
                    "4" => "SDI",
                    "5" => "Internal",
                    "6" => "RADIUS-with-Expiry",
                    "7" => "Kerberos/Active-Directory",
                },
                16 => { "0" => "Disabled",   "1" => "Enabled" },
                17 => { "0" => "Disabled",   "1" => "Enabled" },
                30 => { 1   => "LAN-to-LAN", 2   => "Remote-Access" },
                31 => { "0" => "Disabled",   "1" => "Enabled" },
                34 => { "0" => "Disabled",   "1" => "Enabled" },
                37 => { "0" => "Disabled",   "1" => "Enabled" },
                38 => { "0" => "Disabled",   "1" => "Enabled" },
                39 => { "0" => "Disabled",   "1" => "Enabled" },
                40 => {
                    1 => "Required",
                    2 => "If-Supported-By-Peer-Certificate",
                    3 => "Do-Not-Check",
                },
                41 => { "0" => "Disabled", "1" => "Enabled" },
                42 => { "0" => "Disabled", "1" => "Enabled" },
                45 => {
                    1 => "Cisco-CIC",
                    2 => "Zone-Labs",
                    3 => "NetworkICE",
                    4 => "Sygate",
                    5 => "Cisco-IPSA",
                },
                48 => { "0" => "Disabled", "1" => "Enabled" },
                49 => { "0" => "Disabled", "1" => "Enabled" },
                51 => { "0" => "Disabled", "1" => "Enabled" },
                55 => {
                    "0" => "No-Split-Tunneling",
                    "1" => "Split-Tunneling",
                    "2" => "Local-LAN-Permitted",
                },
                56 => {
                    "0" => "None",
                    "1" => "Policy-Remotely-Defined",
                    "2" => "Policy-Pushed",
                    "4" => "Policy-from-Server",
                },
                58 => { "0" => "Required", "1" => "Optional" },
                59 => {
                    1 => "Use-Client-Configured-List",
                    2 => "Disable-and-clear-client-list",
                    3 => "Use-Backup-Server-List",
                },
                62 => { "0" => "Disabled", "1" => "Enabled" },
                64 => { "0" => "Disabled", "1" => "Enabled" },
                65 => { "0" => "None",     "1" => "Radius", "2" => "LDAP" },
                66 => { "0" => "No",       "1" => "Yes" },
                75 => { "0" => "Disabled", "1" => "Enabled" },
                81 => {
                    1 => "No-Modify",
                    2 => "No-Proxy",
                    3 => "Auto-detect",
                    4 => "Use-Concentrator-Setting",
                },
                83  => { "0" => "None",     "1" => "Local" },
                88  => { "0" => "No",       "1" => "Yes" },
                89  => { "0" => "No",       "1" => "Yes" },
                93  => { "0" => "Disabled", "1" => "Enabled" },
                94  => { "0" => "Disabled", "1" => "Enabled" },
                95  => { "0" => "Disabled", "1" => "Enabled" },
                96  => { "0" => "Disabled", "1" => "Enabled" },
                97  => { "0" => "Disabled", "1" => "Enabled" },
                98  => { "0" => "Disabled", "1" => "Enabled" },
                99  => { "0" => "Disabled", "1" => "Enabled" },
                101 => { "0" => "Disabled", "1" => "Enabled" },
                102 => { "0" => "Disabled", "1" => "Enabled" },
                103 => { "0" => "Disabled", "1" => "Enabled" },
                104 => { "0" => "Disabled", "1" => "Enabled" },
                105 => { "0" => "Disabled", "1" => "Enabled" },
                111 => { "0" => "Off",      "1" => "SSL", "2" => "New-Tunnel" },
                112 => { "0" => "Off",      "1" => "Deflate-Compression" },
                120 => { "0" => "Off",      "1" => "Deflate-Compression" },
                122 => { "0" => "Disabled", "1" => "Enabled" },
                123 => { "0" => "Disabled", "1" => "Enabled" },
                126 => { "0" => "None",     "1" => "Visible" },
                131 => {
                    "0" => "Disabled",
                    "1" => "Enabled",
                    "3" => "Enable-Default-Service",
                    "5" => "Enable-Default-Clientless",
                },
                135 => { "0" => "Disabled", "1" => "Enabled" },
                138 =>
                  { "0" => "Disabled", "1" => "Enabled", "2" => "AutoStart" },
                150 => {
                    1 => "Cisco-VPN-Client-IKEv1",
                    2 => "AnyConnect-Client-SSL-VPN",
                    3 => "Clientless-SSL-VPN",
                    4 => "Cut-Through-Proxy",
                    5 => "L2TP/IPsec-SSL-VPN",
                    6 => "AnyConnect-Client-IPSec-VPN-IKEv2",
                },
                151 => {
                    "0" => "None",
                    "1" => "AnyConnect-Client-SSL-VPN",
                    "2" => "AnyConnect-Client-IPSec-VPN/IKEv2",
                    "3" => "Clientless-SSL-VPN",
                    "4" => "Clientless-Email-Proxy",
                    "5" => "Cisco-VPN-Client/IKEv1",
                    "6" => "IKEv1-LAN-to-LAN",
                    "7" => "IKEv2-LAN-to-LAN",
                    "8" => "VPN-Load-Balancing",
                },
                152 => {
                    "0" => "None",
                    "1" => "Clientless",
                    "2" => "Client",
                    "3" => "Client-Only"
                },
                225 => { "0" => "Disabled", "1" => "Enabled" },
            },
            3199 =>
              { 1 => { 1 => "User", 2 => "Super-User", 3 => "SSuper-User" } },
            3224 => {
                1 => {
                    1 => "Root-Admin",
                    2 => "All-VSYS-Root-Admin",
                    3 => "VSYS-Admin",
                    4 => "Read-Only-Admin",
                    5 => "Read-Only-VSYS-Admin",
                },
            },
            3309 => { 4 => { "0" => "PrivatePool", "1" => "PublicPool" } },
            3375 => {
                1 => {
                    "0"   => "Administrator",
                    "20"  => "Resource-Admin",
                    "40"  => "User-Manager",
                    "80"  => "Auditor",
                    "100" => "Manager",
                    "300" => "App-Editor",
                    "350" => "Advanced-Operator",
                    "400" => "Operator",
                    "450" => "Firewall-Manager",
                    "480" => "Fraud-Protection-Manager",
                    "500" => "Certificate-Manager",
                    "510" => "IRule-Manager",
                    "700" => "Guest",
                    "800" => "Web-Application-Security-Administrator",
                    "810" => "Web-Application-Security-Editor",
                    "850" => "Acceleration-Policy-Editor",
                    "900" => "No-Access",
                },
                2 => { "0" => "Disabled", "1" => "Enabled" },
                4 => { "0" => "Disabled", "1" => "Enabled" },
            },
            4491 => {
                1 => {
                    "0"  => "Reserved",
                    "1"  => "Signaling-Start",
                    "2"  => "Signaling-Stop",
                    "3"  => "Database-Query",
                    "4"  => "Intelligent-Peripheral-Usage-Start",
                    "5"  => "Intelligent-Peripheral-Usage-Stop",
                    "6"  => "Service-Instance",
                    "7"  => "QoS-Reserve",
                    "8"  => "QoS-Release",
                    "9"  => "Service-Activation",
                    "10" => "Service-Deactivation",
                    "11" => "Media-Report",
                    "12" => "Signal-Instance",
                    "13" => "Interconnect-Signaling-Start",
                    "14" => "Interconnect-Signaling-Stop",
                    "15" => "Call-Answer",
                    "16" => "Call-Disconnect",
                    "17" => "Time-Change",
                    "19" => "QoS-Commit",
                    "20" => "Media-Alive",
                    "31" => "Policy-Request",
                    "32" => "Policy-Delete",
                    "33" => "Policy-Update",
                },
                7 => {
                    "0" => "Reserved",
                    "1" => "Toll-Free-Number-Looukp",
                    "2" => "LNP-Number-Lookup",
                    "3" => "Calling-Name-Delivery-Lookup",
                },
                29 => {
                    "0" => "Reserved",
                    "1" => "Open",
                    "2" => "Change",
                    "3" => "Close"
                },
                37 => {
                    "0" => "Undefined",
                    "1" => "Originating",
                    "2" => "Terminating"
                },
                50 =>
                  { "0" => "Reserved", "1" => "Upstream", "2" => "Downstream" },
                51 => {
                    "0" => "Reserved",
                    "1" => "Network-Signal",
                    "2" => "Subject-Signal"
                },
                52 => {
                    "0"  => "Reserved-0",
                    "1"  => "Ringing",
                    "2"  => "Distinctive-Ringing-2",
                    "3"  => "Distinctive-Ringing-3",
                    "4"  => "Distinctive-Ringing-4",
                    "5"  => "Ringsplash",
                    "6"  => "Call-Waiting-Tone-1",
                    "7"  => "Call-Waiting-Tone-2",
                    "8"  => "Call-Waiting-Tone-3",
                    "9"  => "Call-Waiting-Tone-4",
                    "10" => "Reserved-10",
                    "11" => "Distinctive-Ringing-0",
                    "12" => "Distinctive-Ringing-1",
                    "13" => "Distinctive-Ringing-5",
                    "14" => "Distinctive-Ringing-6",
                    "15" => "Distinctive-Ringing-7",
                },
                61 => {
                    "0" => "Reserved-0",
                    "1" => "Dial-Tone",
                    "2" => "Stutter-Dial-Tone",
                    "3" => "Ring-Back-Tone",
                    "4" => "Reorder-Tone",
                    "5" => "Busy-Tone",
                    "6" => "Confirmation-Tone",
                    "7" => "Reserved-7",
                    "8" => "Message-Waiting-Indicator",
                    "9" => "Off-hook-Warning-Tone",
                },
                65 => {
                    "0" => "Client",
                    "1" => "Policy-Server",
                    "2" => "Embedded-Client"
                },
                66 => {
                    1   => "Gate-Closed-By-PS",
                    2   => "Inactivity-Resource-Recovery-Timer-Expiration",
                    3   => "CM-Failure",
                    4   => "Pre-Empted",
                    5   => "RSVP-PathTear-request",
                    6   => "CM-Request",
                    7   => "Admitted-Timer-Expiration",
                    127 => "Other",
                },
                67 => {
                    1   => "Policy-Server-Admission-Control-Failure",
                    2   => "Insufficient-Resources",
                    3   => "Unknown-Subscriber",
                    4   => "Unauthorized-AMID",
                    5   => "Undefined-Service-Class-Name",
                    6   => "Incompatible-Envelope",
                    127 => "Other",
                },
                68 => {
                    1   => "Application-Manager-Request",
                    2   => "CMTS-Decistion",
                    127 => "Other",
                },
                69 => {
                    1   => "Traffic-Profile",
                    2   => "Classifier",
                    3   => "Volume-Limit",
                    4   => "Time-Limit",
                    5   => "Opaque-Data",
                    6   => "Multiple-Updates",
                    127 => "Other",
                },
                70 => { 1 => "Policy-Approved", 2 => "Policy-Denied" },
            },
            4735 => {
                16 => {
                    "0" => "Read-Status",
                    "1" => "Read-Config",
                    "2" => "Read-Write",
                    "3" => "Admin",
                    "4" => "Super-user",
                },
            },
            4874 => {
                12 => { "0" => "disable", "1" => "enable" },
                13 => { "0" => "disable", "1" => "enable" },
                14 => { 1 => "UBR", 2 => "UBRPCR", 3 => "nrtVBR", 4 => "CBR" },
                19 => { "0" => "disable", "1" => "enable" },
                22 => { "0" => "disable", "1" => "enable" },
                23 => { "0" => "disable", "1" => "enable" },
                29 => {
                    1  => "IP",
                    2  => "ATM",
                    3  => "HDLC",
                    4  => "ETHERNET",
                    5  => "SERVER-PORT",
                    6  => "ATM-1483",
                    7  => "FRAME-RELAY",
                    8  => "MPLS-MINOR",
                    9  => "CBF",
                    10 => "IP-TUNNEL",
                    11 => "VLAN-SUB",
                    12 => "PPPOE-SUB",
                },
                30 => { "0" => "None", "1" => "CISCO-CLID" },
                38 => {
                    "0" => "None",
                    "1" => "PAP",
                    "2" => "CHAP",
                    "3" => "PAP-CHAP",
                    "4" => "CHAP-PAP",
                },
                41 => { "0" => "None", "1" => "Analog", "2" => "Digital" },
                58 => { "0" => "off",  "1" => "on",     "2" => "noop" },
                69 =>
                  { "0" => "disabled", "1" => "time", "2" => "time-volume" },
                70 => { "0" => "dont-ignore-df-bit", "1" => "ignore-df-bit" },
                77 => { 1   => "v1",                 2   => "v2" },
                78 => { 1   => "v1",                 2   => "v2", 3 => "v3" },
                90 => {
                    "0" => "disable",
                    "1" => "failover",
                    "2" => "silent-failover",
                    "3" => "failover-with-silent-backup",
                },
                94 => {
                    1 => "static-layer2",
                    2 => "dynamic-layer2",
                    3 => "qos",
                    4 => "actual"
                },
                97  => { "0" => "disabled", "1" => "enabled" },
                100 => { "0" => "disabled", "1" => "enabled" },
                101 => { "0" => "disabled", "1" => "enabled" },
                102 => { "0" => "disabled", "1" => "enabled" },
                103 => { "0" => "disabled", "1" => "enabled" },
                104 => { "0" => "disabled", "1" => "enabled" },
                105 => { "0" => "disabled", "1" => "enabled" },
                127 => { 1   => "SHOWTIME", 2   => "IDLE", 3 => "SILENT" },
                128 => {
                    1 => "ADSL1",
                    2 => "ADSL2",
                    3 => "ADSL2PLUS",
                    4 => "VDSL1",
                    5 => "VDSL2",
                    6 => "SDSL",
                    7 => "UNKNOWN",
                },
                144 => { "0" => "disabled", "1" => "enabled" },
                173 => { 1   => "opscript" },
                193 => { "0" => "disabled", "1" => "enabled" },
                206 => { "0" => "disabled", "1" => "client-renew" },
                210 => {
                    1    => "Acct-Start-Ack",
                    2    => "Periodic",
                    4    => "IP-Active",
                    8    => "IP-Inactive",
                    16   => "IPv6-Active",
                    32   => "IPv6-Inactive",
                    64   => "Session-Active",
                    128  => "Session-Inactive",
                    256  => "Line-Speed-Change",
                    512  => "Address-Assignment-Change",
                    1024 => "CoA-Complete",
                },
                212 => { "0" => "disabled", "1" => "enabled" },
                219 => {
                    "0" => "Other",
                    "1" => "GPON",
                    "2" => "XG-PON1",
                    "3" => "TWDM-PON",
                    "4" => "XGS-PON",
                    "5" => "WDM-PON",
                    "7" => "UNKNOWN",
                },
            },
            5003 => {
                35 => {
                    50  => "ACL-Auth-UserLevel",
                    100 => "ACL-Auth-AdminLevel",
                    200 => "ACL-Auth-SecurityAdminLevel",
                },
            },
            5535 => {
                5 => {
                    "0"  => "Best-Effort",
                    "10" => "AF11",
                    "12" => "AF12",
                    "14" => "AF13",
                    "18" => "AF21",
                    "20" => "AF22",
                    "22" => "AF23",
                    "26" => "AF31",
                    "28" => "AF32",
                    "30" => "AF33",
                    "34" => "AF41",
                    "36" => "AF42",
                    "38" => "AF43",
                    "46" => "EF",
                },
                117 => { 1 => "HAAA", 2 => "VAAA" },
            },
            5948 => {
                14 => { 1 => "IP-IP", 2 => "ESP", 3 => "L2TP" },
                15 => { 1 => "NAT",   2 => "NAPT" },
            },
            6321 => {
                221 => { "0" => "Disabled", "1" => "Enabled" },
                222 => { "0" => "Disabled", "1" => "Enabled" },
                223 => { "0" => "Disabled", "1" => "Enabled" },
            },
            6527 => {
                1  => { 1 => "ftp",             2 => "console", 3 => "both" },
                3  => { 1 => "true",            2 => "false" },
                5  => { 1 => "permit-all",      2 => "deny-all", 3 => "none" },
                7  => { 1 => "permit",          2 => "deny" },
                47 => { 1 => "weighted-access", 2 => "existing-first" },
                54 => { 1 => "nothing", 2 => "sensitive-only", 3 => "all" },
                65 => { 1 => "group1",  2 => "group2",         5 => "group5" },
                66 => {
                    1 => "null",
                    2 => "des",
                    3 => "des3",
                    4 => "aes128",
                    5 => "aes192",
                    6 => "aes256"
                },
                67  => { 1 => "null",      2 => "md5", 3 => "sha1" },
                97  => { 1 => "never",     2 => "always" },
                122 => { 1 => "no-action", 2 => "enable", 3 => "disable" },
                124 => {
                    "0" => "be",
                    "1" => "l2",
                    "2" => "af",
                    "3" => "l1",
                    "4" => "h2",
                    "5" => "ef",
                    "6" => "h1",
                    "7" => "nc",
                },
                125 => { 1 => "ingress", 2 => "egress" },
                130 => { 1 => "host",    2 => "audit-start", 3 => "audit-end" },
                145 => { 1 => "gn",      2 => "s2a",         3 => "s2b" },
                163 => {
                    1  => "regular",
                    2  => "sla-start",
                    3  => "sla-stop",
                    4  => "Framed-IP-Address-up",
                    5  => "Framed-IP-Address-down",
                    6  => "Alc-Ipv6-Address-up",
                    7  => "Alc-Ipv6-Address-down",
                    8  => "Delegated-IPv6-Prefix-up",
                    9  => "Delegated-IPv6-Prefix-down",
                    10 => "Framed-IPv6-Prefix-up",
                    11 => "Framed-IPv6-Prefix-down",
                },
            },
            7262 => {
                1 => {
                    1 => "DragonWave-Admin-User",
                    2 => "DragonWave-NOC-User",
                    3 => "DragonWave-Super-User",
                },
            },
            7751 => {
                6 => {
                    "0" => "Subscribed",
                    "1" => "Sent-By-MS",
                    "2" => "Chosen-By-SGSN"
                },
                7  => { "0" => "Not-Required", "1" => "Required" },
                10 => { "0" => "Success",      "1" => "Failure" },
                12 => {
                    1 => "PPP-SIM",
                    2 => "Dummy-IMSI",
                    3 => "Soft-SIM",
                    4 => "Radius-SIM",
                    5 => "Post-paid",
                    6 => "Pre-paid",
                    7 => "Local-Radius",
                    8 => "Proxy-Radius",
                },
            },
            8164 => {
                3 => {
                    "0"   => "Not-Defined",
                    "1"   => "Admin-Disconnect",
                    "2"   => "Remote-Disconnect",
                    "3"   => "Local-Disconnect",
                    "4"   => "Disc-No-Resource",
                    "5"   => "Disc-Excd-Service-Limit",
                    "6"   => "PPP-LCP-Neg-Failed",
                    "7"   => "PPP-LCP-No-Response",
                    "8"   => "PPP-LCP-Loopback",
                    "9"   => "PPP-LCP-Max-Retry",
                    "10"  => "PPP-Echo-Failed",
                    "11"  => "PPP-Auth-Failed",
                    "12"  => "PPP-Auth-Failed-No-AAA-Resp",
                    "13"  => "PPP-Auth-No-Response",
                    "14"  => "PPP-Auth-Max-Retry",
                    "15"  => "Invalid-AAA-Attr",
                    "16"  => "Failed-User-Filter",
                    "17"  => "Failed-Provide-Service",
                    "18"  => "Invalid-IP-Address-AAA",
                    "19"  => "Invalid-IP-Pool-AAA",
                    "20"  => "PPP-IPCP-Neg-Failed",
                    "21"  => "PPP-IPCP-No-Response",
                    "22"  => "PPP-IPCP-Max-Retry",
                    "23"  => "PPP-No-Rem-IP-Address",
                    "24"  => "Inactivity-Timeout",
                    "25"  => "Session-Timeout",
                    "26"  => "Max-Data-Excd",
                    "27"  => "Invalid-IP-Source-Address",
                    "28"  => "MSID-Auth-Failed",
                    "29"  => "MSID-Auth-Fauiled-No-AAA-Resp",
                    "30"  => "A11-Max-Retry",
                    "31"  => "A11-Lifetime-Expired",
                    "32"  => "A11-Message-Integrity-Failure",
                    "33"  => "PPP-lcp-remote-disc",
                    "34"  => "Session-setup-timeout",
                    "35"  => "PPP-keepalive-failure",
                    "36"  => "Flow-add-failed",
                    "37"  => "Call-type-detection-failed",
                    "38"  => "Wrong-ipcp-params",
                    "39"  => "MIP-remote-dereg",
                    "40"  => "MIP-lifetime-expiry",
                    "41"  => "MIP-proto-error",
                    "42"  => "MIP-auth-failure",
                    "43"  => "MIP-reg-timeout",
                    "44"  => "Invalid-dest-context",
                    "45"  => "Source-context-removed",
                    "46"  => "Destination-context-removed",
                    "47"  => "Req-service-addr-unavailable",
                    "48"  => "Demux-mgr-failed",
                    "49"  => "Internal-error",
                    "50"  => "AAA-context-removed",
                    "51"  => "invalid-service-type",
                    "52"  => "mip-relay-req-failed",
                    "53"  => "mip-rcvd-relay-failure",
                    "54"  => "ppp-restart-inter-pdsn-handoff",
                    "55"  => "gre-key-mismatch",
                    "56"  => "invalid_tunnel_context",
                    "57"  => "no_peer_lns_address",
                    "58"  => "failed_tunnel_connect",
                    "59"  => "l2tp-tunnel-disconnect-remote",
                    "60"  => "l2tp-tunnel-timeout",
                    "61"  => "l2tp-protocol-error-remote",
                    "62"  => "l2tp-protocol-error-local",
                    "63"  => "l2tp-auth-failed-remote",
                    "64"  => "l2tp-auth-failed-local",
                    "65"  => "l2tp-try-another-lns-from-remote",
                    "66"  => "l2tp-no-resource-local",
                    "67"  => "l2tp-no-resource-remote",
                    "68"  => "l2tp-tunnel-disconnect-local",
                    "69"  => "l2tp-admin-disconnect_remote",
                    "70"  => "l2tpmgr-reached-max-capacity",
                    "71"  => "MIP-reg-revocation",
                    "72"  => "path-failure",
                    "73"  => "dhcp-relay-ip-validation-failed",
                    "74"  => "gtp-unknown-pdp-addr-or-pdp-type",
                    "75"  => "gtp-all-dynamic-pdp-addr-occupied",
                    "76"  => "gtp-no-memory-is-available",
                    "77"  => "dhcp-relay-static-ip-addr-not-allowed",
                    "78"  => "dhcp-no-ip-addr-allocated",
                    "79"  => "dhcp-ip-addr-allocation-tmr-exp",
                    "80"  => "dhcp-ip-validation-failed",
                    "81"  => "dhcp-static-addr-not-allowed",
                    "82"  => "dhcp-ip-addr-not-available-at-present",
                    "83"  => "dhcp-lease-expired",
                    "84"  => "lpool-ip-validation-failed",
                    "85"  => "lpool-static-ip-addr-not-allowed",
                    "86"  => "static-ip-validation-failed",
                    "87"  => "static-ip-addr-not-present",
                    "88"  => "static-ip-addr-not-allowed",
                    "89"  => "radius-ip-validation-failed",
                    "90"  => "radius-ip-addr-not-provided",
                    "91"  => "invalid-ip-addr-from-sgsn",
                    "92"  => "no-more-sessions-in-aaa",
                    "93"  => "ggsn-aaa-auth-req-failed",
                    "94"  => "conflict-in-ip-addr-assignment",
                    "95"  => "apn-removed",
                    "96"  => "credits-used-bytes-in",
                    "97"  => "credits-used-bytes-out",
                    "98"  => "credits-used-bytes-total",
                    "99"  => "prepaid-failed",
                    "100" => "l2tp-ipsec-tunnel-failure",
                    "101" => "l2tp-ipsec-tunnel-disconnected",
                    "102" => "mip-ipsec-sa-inactive",
                    "103" => "Long-Duration-Timeout",
                    "104" => "proxy-mip-registration-failure",
                    "105" => "proxy-mip-binding-update",
                    "106" => "proxy-mip-inter-pdsn-handoff-require-ip-address",
                    "107" => "proxy-mip-inter-pdsn-handoff-mismatched-address",
                    "108" => "Local-purge",
                    "109" => "failed-update-handoff",
                    "110" => "closed_rp-handoff-complete",
                    "111" => "closed_rp-duplicate-session",
                    "112" => "closed_rp-handoff-session-not-found",
                    "113" => "closed_rp-handoff-failed",
                    "114" => "pcf-monitor-keep-alive-failed",
                    "115" => "call-internal-reject",
                    "116" => "call-restarted",
                    "117" => "a11-mn-ha-auth-failure",
                    "118" => "a11-badly-formed",
                    "119" => "a11-t-bit-not-set",
                    "120" => "a11-unsupported-vendor-id",
                    "121" => "a11-mismatched-id",
                    "122" => "mipha-dup-home-addr-req",
                    "123" => "mipha-dup-imsi-session",
                    "124" => "ha-unreachable",
                    "125" => "IPSP-addr-in-use",
                    "126" => "mipfa-dup-home-addr-req",
                    "127" => "mipha-ip-pool-busyout",
                    "128" => "inter-pdsn-handoff",
                    "129" => "active-to-dormant",
                    "130" => "ppp-renegotiation",
                    "131" => "active-start-param-change",
                    "132" => "tarrif-boundary",
                    "133" => "a11-disconnect-no-active-stop",
                    "134" => "nw-reachability-failed-reject",
                    "135" => "nw-reachability-failed-redirect",
                    "136" => "container-max-exceeded",
                    "137" => "static-addr-not-allowed-in-apn",
                    "138" => "static-addr-required-by-radius",
                    "139" => "static-addr-not-allowed-by-radius",
                    "140" => "mip-registration-dropped",
                    "141" => "counter-rollover",
                    "142" => "constructed-nai-auth-fail",
                    "143" => "inter-pdsn-service-optimize-handoff-disabled",
                    "144" => "gre-key-collision",
                    "145" => "inter-pdsn-service-optimize-handoff-triggered",
                    "146" => "intra-pdsn-handoff-triggered",
                    "147" => "delayed-abort-timer-expired",
                    "148" => "Admin-AAA-disconnect",
                    "149" => "Admin-AAA-disconnect-handoff",
                    "150" => "PPP-IPV6CP-Neg-Failed",
                    "151" => "PPP-IPV6CP-No-Response",
                    "152" => "PPP-IPV6CP-Max-Retry",
                    "153" => "PPP-Restart-Invalid-source-IPV4-address",
                    "154" => "a11-disconnect-handoff-no-active-stop",
                    "155" => "call-restarted-inter-pdsn-handoff",
                    "156" => "call-restarted-ppp-termination",
                    "157" => "mipfa-resource-conflict",
                    "158" => "failed-auth-with-charging-svc",
                    "159" => "mipha-dup-imsi-session-purge",
                    "160" => "mipha-rev-pending-newcall",
                    "161" => "volume-quota-reached",
                    "162" => "duration-quota-reached",
                    "163" => "gtp-user-authentication-failed",
                    "164" => "MIP-reg-revocation-no-lcp-term",
                    "165" => "MIP-private-ip-no-rev-tunnel",
                    "166" => "Invalid-Prepaid-AAA-attr-in-auth-response",
                    "167" => "mipha-prepaid-reset-dynamic-newcall",
                    "168" => "gre-flow-control-timeout",
                    "169" => "mip-paaa-bc-query-not-found",
                    "170" => "mipha-dynamic-ip-addr-not-available",
                    "171" => "a11-mismatched-id-on-handoff",
                    "172" => "a11-badly-formed-on-handoff",
                    "173" => "a11-unsupported-vendor-id-on-handoff",
                    "174" => "a11-t-bit-not-set-on-handoff",
                    "175" => "MIP-reg-revocation-i-bit-on",
                    "176" => "A11-RRQ-Deny-Max-Count",
                    "177" => "Dormant-Transition-During-Session-Setup",
                    "178" => "PPP-Rem-Reneg-Disc-Always-Cfg",
                    "179" => "PPP-Rem-Reneg-Disc-NAI-MSID-Mismatch",
                    "180" => "mipha-subscriber-ipsec-tunnel-down",
                    "181" => "mipha-subscriber-ipsec-tunnel-failed",
                    "182" => "mipha-subscriber-ipsecmgr-death",
                    "183" => "flow-is-deactivated",
                    "184" => "ecsv2-license-exceeded",
                    "185" => "IPSG-Auth-Failed",
                    "186" => "driver-initiated",
                    "187" => "ims-authorization-failed",
                    "188" => "service-instance-released",
                    "189" => "flow-released",
                    "190" => "ppp-renego-no-ha-addr",
                    "191" => "intra-pdsn-handoff",
                    "192" => "overload-disconnect",
                    "193" => "css-service-not-found",
                    "194" => "Auth-Failed",
                    "195" => "dhcp-client-sent-release",
                    "196" => "dhcp-client-sent-nak",
                    "197" => "msid-dhcp-chaddr-mismatch",
                    "198" => "link-broken",
                    "199" => "prog-end-timeout",
                    "200" => "qos-update-wait-timeout",
                    "201" => "css-synch-cause",
                    "202" => "Gtp-context-replacement",
                    "203" => "PDIF-Auth-failed",
                    "204" => "l2tp-unknown-apn",
                    "205" => "ms-unexpected-network-reentry",
                    "206" => "r6-invalid-nai",
                    "207" => "eap-max-retry-reached",
                    "208" => "vbm-hoa-session-disconnected",
                    "209" => "vbm-voa-session-disconnected",
                    "210" => "in-acl-disconnect-on-violation",
                    "211" => "eap-msk-lifetime-expiry",
                    "212" => "eap-msk-lifetime-too-low",
                    "213" => "mipfa-inter-tech-handoff",
                    "214" => "r6-max-retry-reached",
                    "215" => "r6-nwexit-recd",
                    "216" => "r6-dereg-req-recd",
                    "217" => "r6-remote-failure",
                    "218" => "r6r4-protocol-errors",
                    "219" => "wimax-qos-invalid-aaa-attr",
                    "220" => "npu-gre-flows-not-available",
                    "221" => "r4-max-retry-reached",
                    "222" => "r4-nwexit-recd",
                    "223" => "r4-dereg-req-recd",
                    "224" => "r4-remote-failure",
                    "225" => "ims-authorization-revoked",
                    "226" => "ims-authorization-released",
                    "227" => "ims-auth-decision-invalid",
                    "228" => "mac-addr-validation-failed",
                    "229" => "excessive-wimax-pd-flows-cfgd",
                    "230" => "sgsn-canc-loc-sub",
                    "231" => "sgsn-canc-loc-upd",
                    "232" => "sgsn-mnr-exp",
                    "233" => "sgsn-ident-fail",
                    "234" => "sgsn-sec-fail",
                    "235" => "sgsn-auth-fail",
                    "236" => "sgsn-glu-fail",
                    "237" => "sgsn-imp-det",
                    "238" => "sgsn-smgr-purge",
                    "239" => "sgsn-subs-handed-to-peer",
                    "240" => "sgsn-dns-fail-inter-rau",
                    "241" => "sgsn-cont-rsp-fail",
                    "242" => "sgsn-hlr-not-found-for-imsi",
                    "243" => "sgsn-ms-init-det",
                    "244" => "sgsn-opr-policy-fail",
                    "245" => "sgsn-duplicate-context",
                    "246" => "hss-profile-update-failed",
                    "247" => "sgsn-no-pdp-activated",
                    "248" => "asnpc-idle-mode-timeout",
                    "249" => "asnpc-idle-mode-exit",
                    "250" => "asnpc-idle-mode-auth-failed",
                    "251" => "asngw-invalid-qos-configuration",
                    "252" => "sgsn-dsd-allgprswithdrawn",
                    "253" => "r6-pmk-key-change-failure",
                    "254" => "sgsn-illegal-me",
                    "255" => "sess-termination-timeout",
                    "256" => "sgsn-sai-fail",
                    "257" => "sgsn-rnc-removal",
                    "258" => "sgsn-rai-removal",
                    "259" => "sgsn-init-deact",
                    "260" => "ggsn-init-deact",
                    "261" => "hlr-init-deact",
                    "262" => "ms-init-deact",
                    "263" => "sgsn-detach-init-deact",
                    "264" => "sgsn-rab-rel-init-deact",
                    "265" => "sgsn-iu-rel-init-deact",
                    "266" => "sgsn-gtpu-path-failure",
                    "267" => "sgsn-gtpc-path-failure",
                    "268" => "sgsn-local-handoff-init-deact",
                    "269" => "sgsn-remote-handoff-init-deact",
                    "270" => "sgsn-gtp-no-resource",
                    "271" => "sgsn-rnc-no-resource",
                    "272" => "sgsn-odb-init-deact",
                    "273" => "sgsn-invalid-ti",
                    "274" => "sgsn-ggsn-ctxt-non-existent",
                    "275" => "sgsn-apn-restrict-vio",
                    "276" => "sgsn-regular-deact",
                    "277" => "sgsn-abnormal-deact",
                    "278" => "sgsn-actv-rejected-by-peer",
                    "279" => "sgsn-err-ind",
                    "280" => "asngw-non-anchor-prohibited",
                    "281" => "asngw-im-entry-prohibited",
                    "282" => "session-idle-mode-entry-timeout",
                    "283" => "session-idle-mode-exit-timeout",
                    "284" => "asnpc-ms-power-down-nwexit",
                    "285" => "asnpc-r4-nwexit-recd",
                    "286" => "sgsn-iu-rel-before-call-est",
                    "287" => "ikev2-subscriber-ipsecmgr-death",
                    "288" => "All-dynamic-pool-addr-occupied",
                    "289" => "mip6ha-ip-addr-not-available",
                    "290" => "bs-monitor-keep-alive-failed",
                    "291" => "sgsn-att-in-reg-state",
                    "292" => "sgsn-inbound-srns-in-reg-state",
                    "293" => "dt-ggsn-tun-reestablish-failed",
                    "294" => "sgsn-unknown-pdp",
                    "295" => "sgsn-pdp-auth-failure",
                    "296" => "sgsn-duplicate-pdp-context",
                    "297" => "sgsn-no-rsp-from-ggsn",
                    "298" => "sgsn-failure-rsp-from-ggsn",
                    "299" => "sgsn-apn-unknown",
                    "300" => "sgsn-serv-req-init-deact",
                    "301" => "sgsn-attach-on-attch-init-abort",
                    "302" => "sgsn-iu-rel-in-israu-init-abort",
                    "303" => "sgsn-smgr-init-abort",
                    "304" => "sgsn-mm-ctx-cleanup-init-abort",
                    "305" => "sgsn-unknown-abort",
                    "306" => "sgsn-guard-timeout-abort",
                    "307" => "vpn-bounce-dhcpip-validate-req",
                    "308" => "mipv6-id-mismatch",
                    "309" => "aaa-session-id-not-found",
                    "310" => "x1-max-retry-reached",
                    "311" => "x1-nwexit-recd",
                    "312" => "x1-dereg-req-recd",
                    "313" => "x1-remote-failure",
                    "314" => "x1x2-protocol-errors",
                    "315" => "x2-max-retry-reached",
                    "316" => "x2-nwexit-recd",
                    "317" => "x2-dereg-req-recd",
                    "318" => "x2-remote-failure",
                    "319" => "x1-pmk-key-change-failure",
                    "320" => "sa-rekeying-failure",
                    "321" => "sess-sleep-mode-entry-timeout",
                    "322" => "phsgw-non-anchor-prohibited",
                    "323" => "asnpc-pc-relocation-failed",
                    "324" => "asnpc-pc-relocation",
                    "325" => "auth_policy_mismatch",
                    "326" => "sa-lifetime-expiry",
                    "327" => "asnpc-del-ms-entry-recd",
                    "328" => "phspc-sleep-mode-timeout",
                    "329" => "phspc-sleep-mode-exit",
                    "330" => "phspc-sleep-mode-auth-failed",
                    "331" => "phspc-ms-power-down-nwexit",
                    "332" => "phspc-x2-nwexit-recd",
                    "333" => "invalid-nat-config",
                    "334" => "asngw-tid-entry-not-found",
                    "335" => "No-NAT-IP-Address",
                    "336" => "excessive-phs-pd-flows-cfgd",
                    "337" => "phsgw-invalid-qos-configuration",
                    "338" => "Interim-Update",
                    "339" => "sgsn-attach-abrt-rad-lost",
                    "340" => "sgsn-inbnd-irau-abrt-rad-lost",
                    "341" => "ike-keepalive-failed",
                    "342" => "sgsn-attach-abrt-ms-suspend",
                    "343" => "sgsn-inbnd-irau-abrt-ms-suspend",
                    "344" => "duplicate-session-detected",
                    "345" => "sgsn-xid-response-failure",
                    "346" => "sgsn-nse-cleanup",
                    "347" => "sgsn-gtp-req-failure",
                    "348" => "sgsn-imsi-mismatch",
                    "349" => "sgsn-bvc-blocked",
                    "350" => "sgsn-attach-on-inbound-irau",
                    "351" => "sgsn-attach-on-outbound-irau",
                    "352" => "sgsn-incorrect-state",
                    "353" => "sgsn-t3350-expiry",
                    "354" => "sgsn-page-timer-expiry",
                    "355" => "phsgw-tid-entry-not-found",
                    "356" => "phspc-del-ms-entry-recd",
                    "357" => "sgsn-pdp-local-purge",
                    "358" => "phs-invalid-nai",
                    "359" => "session-sleep-mode-exit-timeout",
                    "360" => "sgsn-offload-phase2",
                    "361" => "phs-thirdparty-auth-fail",
                    "362" => "remote-error-notify",
                    "363" => "no-response",
                    "364" => "PDG-Auth-failed",
                    "365" => "mme-s1AP-send-failed",
                    "366" => "mme-egtpc-connection-failed",
                    "367" => "mme-egtpc-create-session-failed",
                    "368" => "mme-authentication-failure",
                    "369" => "mme-ue-detach",
                    "370" => "mme-mme-detach",
                    "371" => "mme-hss-detach",
                    "372" => "mme-pgw-detach",
                    "373" => "mme-sub-validation-failure",
                    "374" => "mme-hss-connection-failure",
                    "375" => "mme-hss-user-unknown",
                    "376" => "dhcp-lease-mismatch-detected",
                    "377" => "nemo-link-layer-down",
                    "378" => "eapol-max-retry-reached",
                    "379" => "sgsn-offload-phase3",
                    "380" => "mbms-bearer-service-disconnect",
                    "381" => "disconnect-on-violation-odb",
                    "382" => "disconn-on-violation-focs-odb",
                    "383" => "CSCF-REG-Admin-disconnect",
                    "384" => "CSCF-REG-User-disconnect",
                    "385" => "CSCF-REG-Inactivity-timeout",
                    "386" => "CSCF-REG-Network-disconnect",
                    "387" => "CSCF-Call-Admin-disconnect",
                    "388" => "CSCF-CAll-User-disconnect",
                    "389" => "CSCF-CALL-Local-disconnect",
                    "390" => "CSCF-CALL-No-Resource",
                    "391" => "CSCF-CALL-No-Respone",
                    "392" => "CSCF-CALL-Inactivity-timeout",
                    "393" => "CSCF-CALL-Media-Auth-Failure",
                    "394" => "CSCF-REG-No-Resource",
                    "395" => "ms-unexpected-idle-mode-entry",
                    "396" => "re-auth-failed",
                    "397" => "sgsn-pdp-nse-cleanup",
                    "398" => "sgsn-mm-ctxt-gtp-no-resource",
                    "399" => "unknown-apn",
                    "400" => "gtpc-path-failure",
                    "401" => "gtpu-path-failure",
                    "402" => "actv-rejected-by-sgsn",
                    "403" => "sgsn-pdp-gprs-camel-release",
                    "404" => "sgsn-check-imei-failure",
                    "405" => "sgsn-sndcp-init-deact",
                    "406" => "sgsn-pdp-inactivity-timeout",
                    "407" => "fw-and-nat-policy-removed",
                    "408" => "FNG-Auth-failed",
                    "409" => "ha-stale-key-disconnect",
                    "410" => "No-IPV6-address-for-subscriber",
                    "411" => "prefix-registration-failure",
                    "412" => "disconnect-from-policy-server",
                    "413" => "s6b-auth-failed",
                    "414" => "gtpc-err-ind",
                    "415" => "gtpu-err-ind",
                    "416" => "invalid-pdn-type",
                    "417" => "aaa-auth-req-failed",
                    "418" => "apn-denied-no-subscription",
                    "419" => "Sgw-context-replacement",
                    "420" => "dup-static-ip-addr-req",
                    "421" => "apn-restrict-violation",
                    "422" => "invalid-wapn",
                    "423" => "ttg-nsapi-allocation-failed",
                    "424" => "mandatory-gtp-ie-missing",
                    "425" => "aaa-unreachable",
                    "426" => "asngw-service-flow-deletion",
                    "427" => "CT-PMIP-RRQ-NVSE-Value-Change",
                    "428" => "tcp-read-failed",
                    "429" => "tcp-write-failed",
                    "430" => "ssl-handshake-failed",
                    "431" => "ssl-renegotiate-failed",
                    "432" => "ssl-bad-message",
                    "433" => "ssl-alert-received",
                    "434" => "ssl-disconnect",
                    "435" => "ssl-migration",
                    "436" => "sgsn-ard-failure",
                    "437" => "sgsn-camel-release",
                    "447" => "Hotlining-Status-Change",
                    "448" => "ggsn-no-rsp-from-sgsn",
                    "449" => "diameter-protocol-error",
                    "450" => "diameter-request-timeout",
                    "451" => "operator-policy",
                    "452" => "spr-connection-timeout",
                    "453" => "mipha-dup-wimax-session",
                    "454" => "invalid-version-attr",
                    "455" => "sgsn-zone-code-failure",
                },
                4 => {
                    "0"   => "Not-Defined",
                    "1"   => "Call-Lcp-Down",
                    "2"   => "Call-Disconnecting",
                    "3"   => "Call-PPP-Renegotiating",
                    "10"  => "Call-Lcp-Down_1",
                    "11"  => "Call-Arrived",
                    "12"  => "Call-Lcp-Up",
                    "13"  => "Call-Authenticating",
                    "14"  => "Call-Authenticated",
                    "15"  => "Call-Ipcp-Up",
                    "16"  => "Call-Simple-IP-Connected",
                    "17"  => "Call-Mobile-IP-Connected",
                    "45"  => "Call-Pdg-Tcp-Connecting",
                    "46"  => "Call-Pdg-Ssl-Connecting",
                    "70"  => "Call-Bcmcs-Authenticating",
                    "85"  => "Call-Tunnel-Connecting",
                    "95"  => "Call-Imsa-Authorizing",
                    "97"  => "Call-Imsa-Authorized",
                    "98"  => "Call-MBMS-UE-Authorizing",
                    "99"  => "Call-MBMS-Bearer-Authorizing",
                    "115" => "Call-Tunnel-Connected",
                    "120" => "Call-Pdp-Type-IP-Connected",
                    "125" => "Call-Pdp-Type-IPv6-Connected",
                    "130" => "Call-Pdp-Type-PPP-Connected",
                    "140" => "Call-Proxy-Mobile-IP-Connected",
                    "141" => "Call-Pdg-Ssl-Connected",
                    "142" => "Call-Pdg-Connected",
                    "145" => "Call-Ipsg-Connected",
                    "150" => "Call-Bcmcs-Connected",
                    "155" => "Call-MBMS-UE-Connected",
                    "156" => "Call-MBMS-Bearer-Connected",
                    "160" => "Call-Pending-Addr-From-DHCP",
                    "170" => "Call-Got-Addr-From-DHCP",
                    "180" => "Call-HA-IPSEC-Tunnel-Connecting",
                    "190" => "Call-HA-IPSEC-Connected",
                    "200" => "Call-ASN-Non-Anchor-Connected",
                    "210" => "Call-ASNPC-Connected",
                    "220" => "Call-Mobile-IPv6-Connected",
                    "221" => "Call-PMIPv6-Connected",
                    "230" => "Call-PHSPC-Connected",
                    "235" => "Call-GTP-IPv4-Connected",
                    "236" => "Call-GTP-IPv6-Connected",
                    "237" => "Call-GTP-IPv4-IPv6-Connected",
                    "245" => "Call-SGW-Connected",
                    "246" => "Call-MME-Attached",
                    "247" => "Call-Auth-Only-Connected",
                },
                9 => {
                    "0" => "None",
                    "1" => "Stac-LZS",
                    "2" => "MPPC",
                    "3" => "MPCC-Stac-LZS",
                    "4" => "Deflate",
                    "5" => "Deflate-Stac-LZS",
                    "6" => "Deflate-MPCC",
                    "7" => "Deflate-MPCC-Stac-LZS",
                },
                14 => { "0" => "No",     "1" => "Yes" },
                19 => { "0" => "Normal", "1" => "Stateless" },
                20 => {
                    "0"  => "None",
                    "1"  => "Simple-IP",
                    "2"  => "Mobile-IP",
                    "3"  => "Simple-IP-Mobile-IP",
                    "4"  => "HA-Mobile-IP",
                    "5"  => "Simple-IP-HA-Mobile-IP",
                    "6"  => "Mobile-IP-HA-Mobile-IP",
                    "7"  => "All",
                    "8"  => "GGSN-PDP-TYPE-IP",
                    "16" => "GGSN-PDP-TYPE-PPP",
                    "32" => "Network-Mobility",
                    "38" => "FA-HA-NEMO",
                    "63" => "All_New",
                },
                21 => {
                    "0"  => "None",
                    "1"  => "CLI",
                    "2"  => "FTP",
                    "3"  => "CLI-FTP",
                    "4"  => "Intercept",
                    "5"  => "CLI-Intercept",
                    "7"  => "CLI-Intercept-FTP",
                    "8"  => "ECS",
                    "9"  => "CLI-ECS",
                    "11" => "CLI-FTP-ECS",
                    "13" => "CLI-Intercept-ECS",
                    "15" => "CLI-Intercept-FTP-ECS",
                },
                22 => { "0" => "Disabled", "1" => "Enabled" },
                24 => {
                    "0"  => "None",
                    "1"  => "PDSN",
                    "2"  => "Management",
                    "3"  => "HA",
                    "4"  => "GGSN",
                    "5"  => "LNS",
                    "6"  => "IPSG",
                    "7"  => "CSCF",
                    "8"  => "ASNGW",
                    "9"  => "PDIF",
                    "10" => "STANDALONE_FA",
                    "11" => "SGSN",
                    "12" => "PHSGW",
                    "13" => "PDG",
                    "14" => "MIPV6HA",
                    "15" => "PGW",
                    "16" => "SGW",
                    "17" => "FNG",
                    "18" => "OGW",
                    "19" => "HNBGW",
                    "20" => "BNG",
                },
                25 => { "0" => "Disable", "1" => "Enable" },
                27 => { 1   => "random",  2 => "balanced", 3 => "prioritized" },
                31 => { "0" => "Uncompressed", "1" => "Compressed" },
                43 => {
                    "0" => "no-local-alloc-validate",
                    "1" => "local-alloc",
                    "2" => "local-alloc-validate",
                },
                45 => {
                    1 => "Detection",
                    2 => "Disconnection",
                    3 => "Dormant-Only-Disconnection",
                    4 => "Dormant-Only-Detection",
                },
                46 => { "0" => "Disabled", "1" => "Enabled" },
                47 => { "0" => "Disabled", "1" => "Enabled" },
                48 => {
                    "0" => "Disabled",
                    "1" => "EnabledOrNVSE_Custom1",
                    "2" => "NVSE_Custom2",
                    "3" => "NVSE_Starent",
                },
                49 => { "0" => "Disabled", "1" => "Enabled" },
                50 => { "0" => "Disabled", "1" => "Enabled" },
                51 => { "0" => "Disabled", "1" => "Enabled" },
                52 => { "0" => "Disabled", "1" => "Enabled" },
                53 => {
                    "0" => "Alloc_Local_Pool",
                    "1" => "Alloc_Dhcp_Client",
                    "2" => "Alloc_Radius",
                    "3" => "Alloc_No_Alloc",
                    "4" => "Alloc_Static_Alloc",
                    "5" => "Alloc_Dhcp_Relay",
                },
                54 => { "0" => "Disabled", "1" => "Enabled" },
                60 => { "0" => "Disabled", "1" => "Enabled" },
                62 => {
                    "0" => "GTP_VERSION_0",
                    "1" => "GTP_VERSION_1",
                    "2" => "GTP_VERSION_2"
                },
                63 => {
                    "0" => "Normal",
                    "1" => "DF-Ignore",
                    "2" => "DF-Fragment-ICMP-Notify"
                },
                64 => { "0" => "None",     "1" => "Radius", "2" => "GTPP" },
                67 => { "0" => "Force",    "1" => "Detect" },
                68 => { "0" => "Disabled", "1" => "Enabled" },
                69 => { "0" => "Normal",   "1" => "Suppress" },
                70 => { "0" => "Normal",   "1" => "Suppress" },
                71 => { "0" => "Normal",   "1" => "Suppress" },
                73 =>
                  { "0" => "Disabled", "1" => "Policing", "2" => "Shaping" },
                77 => {
                    "0" => "Transmit",
                    "1" => "Drop",
                    "2" => "Lower-IP-Precedence",
                    "3" => "Buffer",
                    "4" => "Transmit-On-Buffer-Full",
                },
                78 => {
                    "0" => "Transmit",
                    "1" => "Drop",
                    "2" => "Lower-IP-Precedence",
                    "3" => "Buffer",
                    "4" => "Transmit-On-Buffer-Full",
                },
                79 =>
                  { "0" => "Disabled", "1" => "Policing", "2" => "Shaping" },
                83 => {
                    "0" => "Transmit",
                    "1" => "Drop",
                    "2" => "Lower-IP-Precedence",
                    "3" => "Buffer",
                    "4" => "Transmit-On-Buffer-Full",
                },
                84 => {
                    "0" => "Transmit",
                    "1" => "Drop",
                    "2" => "Lower-IP-Precedence",
                    "3" => "Buffer",
                    "4" => "Transmit-On-Buffer-Full",
                },
                85 => {
                    "0" => "None",
                    "1" => "Access-Tunnel",
                    "2" => "Data-Tunnel",
                    "3" => "Both"
                },
                92 => { "0" => "Disabled", "1" => "Enabled", "2" => "Passive" },
                93 => { "0" => "Disabled", "1" => "Enabled", "2" => "Passive" },
                95 => { "0" => "Disabled", "1" => "Enabled" },
                98 => {
                    "0" => "Best_Effort",
                    "1" => "Bronze",
                    "2" => "Silver",
                    "3" => "Gold",
                    "4" => "From_DSCP",
                },
                99  => { 1 => "MD5", 2 => "MD5_RFC2002", 3 => "HMAC_MD5" },
                100 => {
                    "0" => "None",
                    "1" => "No_Early_PDUs",
                    "2" => "Delay_GTP_Response"
                },
                103 => { "0" => "Disabled", "1" => "Enabled" },
                105 => {
                    "0" => "None",
                    "1" => "No_Early_PDUs",
                    "2" => "Delay_GTP_Response"
                },
                106 => { "0" => "Deny", "1" => "Accept" },
                107 => { "0" => "Deny", "1" => "Accept" },
                108 => { "0" => "Deny", "1" => "Accept" },
                111 => {
                    "0"  => "Best-Effort",
                    "1"  => "Pass-Through",
                    "10" => "AF11",
                    "12" => "AF12",
                    "14" => "AF13",
                    "18" => "AF21",
                    "20" => "AF22",
                    "22" => "AF23",
                    "26" => "AF31",
                    "28" => "AF32",
                    "30" => "AF33",
                    "34" => "AF41",
                    "36" => "AF42",
                    "38" => "AF43",
                    "46" => "EF",
                },
                112 => {
                    "0"  => "Best-Effort",
                    "1"  => "Pass-Through",
                    "10" => "AF11",
                    "12" => "AF12",
                    "14" => "AF13",
                    "18" => "AF21",
                    "20" => "AF22",
                    "22" => "AF23",
                    "26" => "AF31",
                    "28" => "AF32",
                    "30" => "AF33",
                    "34" => "AF41",
                    "36" => "AF42",
                    "38" => "AF43",
                    "46" => "EF",
                },
                113 => {
                    "0"  => "Best-Effort",
                    "1"  => "Pass-Through",
                    "10" => "AF11",
                    "12" => "AF12",
                    "14" => "AF13",
                    "18" => "AF21",
                    "20" => "AF22",
                    "22" => "AF23",
                    "26" => "AF31",
                    "28" => "AF32",
                    "30" => "AF33",
                    "34" => "AF41",
                    "36" => "AF42",
                    "38" => "AF43",
                    "46" => "EF",
                },
                114 => {
                    "0"  => "Best-Effort",
                    "1"  => "Pass-Through",
                    "10" => "AF11",
                    "12" => "AF12",
                    "14" => "AF13",
                    "18" => "AF21",
                    "20" => "AF22",
                    "22" => "AF23",
                    "26" => "AF31",
                    "28" => "AF32",
                    "30" => "AF33",
                    "34" => "AF41",
                    "36" => "AF42",
                    "38" => "AF43",
                    "46" => "EF",
                },
                115 => {
                    "0"  => "Best-Effort",
                    "1"  => "Pass-Through",
                    "10" => "AF11",
                    "12" => "AF12",
                    "14" => "AF13",
                    "18" => "AF21",
                    "20" => "AF22",
                    "22" => "AF23",
                    "26" => "AF31",
                    "28" => "AF32",
                    "30" => "AF33",
                    "34" => "AF41",
                    "36" => "AF42",
                    "38" => "AF43",
                    "46" => "EF",
                },
                116 => {
                    "0"  => "Best-Effort",
                    "1"  => "Pass-Through",
                    "10" => "AF11",
                    "12" => "AF12",
                    "14" => "AF13",
                    "18" => "AF21",
                    "20" => "AF22",
                    "22" => "AF23",
                    "26" => "AF31",
                    "28" => "AF32",
                    "30" => "AF33",
                    "34" => "AF41",
                    "36" => "AF42",
                    "38" => "AF43",
                    "46" => "EF",
                },
                123 => { "0" => "Disabled", "1" => "Enabled" },
                126 => { "0" => "Disabled", "1" => "Enabled" },
                128 => {
                    "0" => "no_prepaid",
                    "1" => "custom_prepaid",
                    "2" => "standard_prepaid",
                    "4" => "wimax_prepaid",
                },
                129 => { "0" => "prepaid_duration", "1" => "prepaid_volume" },
                130 => { "0" => "Disabled",         "1" => "Enabled" },
                133 => { "0" => "Disabled",         "1" => "Enabled" },
                134 => { "0" => "Disabled",         "1" => "Enabled" },
                135 => {
                    "0" => "current_time",
                    "1" => "last-user-layer3-activity-time",
                    "2" => "last-airlink-activity-time",
                    "3" => "last-airlink-activity-time-last-reported",
                },
                140 => {
                    "0"   => "QOSCHANGE",
                    "1"   => "TARIFFTIMECHANGE",
                    "500" => "SGSNCHANGE"
                },
                143 => { 1   => "Session-Disconnect" },
                144 => { "0" => "No",       "1" => "Yes" },
                146 => { "0" => "Disabled", "1" => "Enabled" },
                150 => {
                    "0" => "None",
                    "1" => "VJ",
                    "2" => "ROHC",
                    "3" => "VJ_ROHC"
                },
                151 => {
                    "0" => "Reliable",
                    "1" => "Optimistic",
                    "2" => "Unidirectional"
                },
                153 => { "0" => "Any", "1" => "Uplink", "2" => "Downlink" },
                156 => {
                    "0" => "no-local-alloc-validate",
                    "1" => "local-alloc",
                    "2" => "local-alloc-validate",
                },
                157 => { "0" => "auto-renew", "1" => "disconnect" },
                163 => { "0" => "Disabled",   "1" => "Enabled" },
                164 => {
                    "0" => "NoneOrDisabled",
                    "1" => "Starent_NVSE",
                    "2" => "NVSE_Custom1",
                    "3" => "NVSE_Custom2",
                },
                165 => { "0" => "Disabled", "1" => "Enabled" },
                170 => { "0" => "No",       "1" => "Yes" },
                172 => { "0" => "No",       "1" => "Yes" },
                173 => { "0" => "No",       "1" => "Yes" },
                174 => { "0" => "Disabled", "1" => "Enabled" },
                187 => {
                    "0" => "Never",
                    "1" => "Always",
                    "2" => "NAI_Prefix_MSID_Mismatch"
                },
                188 => {
                    "0" => "Disabled",
                    "1" => "EnabledOrNVSE_Starent",
                    "2" => "NVSE_CUstom1",
                    "3" => "NVSE_Custom2",
                },
                192 => {
                    "0" => "flow-based-auxiliary",
                    "1" => "flow-based-all",
                    "2" => "flow-based-none",
                    "3" => "session-based",
                    "4" => "main-a10-only",
                },
                196 => { "0" => "Disabled", "1" => "Enabled" },
                198 => { "0" => "False",    "1" => "True" },
                219 => {
                    "0" => "Normal_Subscriber",
                    "1" => "Ting_100",
                    "2" => "Ting_500",
                    "3" => "Ting_Buddy",
                    "4" => "Ting_Star",
                    "5" => "Ting_Nolimit_SMS",
                    "6" => "Kids_Locator",
                    "7" => "Ting_2000",
                    "8" => "Handicapped_Welfare",
                    "9" => "Reserved",
                },
                221 => {
                    "0" => "None",
                    "1" => "Receive",
                    "2" => "Transmit",
                    "3" => "Both"
                },
                225 => { "0" => "Disabled",         "1" => "Enabled" },
                236 => { "0" => "No",               "1" => "Yes" },
                253 => { "0" => "Suppress",         "1" => "Send" },
                256 => { "0" => "ORIGINATING_ROLE", "1" => "TERMINATING_ROLE" },
                267 => {
                    "0" => "Normal_End_Of_Session",
                    "1" => "Successful_Transaction",
                    "2" => "End_Of_Subscriber_Dialog",
                    "3" => "3XX_Redirection",
                    "4" => "4XX_Request_Failure",
                    "5" => "5XX_Server_Failure",
                    "6" => "6XX_Global_Failure",
                    "7" => "Unspecified_Error",
                    "8" => "Unsuccessful_Session_Setup",
                    "9" => "Internal_Error",
                },
                268 => { "0" => "S-CSCF", "1" => "P-CSCF", "2" => "I-CSCF" },
                274 => { "0" => "False",          "1" => "True" },
                282 => { "0" => "Disable",        "1" => "Enable" },
                283 => { "0" => "Disable",        "1" => "Enable" },
                284 => { "0" => "Disable",        "1" => "Enable" },
                285 => { "0" => "Disable",        "1" => "Enable" },
                291 => { "0" => "Disable",        "1" => "Enable" },
                292 => { "0" => "Disable",        "1" => "Enable" },
                293 => { "0" => "Disable",        "1" => "Enable" },
                294 => { "0" => "Disable",        "1" => "Enable" },
                298 => { "0" => "Disable",        "1" => "Enable" },
                299 => { "0" => "No",             "1" => "Yes" },
                306 => { "0" => "Disabled",       "1" => "Enabled" },
                310 => { "0" => "Active-Handoff", "1" => "Location-Update" },
                313 => {
                    6        => "Administrative",
                    7        => "NAS_Prompt",
                    19650516 => "Inspector",
                    19660618 => "Security_Admin",
                },
                314 => {
                    "0" => "Alloc_Local_Pool",
                    "1" => "Alloc_Dhcp_Client",
                    "2" => "Alloc_No_Alloc",
                    "3" => "Alloc_Static_Alloc",
                },
                316   => { "0" => "No",       "1" => "Yes" },
                317   => { "0" => "No",       "1" => "Yes" },
                318   => { "0" => "No",       "1" => "Yes" },
                65530 => { "0" => "Disabled", "1" => "Enabled" },
            },
            8741 => {
                1 => {
                    1 => "Remote-Access",
                    2 => "Bypass-Filters",
                    3 => "VPN-Client-Access",
                    4 => "Access-To-VPN",
                    5 => "Limited-Management",
                    6 => "L2TP-Client-Access",
                    7 => "Wireless-Guest",
                    8 => "Wireless-Add-ACL",
                    9 => "Internet-Access",
                },
            },
            8742 => {
                27 => {
                    1 => "Personal-Device",
                    2 => "Shared-Device",
                    3 => "Deleted-Device"
                },
                38 => { 1 => "AirGroup-v1", 2 => "AirGroup-v2" },
            },
            10415 => {
                21 => {
                    1   => "UTRAN",
                    2   => "GERAN",
                    3   => "WLAN",
                    4   => "GAN",
                    5   => "HSPA-Evolution",
                    6   => "EUTRAN",
                    7   => "Virtual",
                    101 => "IEEE-802.16e",
                    102 => "3GPP2-eHRPD",
                    103 => "3GPP2-HRPD",
                    104 => "3GPP2-1xRTT",
                },
                27 => {
                    "0" => "Do-Not-Allocate",
                    "1" => "Allocate-IPv4-Address",
                    "2" => "Allocate-IPv6-Prefix",
                    "3" => "Allocate-IPv4-and-IPv6",
                },
            },
            11344 => {
                127 => {
                    "0"   => "None",
                    "1"   => "Authentication",
                    "2"   => "Accounting",
                    "3"   => "Auth-Acct",
                    "4"   => "Proxy-Authentication",
                    "8"   => "Proxy-Accounting",
                    "12"  => "Proxy-Auth-Acct",
                    "16"  => "Internal",
                    "31"  => "All",
                    "32"  => "Client",
                    "64"  => "Server",
                    "128" => "Home-Server",
                },
                173 => {
                    "0" => "Alive",
                    "1" => "Zombie",
                    "2" => "Dead",
                    "3" => "Idle",
                    "4" => "Admin-Down",
                    "5" => "Connection-Fail",
                },
                190 => {
                    1    => "Success",
                    2    => "Failure",
                    3    => "User-Account-Authorizations-Change-Soon",
                    4    => "Clock-Skew-Detected",
                    5    => "Contact-Administrator",
                    6    => "User-Account-Credentials-Change-Requires",
                    1001 => "Inner-Method-Error",
                    1002 => "Unspecified-Authentication-Infrastructure-Problem",
                    1003 => "Unspecified-Authentication-Failure",
                    1004 => "Unspecified-Authorization-Failure",
                    1005 => "User-Account-Credentials-Unavailable",
                    1006 => "User-Account-Expired",
                    1007 => "User-Account-Locked-Try-Again-Later",
                    1008 => "User-Account-Locked-Admin-Intervention-Required",
                    1009 => "Authentication-Infrastructure-Unavailable",
                    1010 => "Authentication-Infrastructure-Not-Trusted",
                    1011 => "Clock-Skew-Too-Great",
                    1012 => "Invalid-Inner-Realm",
                    1013 => "Token-Out-of-Sync-Admin-Intervention-Required",
                    1014 => "Token-Out-of-Sync-PIN-Change-Required",
                    1015 => "Token-Revoked",
                    1016 => "Tokens-Exhausted",
                    1017 => "Challenge-Expired",
                    1018 => "Challenge-Algorithm-Mismatch",
                    1019 => "Client-Certificate-Not-Supplied",
                    1020 => "Client-Certificate-Rejected",
                    1021 => "Realm-Mismatch-Inner-Outer-Identity",
                    1022 => "Unsupported-Algorithm-in-CSR",
                    1023 => "Unsupported-Extension-in-CSR",
                    1024 => "Bad-Identity-in-CSR",
                    1025 => "Bad-CSR",
                    1026 => "Internal-CA-Error",
                    1027 => "General-PKI-Error",
                    1028 => "Inner-Method-Channel-Binding-Not-Supplied",
                    1029 => "Inner-Method-Channel-Binding-Missing-Info",
                    1030 => "Inner-Method-Channel-Binding-Data-Failed",
                    1031 => "User-Account-Credentials-Incorrect",
                    2001 => "Tunnel-Compromise-Error",
                    2002 => "Unexpected-TLVs",
                },
            },
            11862 => {
                "0" => {
                    "0" => "INVITE",
                    "1" => "BYE",
                    "2" => "REGISTER",
                    "3" => "OTHER"
                },
            },
            12740 => {
                6 => {
                    "0" => "group-administrator",
                    "1" => "pool-administrator",
                    "2" => "pool-administrator-ro-entire-group",
                    "3" => "volume-administrator",
                },
            },
            13209 => {
                8  => { "0" => "Relative", "1" => "Absolute" },
                11 => {
                    1  => "User-Not-Found",
                    2  => "Wrong-Password",
                    3  => "No-Zone-Access",
                    4  => "Inactive-Access-Node",
                    5  => "Inconsistent-Access-Node",
                    6  => "Disabled-Account",
                    7  => "No-Accessprofile",
                    8  => "Internal-Error",
                    9  => "Realm-Error",
                    10 => "No-Credits",
                    11 => "Max-Session",
                    12 => "Remote-Server-Reject",
                    14 => "Realm-Inactive",
                    15 => "Opaque-Failed",
                    16 => "Service-Closed",
                    17 => "LDAP-Failed",
                    18 => "Inactive-Account",
                    19 => "Expired-Account",
                    20 => "Incomplete-Account",
                    21 => "License-Limit-Reached",
                    22 => "Unsupported-Service",
                    23 => "Ruleset-Reject",
                    24 => "Ruleset-Failed",
                },
                42 => { "0" => "User", "1" => "Auto", "2" => "IP-Request" },
                43 => { 1   => "CoA-Login" },
                57 => { 1   => "Simulate-EAP-TLS" },
            },
            14179 => {
                2 => {
                    "0" => "Silver",
                    "1" => "Gold",
                    "2" => "Platinum",
                    "3" => "Bronze"
                },
            },
            14501 => {
                2 => {
                    "0" => "No-Access",
                    "1" => "Read-Only-Access",
                    "2" => "Read-Write-Access",
                },
            },
            14559 => {},
            14823 => {
                27 => {
                    1 => "Personal-Device",
                    2 => "Shared-Device",
                    3 => "Deleted-Device"
                },
                38 => { 1   => "AirGroup-v1", 2   => "AirGroup-v2" },
                49 => { "0" => "Critical",    "1" => "High", "2" => "Low" },
                50 => {
                    1 => "Infrastructure-Mode",
                    2 => "Client-Mode",
                    3 => "Multi-Domain-Mode",
                },
                52 => { "0" => "DSCP",    "1" => "QoS", "2" => "None" },
                58 => { "0" => "Disable", "1" => "Enable" },
                64 =>
                  { "0" => "None", "1" => "Promiscuous", "2" => "Secondary" },
                68 => {
                    1 => "DDP-Boostrap-Authorization",
                    2 => "DDP-Identity-Update",
                    3 => "DDP-Net-Access",
                },
            },
            14988 => {
                6 => {
                    "0" => "No-encryption",
                    "1" => "40-bit-WEP",
                    "2" => "104-bit-WEP",
                    "3" => "AES-CCM",
                    "4" => "TKIP",
                },
                27 => { "0" => "802.1q", "1" => "802.1ad" },
            },
            16313 => { 10 => { "0" => "No-Show", "1" => "Show" } },
            16445 => {
                65411 => { "0" => "GERAN",  "1" => "UTRAN", "2" => "NONE" },
                65414 => { "0" => "North",  "1" => "South" },
                65415 => { "0" => "Height", "1" => "Depth" },
                65423 => {
                    "0" => "CSG-Capable",
                    "1" => "Not-CSG-Capable",
                    "2" => "Rel-5",
                    "3" => "Rel-6",
                    "4" => "Rel-7",
                    "5" => "Rel-8",
                },
            },
            16459 => {
                172 => {
                    "0" => "Internal",
                    "1" => "SIP",
                    "2" => "H.323",
                    "3" => "FXO",
                    "4" => "T1-E1-CAS",
                    "5" => "T1-E1-CCS",
                    "6" => "ISDN-PRI",
                },
                174 => {
                    "0" => "Ethernet",
                    "1" => "FXO",
                    "2" => "T1-E1-User",
                    "3" => "T1-E1-Network",
                    "4" => "ISDN",
                },
                195 => {
                    "0" => "No-Reason",
                    "1" => "Call-Forward-Uncondit",
                    "2" => "Call-Forward-Busy",
                    "3" => "Call-Forward-NoAnswer",
                    "4" => "Call-Tranfer",
                    "5" => "Call-Park",
                    "6" => "Call-Pickup",
                    "7" => "ManyExtension-Ringing",
                    "8" => "Hunt-Group",
                },
                196 => {
                    "0" => "Call-Is-Redirected",
                    "1" => "Call-Origin-OnHook",
                    "2" => "Call-Temin-OnHook",
                    "3" => "Disconected-by-CAC",
                    "4" => "Other",
                },
            },
            17713 => {
                1 => {
                    "0" => "Invalid",
                    "1" => "Read-Only",
                    "2" => "System-Admin",
                    "3" => "Security-Officer",
                    "4" => "Deliberately-Bad",
                },
                50 => {
                    2 => "Install",
                    3 => "Admin",
                    4 => "User",
                    5 => "Read-Only"
                },
                51 => { "0" => "Normal", "1" => "High", "2" => "Low" },
            },
            18022 => {
                1 => {
                    1 => "SUPERUSER",
                    2 => "PROVISIONING",
                    3 => "MAINTENANCE",
                    4 => "RETRIEVE"
                },
                4 => { "0" => "N", "1" => "Y" },
                5 => { "0" => "N", "1" => "Y" },
                6 => { "0" => "N", "1" => "Y" },
            },
            18681 => {
                31 =>
                  { "0" => "Pre-Shared-Key", "1" => "X509-Subject-CommonName" },
            },
            19382 =>
              { 8 => { 1 => "MMS-Picture", 2 => "Unused", 3 => "Internet" } },
            21074 => {
                2 => { "0" => "IPV4_CS", "1" => "ETHERNET_CS" },
                3 => {
                    3  => "QPSK_1/2",
                    4  => "QPSK_3/4",
                    5  => "QAM16_1/2",
                    6  => "QAM16_3/4",
                    7  => "QAM64_1/2",
                    8  => "QAM64_2/3",
                    9  => "QAM64_3/4",
                    10 => "QAM64_5/6",
                },
                4 => {
                    3  => "QPSK_1/2",
                    4  => "QPSK_3/4",
                    5  => "QAM16_1/2",
                    6  => "QAM16_3/4",
                    7  => "QAM64_1/2",
                    8  => "QAM64_2/3",
                    9  => "QAM64_3/4",
                    10 => "QAM64_5/6",
                },
            },
            21274 => {
                2 => {
                    101 => "camiantView",
                    102 => "camiantUser",
                    104 => "camiantService"
                },
            },
            23782 => {
                105 => { 1 => "Enabled", 2 => "Disabled" },
                107 => { 1 => "Enabled", 2 => "Disabled" },
                108 => { 1 => "Enabled", 2 => "Disabled" },
                110 => { 1 => "Yes",     2 => "No" },
                111 => { 1 => "Yes",     2 => "No" },
                113 => { 1 => "Deny",    2 => "Allow" },
            },
            24023 => {
                11 => { "0" => "Disabled",  "1" => "Full-Packet-Local-PCAP" },
                12 => { "0" => "Allow-All", "1" => "Deny-RADIUS" },
            },
            24757 => {
                1 => {
                    "0" => "Not-Supported",
                    "1" => "eCFF-IPv4-Transport",
                    "2" => "eCFF-IPv6-Transport",
                    "4" => "eHAv4",
                    "8" => "eHAv6",
                },
                23 => {
                    "0" => "Reserved-0",
                    "1" => "Reserved-1",
                    "2" => "PMIP4",
                    "3" => "CMIP4",
                    "4" => "CMIP6",
                    "5" => "Ethernet-CS",
                },
                28 => {
                    "0" => "Reserved-0",
                    "1" => "IN",
                    "2" => "OUT",
                    "3" => "Bi-Directional",
                    "4" => "FF",
                },
                29 => {
                    1  => "VoIP",
                    2  => "Robust-Browser",
                    3  => "Secure-Browser-VPN",
                    4  => "Streaming-Video",
                    5  => "Streaming-Live-TV",
                    6  => "Music-Photo-Download",
                    7  => "Multi-Player-Gaming",
                    8  => "Location-Based-Services",
                    9  => "Text-Audio-Books",
                    10 => "Video-Conversation",
                    11 => "Message",
                    12 => "Control",
                    13 => "Data",
                },
                35 => {
                    1  => "Volume-Metering",
                    2  => "Duration-Metering",
                    4  => "Resource-Metering",
                    8  => "Pools",
                    16 => "Rating-Groups",
                    32 => "Multi-Services",
                    64 => "Tariff-Switch",
                },
                36 => { 1 => "Dynamic-Authorization" },
                37 => {
                    1  => "Balance-Check",
                    2  => "Price-Enquiry",
                    3  => "Redirect-Or-Filter",
                    4  => "Quota-Reached",
                    5  => "TITSU-Approaching",
                    6  => "Remote-Forced-Disconnect",
                    7  => "Client-Service-Termination",
                    8  => "Access-Service-Terminated",
                    9  => "Service-Not-Established",
                    10 => "One-Time-Charging",
                },
                58 => { "0" => "No", "1" => "Yes" },
                60 => {
                    "0"     => "Deregister-MS",
                    "1"     => "Suspend-MS-Traffic",
                    "2"     => "Suspend-User-Traffic",
                    "3"     => "Resume-Traffic",
                    "4"     => "MS-Terminate",
                    "5"     => "MS-Idle",
                    "6"     => "MS-Completed-IPv6-Handover",
                    "65535" => "BS-Sends-RES-Cmd",
                },
                82 => { "0" => "False", "1" => "True" },
                84 => {
                    1 => "IPv4-CS",
                    2 => "IPv6-CS",
                    3 => "Ethernet",
                    4 => "Activate",
                    8 => "Dynamic",
                },
                89  => { 1   => "Fixed", 2   => "Nomadic", 3 => "Mobile" },
                90  => { "0" => "No",    "1" => "Yes" },
                143 => {
                    1  => "Authentication-Information-Request",
                    2  => "Authentication-Information-Answer",
                    3  => "Update-Location-Request",
                    4  => "Update-Location-Answer",
                    5  => "Cancel-Location-Request",
                    6  => "Cancel-Location-Answer",
                    7  => "Purge-UE-Request",
                    8  => "Purge-UE-Answer",
                    9  => "Insert-Subscriber-Data-Request",
                    10 => "Insert-Subscriber-Data-Answer",
                    11 => "Delete-Subscriber-Data-Request",
                    12 => "Delete-Subscriber-Data-Answer",
                    13 => "Notification-Request",
                    14 => "Notification-Answer",
                    15 => "Accounting",
                },
                144 => { "0" => "Yes" },
                155 => {
                    "0" => "MME_UPDATE_PROCEDURE",
                    "2" => "SUBSCRIPTION_WITHDRAWAL",
                    "4" => "INITIAL_ATTACH_PROCEDURE",
                },
                156 => { "0" => "Active-Location-Retrieval" },
            },
            25053 => {
                106 => {
                    "0" => "Subscribed",
                    "1" => "SentByMS",
                    "2" => "ChosenBySGSN"
                },
                107 => { "0" => "NotRequired", "1" => "Required" },
                109 => { 1   => "SCG",         2   => "Others" },
                110 => { "0" => "Success",     "1" => "Failure" },
                112 => {
                    1  => "PPP-SIM",
                    2  => "DummyIMSI",
                    3  => "SoftSIM",
                    4  => "RadiusSIM",
                    5  => "Postpaid",
                    6  => "Prepaid",
                    7  => "LocalRadius",
                    8  => "ProxyRadius",
                    9  => "Voucher",
                    10 => "EAP-SIM",
                },
                125 => {
                    2 => "TTG",
                    3 => "Local-Breakout",
                    4 => "Local-Breakout-AP",
                    5 => "L3GRE",
                    6 => "L2GRE",
                    7 => "QinQL3",
                    8 => "PMIP",
                },
                126 => { "0" => "Accounting-Off", "1" => "Accounting-On" },
            },
            25506 => {
                20 => {
                    1 => "Trigger-Request",
                    2 => "Terminate-Request",
                    3 => "SetPolicy",
                    4 => "Result",
                    5 => "PortalClear",
                },
                29 => {
                    "0" => "Visit",
                    "1" => "Monitor",
                    "2" => "System",
                    "3" => "Manage"
                },
            },
            26928 => {
                1 => {
                    "0" => "Read-Only-Admin",
                    "1" => "Super-Admin",
                    "2" => "Read-Write-Admin",
                },
                4   => { "0" => "Permit", "1" => "Restricted", "2" => "Deny" },
                9   => { 1   => "Disconnect-Request", 2 => "COA-Request" },
                213 => { 1   => "Service",            2 => "Non-Service" },
            },
            27880 => {
                13 => {
                    "0"   => "None",
                    "1"   => "Unallocated-Number",
                    "2"   => "No-Route-Transit-Net",
                    "3"   => "No-Route-Destination",
                    "6"   => "Channel-Unacceptable",
                    "7"   => "Call-Awarded-Delivery",
                    "16"  => "Normal-Clearing",
                    "17"  => "User-Busy",
                    "18"  => "No-User-Response",
                    "19"  => "No-Answer",
                    "20"  => "Subscriber-Absent",
                    "21"  => "Call-Rejected",
                    "22"  => "Number-Changed",
                    "23"  => "Redirecto-To-New-Destination",
                    "25"  => "Exchange-Routing-Error",
                    "27"  => "Destination-Out-Of-Order",
                    "28"  => "Invalid-Number-Format",
                    "29"  => "Facility-Rejected",
                    "30"  => "Response-To-Status-Enquiry",
                    "31"  => "Normal-Unspecified",
                    "34"  => "Normal-Circuit-Congestion",
                    "38"  => "Network-Out-Of-Order",
                    "41"  => "Normal-Temporary-Failure",
                    "42"  => "Switch-Congestion",
                    "43"  => "Access-Info-Discarded",
                    "44"  => "Requested-Chan-Unavail",
                    "45"  => "Pre-Empted",
                    "50"  => "Facility-Not-Subscribed",
                    "52"  => "Outgoing-Call-Barred",
                    "54"  => "Incoming-Call-Barred",
                    "57"  => "Bearercapability-Notauth",
                    "58"  => "Bearercapability-Notavail",
                    "63"  => "Service-Unavailable",
                    "65"  => "Bearercapability-Notimpl",
                    "66"  => "Chan-Not-Implemented",
                    "69"  => "Facility-Not-Implemented",
                    "79"  => "Service-Not-Implemented",
                    "81"  => "Invalid-Call-Reference",
                    "88"  => "Incompatible-Destination",
                    "95"  => "Invalid-Msg-Unspecified",
                    "96"  => "Mandatory-IE-Missing",
                    "97"  => "Message-Type-Nonexist",
                    "98"  => "Wrong-Message",
                    "99"  => "IE-Nonexist",
                    "100" => "Invalid-IE-Contents",
                    "101" => "Wrong-Call-State",
                    "102" => "Recovery-On-Timer-Expire",
                    "103" => "Mandatory-IE-Length-Error",
                    "111" => "Protocol-Error",
                    "127" => "Interworking",
                    "142" => "Success",
                    "487" => "Originator-Cancel",
                    "500" => "Crash",
                    "501" => "System-Shutdown",
                    "502" => "Lose-Race",
                    "503" => "Manager-Request",
                    "600" => "Blind-Transfer",
                    "601" => "Attended-Transfer",
                    "602" => "Allotted-Timeout",
                    "603" => "User-Challenge",
                    "604" => "Media-Timeout",
                    "605" => "Picked-Off",
                    "606" => "User-Not-Registered",
                },
            },
            28557 => {
                2 => {
                    1  => "HS-User-l2tp",
                    2  => "HS-User-8021x",
                    4  => "HS-User-smartvpn",
                    8  => "HS-User-normal",
                    16 => "HS-User-Admin",
                },
                4 => {
                    1  => "HS-Admin-Console",
                    2  => "HS-Admin-Telnet",
                    4  => "HS-Admin-SSH",
                    8  => "HS-Admin-HTTP",
                    16 => "HS-Admin-HTTPS",
                },
                6 => {
                    1 => "HS-Mobile-ChinaMobile",
                    2 => "HS-Mobile-ChinaUnicom",
                    3 => "HS-Mobile-ChinaTelecom",
                },
            },
            30065 => { 6 => { 1 => "start", 2 => "complete" } },
            35265 => {
                11 => {
                    1  => "User-Answer",
                    2  => "Incomplete-Number",
                    3  => "Unassigned-Number",
                    4  => "Unsuccessful-Other-Cause",
                    5  => "User-Busy",
                    6  => "Out-of-Order",
                    7  => "No-Answer",
                    8  => "Unavailable-Trunk",
                    9  => "Access-Denied",
                    10 => "Unavailable-Voice-Channel",
                    11 => "RADIUS-Server-Unavailable",
                },
            },
            35987 => {
                13 => {
                    "0"   => "None",
                    "1"   => "Unallocated-Number",
                    "2"   => "No-Route-Transit-Net",
                    "3"   => "No-Route-Destination",
                    "6"   => "Channel-Unacceptable",
                    "7"   => "Call-Awarded-Delivery",
                    "16"  => "Normal-Clearing",
                    "17"  => "User-Busy",
                    "18"  => "No-User-Response",
                    "19"  => "No-Answer",
                    "20"  => "Subscriber-Absent",
                    "21"  => "Call-Rejected",
                    "22"  => "Number-Changed",
                    "23"  => "Redirecto-To-New-Destination",
                    "25"  => "Exchange-Routing-Error",
                    "27"  => "Destination-Out-Of-Order",
                    "28"  => "Invalid-Number-Format",
                    "29"  => "Facility-Rejected",
                    "30"  => "Response-To-Status-Enquiry",
                    "31"  => "Normal-Unspecified",
                    "34"  => "Normal-Circuit-Congestion",
                    "38"  => "Network-Out-Of-Order",
                    "41"  => "Normal-Temporary-Failure",
                    "42"  => "Switch-Congestion",
                    "43"  => "Access-Info-Discarded",
                    "44"  => "Requested-Chan-Unavail",
                    "45"  => "Pre-Empted",
                    "50"  => "Facility-Not-Subscribed",
                    "52"  => "Outgoing-Call-Barred",
                    "54"  => "Incoming-Call-Barred",
                    "57"  => "Bearercapability-Notauth",
                    "58"  => "Bearercapability-Notavail",
                    "63"  => "Service-Unavailable",
                    "65"  => "Bearercapability-Notimpl",
                    "66"  => "Chan-Not-Implemented",
                    "69"  => "Facility-Not-Implemented",
                    "79"  => "Service-Not-Implemented",
                    "81"  => "Invalid-Call-Reference",
                    "88"  => "Incompatible-Destination",
                    "95"  => "Invalid-Msg-Unspecified",
                    "96"  => "Mandatory-IE-Missing",
                    "97"  => "Message-Type-Nonexist",
                    "98"  => "Wrong-Message",
                    "99"  => "IE-Nonexist",
                    "100" => "Invalid-IE-Contents",
                    "101" => "Wrong-Call-State",
                    "102" => "Recovery-On-Timer-Expire",
                    "103" => "Mandatory-IE-Length-Error",
                    "111" => "Protocol-Error",
                    "127" => "Interworking",
                    "142" => "Success",
                    "487" => "Originator-Cancel",
                    "500" => "Crash",
                    "501" => "System-Shutdown",
                    "502" => "Lose-Race",
                    "503" => "Manager-Request",
                    "600" => "Blind-Transfer",
                    "601" => "Attended-Transfer",
                    "602" => "Allotted-Timeout",
                    "603" => "User-Challenge",
                    "604" => "Media-Timeout",
                    "605" => "Picked-Off",
                    "606" => "User-Not-Registered",
                },
            },
            43823 => {
                6 => {
                    "0" => "Auth",
                    "1" => "DHCP",
                    "2" => "PAP",
                    "3" => "CHAP",
                    "4" => "MS_CHAPv2",
                    "5" => "MAC_QinQ",
                    "6" => "ARP",
                    "7" => "DHCPv6",
                },
                10 => { 1   => "Check-Acct" },
                37 => { "0" => "Discover", "1" => "Inform", "2" => "Request" },
                70 => {
                    1 => "Solicit",
                    3 => "Request",
                    5 => "Renew",
                    6 => "Rebind"
                },
            },
            49426 => {
                8 => {
                    1 => "Deleted",
                    2 => "Disabled",
                    3 => "Disputes",
                    4 => "Expired",
                    5 => "Unknown",
                    6 => "Exhausted",
                    7 => "WrongMAC",
                    8 => "VLANmismatch",
                },
            },
            61349 => {
                10 => {
                    "2"          => "Role-Reject",
                    "3"          => "Static-Reject",
                    "7"          => "Challenge-Dyna-Reject",
                    "8"          => "RADIUS-Key-Parse-Error",
                    "9"          => "Account-Does-Not-Exist",
                    "16"         => "Token-Expired",
                    "20"         => "Push-Check-Code-Error",
                    "21"         => "Push-Code-Error",
                    "22"         => "Single-Only-Dyna-Reject",
                    "23"         => "Static-PWD-Error",
                    "24"         => "PIN-Word-Error",
                    "25"         => "Source-IP-Error",
                    "28"         => "Static-PWD-Expired",
                    "30"         => "Strategy-Config-Error",
                    "31"         => "EQP-Expiration-Error",
                    "32"         => "Account-EQP-Token-Mismatch",
                    "33"         => "Cannot-Login-Time",
                    "34"         => "Org-Reject",
                    "2324"       => "Static-PWD-Or-PIN-Error",
                    "4294967295" => "Unknown-Error",
                },
            },
        },
        val => {
            6 => {
                "Administrative-User"     => 6,
                "Annex-Authorize-Only"    => 103809025,
                "Annex-Framed-Tunnel"     => 103809026,
                "Authenticate-Only"       => 8,
                "Authorize-Only"          => 17,
                "Call-Check"              => 10,
                "Callback-Administrative" => 11,
                "Callback-Framed"         => 4,
                "Callback-Framed-User"    => 4,
                "Callback-Login"          => 3,
                "Callback-Login-User"     => 3,
                "Callback-NAS-Prompt"     => 9,
                "Dialback-Framed-User"    => 4,
                "Dialback-Login-User"     => 3,
                "Dialout-Framed-User"     => 5,
                "Exec-User"               => 7,
                "Fax"                     => 13,
                "Framed"                  => 2,
                "Framed-Management"       => 18,
                "Framed-User"             => 2,
                "IAPP-AP-Check"           => 16,
                "IAPP-Register"           => 15,
                "Login"                   => 1,
                "Login-User"              => 1,
                "Modem-Relay"             => 14,
                "NAS-Prompt-User"         => 7,
                "Outbound-User"           => 5,
                "Shell-User"              => 6,
                "Sip-session"             => 12,
                "Voice"                   => 12,
            },
            7 => {
                "ARAP"               => 3,
                "Bintec-FRAME-RELAY" => 17825801,
                "Bintec-IP-HDLC"     => 17825798,
                "Bintec-IP-LAPB"     => 17825796,
                "Bintec-MPR-HDLC"    => 17825800,
                "Bintec-MPR-LAPB"    => 17825799,
                "Bintec-X25"         => 17825794,
                "Bintec-X25-NOSIG"   => 17825805,
                "Bintec-X25-PPP"     => 17825795,
                "Bintec-X25-PPP-OPT" => 17825806,
                "Bintec-X31-BCHAN"   => 17825802,
                "Bintec-X75-PPP"     => 17825803,
                "Bintec-X75BTX-PPP"  => 17825804,
                "Gandalf-SLML"       => 4,
                "GPRS-PDP-Context"   => 7,
                "PPP"                => 1,
                "PPTP"               => 9,
                "SLIP"               => 2,
                "X.75-Synchronous"   => 6,
                "Xylogics-IPX-SLIP"  => 5,
            },
            10 => {
                "Broadcast"        => 1,
                "Broadcast-Listen" => 3,
                "Listen"           => 2,
                "None"             => 0
            },
            13 => {
                "IPX-Header-Compression" => 2,
                "None"                   => 0,
                "Stac-LZS"               => 3,
                "Van-Jacobsen-TCP-IP"    => 1,
                "Van-Jacobson-TCP-IP"    => 1,
                "VJ-TCP-IP"              => 1,
            },
            15 => {
                "LAT"             => 4,
                "PortMaster"      => 3,
                "Rlogin"          => 1,
                "TCP-Clear"       => 2,
                "TCP-Clear-Quiet" => 8,
                "Telnet"          => 0,
                "X25-PAD"         => 5,
                "X25-T3POS"       => 6,
            },
            16 => { Rlogin => 513, Rsh => 514, Telnet => 23 },
            29 => {
                "Default"          => 0,
                "Manage-Resources" => 2,
                "RADIUS-Request"   => 1
            },
            40 => {
                "Accounting-Off"           => 8,
                "Accounting-On"            => 7,
                "Alive"                    => 3,
                "Annex-Accounting-Restart" => 103809030,
                "Annex-Accounting-Shutoff" => 103809031,
                "Annex-ATCP-Start"         => 103809029,
                "Annex-Call-Reject"        => 103809026,
                "Annex-IPCP-Start"         => 103809027,
                "Annex-IPXCP-Start"        => 103809028,
                "Annex-Line-Seizure"       => 103809039,
                "Annex-MP-Start"           => 103809037,
                "Annex-MP-Stop"            => 103809038,
                "Annex-Rlogin-Start"       => 103809040,
                "Annex-Rlogin-Stop"        => 103809041,
                "Annex-Tunnel-Link-Start"  => 103809035,
                "Annex-Tunnel-Link-Stop"   => 103809036,
                "Annex-Tunnel-Reject"      => 103809034,
                "Annex-Tunnel-Start"       => 103809032,
                "Annex-Tunnel-Stop"        => 103809033,
                "Annex-User-Reject"        => 103809025,
                "Cancel"                   => 6,
                "Failed"                   => 15,
                "Interim-Update"           => 3,
                "Modem-Start"              => 4,
                "Modem-Stop"               => 5,
                "Start"                    => 1,
                "Stop"                     => 2,
                "Subsystem-Off"            => 19,
                "Subsystem-On"             => 18,
                "Tunnel-Link-Reject"       => 14,
                "Tunnel-Link-Start"        => 12,
                "Tunnel-Link-Stop"         => 13,
                "Tunnel-Reject"            => 11,
                "Tunnel-Start"             => 9,
                "Tunnel-Stop"              => 10,
                "WB-Login"                 => 217,
                "WB-Logout"                => 218,
                "WB-WRitelog"              => 219,
            },
            45 => { Diameter => 4, Local => 2, RADIUS => 1, Remote => 3 },
            49 => {
                "Admin-Reboot"             => 7,
                "Admin-Reset"              => 6,
                "Callback"                 => 16,
                "Host-Request"             => 18,
                "Idle-Timeout"             => 4,
                "Lost-Carrier"             => 2,
                "Lost-Service"             => 3,
                "NAS-Error"                => 9,
                "NAS-Reboot"               => 11,
                "NAS-Request"              => 10,
                "Port-Disabled"            => 22,
                "Port-Error"               => 8,
                "Port-Preempted"           => 13,
                "Port-Reinit"              => 21,
                "Port-Suspended"           => 14,
                "Port-Unneeded"            => 12,
                "Reauthentication-Failure" => 20,
                "Service-Unavailable"      => 15,
                "Session-Timeout"          => 5,
                "Supplicant-Restart"       => 19,
                "User-Error"               => 17,
                "User-Request"             => 1,
            },
            57 => { Disabled => 2, Enabled => 1 },
            61 => {
                "ADSL-CAP"           => 12,
                "ADSL-DMT"           => 13,
                "Async"              => 0,
                "Cable"              => 17,
                "Ethernet"           => 15,
                "FDDI"               => 21,
                "FTTP"               => 26,
                "G.3-Fax"            => 10,
                "HDLC-Clear-Channel" => 7,
                "IAPP"               => 25,
                "IDSL"               => 14,
                "ISDN"               => 2,
                "ISDN-V110"          => 4,
                "ISDN-V120"          => 3,
                "PIAFS"              => 6,
                "PPPoA"              => 30,
                "PPPoEoA"            => 31,
                "PPPoEoE"            => 32,
                "PPPoEoQinQ"         => 34,
                "PPPoEoVLAN"         => 33,
                "SDSL"               => 11,
                "Sync"               => 1,
                "Token-Ring"         => 20,
                "Virtual"            => 5,
                "Wireless-1X-EV"     => 24,
                "Wireless-802.11"    => 19,
                "Wireless-802.16"    => 27,
                "Wireless-802.20"    => 28,
                "Wireless-802.22"    => 29,
                "Wireless-CDMA2000"  => 22,
                "Wireless-Other"     => 18,
                "Wireless-UMTS"      => 23,
                "Wireless-XGP"       => 36,
                "X.25"               => 8,
                "X.75"               => 9,
                "xDSL"               => 16,
                "xPON"               => 35,
            },
            64 => {
                "AH"       => 6,
                "ATMP"     => 4,
                "DVS"      => 11,
                "ESP"      => 9,
                "GRE"      => 10,
                "IP"       => 7,
                "IP-in-IP" => 12,
                "L2F"      => 2,
                "L2TP"     => 3,
                "MIN-IP"   => 8,
                "PPTP"     => 1,
                "VLAN"     => 13,
                "VTP"      => 5,
            },
            65 => {
                "Appletalk"    => 12,
                "Banyan-Vines" => 14,
                "BBN-1822"     => 5,
                "DecNet-IV"    => 13,
                "E.163"        => 7,
                "E.164"        => 8,
                "E.164-NSAP"   => 15,
                "F.69"         => 9,
                "HDLC"         => 4,
                "IEEE-802"     => 6,
                "IP"           => 1,
                "IPv4"         => 1,
                "IPv6"         => 2,
                "IPX"          => 11,
                "NSAP"         => 3,
                "X.121"        => 10,
            },
            72 => {
                "Default-Zone"          => 1,
                "Zone-Filter-Exclusive" => 4,
                "Zone-Filter-Inclusive" => 2,
            },
            76  => { "Echo" => 1, "No-Echo" => 0 },
            101 => {
                "Administratively-Prohibited"            => 501,
                "Invalid-Attribute-Value"                => 407,
                "Invalid-EAP-Packet"                     => 202,
                "Invalid-Request"                        => 404,
                "Missing-Attribute"                      => 402,
                "Multiple-Session-Selection-Unsupported" => 508,
                "NAS-Identification-Mismatch"            => 403,
                "Proxy-Processing-Error"                 => 505,
                "Proxy-Request-Not-Routable"             => 502,
                "Request-Initiated"                      => 507,
                "Residual-Context-Removed"               => 201,
                "Resources-Unavailable"                  => 506,
                "Session-Context-Not-Found"              => 503,
                "Session-Context-Not-Removable"          => 504,
                "Unsupported-Attribute"                  => 401,
                "Unsupported-Extension"                  => 406,
                "Unsupported-Service"                    => 405,
            },
            126 => {
                "False"         => 0,
                "Temp-Rtes-No"  => 0,
                "Temp-Rtes-Yes" => 1,
                "True"          => 1
            },
            127 => { "ATMP-Tunnel"       => 0, "VTP-Tunnel"         => 1 },
            128 => { "Shared-Profile-No" => 0, "Shared-Profile-Yes" => 1 },
            131 => {
                "Civic-Location"      => 1,
                "Dialout-Allowed"     => 1,
                "Dialout-Not-Allowed" => 0,
                "Geo-Location"        => 2,
                "NAS-Location"        => 8,
                "Users-Location"      => 4,
            },
            132 => {
                "Civic-Location"  => 1,
                "Future-Requests" => 16,
                "Geo-Location"    => 2,
                "NAS-Location"    => 8,
                "None"            => 32,
                "Users-Location"  => 4,
            },
            133 => {
                "BACP-No"   => 0,
                "BACP-Yes"  => 1,
                "FTP"       => 4,
                "Netconf"   => 3,
                "RCP"       => 7,
                "SCP"       => 8,
                "SFTP"      => 6,
                "SNMP"      => 1,
                "TFTP"      => 5,
                "Web-Based" => 2,
            },
            134 => {
                "Integrity-Confidentiality-Protection" => 3,
                "Integrity-Protection"                 => 2,
                "No-Protection"                        => 1,
            },
            137 => { "DNS-Assign-No" => 0, "DNS-Assign-Yes" => 1 },
            138 => {
                "Ascend-User-Acct-None"         => 0,
                "Ascend-User-Acct-User"         => 1,
                "Ascend-User-Acct-User-Default" => 2,
            },
            142 => { "Base-10"            => 0, "Base-16"              => 1 },
            147 => { "DHCP-Reply-No"      => 0, "DHCP-Reply-Yes"       => 1 },
            149 => { "Expect-Callback-No" => 0, "Expect-Callback-Yes"  => 1 },
            150 => { "Ascend-ColdStart"   => 1, "Ascend-Session-Event" => 2 },
            155 => { "Multicast-No"       => 0, "Multicast-Yes"        => 1 },
            157 =>
              { "Ascend-LinkUp-AlwaysUp" => 1, "Ascend-LinkUp-Default" => 0 },
            159 => {
                "Ascend-FR-DCE" => 1,
                "Ascend-FR-DTE" => 0,
                "Ascend-FR-NNI" => 2
            },
            160 => {
                "Ascend-FR-No-Link-Mgt" => 0,
                "Ascend-FR-Q-933A"      => 2,
                "Ascend-FR-T1-617D"     => 1,
            },
            163 => {
                "GSS-API"                => 8,
                "IEEE-802.16e"           => 4,
                "IEEE-802.1X-No-Preauth" => 2,
                "IEEE-802.1X-Preauth"    => 3,
                "IKEv2"                  => 5,
                "PANA-No-Preauth"        => 7,
                "PANA-Preauth"           => 9,
                "PPP"                    => 6,
                "Wired-IEEE-802.1X"      => 1,
            },
            170 => {
                "TS-Idle-Input"        => 1,
                "TS-Idle-Input-Output" => 2,
                "TS-Idle-None"         => 0
            },
            171 => {
                "DBA-None"          => 2,
                "DBA-Transmit"      => 0,
                "DBA-Transmit-Recv" => 1
            },
            175 => { "FT1-No" => 0, "FT1-Yes" => 1 },
            177 => {
                "AO/DI"         => 6,
                "MegaMax"       => 7,
                "Nailed"        => 1,
                "Nailed/Mpp"    => 2,
                "Perm/Switched" => 3,
                "Switched"      => 0,
            },
            195 => {
                "Bad-Or-Missing-Port-Number"     => 54,
                "Call-Disconnected"              => 3,
                "CLID-Authentication-Failed"     => 4,
                "CLID-RADIUS-Timeout"            => 5,
                "Connection-Closed"              => 63,
                "Connection-Refused"             => 61,
                "Connection-Timeout"             => 62,
                "DCD-Detected-Then-Inactive"     => 11,
                "Disconnect-Due-To-Callback"     => 102,
                "Disconnect-Req-By-Local-Admin"  => 151,
                "Disconnect-Req-By-RADIUS"       => 150,
                "Host-Reset"                     => 60,
                "Host-Unreachable"               => 65,
                "Host-Unreachable-Admin"         => 67,
                "Hostname-Resolution-Failed"     => 53,
                "Invalid-Incoming-User"          => 101,
                "Invalid-IP-Address"             => 52,
                "Max-Call-Duration-Reached"      => 195,
                "Modem-Invalid-Result-Codes"     => 12,
                "Modem-No-DCD"                   => 10,
                "MPP-No-NULL-Msg-Timeout"        => 35,
                "Network-Unreachable"            => 64,
                "Network-Unreachable-Admin"      => 66,
                "No-Reason"                      => 0,
                "Not-Applicable"                 => 1,
                "Out-Of-Resources"               => 51,
                "Port-Unreachable"               => 68,
                "PPP-Auth-Timeout-Exceeded"      => 170,
                "PPP-CHAP-Auth-Failed"           => 43,
                "PPP-LCP-Close-MP-Add-Fail"      => 49,
                "PPP-LCP-Negotion-Failed"        => 41,
                "PPP-LCP-Timeout"                => 40,
                "PPP-MP-Bundle-Unknown"          => 48,
                "PPP-No-NCPs-Open"               => 47,
                "PPP-PAP-Auth-Failed"            => 42,
                "PPP-Rcv-Close-Event"            => 46,
                "PPP-Rcv-Terminate-Req"          => 45,
                "PPP-Rmt-Auth-Failed"            => 44,
                "Proto-Disabled-Or-Unsupported"  => 120,
                "Remote-End-Hung-Up"             => 185,
                "Resource-Has-Been-Quiesced"     => 190,
                "Session-Table-Full"             => 50,
                "Session-Timeout"                => 100,
                "TermSrv-Bad-Rlogin-Option"      => 32,
                "TermSrv-CTRL-C-In-Login"        => 27,
                "TermSrv-Destroyed"              => 28,
                "TermSrv-Exit-Login-Failed"      => 25,
                "TermSrv-Exit-Raw-TCP"           => 24,
                "TermSrv-Exit-Raw-TCP-Disabled"  => 26,
                "TermSrv-Exit-Rlogin"            => 31,
                "TermSrv-Exit-Telnet"            => 22,
                "TermSrv-Idle-Timeout"           => 21,
                "TermSrv-No-IPaddr"              => 23,
                "TermSrv-Not-Enough-Resources"   => 33,
                "TermSrv-User-Closed-VCon"       => 29,
                "TermSrv-User-Quit"              => 20,
                "TermSrv-VCon-Destroyed"         => 30,
                "Unknown"                        => 2,
                "User-Executed-Do-Hangup"        => 180,
                "V110-Timeout-Sync-Retry-Exceed" => 160,
            },
            196 => {
                "ATNCP-Opened"              => 81,
                "BACP-Opened"               => 83,
                "BACP-Opening"              => 82,
                "BNCP-Opened"               => 68,
                "BNCP-Opening"              => 64,
                "Call-Up"                   => 10,
                "CCP-Opened"                => 66,
                "CCP-Opening"               => 62,
                "IPNCP-Opened"              => 67,
                "IPNCP-Opening"             => 63,
                "IPXNCP-Opened"             => 80,
                "LAN-Session-Up"            => 60,
                "LCP-Opened"                => 65,
                "LCP-Opening"               => 61,
                "LCP-State-Ack-Received"    => 76,
                "LCP-State-Ack-Sent"        => 77,
                "LCP-State-Closed"          => 71,
                "LCP-State-Closing"         => 73,
                "LCP-State-Initial"         => 69,
                "LCP-State-Request-Sent"    => 75,
                "LCP-State-Starting"        => 70,
                "LCP-State-Stopped"         => 72,
                "LCP-State-Stopping"        => 74,
                "Modem-Awaiting-Codes"      => 32,
                "Modem-Awaiting-DCD"        => 31,
                "Modem-Outdial-Call-Up"     => 50,
                "Modem-Up"                  => 30,
                "No-Progress"               => 0,
                "TermSrv-Raw-TCP-Connected" => 43,
                "TermSrv-Raw-TCP-Started"   => 41,
                "TermSrv-Rlogin-Connected"  => 46,
                "TermSrv-Rlogin-Started"    => 45,
                "TermSrv-Started"           => 40,
                "TermSrv-Telnet-Connected"  => 44,
                "TermSrv-Telnet-Started"    => 42,
                "V110-State-Carrier"        => 92,
                "V110-State-Closed"         => 94,
                "V110-State-Opened"         => 91,
                "V110-State-Reset"          => 93,
                "V110-Up"                   => 90,
            },
            200 => { "Tok-Imm-No"       => 0, "Tok-Imm-Yes"  => 1 },
            201 => { "Not-Require-Auth" => 0, "Require-Auth" => 1 },
            207 => { "Days-Of-Warning"  => 0 },
            208 => { "Lifetime-In-Days" => 0 },
            210 => { "VJ-Slot-Comp-No"  => 1 },
            211 => { "PPP-VJ-1172"      => 1 },
            216 => { "IPX-Peer-Dialin"  => 1, "IPX-Peer-Router" => 0 },
            219 => { "FR-Direct-No"     => 0, "FR-Direct-Yes"   => 1 },
            222 => {
                "Handle-IPX-Client" => 1,
                "Handle-IPX-None"   => 0,
                "Handle-IPX-Server" => 2,
            },
            226 => {
                "Abbrev-Number"       => 5,
                "Intl-Number"         => 1,
                "Local-Number"        => 4,
                "National-Number"     => 2,
                "Net-Specific-Number" => 3,
                "Unknown-Number"      => 0,
            },
            228 => { "Route-IP-No"  => 0, "Route-IP-Yes"  => 1 },
            229 => { "Route-IPX-No" => 0, "Route-IPX-Yes" => 1 },
            230 => { "Bridge-No"    => 0, "Bridge-Yes"    => 1 },
            231 => {
                "Send-Auth-CHAP"    => 2,
                "Send-Auth-MS-CHAP" => 3,
                "Send-Auth-None"    => 0,
                "Send-Auth-PAP"     => 1,
            },
            233 => {
                "Link-Comp-MS-Stac"      => 3,
                "Link-Comp-None"         => 0,
                "Link-Comp-Stac"         => 1,
                "Link-Comp-Stac-Draft-9" => 2,
            },
            239 => {
                "History-Constant"  => 0,
                "History-Linear"    => 1,
                "History-Quadratic" => 2,
            },
            241 => {
                "Allocation"              => 1,
                "Deallocation"            => 2,
                "Fragmentation-Supported" => 1,
                "More-Data-Pending"       => 2,
                "More-Data-Request"       => 3,
                "Reserved"                => 0,
            },
            246 => { "Callback-No" => 0, "Callback-Yes" => 1 },
            247 => {
                "Nailed-56KR"                    => 1,
                "Nailed-64K"                     => 2,
                "Switched-1024K"                 => 23,
                "Switched-1088K"                 => 24,
                "Switched-1152K"                 => 25,
                "Switched-1216K"                 => 26,
                "Switched-1280K"                 => 27,
                "Switched-128K"                  => 9,
                "Switched-1344K"                 => 28,
                "Switched-1408K"                 => 29,
                "Switched-1472K"                 => 30,
                "Switched-1536K"                 => 7,
                "Switched-1536KR"                => 8,
                "Switched-1600K"                 => 31,
                "Switched-1664K"                 => 32,
                "Switched-1728K"                 => 33,
                "Switched-1792K"                 => 34,
                "Switched-1856K"                 => 35,
                "Switched-1920K"                 => 36,
                "Switched-192K"                  => 10,
                "Switched-256K"                  => 11,
                "Switched-320K"                  => 12,
                "Switched-384K"                  => 6,
                "Switched-384K-MR"               => 13,
                "Switched-384KR"                 => 5,
                "Switched-448K"                  => 14,
                "Switched-512K"                  => 15,
                "Switched-56K"                   => 4,
                "Switched-576K"                  => 16,
                "Switched-640K"                  => 17,
                "Switched-64KR"                  => 3,
                "Switched-704K"                  => 18,
                "Switched-768K"                  => 19,
                "Switched-832K"                  => 20,
                "Switched-896K"                  => 21,
                "Switched-960K"                  => 22,
                "Switched-ATM"                   => 69,
                "Switched-atmodem"               => 43,
                "Switched-clear-56-v110"         => 41,
                "Switched-clear-bearer-v110"     => 39,
                "Switched-FR"                    => 70,
                "Switched-inherited"             => 37,
                "Switched-modem"                 => 42,
                "Switched-Pots"                  => 68,
                "Switched-restricted-64-x30"     => 40,
                "Switched-restricted-bearer-x30" => 38,
                "Switched-V110-192-56"           => 48,
                "Switched-V110-192-56R"          => 53,
                "Switched-V110-192-64"           => 58,
                "Switched-V110-192-64R"          => 63,
                "Switched-V110-24-56"            => 45,
                "Switched-V110-24-56R"           => 50,
                "Switched-V110-24-64"            => 55,
                "Switched-V110-24-64R"           => 60,
                "Switched-V110-384-56"           => 49,
                "Switched-V110-384-56R"          => 54,
                "Switched-V110-384-64"           => 59,
                "Switched-V110-384-64R"          => 64,
                "Switched-V110-48-56"            => 46,
                "Switched-V110-48-56R"           => 51,
                "Switched-V110-48-64"            => 56,
                "Switched-V110-48-64R"           => 61,
                "Switched-V110-96-56"            => 47,
                "Switched-V110-96-56R"           => 52,
                "Switched-V110-96-64"            => 57,
                "Switched-V110-96-64R"           => 62,
                "Switched-Voice-Bearer"          => 0,
            },
            248  => { "Force-56-No" => 0, "Force-56-Yes" => 1 },
            500  => { No            => 0, Yes            => 1 },
            501  => { No            => 0, Yes            => 1 },
            1000 => { Accept => 254,      Local => 1, Reject => 4, Unix => 1 },
            1011 => { Local  => 1 },
            1012 => { Local  => 1 },
            1013 => { Local  => 1 },
            1014 => {
                "Challenge"   => 3,
                "Client-Lost" => 4,
                "Local"       => 1,
                "Reject"      => 2
            },
            1016 => {
                "Fail"                => 1,
                "Fail-Accounting"     => 3,
                "Fail-Authentication" => 2,
                "Fail-CoA"            => 4,
                "Fail-Disconnect"     => 5,
            },
            1018 => {
                "3Com-Wireless"         => 24,
                "Actiontec-Wireless"    => 35,
                "AirFortress-EAP"       => 37,
                "AKA"                   => 23,
                "AKA2"                  => 50,
                "Arcot-Systems-EAP"     => 16,
                "Cisco-LEAP"            => 17,
                "Cisco-MS-CHAPv2"       => 29,
                "Cogent-Biomentric-EAP" => 36,
                "CRYPTOCard"            => 28,
                "Defender-Token"        => 14,
                "DeviceConnect-EAP"     => 40,
                "DSS-Unilateral"        => 10,
                "DynamID"               => 30,
                "EAP-AKA"               => 23,
                "EAP-FAST"              => 43,
                "EAP-GTC"               => 6,
                "EAP-IKEv2"             => 49,
                "EAP-MD5"               => 4,
                "EAP-MSCHAPv2"          => 26,
                "EAP-SIM"               => 18,
                "EAP-TLS"               => 13,
                "EAP-TTLS"              => 21,
                "EKEv1"                 => 53,
                "FAST"                  => 43,
                "Generic-Token-Card"    => 6,
                "GPSK"                  => 51,
                "GTC"                   => 6,
                "HTTP-Digest"           => 38,
                "Identity"              => 1,
                "IKEv2"                 => 49,
                "KEA"                   => 11,
                "KEA-Validate"          => 12,
                "LEAP"                  => 17,
                "Link"                  => 45,
                "MAKE"                  => 27,
                "MD5"                   => 4,
                "MD5-Challenge"         => 4,
                "Microsoft-MS-CHAPv2"   => 26,
                "MOBAC"                 => 42,
                "MS-Authentication-TLV" => 33,
                "MSCHAPv2"              => 26,
                "NAK"                   => 3,
                "Nokia-IP-Smart-Card"   => 18,
                "None"                  => 0,
                "Notification"          => 2,
                "One-Time-Password"     => 5,
                "OTP"                   => 5,
                "PAX"                   => 46,
                "PEAP"                  => 25,
                "PSK"                   => 47,
                "PT-EAP"                => 54,
                "PWD"                   => 52,
                "Remote-Access-Service" => 22,
                "Rob-EAP"               => 31,
                "RSA-Public-Key"        => 9,
                "RSA-SecurID-EAP"       => 15,
                "SAKE"                  => 48,
                "SecurID-EAP"           => 32,
                "SecuriSuite-EAP"       => 39,
                "SentriNET"             => 34,
                "SIM"                   => 18,
                "SPEKE"                 => 41,
                "SRP-SHA1"              => 19,
                "TEAP"                  => 55,
                "TLS"                   => 13,
                "TNC"                   => 38,
                "TTLS"                  => 21,
                "Zonelabs"              => 44,
            },
            1019 => { No      => 0, Yes     => 1 },
            1021 => { Failure => 4, Request => 1, Response => 2, Success => 3 },
            1035 => { No      => 0, Yes     => 1 },
            1047 => {
                "Access-Accept"                      => 2,
                "Access-Challenge"                   => 11,
                "Access-Reject"                      => 3,
                "Access-Request"                     => 1,
                "Accounting-Message"                 => 10,
                "Accounting-Request"                 => 4,
                "Accounting-Response"                => 5,
                "Accounting-Status"                  => 6,
                "Alternate-Resource-Reclaim-Request" => 25,
                "CoA-ACK"                            => 44,
                "CoA-NAK"                            => 45,
                "CoA-Request"                        => 43,
                "Disconnect-ACK"                     => 41,
                "Disconnect-NAK"                     => 42,
                "Disconnect-Request"                 => 40,
                "Event-Request"                      => 33,
                "Event-Response"                     => 34,
                "IP-Address-Allocate"                => 50,
                "IP-Address-Release"                 => 51,
                "NAS-Reboot-Request"                 => 26,
                "NAS-Reboot-Response"                => 27,
                "New-Pin"                            => 30,
                "Next-Passcode"                      => 29,
                "Password-Accept"                    => 8,
                "Password-Expired"                   => 32,
                "Password-Reject"                    => 9,
                "Password-Request"                   => 7,
                "Resource-Free-Request"              => 21,
                "Resource-Free-Response"             => 22,
                "Resource-Query-Request"             => 23,
                "Resource-Query-Response"            => 24,
                "Status-Client"                      => 13,
                "Status-Server"                      => 12,
                "Terminate-Session"                  => 31,
            },
            1080 => {
                "Access-Accept"       => 2,
                "Access-Challenge"    => 11,
                "Access-Reject"       => 3,
                "Access-Request"      => 1,
                "Accounting-Message"  => 10,
                "Accounting-Request"  => 4,
                "Accounting-Response" => 5,
                "Accounting-Status"   => 6,
                "CoA-ACK"             => 44,
                "CoA-NAK"             => 45,
                "CoA-Request"         => 43,
                "Disconnect-ACK"      => 41,
                "Disconnect-NAK"      => 42,
                "Disconnect-Request"  => 40,
                "Do-Not-Respond"      => 256,
                "Password-Accept"     => 8,
                "Password-Reject"     => 9,
                "Password-Request"    => 7,
                "Status-Client"       => 13,
                "Status-Server"       => 12,
            },
            1082 => { No => 0, Yes => 1 },
            1103 => {
                DER_ASN1_DN => 9,
                DER_ASN1_GN => 10,
                FQDN        => 2,
                IPV4_ADDR   => 1,
                IPV6_ADDR   => 5,
                KEY_ID      => 11,
                RFC822_ADDR => 3,
            },
            1106 => { both => 3, cert => 2, none => 0, secret => 1 },
            1107 => { No   => 0, Yes  => 1 },
            1108 => {
                fail     => 1,
                handled  => 3,
                invalid  => 4,
                noop     => 7,
                notfound => 6,
                ok       => 2,
                reject   => 0,
                updated  => 8,
                userlock => 5,
            },
            1122 => { false   => 0, no      => 0, true => 1, yes => 1 },
            1127 => { no      => 0, yes     => 1 },
            1128 => { no      => 0, yes     => 1 },
            1147 => { failure => 3, success => 2 },
            1173 => { no      => 0, yes     => 1 },
            1174 => { no      => 0, yes     => 1 },
            1176 => { no      => 0, yes     => 1 },
            1197 => { No      => 0, Yes     => 1 },
            1200 => {
                "Challenge"         => 11,
                "Notification"      => 12,
                "Re-authentication" => 13,
                "Start"             => 10,
            },
            1223 => {
                "3Com-Wireless"         => 24,
                "Actiontec-Wireless"    => 35,
                "AirFortress-EAP"       => 37,
                "AKA"                   => 23,
                "AKA2"                  => 50,
                "Arcot-Systems-EAP"     => 16,
                "Cisco-LEAP"            => 17,
                "Cisco-MS-CHAPv2"       => 29,
                "Cogent-Biomentric-EAP" => 36,
                "CRYPTOCard"            => 28,
                "Defender-Token"        => 14,
                "DeviceConnect-EAP"     => 40,
                "DSS-Unilateral"        => 10,
                "DynamID"               => 30,
                "EAP-AKA"               => 23,
                "EAP-FAST"              => 43,
                "EAP-GTC"               => 6,
                "EAP-IKEv2"             => 49,
                "EAP-MD5"               => 4,
                "EAP-MSCHAPv2"          => 26,
                "EAP-SIM"               => 18,
                "EAP-TLS"               => 13,
                "EAP-TTLS"              => 21,
                "EKEv1"                 => 53,
                "FAST"                  => 43,
                "Generic-Token-Card"    => 6,
                "GPSK"                  => 51,
                "GTC"                   => 6,
                "HTTP-Digest"           => 38,
                "Identity"              => 1,
                "IKEv2"                 => 49,
                "KEA"                   => 11,
                "KEA-Validate"          => 12,
                "LEAP"                  => 17,
                "Link"                  => 45,
                "MAKE"                  => 27,
                "MD5"                   => 4,
                "MD5-Challenge"         => 4,
                "Microsoft-MS-CHAPv2"   => 26,
                "MOBAC"                 => 42,
                "MS-Authentication-TLV" => 33,
                "MSCHAPv2"              => 26,
                "NAK"                   => 3,
                "Nokia-IP-Smart-Card"   => 18,
                "None"                  => 0,
                "Notification"          => 2,
                "One-Time-Password"     => 5,
                "OTP"                   => 5,
                "PAX"                   => 46,
                "PEAP"                  => 25,
                "PSK"                   => 47,
                "PT-EAP"                => 54,
                "PWD"                   => 52,
                "Remote-Access-Service" => 22,
                "Rob-EAP"               => 31,
                "RSA-Public-Key"        => 9,
                "RSA-SecurID-EAP"       => 15,
                "SAKE"                  => 48,
                "SecurID-EAP"           => 32,
                "SecuriSuite-EAP"       => 39,
                "SentriNET"             => 34,
                "SIM"                   => 18,
                "SPEKE"                 => 41,
                "SRP-SHA1"              => 19,
                "TEAP"                  => 55,
                "TLS"                   => 13,
                "TNC"                   => 38,
                "TTLS"                  => 21,
                "Zonelabs"              => 44,
            },
            1224 => {
                "3Com-Wireless"         => 24,
                "Actiontec-Wireless"    => 35,
                "AirFortress-EAP"       => 37,
                "AKA"                   => 23,
                "AKA2"                  => 50,
                "Arcot-Systems-EAP"     => 16,
                "Cisco-LEAP"            => 17,
                "Cisco-MS-CHAPv2"       => 29,
                "Cogent-Biomentric-EAP" => 36,
                "CRYPTOCard"            => 28,
                "Defender-Token"        => 14,
                "DeviceConnect-EAP"     => 40,
                "DSS-Unilateral"        => 10,
                "DynamID"               => 30,
                "EAP-AKA"               => 23,
                "EAP-FAST"              => 43,
                "EAP-GTC"               => 6,
                "EAP-IKEv2"             => 49,
                "EAP-MD5"               => 4,
                "EAP-MSCHAPv2"          => 26,
                "EAP-SIM"               => 18,
                "EAP-TLS"               => 13,
                "EAP-TTLS"              => 21,
                "EKEv1"                 => 53,
                "FAST"                  => 43,
                "Generic-Token-Card"    => 6,
                "GPSK"                  => 51,
                "GTC"                   => 6,
                "HTTP-Digest"           => 38,
                "Identity"              => 1,
                "IKEv2"                 => 49,
                "KEA"                   => 11,
                "KEA-Validate"          => 12,
                "LEAP"                  => 17,
                "Link"                  => 45,
                "MAKE"                  => 27,
                "MD5"                   => 4,
                "MD5-Challenge"         => 4,
                "Microsoft-MS-CHAPv2"   => 26,
                "MOBAC"                 => 42,
                "MS-Authentication-TLV" => 33,
                "MSCHAPv2"              => 26,
                "NAK"                   => 3,
                "Nokia-IP-Smart-Card"   => 18,
                "None"                  => 0,
                "Notification"          => 2,
                "One-Time-Password"     => 5,
                "OTP"                   => 5,
                "PAX"                   => 46,
                "PEAP"                  => 25,
                "PSK"                   => 47,
                "PT-EAP"                => 54,
                "PWD"                   => 52,
                "Remote-Access-Service" => 22,
                "Rob-EAP"               => 31,
                "RSA-Public-Key"        => 9,
                "RSA-SecurID-EAP"       => 15,
                "SAKE"                  => 48,
                "SecurID-EAP"           => 32,
                "SecuriSuite-EAP"       => 39,
                "SentriNET"             => 34,
                "SIM"                   => 18,
                "SPEKE"                 => 41,
                "SRP-SHA1"              => 19,
                "TEAP"                  => 55,
                "TLS"                   => 13,
                "TNC"                   => 38,
                "TTLS"                  => 21,
                "Zonelabs"              => 44,
            },
            1938 => { clear     => 3, load    => 2, refresh => 4, save => 1 },
            1943 => { no        => 0, skipped => 2, unknown => 3, yes  => 1 },
            2100 => { Microsoft => 311 },
            2106 => { i64       => 6, x86 => 0, x86_64 => 9 },
            2109 => { client    => 1, dc  => 2, server => 3 },
            2119 => { no        => 0, yes => 1 },
        },
        vendors => {
            "3com"                          => 43,
            "3GPP"                          => 10415,
            "3GPP2"                         => 5535,
            "Acc"                           => 5,
            "Acme"                          => 9148,
            "Actelis"                       => 5468,
            "ADSL-Forum"                    => 3561,
            "Adtran"                        => 664,
            "Adva"                          => 2544,
            "Aerohive"                      => 26928,
            "Airespace"                     => 14179,
            "Alcatel"                       => 3041,
            "Alcatel-ESAM"                  => 637,
            "Alcatel-Lucent-Service-Router" => 6527,
            "Alphion"                       => 8742,
            "Alteon"                        => 1872,
            "Altiga"                        => 3076,
            "ALU-AAA"                       => 831,
            "Alvarion"                      => 12394,
            "APC"                           => 318,
            "Aptilo"                        => 13209,
            "Aptis"                         => 2637,
            "Arbor"                         => 9694,
            "Arista"                        => 30065,
            "Aruba"                         => 14823,
            "Ascend"                        => 529,
            "ASN"                           => 23782,
            "AudioCodes"                    => 5003,
            "Azaire"                        => 7751,
            "Bay-Networks"                  => 1584,
            "Big-Switch-Networks"           => 37538,
            "BinTec"                        => 272,
            "BlueCoat"                      => 14501,
            "Boingo"                        => 22472,
            "Bristol"                       => 4363,
            "BroadSoft"                     => 6431,
            "Brocade"                       => 1588,
            "BSkyB"                         => 16924,
            "BT"                            => 594,
            "CableLabs"                     => 4491,
            "Cabletron"                     => 52,
            "Cajun_p330"                    => 2167,
            "Calix"                         => 6321,
            "Cambium"                       => 17713,
            "Camiant"                       => 21274,
            "Centec"                        => 27975,
            "CheckPoint"                    => 2620,
            "ChilliSpot"                    => 14559,
            "Ciena"                         => 1271,
            "Cisco"                         => 9,
            "Cisco-ASA"                     => 3076,
            "Cisco-BBSM"                    => 5263,
            "Cisco-VPN5000"                 => 255,
            "Citrix"                        => 66,
            "Ckey"                          => 61349,
            "Clavister"                     => 5089,
            "Cnergee"                       => 49426,
            "Colubris"                      => 8744,
            "Columbia-University"           => 11862,
            "Compatible"                    => 255,
            "Cosine"                        => 3085,
            "Covaro"                        => 18022,
            "DANTE"                         => 27262,
            "DellEMC"                       => 674,
            "Digium"                        => 22736,
            "Dlink"                         => 171,
            "DragonWave"                    => 7262,
            "EfficientIP"                   => 2440,
            "Eleven"                        => 52970,
            "Eltex"                         => 35265,
            "Epygi"                         => 16459,
            "Equallogic"                    => 12740,
            "Ericsson"                      => 193,
            "Ericsson-AB"                   => 2352,
            "Ericsson-Packet-Core-Networks" => 10923,
            "ERX"                           => 4874,
            "Extreme"                       => 1916,
            "F5"                            => 3375,
            "fdXtended"                     => 34536,
            "Force10"                       => 6027,
            "Fortinet"                      => 12356,
            "Foundry"                       => 1991,
            "FreeRADIUS"                    => 11344,
            "Freeswitch"                    => 27880,
            "Gandalf"                       => 64,
            "Garderos"                      => 16108,
            "Gemtek"                        => 10529,
            "H3C"                           => 25506,
            "Hillstone"                     => 28557,
            "HP"                            => 11,
            "Huawei"                        => 2011,
            "IEA-Software"                  => 24023,
            "Infinera"                      => 8708,
            "Infoblox"                      => 7779,
            "infonet"                       => 4453,
            "Inverse"                       => 29464,
            "ipUnplugged"                   => 5925,
            "Issanni"                       => 5948,
            "ITK"                           => 1195,
            "Juniper"                       => 2636,
            "KarlNet"                       => 762,
            "Kineto"                        => 16445,
            "Lancom"                        => 2356,
            "Lantronix"                     => 244,
            "Livingston"                    => 307,
            "Local-Web"                     => 19220,
            "Lucent"                        => 4846,
            "Manzara"                       => 19382,
            "Meinberg"                      => 5597,
            "Mellanox"                      => 33049,
            "Meraki"                        => 29671,
            "Merit"                         => 61,
            "Meru"                          => 15983,
            "Microsemi"                     => 40676,
            "Microsoft"                     => 311,
            "Mikrotik"                      => 14988,
            "Mimosa"                        => 43356,
            "Motorola"                      => 161,
            "Navini"                        => 6504,
            "NET"                           => 177,
            "NetBorder"                     => 35987,
            "NetElastic"                    => 54268,
            "Netscreen"                     => 3224,
            "NetworkPhysics"                => 7119,
            "Nexans"                        => 266,
            "Nile"                          => 58313,
            "Nokia"                         => 94,
            "Nomadix"                       => 3309,
            "Nortel"                        => 562,
            "NTUA"                          => 969,
            "OpenWiFi"                      => 58888,
            "Packeteer"                     => 2334,
            "PaloAlto"                      => 25461,
            "Patton"                        => 1768,
            "Perle"                         => 1966,
            "pfSense"                       => 13644,
            "Pica8"                         => 35098,
            "Propel"                        => 14895,
            "Prosoft"                       => 4735,
            "Proxim"                        => 841,
            "Purewave"                      => 21074,
            "Quiconnect"                    => 14436,
            "Quintum"                       => 6618,
            "RCNTEC"                        => 46235,
            "RedCreek"                      => 1958,
            "Riverbed"                      => 17163,
            "Riverstone"                    => 5567,
            "Roaring-Penguin"               => 10055,
            "Ruckus"                        => 25053,
            "RuggedCom"                     => 15004,
            "SG"                            => 2454,
            "Shasta"                        => 3199,
            "Shiva"                         => 166,
            "Siemens"                       => 4329,
            "Slipstream"                    => 7000,
            "SmartShareSystems"             => 30585,
            "SofaWare"                      => 6983,
            "SoftBank"                      => 22197,
            "SonicWall"                     => 8741,
            "SpringTide"                    => 3551,
            "Starent"                       => 8164,
            "Surfnet"                       => 1076,
            "Symbol"                        => 388,
            "T-Systems-Nova"                => 16787,
            "Telebit"                       => 117,
            "Telkom"                        => 1431,
            "Telrad"                        => 5323,
            "TERENA"                        => 25178,
            "TPLink"                        => 11863,
            "Trapeze"                       => 14525,
            "Travelping"                    => 18681,
            "TrippLite"                     => 850,
            "Tropos"                        => 14529,
            "UKERNA"                        => 25622,
            "Unix"                          => 4,
            "USR"                           => 429,
            "UTStarcom"                     => 7064,
            "ValemountNetworks"             => 16313,
            "VasExperts"                    => 43823,
            "VerizonWireless"               => 12951,
            "Versanet"                      => 2180,
            "Walabi"                        => 2004,
            "Waverider"                     => 2979,
            "Wichorus"                      => 27030,
            "WiFi-Alliance"                 => 40808,
            "WiMAX"                         => 24757,
            "WISPr"                         => 14122,
            "Xedia"                         => 838,
            "Xylan"                         => 800,
            "Yubico"                        => 41482,
            "Zeus"                          => 7146,
            "ZTE"                           => 3902,
            "Zyxel"                         => 890,
        },
        vsattr => {
            4 => {
                "Unix-FTP-GID"         => [ 11, "integer" ],
                "Unix-FTP-Group-Ids"   => [ 15, "string" ],
                "Unix-FTP-Group-Names" => [ 14, "string" ],
                "Unix-FTP-Home"        => [ 12, "string" ],
                "Unix-FTP-Shell"       => [ 13, "string" ],
                "Unix-FTP-UID"         => [ 10, "integer" ],
            },
            5 => {
                "Acc-Access-Community"         => [ 42, "integer" ],
                "Acc-Access-Partition"         => [ 5,  "string" ],
                "Acc-Acct-On-Off-Reason"       => [ 21, "integer" ],
                "Acc-Ace-Token"                => [ 44, "string" ],
                "Acc-Ace-Token-Ttl"            => [ 45, "integer" ],
                "Acc-Apsm-Oversubscribed"      => [ 20, "integer" ],
                "Acc-Bridging-Support"         => [ 19, "integer" ],
                "Acc-Callback-CBCP-Type"       => [ 37, "integer" ],
                "Acc-Callback-Delay"           => [ 34, "integer" ],
                "Acc-Callback-Mode"            => [ 36, "integer" ],
                "Acc-Callback-Num-Valid"       => [ 35, "string" ],
                "Acc-Calling-Station-Category" => [ 99, "integer" ],
                "Acc-Ccp-Option"               => [ 2,  "integer" ],
                "Acc-Clearing-Cause"           => [ 15, "integer" ],
                "Acc-Clearing-Location"        => [ 16, "integer" ],
                "Acc-Connect-Rx-Speed"         => [ 31, "integer" ],
                "Acc-Connect-Tx-Speed"         => [ 30, "integer" ],
                "Acc-Customer-Id"              => [ 6,  "string" ],
                "Acc-Dial-Port-Index"          => [ 27, "integer" ],
                "Acc-Dialout-Auth-Mode"        => [ 38, "integer" ],
                "Acc-Dialout-Auth-Password"    => [ 39, "string" ],
                "Acc-Dialout-Auth-Username"    => [ 40, "string" ],
                "Acc-Dns-Server-Pri"           => [ 23, "ipaddr" ],
                "Acc-Dns-Server-Sec"           => [ 24, "ipaddr" ],
                "Acc-Igmp-Admin-State"         => [ 47, "integer" ],
                "Acc-Igmp-Version"             => [ 48, "integer" ],
                "Acc-Input-Errors"             => [ 3,  "integer" ],
                "Acc-Ip-Compression"           => [ 28, "integer" ],
                "Acc-Ip-Gateway-Pri"           => [ 7,  "ipaddr" ],
                "Acc-Ip-Gateway-Sec"           => [ 8,  "ipaddr" ],
                "Acc-Ip-Pool-Name"             => [ 46, "string" ],
                "Acc-Ipx-Compression"          => [ 29, "integer" ],
                "Acc-Location-Id"              => [ 98, "string" ],
                "Acc-ML-Call-Threshold"        => [ 11, "integer" ],
                "Acc-ML-Clear-Threshold"       => [ 12, "integer" ],
                "Acc-ML-Damping-Factor"        => [ 13, "integer" ],
                "Acc-ML-MLX-Admin-State"       => [ 10, "integer" ],
                "Acc-MN-HA-Secret"             => [ 73, "string" ],
                "Acc-Modem-Error-Protocol"     => [ 33, "string" ],
                "Acc-Modem-Modulation-Type"    => [ 32, "string" ],
                "Acc-Nbns-Server-Pri"          => [ 25, "ipaddr" ],
                "Acc-Nbns-Server-Sec"          => [ 26, "ipaddr" ],
                "Acc-Output-Errors"            => [ 4,  "integer" ],
                "Acc-Reason-Code"              => [ 1,  "integer" ],
                "Acc-Request-Type"             => [ 18, "integer" ],
                "Acc-Route-Policy"             => [ 9,  "integer" ],
                "Acc-Service-Profile"          => [ 17, "string" ],
                "Acc-Tunnel-Port"              => [ 22, "integer" ],
                "Acc-Tunnel-Secret"            => [ 14, "string" ],
                "Acc-Vpsm-Reject-Cause"        => [ 43, "integer" ],
            },
            9 => {
                "call-id"                        => [ 141, "string" ],
                "Cisco-Abort-Cause"              => [ 21,  "string" ],
                "Cisco-Account-Info"             => [ 250, "string" ],
                "Cisco-Assign-IP-Pool"           => [ 218, "integer" ],
                "Cisco-AVPair"                   => [ 1,   "string" ],
                "Cisco-Call-Filter"              => [ 243, "integer" ],
                "Cisco-Call-Type"                => [ 19,  "string" ],
                "Cisco-Command-Code"             => [ 252, "string" ],
                "Cisco-Control-Info"             => [ 253, "string" ],
                "Cisco-Data-Filter"              => [ 242, "integer" ],
                "Cisco-Data-Rate"                => [ 197, "integer" ],
                "Cisco-DHCP-Relay-GiAddr"        => [ 50,  "string" ],
                "Cisco-DHCP-Subscriber-Id"       => [ 65,  "string" ],
                "Cisco-DHCP-User-Class"          => [ 47,  "string" ],
                "Cisco-DHCP-Vendor-Class"        => [ 48,  "string" ],
                "Cisco-DHCPv6-Link-Address"      => [ 66,  "string" ],
                "Cisco-Disconnect-Cause"         => [ 195, "integer" ],
                "Cisco-Email-Server-Ack-Flag"    => [ 17,  "string" ],
                "Cisco-Email-Server-Address"     => [ 16,  "string" ],
                "Cisco-Fax-Account-Id-Origin"    => [ 3,   "string" ],
                "Cisco-Fax-Auth-Status"          => [ 15,  "string" ],
                "Cisco-Fax-Connect-Speed"        => [ 8,   "string" ],
                "Cisco-Fax-Coverpage-Flag"       => [ 6,   "string" ],
                "Cisco-Fax-Dsn-Address"          => [ 11,  "string" ],
                "Cisco-Fax-Dsn-Flag"             => [ 12,  "string" ],
                "Cisco-Fax-Mdn-Address"          => [ 13,  "string" ],
                "Cisco-Fax-Mdn-Flag"             => [ 14,  "string" ],
                "Cisco-Fax-Modem-Time"           => [ 7,   "string" ],
                "Cisco-Fax-Msg-Id"               => [ 4,   "string" ],
                "Cisco-Fax-Pages"                => [ 5,   "string" ],
                "Cisco-Fax-Process-Abort-Flag"   => [ 10,  "string" ],
                "Cisco-Fax-Recipient-Count"      => [ 9,   "string" ],
                "Cisco-Gateway-Id"               => [ 18,  "string" ],
                "Cisco-Idle-Limit"               => [ 244, "integer" ],
                "Cisco-In-ACL"                   => [ 57,  "string" ],
                "Cisco-IP-Direct"                => [ 209, "integer" ],
                "Cisco-IP-Pool-Definition"       => [ 217, "string" ],
                "Cisco-IPv6-In-ACL"              => [ 61,  "string" ],
                "Cisco-IPv6-Out-ACL"             => [ 62,  "string" ],
                "Cisco-Link-Compression"         => [ 233, "integer" ],
                "Cisco-Maximum-Channels"         => [ 235, "integer" ],
                "Cisco-Maximum-Time"             => [ 194, "integer" ],
                "Cisco-Multilink-ID"             => [ 187, "integer" ],
                "Cisco-NAS-Port"                 => [ 2,   "string" ],
                "Cisco-Num-In-Multilink"         => [ 188, "integer" ],
                "Cisco-Out-ACL"                  => [ 58,  "string" ],
                "Cisco-Parent-Session-Id"        => [ 52,  "string" ],
                "Cisco-Policy-Down"              => [ 38,  "string" ],
                "Cisco-Policy-Up"                => [ 37,  "string" ],
                "Cisco-Port-Used"                => [ 20,  "string" ],
                "Cisco-PPP-Async-Map"            => [ 212, "integer" ],
                "Cisco-PPP-VJ-Slot-Comp"         => [ 210, "integer" ],
                "Cisco-Pre-Input-Octets"         => [ 190, "integer" ],
                "Cisco-Pre-Input-Packets"        => [ 192, "integer" ],
                "Cisco-Pre-Output-Octets"        => [ 191, "integer" ],
                "Cisco-Pre-Output-Packets"       => [ 193, "integer" ],
                "Cisco-PreSession-Time"          => [ 198, "integer" ],
                "Cisco-PW-Lifetime"              => [ 208, "integer" ],
                "Cisco-Relay-Information-Option" => [ 46,  "string" ],
                "Cisco-Route-IP"                 => [ 228, "integer" ],
                "Cisco-Service-Info"             => [ 251, "string" ],
                "Cisco-Service-Name"             => [ 51,  "string" ],
                "Cisco-Sub-Activate-Service"     => [ 60,  "string" ],
                "Cisco-Sub-Deactivate-Service"   => [ 63,  "string" ],
                "Cisco-Sub-PBR-Policy-In"        => [ 59,  "string" ],
                "Cisco-Sub-QoS-Pol-In"           => [ 55,  "string" ],
                "Cisco-Sub-QoS-Pol-Out"          => [ 56,  "string" ],
                "Cisco-Subscriber-Password"      => [ 249, "string" ],
                "Cisco-Target-Util"              => [ 234, "integer" ],
                "Cisco-Xmit-Rate"                => [ 255, "integer" ],
                "dsp-id"                         => [ 151, "string" ],
                "gw-final-xlated-cdn"            => [ 113, "string" ],
                "gw-final-xlated-cgn"            => [ 117, "string" ],
                "gw-rxd-cdn"                     => [ 112, "string" ],
                "gw-rxd-cgn"                     => [ 116, "string" ],
                "h323-billing-model"             => [ 109, "string" ],
                "h323-call-origin"               => [ 26,  "string" ],
                "h323-call-type"                 => [ 27,  "string" ],
                "h323-conf-id"                   => [ 24,  "string" ],
                "h323-connect-time"              => [ 28,  "string" ],
                "h323-credit-amount"             => [ 101, "string" ],
                "h323-credit-time"               => [ 102, "string" ],
                "h323-currency"                  => [ 110, "string" ],
                "h323-disconnect-cause"          => [ 30,  "string" ],
                "h323-disconnect-time"           => [ 29,  "string" ],
                "h323-gw-id"                     => [ 33,  "string" ],
                "h323-incoming-conf-id"          => [ 35,  "string" ],
                "h323-preferred-lang"            => [ 107, "string" ],
                "h323-prompt-id"                 => [ 104, "string" ],
                "h323-redirect-ip-address"       => [ 108, "string" ],
                "h323-redirect-number"           => [ 106, "string" ],
                "h323-remote-address"            => [ 23,  "string" ],
                "h323-return-code"               => [ 103, "string" ],
                "h323-setup-time"                => [ 25,  "string" ],
                "h323-time-and-day"              => [ 105, "string" ],
                "h323-voice-quality"             => [ 31,  "string" ],
                "incoming-req-uri"               => [ 146, "string" ],
                "method"                         => [ 143, "string" ],
                "next-hop-dn"                    => [ 149, "string" ],
                "next-hop-ip"                    => [ 148, "string" ],
                "outgoing-req-uri"               => [ 147, "string" ],
                "prev-hop-ip"                    => [ 145, "string" ],
                "prev-hop-via"                   => [ 144, "string" ],
                "release-source"                 => [ 115, "string" ],
                "remote-media-address"           => [ 114, "string" ],
                "session-protocol"               => [ 142, "string" ],
                "sip-conf-id"                    => [ 100, "string" ],
                "sip-hdr"                        => [ 150, "string" ],
                "subscriber"                     => [ 111, "string" ],
            },
            11 => {
                "HP-Access-Profile"                   => [ 62,  "string" ],
                "HP-Bandwidth-Max-Egress"             => [ 48,  "integer" ],
                "HP-Bandwidth-Max-Ingress"            => [ 46,  "integer" ],
                "HP-Bonjour-Inbound-Profile"          => [ 66,  "string" ],
                "HP-Bonjour-Outbound-Profile"         => [ 67,  "string" ],
                "HP-Capability-Advert"                => [ 255, "octets" ],
                "HP-Captive-Portal-URL"               => [ 24,  "string" ],
                "HP-Command-Exception"                => [ 3,   "integer" ],
                "HP-Command-String"                   => [ 2,   "string" ],
                "HP-Cos"                              => [ 40,  "string" ],
                "HP-CPPM-Role"                        => [ 27,  "string" ],
                "HP-CPPM-Secondary-Role"              => [ 28,  "string" ],
                "HP-Egress-VLAN-Name"                 => [ 65,  "string" ],
                "HP-Egress-VLANID"                    => [ 64,  "integer" ],
                "HP-Ip-Filter-Raw"                    => [ 61,  "string" ],
                "HP-Management-Protocol"              => [ 26,  "integer" ],
                "HP-Nas-Filter-Rule"                  => [ 61,  "string" ],
                "HP-Nas-Rules-IPv6"                   => [ 63,  "integer" ],
                "HP-Port-Auth-Mode-Dot1x"             => [ 13,  "integer" ],
                "HP-Port-Bounce-Host"                 => [ 23,  "integer" ],
                "HP-Port-Client-Limit-Dot1x"          => [ 10,  "integer" ],
                "HP-Port-Client-Limit-MA"             => [ 11,  "integer" ],
                "HP-Port-Client-Limit-WA"             => [ 12,  "integer" ],
                "HP-Port-MA-Port-Mode"                => [ 14,  "integer" ],
                "HP-Port-Priority-Regeneration-Table" => [ 40,  "string" ],
                "HP-Privilege-Level"                  => [ 1,   "integer" ],
                "HP-URI-Access"                       => [ 82,  "string" ],
                "HP-URI-Exception"                    => [ 83,  "integer" ],
                "HP-URI-Json-String"                  => [ 81,  "string" ],
                "HP-URI-String"                       => [ 80,  "string" ],
                "HP-User-Role"                        => [ 25,  "string" ],
                "HP-VC-groups"                        => [ 192, "string" ],
            },
            43 => {
                "3Com-Connect_Id"            => [ 26,  "integer" ],
                "3Com-Encryption-Type"       => [ 4,   "string" ],
                "3Com-End-Date"              => [ 7,   "string" ],
                "3Com-Ip-Host-Addr"          => [ 60,  "string" ],
                "3Com-Mobility-Profile"      => [ 3,   "string" ],
                "3Com-NAS-Startup-Timestamp" => [ 59,  "integer" ],
                "3Com-Product-ID"            => [ 255, "string" ],
                "3Com-SSID"                  => [ 6,   "string" ],
                "3Com-Time-Of-Day"           => [ 5,   "string" ],
                "3Com-URL"                   => [ 8,   "string" ],
                "3Com-User-Access-Level"     => [ 1,   "integer" ],
                "3Com-VLAN-Name"             => [ 2,   "string" ],
            },
            52 => {
                "Cabletron-Protocol-Callable" => [ 202, "integer" ],
                "Cabletron-Protocol-Enable"   => [ 201, "integer" ],
            },
            61 => {
                "Merit-Proxy-Action" => [ 211, "string" ],
                "Merit-User-Id"      => [ 222, "string" ],
                "Merit-User-Realm"   => [ 223, "string" ],
            },
            64 => {
                "Gandalf-Around-The-Corner"     => [ 14, "integer" ],
                "Gandalf-Authentication-String" => [ 5,  "string" ],
                "Gandalf-Calling-Line-ID-1"     => [ 18, "string" ],
                "Gandalf-Calling-Line-ID-2"     => [ 22, "string" ],
                "Gandalf-Channel-Group-Name-1"  => [ 15, "string" ],
                "Gandalf-Channel-Group-Name-2"  => [ 19, "string" ],
                "Gandalf-Compression-Status"    => [ 2,  "integer" ],
                "Gandalf-Dial-Prefix-Name-1"    => [ 16, "string" ],
                "Gandalf-Dial-Prefix-Name-2"    => [ 20, "string" ],
                "Gandalf-Fwd-Broadcast-In"      => [ 9,  "integer" ],
                "Gandalf-Fwd-Broadcast-Out"     => [ 12, "integer" ],
                "Gandalf-Fwd-Multicast-In"      => [ 8,  "integer" ],
                "Gandalf-Fwd-Multicast-Out"     => [ 11, "integer" ],
                "Gandalf-Fwd-Unicast-In"        => [ 10, "integer" ],
                "Gandalf-Fwd-Unicast-Out"       => [ 13, "integer" ],
                "Gandalf-Hunt-Group"            => [ 30, "string" ],
                "Gandalf-IPX-Spoofing-State"    => [ 23, "integer" ],
                "Gandalf-IPX-Watchdog-Spoof"    => [ 24, "integer" ],
                "Gandalf-Min-Outgoing-Bearer"   => [ 3,  "integer" ],
                "Gandalf-Modem-Mode"            => [ 31, "integer" ],
                "Gandalf-Modem-Required-1"      => [ 32, "integer" ],
                "Gandalf-Modem-Required-2"      => [ 33, "integer" ],
                "Gandalf-Operational-Modes"     => [ 1,  "integer" ],
                "Gandalf-Phone-Number-1"        => [ 17, "string" ],
                "Gandalf-Phone-Number-2"        => [ 21, "string" ],
                "Gandalf-PPP-Authentication"    => [ 6,  "integer" ],
                "Gandalf-PPP-NCP-Type"          => [ 7,  "integer" ],
                "Gandalf-Remote-LAN-Name"       => [ 0,  "string" ],
                "Gandalf-SAP-Group-Name-1"      => [ 25, "string" ],
                "Gandalf-SAP-Group-Name-2"      => [ 26, "string" ],
                "Gandalf-SAP-Group-Name-3"      => [ 27, "string" ],
                "Gandalf-SAP-Group-Name-4"      => [ 28, "string" ],
                "Gandalf-SAP-Group-Name-5"      => [ 29, "string" ],
            },
            66 => {
                "Citrix-GID"         => [ 11, "integer" ],
                "Citrix-Group-Ids"   => [ 15, "string" ],
                "Citrix-Group-Names" => [ 14, "string" ],
                "Citrix-Home"        => [ 12, "string" ],
                "Citrix-Shell"       => [ 13, "string" ],
                "Citrix-UID"         => [ 10, "integer" ],
                "Citrix-User-Groups" => [ 16, "string" ],
            },
            94 => {
                "Nokia-AVPair"                     => [ 1,  "string" ],
                "Nokia-OCS-ID1"                    => [ 12, "integer" ],
                "Nokia-OCS-ID2"                    => [ 13, "integer" ],
                "Nokia-Requested-APN"              => [ 15, "string" ],
                "Nokia-Service-Charging-Type"      => [ 8,  "octets" ],
                "Nokia-Service-Encrypted-Password" => [ 9,  "octets" ],
                "Nokia-Service-Id"                 => [ 4,  "octets" ],
                "Nokia-Service-Name"               => [ 3,  "octets" ],
                "Nokia-Service-Password"           => [ 6,  "octets" ],
                "Nokia-Service-Primary-Indicator"  => [ 7,  "octets" ],
                "Nokia-Service-Username"           => [ 5,  "octets" ],
                "Nokia-Session-Access-Method"      => [ 10, "octets" ],
                "Nokia-Session-Charging-Type"      => [ 11, "octets" ],
                "Nokia-TREC-Index"                 => [ 14, "integer" ],
                "Nokia-User-Profile"               => [ 2,  "string" ],
            },
            117 => {
                "Telebit-Accounting-Info"  => [ 4, "string" ],
                "Telebit-Activate-Command" => [ 3, "string" ],
                "Telebit-Login-Command"    => [ 1, "string" ],
                "Telebit-Login-Option"     => [ 5, "string" ],
                "Telebit-Port-Name"        => [ 2, "string" ],
            },
            161 => {
                "Motorola-Accounting-Message"             => [ 80, "string" ],
                "Motorola-Canopy-BCASTMIR"                => [ 24, "integer" ],
                "Motorola-Canopy-DLBL"                    => [ 9,  "integer" ],
                "Motorola-Canopy-DLBR"                    => [ 8,  "integer" ],
                "Motorola-Canopy-HPDLCIR"                 => [ 4,  "integer" ],
                "Motorola-Canopy-HPENABLE"                => [ 5,  "integer" ],
                "Motorola-Canopy-HPULCIR"                 => [ 3,  "integer" ],
                "Motorola-Canopy-LPDLCIR"                 => [ 2,  "integer" ],
                "Motorola-Canopy-LPULCIR"                 => [ 1,  "integer" ],
                "Motorola-Canopy-ULBL"                    => [ 7,  "integer" ],
                "Motorola-Canopy-ULBR"                    => [ 6,  "integer" ],
                "Motorola-Canopy-UserLevel"               => [ 50, "integer" ],
                "Motorola-Canopy-VLAGETO"                 => [ 20, "integer" ],
                "Motorola-Canopy-VLFRAMES"                => [ 15, "integer" ],
                "Motorola-Canopy-VLIDSET"                 => [ 16, "integer" ],
                "Motorola-Canopy-VLIGVID"                 => [ 21, "integer" ],
                "Motorola-Canopy-VLLEARNEN"               => [ 14, "integer" ],
                "Motorola-Canopy-VLMGVID"                 => [ 22, "integer" ],
                "Motorola-Canopy-VLSMMGPASS"              => [ 23, "integer" ],
                "Motorola-WiMAX-Convergence-Sublayer"     => [ 63, "octets" ],
                "Motorola-WiMAX-DNS-Server-IP-Address"    => [ 20, "octets" ],
                "Motorola-WiMAX-EMS-Address"              => [ 31, "ipaddr" ],
                "Motorola-WiMAX-HO-SVC-CLASS"             => [ 35, "octets" ],
                "Motorola-WiMAX-Home-BTS"                 => [ 50, "octets" ],
                "Motorola-WiMAX-Maximum-Commit-Bandwidth" => [ 61, "octets" ],
                "Motorola-WiMAX-Maximum-Total-Bandwidth"  => [ 60, "octets" ],
                "Motorola-WiMAX-MIP-KEY"                  => [ 11, "string" ],
                "Motorola-WiMAX-MIP-MN-HOME-ADDRESS"      => [ 10, "ipaddr" ],
                "Motorola-WiMAX-MIP-SPI"                  => [ 12, "integer" ],
                "Motorola-WiMAX-MN-HA"                    => [ 13, "ipaddr" ],
                "Motorola-WiMAX-Network-Domain-Name"      => [ 30, "string" ],
                "Motorola-WiMAX-NTP-Server"               => [ 34, "octets" ],
                "Motorola-WiMAX-Provisioning-Server"      => [ 32, "string" ],
                "Motorola-WiMAX-Service-Flows"            => [ 64, "string" ],
                "Motorola-WiMAX-User-NAI"                 => [ 22, "string" ],
                "Motorola-WiMAX-VLAN-ID"                  => [ 65, "octets" ],
            },
            166 => {
                "Shiva-Acct-Serv-Switch"  => [ 101, "ipaddr" ],
                "Shiva-Bak-Key"           => [ 41,  "string" ],
                "Shiva-Bandwidth-Trap"    => [ 33,  "integer" ],
                "Shiva-Break-Key"         => [ 39,  "string" ],
                "Shiva-Call-Durn-Trap"    => [ 32,  "integer" ],
                "Shiva-Called-Number"     => [ 90,  "string" ],
                "Shiva-Calling-Number"    => [ 91,  "string" ],
                "Shiva-Circuit-Type"      => [ 61,  "integer" ],
                "Shiva-Compression"       => [ 30,  "integer" ],
                "Shiva-Compression-Type"  => [ 96,  "integer" ],
                "Shiva-Connect-Reason"    => [ 104, "integer" ],
                "Shiva-Customer-Id"       => [ 92,  "string" ],
                "Shiva-Default-Host"      => [ 35,  "string" ],
                "Shiva-DHCP-Leasetime"    => [ 45,  "integer" ],
                "Shiva-Dial-Timeout"      => [ 42,  "integer" ],
                "Shiva-Dialback-Delay"    => [ 31,  "integer" ],
                "Shiva-Disconnect-Reason" => [ 100, "integer" ],
                "Shiva-Event-Flags"       => [ 102, "integer" ],
                "Shiva-Function"          => [ 103, "integer" ],
                "Shiva-Fwd-Key"           => [ 40,  "string" ],
                "Shiva-LAT-Groups"        => [ 46,  "string" ],
                "Shiva-LAT-Port"          => [ 43,  "string" ],
                "Shiva-Link-Protocol"     => [ 97,  "integer" ],
                "Shiva-Link-Speed"        => [ 94,  "integer" ],
                "Shiva-Links-In-Bundle"   => [ 95,  "integer" ],
                "Shiva-Max-VCs"           => [ 44,  "integer" ],
                "Shiva-Menu-Name"         => [ 36,  "string" ],
                "Shiva-Minimum-Call"      => [ 34,  "integer" ],
                "Shiva-Network-Protocols" => [ 98,  "integer" ],
                "Shiva-RTC-Timestamp"     => [ 60,  "integer" ],
                "Shiva-Session-Id"        => [ 99,  "integer" ],
                "Shiva-Termtype"          => [ 38,  "string" ],
                "Shiva-Type-Of-Service"   => [ 93,  "integer" ],
                "Shiva-User-Attributes"   => [ 1,   "string" ],
                "Shiva-User-Flags"        => [ 37,  "string" ],
            },
            171 => {
                "Dlink-1p-Priority"                  => [ 4,  "integer" ],
                "Dlink-ACL-Profile"                  => [ 12, "string" ],
                "Dlink-ACL-Rule"                     => [ 13, "string" ],
                "Dlink-ACL-Script"                   => [ 14, "string" ],
                "Dlink-Egress-Bandwidth-Assignment"  => [ 3,  "integer" ],
                "Dlink-Ingress-Bandwidth-Assignment" => [ 2,  "integer" ],
                "Dlink-User-Level"                   => [ 1,  "integer" ],
                "Dlink-VLAN-ID"                      => [ 11, "string" ],
                "Dlink-VLAN-Name"                    => [ 10, "string" ],
            },
            177 => {
                "NET-Abort-Cause"                => [ 76,  "integer" ],
                "NET-Alert-Time"                 => [ 111, "string" ],
                "NET-Bwd-Flow-In-Dst-Addr"       => [ 24,  "string" ],
                "NET-Bwd-Flow-In-Dst-Port"       => [ 25,  "integer" ],
                "NET-Bwd-Flow-In-Realm"          => [ 21,  "string" ],
                "NET-Bwd-Flow-In-Src-Addr"       => [ 22,  "string" ],
                "NET-Bwd-Flow-In-Src-Port"       => [ 23,  "integer" ],
                "NET-Bwd-Flow-Out-Dst-Addr"      => [ 29,  "string" ],
                "NET-Bwd-Flow-Out-Dst-Port"      => [ 30,  "integer" ],
                "NET-Bwd-Flow-Out-Realm"         => [ 26,  "string" ],
                "NET-Bwd-Flow-Out-Src-Addr"      => [ 27,  "string" ],
                "NET-Bwd-Flow-Out-Src-Port"      => [ 28,  "integer" ],
                "NET-Bwd-Octets"                 => [ 43,  "integer" ],
                "NET-Bwd-Packets"                => [ 44,  "integer" ],
                "NET-Bwd-RTCP-Avg-Jitter"        => [ 46,  "integer" ],
                "NET-Bwd-RTCP-MaxJitter"         => [ 48,  "integer" ],
                "NET-Bwd-RTCP-Packets-Lost"      => [ 45,  "integer" ],
                "NET-Bwd-RTP-Avg-Jitter"         => [ 51,  "integer" ],
                "NET-Bwd-RTP-Avg-Latency"        => [ 47,  "integer" ],
                "NET-Bwd-RTP-MaxJitter"          => [ 52,  "integer" ],
                "NET-Bwd-RTP-MaxLatency"         => [ 49,  "integer" ],
                "NET-Bwd-RTP-Packets-Lost"       => [ 50,  "integer" ],
                "NET-Call-Duration"              => [ 116, "integer" ],
                "NET-Call-Number-Type"           => [ 90,  "string" ],
                "NET-Call-Origin"                => [ 71,  "integer" ],
                "NET-Call-Plan"                  => [ 91,  "string" ],
                "NET-Call-Priority"              => [ 79,  "string" ],
                "NET-Call-Type"                  => [ 70,  "integer" ],
                "NET-Called-Name"                => [ 95,  "string" ],
                "NET-Called-Number"              => [ 73,  "string" ],
                "NET-Calling-Name"               => [ 74,  "string" ],
                "NET-Calling-Number"             => [ 72,  "string" ],
                "NET-Connect-Time"               => [ 112, "string" ],
                "NET-Disconnect-Cause"           => [ 75,  "integer" ],
                "NET-Disconnect-Initiator"       => [ 118, "integer" ],
                "NET-Disconnect-Time"            => [ 113, "string" ],
                "NET-Egress-Channel-Id"          => [ 78,  "string" ],
                "NET-Egress-Channel-Number"      => [ 69,  "integer" ],
                "NET-Egress-Final-Routing-Num"   => [ 67,  "string" ],
                "NET-Egress-Local-Addr"          => [ 134, "string" ],
                "NET-Egress-Net-Interface-Id"    => [ 137, "integer" ],
                "NET-Egress-Remote-Addr"         => [ 135, "string" ],
                "NET-Egress-Signaling-Group"     => [ 65,  "integer" ],
                "NET-Egress-Signaling-Port-Num"  => [ 145, "integer" ],
                "NET-Firmware-Version"           => [ 160, "string" ],
                "NET-Fwd-Flow-In-Dst-Addr"       => [ 14,  "string" ],
                "NET-Fwd-Flow-In-Dst-Port"       => [ 15,  "integer" ],
                "NET-Fwd-Flow-In-Realm"          => [ 11,  "string" ],
                "NET-Fwd-Flow-In-Src-Addr"       => [ 12,  "string" ],
                "NET-Fwd-Flow-In-Src-Port"       => [ 13,  "integer" ],
                "NET-Fwd-Flow-Media-Type"        => [ 31,  "string" ],
                "NET-Fwd-Flow-Out-Dst-Addr"      => [ 19,  "string" ],
                "NET-Fwd-Flow-Out-Dst-Port"      => [ 20,  "integer" ],
                "NET-Fwd-Flow-Out-Realm"         => [ 16,  "string" ],
                "NET-Fwd-Flow-Out-Src-Addr"      => [ 17,  "string" ],
                "NET-Fwd-Flow-Out-Src-Port"      => [ 18,  "integer" ],
                "NET-Fwd-Flow-PTime"             => [ 32,  "integer" ],
                "NET-Fwd-Octets"                 => [ 33,  "integer" ],
                "NET-Fwd-Packets"                => [ 34,  "integer" ],
                "NET-Fwd-RTCP-Avg-Jitter"        => [ 36,  "integer" ],
                "NET-Fwd-RTCP-MaxJitter"         => [ 38,  "integer" ],
                "NET-Fwd-RTCP-Packets-Lost"      => [ 35,  "integer" ],
                "NET-Fwd-RTP-Avg-Jitter"         => [ 41,  "integer" ],
                "NET-Fwd-RTP-Avg-Latency"        => [ 37,  "integer" ],
                "NET-Fwd-RTP-MaxJitter"          => [ 42,  "integer" ],
                "NET-Fwd-RTP-MaxLatency"         => [ 39,  "integer" ],
                "NET-Fwd-RTP-Packets-Lost"       => [ 40,  "integer" ],
                "NET-Gw-Id"                      => [ 162, "string" ],
                "NET-Inbound-Seize-Time"         => [ 114, "string" ],
                "NET-Ingress-Channel-Id"         => [ 77,  "string" ],
                "NET-Ingress-Channel-Number"     => [ 68,  "integer" ],
                "NET-Ingress-Local-Addr"         => [ 132, "string" ],
                "NET-Ingress-Net-Interface-Id"   => [ 136, "integer" ],
                "NET-Ingress-Remote-Addr"        => [ 133, "string" ],
                "NET-Ingress-Signaling-Group"    => [ 64,  "integer" ],
                "NET-Ingress-Signaling-Port-Num" => [ 144, "integer" ],
                "NET-Local-Time-Zone"            => [ 161, "string" ],
                "NET-Log-Time"                   => [ 164, "string" ],
                "NET-Namespace"                  => [ 96,  "string" ],
                "NET-Original-Called-Number"     => [ 92,  "string" ],
                "NET-Original-Called-Plan"       => [ 94,  "string" ],
                "NET-Original-Called-Type"       => [ 93,  "string" ],
                "NET-Outbound-Seize-Time"        => [ 115, "string" ],
                "NET-P-Asserted-ID"              => [ 130, "string" ],
                "NET-P-Preferred-ID"             => [ 147, "string" ],
                "NET-Post-Dial-Delay"            => [ 117, "integer" ],
                "NET-Precedence"                 => [ 97,  "string" ],
                "NET-Presentation"               => [ 98,  "string" ],
                "NET-Primary-Routing-Number"     => [ 66,  "string" ],
                "NET-Redirect-Ip-Address"        => [ 141, "string" ],
                "NET-Redirect-Number"            => [ 140, "string" ],
                "NET-Refer-Call-Transfer-Id"     => [ 138, "string" ],
                "NET-Replaced-Header"            => [ 148, "string" ],
                "NET-Routing-Table-Number"       => [ 63,  "integer" ],
                "NET-Screening"                  => [ 99,  "string" ],
                "NET-Session-Egress-CallId"      => [ 61,  "integer" ],
                "NET-Session-Egress-Realm"       => [ 143, "string" ],
                "NET-Session-Forked-Call-Id"     => [ 139, "string" ],
                "NET-Session-Generic-Id"         => [ 62,  "integer" ],
                "NET-Session-Ingress-CallId"     => [ 60,  "integer" ],
                "NET-Session-Ingress-Realm"      => [ 142, "string" ],
                "NET-Setup-Time"                 => [ 110, "string" ],
                "NET-SIP-Diversion"              => [ 131, "string" ],
                "NET-Time-And-Day"               => [ 163, "string" ],
                "NET-Transfer-Capability"        => [ 100, "string" ],
                "NET-Transfer-Mode"              => [ 101, "string" ],
                "NET-Transfer-Rate"              => [ 102, "string" ],
                "NET-Transport-Type"             => [ 146, "integer" ],
                "NET-User-Rate"                  => [ 103, "string" ],
            },
            193 => {
                "Ericsson-ViG-Access-Agent-IP-Address"  => [ 11,  "ipaddr" ],
                "Ericsson-ViG-Access-Agent-name"        => [ 60,  "string" ],
                "Ericsson-ViG-Access-Group-name"        => [ 59,  "string" ],
                "Ericsson-ViG-Access-type"              => [ 86,  "integer" ],
                "Ericsson-ViG-Account-error-reason"     => [ 33,  "integer" ],
                "Ericsson-ViG-Alive-Indicator"          => [ 43,  "integer" ],
                "Ericsson-ViG-Allowed-bandwidth"        => [ 88,  "integer" ],
                "Ericsson-ViG-Auth-DataRequest"         => [ 125, "integer" ],
                "Ericsson-ViG-Authentication-type"      => [ 37,  "integer" ],
                "Ericsson-ViG-Balance"                  => [ 3,   "integer" ],
                "Ericsson-ViG-Business-Agreement-Name"  => [ 16,  "string" ],
                "Ericsson-ViG-Call-Role"                => [ 17,  "integer" ],
                "Ericsson-ViG-Called-ID"                => [ 112, "string" ],
                "Ericsson-ViG-Called-Usr-Group-ID"      => [ 116, "string" ],
                "Ericsson-ViG-Called-Usr-Sub-Group-ID"  => [ 117, "string" ],
                "Ericsson-ViG-Calling-e164-number"      => [ 49,  "string" ],
                "Ericsson-ViG-Calling-Email-address"    => [ 51,  "string" ],
                "Ericsson-ViG-Calling-H323Id"           => [ 50,  "string" ],
                "Ericsson-ViG-Calling-ID"               => [ 111, "string" ],
                "Ericsson-ViG-Calling-User-Group-ID"    => [ 114, "string" ],
                "Ericsson-ViG-Calling-Usr-Sub-Group-ID" => [ 115, "string" ],
                "Ericsson-ViG-Charging-Case"            => [ 98,  "integer" ],
                "Ericsson-ViG-Codec"                    => [ 4,   "integer" ],
                "Ericsson-ViG-CPN-digits"               => [ 65,  "string" ],
                "Ericsson-ViG-CPN-NP"                   => [ 67,  "integer" ],
                "Ericsson-ViG-CPN-PI"                   => [ 68,  "integer" ],
                "Ericsson-ViG-CPN-SI"                   => [ 69,  "integer" ],
                "Ericsson-ViG-CPN-TON"                  => [ 66,  "integer" ],
                "Ericsson-ViG-Currency"                 => [ 5,   "string" ],
                "Ericsson-ViG-Currency-Quote"           => [ 6,   "string" ],
                "Ericsson-ViG-Data-media-rec-backward"  => [ 97,  "string" ],
                "Ericsson-ViG-Data-media-rec-forward"   => [ 96,  "string" ],
                "Ericsson-ViG-Dialled-e164-number"      => [ 52,  "string" ],
                "Ericsson-ViG-Dialled-Email-address"    => [ 54,  "string" ],
                "Ericsson-ViG-Dialled-H323Id"           => [ 53,  "string" ],
                "Ericsson-ViG-Dialled-num-digits"       => [ 70,  "string" ],
                "Ericsson-ViG-Dialled-num-NP"           => [ 72,  "integer" ],
                "Ericsson-ViG-Dialled-num-TON"          => [ 71,  "integer" ],
                "Ericsson-ViG-Digest-Attributes"        => [ 15,  "octets" ],
                "Ericsson-ViG-Digest-Response"          => [ 14,  "string" ],
                "Ericsson-ViG-Emergency-Call-Indicator" => [ 110, "integer" ],
                "Ericsson-ViG-Endpoint-Type"            => [ 8,   "integer" ],
                "Ericsson-ViG-Fax-media-rec-backward"   => [ 95,  "string" ],
                "Ericsson-ViG-Fax-media-rec-forward"    => [ 94,  "string" ],
                "Ericsson-ViG-Global-unique-call-ID"    => [ 40,  "string" ],
                "Ericsson-ViG-Global-unique-service-ID" => [ 41,  "string" ],
                "Ericsson-ViG-Interim-interval"         => [ 42,  "integer" ],
                "Ericsson-ViG-Internal-Rel-reason-orig" => [ 105, "integer" ],
                "Ericsson-ViG-Internal-Rel-reason-val"  => [ 104, "integer" ],
                "Ericsson-ViG-IPT-Time-Stamp"           => [ 126, "integer" ],
                "Ericsson-ViG-Layer-identity"           => [ 34,  "integer" ],
                "Ericsson-ViG-Major-protocol-version"   => [ 35,  "integer" ],
                "Ericsson-ViG-Media-channel-count"      => [ 89,  "integer" ],
                "Ericsson-ViG-Minor-protocol-version"   => [ 36,  "integer" ],
                "Ericsson-ViG-Proxy-IP-Address"         => [ 124, "ipaddr" ],
                "Ericsson-ViG-QoS-Class"                => [ 12,  "integer" ],
                "Ericsson-ViG-Re-selection-counter"     => [ 64,  "integer" ],
                "Ericsson-ViG-Redirecting-num-digits"   => [ 76,  "string" ],
                "Ericsson-ViG-Redirecting-num-NP"       => [ 78,  "integer" ],
                "Ericsson-ViG-Redirecting-num-PI"       => [ 79,  "integer" ],
                "Ericsson-ViG-Redirecting-num-RFD"      => [ 80,  "integer" ],
                "Ericsson-ViG-Redirecting-num-TON"      => [ 77,  "integer" ],
                "Ericsson-ViG-Rel-cause-class"          => [ 101, "integer" ],
                "Ericsson-ViG-Rel-cause-coding-std"     => [ 99,  "integer" ],
                "Ericsson-ViG-Rel-cause-location"       => [ 100, "integer" ],
                "Ericsson-ViG-Rel-cause-value"          => [ 102, "integer" ],
                "Ericsson-ViG-Rel-reason"               => [ 103, "integer" ],
                "Ericsson-ViG-Remote-SK-UA-IP-Address"  => [ 20,  "ipaddr" ],
                "Ericsson-ViG-Requested-bandwidth"      => [ 87,  "integer" ],
                "Ericsson-ViG-Routed-e164-number"       => [ 55,  "string" ],
                "Ericsson-ViG-Routed-Email-address"     => [ 57,  "string" ],
                "Ericsson-ViG-Routed-H323Id"            => [ 56,  "string" ],
                "Ericsson-ViG-Routing-num-digits"       => [ 73,  "string" ],
                "Ericsson-ViG-Routing-num-NP"           => [ 75,  "integer" ],
                "Ericsson-ViG-Routing-num-TON"          => [ 74,  "integer" ],
                "Ericsson-ViG-Routing-tariff"           => [ 63,  "integer" ],
                "Ericsson-ViG-SA-IP-address"            => [ 48,  "ipaddr" ],
                "Ericsson-ViG-Sequence-Number"          => [ 9,   "integer" ],
                "Ericsson-ViG-Service-Description"      => [ 122, "string" ],
                "Ericsson-ViG-Service-Duration"         => [ 119, "integer" ],
                "Ericsson-ViG-Service-Exe-Rslt-Desc"    => [ 121, "string" ],
                "Ericsson-ViG-Service-Execution-Result" => [ 120, "integer" ],
                "Ericsson-ViG-Service-ID"               => [ 106, "integer" ],
                "Ericsson-ViG-Service-Name"             => [ 108, "string" ],
                "Ericsson-ViG-Service-Specific-Info"    => [ 123, "string" ],
                "Ericsson-ViG-Session-ringing-duration" => [ 85,  "integer" ],
                "Ericsson-ViG-Session-routing-duration" => [ 84,  "integer" ],
                "Ericsson-ViG-Site"                     => [ 23,  "string" ],
                "Ericsson-ViG-SiteKeeper-name"          => [ 58,  "string" ],
                "Ericsson-ViG-SK-IP-address"            => [ 46,  "ipaddr" ],
                "Ericsson-ViG-Terminal-Type"            => [ 118, "string" ],
                "Ericsson-ViG-Test-Call-Indicator"      => [ 109, "integer" ],
                "Ericsson-ViG-Time-stamp-DST"           => [ 83,  "integer" ],
                "Ericsson-ViG-Time-stamp-TZ"            => [ 82,  "integer" ],
                "Ericsson-ViG-Time-stamp-UTC"           => [ 81,  "integer" ],
                "Ericsson-ViG-Translated-ID"            => [ 113, "string" ],
                "Ericsson-ViG-Trusted-access"           => [ 38,  "integer" ],
                "Ericsson-ViG-TTL-Absolute"             => [ 44,  "integer" ],
                "Ericsson-ViG-TTL-relative"             => [ 32,  "integer" ],
                "Ericsson-ViG-TTL-Start-Event"          => [ 45,  "integer" ],
                "Ericsson-ViG-UA-IP-address"            => [ 47,  "ipaddr" ],
                "Ericsson-ViG-User-agent-group-name"    => [ 61,  "string" ],
                "Ericsson-ViG-User-agent-name"          => [ 62,  "string" ],
                "Ericsson-ViG-User-ID"                  => [ 107, "string" ],
                "Ericsson-ViG-User-name"                => [ 39,  "string" ],
                "Ericsson-ViG-User-Name-Info"           => [ 127, "integer" ],
                "Ericsson-ViG-Video-media-rec-backward" => [ 93,  "string" ],
                "Ericsson-ViG-Video-media-rec-forward"  => [ 92,  "string" ],
                "Ericsson-ViG-Voice-media-rec-backward" => [ 91,  "string" ],
                "Ericsson-ViG-Voice-media-rec-forward"  => [ 90,  "string" ],
            },
            244 => { "Lantronix-User-Attributes" => [ 1, "string" ] },
            255 => {},
            266 => {
                "Nexans-Port-Default-VLAN-ID" => [ 1, "integer" ],
                "Nexans-Port-Voice-VLAN-ID"   => [ 2, "integer" ],
            },
            272 => {
                "BinTec-biboDialTable"       => [ 225, "string" ],
                "BinTec-biboPPPTable"        => [ 224, "string" ],
                "BinTec-ipExtIfTable"        => [ 226, "string" ],
                "BinTec-ipExtRtTable"        => [ 228, "string" ],
                "BinTec-ipFilterTable"       => [ 237, "string" ],
                "BinTec-ipNatPresetTable"    => [ 229, "string" ],
                "BinTec-ipQoSTable"          => [ 238, "string" ],
                "BinTec-ipRouteTable"        => [ 227, "string" ],
                "BinTec-ipxCircTable"        => [ 230, "string" ],
                "BinTec-ipxStaticRouteTable" => [ 233, "string" ],
                "BinTec-ipxStaticServTable"  => [ 234, "string" ],
                "BinTec-ospfIfTable"         => [ 235, "string" ],
                "BinTec-pppExtIfTable"       => [ 236, "string" ],
                "BinTec-qosIfTable"          => [ 239, "string" ],
                "BinTec-qosPolicyTable"      => [ 240, "string" ],
                "BinTec-ripCircTable"        => [ 231, "string" ],
                "BinTec-sapCircTable"        => [ 232, "string" ],
            },
            307 => {
                "LE-Admin-Group"               => [ 22, "string" ],
                "LE-Advice-of-Charge"          => [ 3,  "string" ],
                "LE-Connect-Detail"            => [ 4,  "string" ],
                "LE-IP-Gateway"                => [ 7,  "ipaddr" ],
                "LE-IP-Pool"                   => [ 6,  "string" ],
                "LE-IPSec-Active-Profile"      => [ 11, "string" ],
                "LE-IPSec-Deny-Action"         => [ 10, "integer" ],
                "LE-IPSec-Log-Options"         => [ 9,  "integer" ],
                "LE-IPSec-Outsource-Profile"   => [ 12, "string" ],
                "LE-IPSec-Passive-Profile"     => [ 13, "string" ],
                "LE-Modem-Info"                => [ 8,  "string" ],
                "LE-Multicast-Client"          => [ 23, "integer" ],
                "LE-NAT-Inmap"                 => [ 18, "string" ],
                "LE-NAT-Log-Options"           => [ 16, "integer" ],
                "LE-NAT-Other-Session-Timeout" => [ 15, "integer" ],
                "LE-NAT-Outmap"                => [ 19, "string" ],
                "LE-NAT-Outsource-Inmap"       => [ 20, "string" ],
                "LE-NAT-Outsource-Outmap"      => [ 21, "string" ],
                "LE-NAT-Sess-Dir-Fail-Action"  => [ 17, "integer" ],
                "LE-NAT-TCP-Session-Timeout"   => [ 14, "integer" ],
                "LE-Terminate-Detail"          => [ 2,  "string" ],
            },
            311 => {
                "MS-Acct-Auth-Type"              => [ 23, "integer" ],
                "MS-Acct-EAP-Type"               => [ 24, "integer" ],
                "MS-AFW-Protection-Level"        => [ 49, "integer" ],
                "MS-AFW-Zone"                    => [ 48, "integer" ],
                "MS-ARAP-PW-Change-Reason"       => [ 21, "integer" ],
                "MS-BAP-Usage"                   => [ 13, "integer" ],
                "MS-CHAP-Challenge"              => [ 11, "octets" ],
                "MS-CHAP-CPW-1"                  => [ 3,  "octets" ],
                "MS-CHAP-CPW-2"                  => [ 4,  "octets" ],
                "MS-CHAP-Domain"                 => [ 10, "string" ],
                "MS-CHAP-Error"                  => [ 2,  "string" ],
                "MS-CHAP-LM-Enc-PW"              => [ 5,  "octets" ],
                "MS-CHAP-MPPE-Keys"              => [ 12, "octets" ],
                "MS-CHAP-NT-Enc-PW"              => [ 6,  "octets" ],
                "MS-CHAP-Response"               => [ 1,  "octets" ],
                "MS-CHAP2-CPW"                   => [ 27, "octets" ],
                "MS-CHAP2-Response"              => [ 25, "octets" ],
                "MS-CHAP2-Success"               => [ 26, "octets" ],
                "MS-Extended-Quarantine-State"   => [ 57, "integer" ],
                "MS-Filter"                      => [ 22, "octets" ],
                "MS-HCAP-Location-Group-Name"    => [ 59, "string" ],
                "MS-HCAP-User-Groups"            => [ 58, "string" ],
                "MS-HCAP-User-Name"              => [ 60, "string" ],
                "MS-Identity-Type"               => [ 41, "integer" ],
                "MS-IPv4-Remediation-Servers"    => [ 52, "octets" ],
                "MS-IPv6-Filter"                 => [ 51, "octets" ],
                "MS-IPv6-Remediation-Servers"    => [ 53, "octets" ],
                "MS-Link-Drop-Time-Limit"        => [ 15, "integer" ],
                "MS-Link-Utilization-Threshold"  => [ 14, "integer" ],
                "MS-Machine-Name"                => [ 50, "string" ],
                "MS-MPPE-Encryption-Policy"      => [ 7,  "integer" ],
                "MS-MPPE-Encryption-Type"        => [ 8,  "integer" ],
                "MS-MPPE-Encryption-Types"       => [ 8,  "integer" ],
                "MS-MPPE-Recv-Key"               => [ 17, "octets" ],
                "MS-MPPE-Send-Key"               => [ 16, "octets" ],
                "MS-Network-Access-Server-Type"  => [ 47, "integer" ],
                "MS-New-ARAP-Password"           => [ 20, "octets" ],
                "MS-Old-ARAP-Password"           => [ 19, "octets" ],
                "MS-Primary-DNS-Server"          => [ 28, "ipaddr" ],
                "MS-Primary-NBNS-Server"         => [ 30, "ipaddr" ],
                "MS-Quarantine-Grace-Time"       => [ 46, "integer" ],
                "MS-Quarantine-IPFilter"         => [ 36, "octets" ],
                "MS-Quarantine-Session-Timeout"  => [ 37, "integer" ],
                "MS-Quarantine-SOH"              => [ 55, "octets" ],
                "MS-Quarantine-State"            => [ 45, "integer" ],
                "MS-Quarantine-User-Class"       => [ 44, "string" ],
                "MS-RAS-Client-Name"             => [ 34, "string" ],
                "MS-RAS-Client-Version"          => [ 35, "string" ],
                "MS-RAS-Correlation"             => [ 56, "octets" ],
                "MS-RAS-Vendor"                  => [ 9,  "integer" ],
                "MS-RAS-Version"                 => [ 18, "string" ],
                "MS-RNAP-Not-Quarantine-Capable" => [ 54, "integer" ],
                "MS-Secondary-DNS-Server"        => [ 29, "ipaddr" ],
                "MS-Secondary-NBNS-Server"       => [ 31, "ipaddr" ],
                "MS-Service-Class"               => [ 42, "string" ],
                "MS-TSG-Device-Redirection"      => [ 63, "integer" ],
                "MS-User-IPv4-Address"           => [ 61, "ipaddr" ],
                "MS-User-IPv6-Address"           => [ 62, "ipv6addr" ],
                "MS-User-Security-Identity"      => [ 40, "string" ],
            },
            318 => {
                "APC-ACCPX-Access1" => [ 8,  "string" ],
                "APC-ACCPX-Access2" => [ 9,  "string" ],
                "APC-ACCPX-Access3" => [ 10, "string" ],
                "APC-ACCPX-Access4" => [ 11, "string" ],
                "APC-ACCPX-Access5" => [ 12, "string" ],
                "APC-ACCPX-Access6" => [ 13, "string" ],
                "APC-ACCPX-Access7" => [ 14, "string" ],
                "APC-ACCPX-Doors"   => [ 6,  "string" ],
                "APC-ACCPX-Status"  => [ 7,  "string" ],
                "APC-Contact"       => [ 5,  "string" ],
                "APC-Outlets"       => [ 2,  "string" ],
                "APC-Perms"         => [ 3,  "string" ],
                "APC-Service-Type"  => [ 1,  "integer" ],
                "APC-Username"      => [ 4,  "string" ],
            },
            388 => {
                "Symbol-Admin-Role"       => [ 1,   "integer" ],
                "Symbol-Allowed-ESSID"    => [ 3,   "string" ],
                "Symbol-Allowed-Radio"    => [ 6,   "string" ],
                "Symbol-Current-ESSID"    => [ 2,   "string" ],
                "Symbol-Downlink-Limit"   => [ 10,  "string" ],
                "Symbol-Expiry-Date-Time" => [ 7,   "string" ],
                "Symbol-Login-Source"     => [ 100, "integer" ],
                "Symbol-Posture-Status"   => [ 9,   "string" ],
                "Symbol-QoS-Profile"      => [ 5,   "integer" ],
                "Symbol-Start-Date-Time"  => [ 8,   "string" ],
                "Symbol-Uplink-Limit"     => [ 11,  "string" ],
                "Symbol-User-Group"       => [ 12,  "string" ],
                "Symbol-WLAN-Index"       => [ 4,   "integer" ],
            },
            429 => {
                "CW-Account-Id"                    => [ 32769, "string" ],
                "CW-Acct-Balance-Decr-Curr"        => [ 32834, "integer" ],
                "CW-Acct-Balance-Start-Amt"        => [ 32832, "integer" ],
                "CW-Acct-Balance-Start-Curr"       => [ 32831, "integer" ],
                "CW-Acct-Balance-Start-Dec"        => [ 32833, "integer" ],
                "CW-Acct-Identification-Code"      => [ 32771, "integer" ],
                "CW-Acct-Type"                     => [ 32770, "integer" ],
                "CW-ARQ-Token"                     => [ 32836, "string" ],
                "CW-Audio-Bytes-In-Frame"          => [ 32827, "integer" ],
                "CW-Audio-Packets-In-Frame"        => [ 32826, "integer" ],
                "CW-Audio-Packets-Lost"            => [ 32825, "integer" ],
                "CW-Audio-Packets-Received"        => [ 32824, "integer" ],
                "CW-Audio-Packets-Sent"            => [ 32823, "integer" ],
                "CW-Audio-Signal-In-Packet"        => [ 32828, "integer" ],
                "CW-Authentication-Fail-Cnt"       => [ 32779, "integer" ],
                "CW-Call-Durn-Connect-Disc"        => [ 32820, "integer" ],
                "CW-Call-End-Time-Msec"            => [ 32819, "integer" ],
                "CW-Call-End-Time-Sec"             => [ 32818, "string" ],
                "CW-Call-Identifier"               => [ 32812, "string" ],
                "CW-Call-Model"                    => [ 32863, "integer" ],
                "CW-Call-Plan-Id"                  => [ 32864, "integer" ],
                "CW-Call-Start-Ingr-GW-Msec"       => [ 32815, "integer" ],
                "CW-Call-Start-Ingr-GW-Sec"        => [ 32814, "string" ],
                "CW-Call-Start-Time-Ans-Msec"      => [ 32817, "integer" ],
                "CW-Call-Start-Time-Ans-Sec"       => [ 32816, "string" ],
                "CW-Call-Termination-Cause"        => [ 32822, "integer" ],
                "CW-Call-Type"                     => [ 32813, "integer" ],
                "CW-Cld-Party-E164-Number"         => [ 32787, "string" ],
                "CW-Cld-Party-E164-Type"           => [ 32786, "integer" ],
                "CW-Cld-Party-Trans-DNS"           => [ 32791, "string" ],
                "CW-Cld-Party-Trans-IP"            => [ 32790, "ipaddr" ],
                "CW-Cld-Party-Trans-Port"          => [ 32789, "integer" ],
                "CW-Cld-Party-Trans-Protocol"      => [ 32788, "integer" ],
                "CW-Clg-Party-E164-Number"         => [ 32781, "string" ],
                "CW-Clg-Party-E164-Type"           => [ 32780, "integer" ],
                "CW-Clg-Party-Trans-DNS"           => [ 32785, "string" ],
                "CW-Clg-Party-Trans-IP"            => [ 32784, "ipaddr" ],
                "CW-Clg-Party-Trans-Port"          => [ 32783, "integer" ],
                "CW-Clg-Party-Trans-Protocol"      => [ 32782, "integer" ],
                "CW-Codec-Type"                    => [ 32821, "integer" ],
                "CW-Egr-Gtkpr-Trans-DNS"           => [ 32811, "string" ],
                "CW-Egr-Gtkpr-Trans-IP"            => [ 32810, "ipaddr" ],
                "CW-Egr-Gtkpr-Trans-Port"          => [ 32809, "integer" ],
                "CW-Egr-Gtkpr-Trans-Protocol"      => [ 32808, "integer" ],
                "CW-Egr-Gway-Trans-DNS"            => [ 32803, "string" ],
                "CW-Egr-Gway-Trans-IP"             => [ 32802, "ipaddr" ],
                "CW-Egr-Gway-Trans-Port"           => [ 32801, "integer" ],
                "CW-Egr-Gway-Trans-Protocol"       => [ 32800, "integer" ],
                "CW-Ingr-Gtkpr-Trans-DNS"          => [ 32807, "string" ],
                "CW-Ingr-Gtkpr-Trans-IP"           => [ 32806, "ipaddr" ],
                "CW-Ingr-Gtkpr-Trans-Port"         => [ 32805, "integer" ],
                "CW-Ingr-Gtkpr-Trans-Protocol"     => [ 32804, "integer" ],
                "CW-Ingr-Gway-E164-Number"         => [ 32795, "string" ],
                "CW-Ingr-Gway-E164-Type"           => [ 32794, "integer" ],
                "CW-Ingr-Gway-Trans-DNS"           => [ 32799, "string" ],
                "CW-Ingr-Gway-Trans-IP"            => [ 32798, "ipaddr" ],
                "CW-Ingr-Gway-Trans-Port"          => [ 32797, "integer" ],
                "CW-Ingr-Gway-Trans-Protocol"      => [ 32796, "integer" ],
                "CW-Local-MG-RTP-DNS"              => [ 32858, "string" ],
                "CW-Local-MG-RTP-IP"               => [ 32857, "ipaddr" ],
                "CW-Local-MG-RTP-Port"             => [ 32856, "integer" ],
                "CW-Local-MG-RTP-Protocol"         => [ 32855, "integer" ],
                "CW-Local-Sig-Trans-DNS"           => [ 32850, "string" ],
                "CW-Local-Sig-Trans-IP"            => [ 32849, "ipaddr" ],
                "CW-Local-Sig-Trans-Port"          => [ 32848, "integer" ],
                "CW-Local-Sig-Trans-Protocol"      => [ 32847, "integer" ],
                "CW-LRQ-Token"                     => [ 32835, "string" ],
                "CW-MG-Id"                         => [ 32844, "integer" ],
                "CW-MGC-Id"                        => [ 32843, "integer" ],
                "CW-Num-Call-Attempt-Session"      => [ 32776, "integer" ],
                "CW-Orig-Line-Identifier"          => [ 32792, "integer" ],
                "CW-OSP-Source-Device"             => [ 32867, "string" ],
                "CW-Port-Id-For-Call"              => [ 32829, "integer" ],
                "CW-Protocol-Transport"            => [ 32846, "integer" ],
                "CW-PSTN-Interface-Number"         => [ 32793, "integer" ],
                "CW-Rate-Plan-Id"                  => [ 32773, "integer" ],
                "CW-Remote-MG-RTP-DNS"             => [ 32862, "string" ],
                "CW-Remote-MG-RTP-IP"              => [ 32861, "ipaddr" ],
                "CW-Remote-MG-RTP-Port"            => [ 32860, "integer" ],
                "CW-Remote-MG-RTP-Protocol"        => [ 32859, "integer" ],
                "CW-Remote-Sig-Trans-DNS"          => [ 32854, "string" ],
                "CW-Remote-Sig-Trans-IP"           => [ 32853, "ipaddr" ],
                "CW-Remote-Sig-Trans-Port"         => [ 32852, "integer" ],
                "CW-Remote-Sig-Trans-Protocol"     => [ 32851, "integer" ],
                "CW-Service-Type"                  => [ 32772, "integer" ],
                "CW-Session-Id"                    => [ 32775, "string" ],
                "CW-Session-Sequence-End"          => [ 32778, "integer" ],
                "CW-Session-Sequence-Num"          => [ 32777, "integer" ],
                "CW-Signaling-Protocol"            => [ 32845, "integer" ],
                "CW-Slot-Id-For-Call"              => [ 32830, "integer" ],
                "CW-Source-Identifier"             => [ 32774, "integer" ],
                "CW-SS7-CIC"                       => [ 32842, "integer" ],
                "CW-SS7-Destn-Ptcode-Address"      => [ 32839, "integer" ],
                "CW-SS7-Destn-Ptcode-Type"         => [ 32838, "integer" ],
                "CW-SS7-Orig-Ptcode-Address"       => [ 32841, "integer" ],
                "CW-SS7-Orig-Ptcode-Type"          => [ 32840, "integer" ],
                "CW-Token-Status"                  => [ 32837, "integer" ],
                "CW-Trans-Cld-Party-E164-Num"      => [ 32866, "string" ],
                "CW-Trans-Cld-Party-E164-Type"     => [ 32865, "integer" ],
                "CW-Version-Id"                    => [ 32768, "integer" ],
                "Initial-Modulation-Type"          => [ 2339,  "integer" ],
                "USR-ACCM-Type"                    => [ 36898, "integer" ],
                "USR-Acct-Reason-Code"             => [ 39020, "integer" ],
                "USR-Actual-Voltage"               => [ 48946, "integer" ],
                "USR-Agent"                        => [ 39030, "integer" ],
                "USR-Appletalk"                    => [ 38927, "integer" ],
                "USR-Appletalk-Network-Range"      => [ 38948, "integer" ],
                "USR-AT-Call-Input-Filter"         => [ 38964, "string" ],
                "USR-AT-Call-Output-Filter"        => [ 38973, "string" ],
                "USR-AT-Input-Filter"              => [ 38961, "string" ],
                "USR-AT-Output-Filter"             => [ 38970, "string" ],
                "USR-AT-RTMP-Input-Filter"         => [ 38962, "string" ],
                "USR-AT-RTMP-Output-Filter"        => [ 38971, "string" ],
                "USR-AT-Zip-Input-Filter"          => [ 38963, "string" ],
                "USR-AT-Zip-Output-Filter"         => [ 38972, "string" ],
                "USR-Auth-Mode"                    => [ 61443, "integer" ],
                "USR-Auth-Next-Server-Address"     => [ 39054, "ipaddr" ],
                "USR-Back-Channel-Data-Rate"       => [ 124,   "integer" ],
                "USR-Bearer-Capabilities"          => [ 38912, "integer" ],
                "USR-Block-Error-Count-Limit"      => [ 192,   "integer" ],
                "USR-Blocks-Received"              => [ 118,   "integer" ],
                "USR-Blocks-Resent"                => [ 119,   "integer" ],
                "USR-Blocks-Sent"                  => [ 117,   "integer" ],
                "USR-Bridging"                     => [ 38928, "integer" ],
                "USR-Bytes-RX-Remain"              => [ 39072, "integer" ],
                "USR-Bytes-TX-Remain"              => [ 39071, "integer" ],
                "USR-Call-Arrival-in-GMT"          => [ 48722, "date" ],
                "USR-Call-Arrival-Time"            => [ 39000, "integer" ],
                "USR-Call-Connect-in-GMT"          => [ 48721, "date" ],
                "USR-Call-Connecting-Time"         => [ 2205,  "integer" ],
                "USR-Call-End-Date-Time"           => [ 49142, "date" ],
                "USR-Call-End-Time"                => [ 39001, "integer" ],
                "USR-Call-Error-Code"              => [ 2203,  "integer" ],
                "USR-Call-Event-Code"              => [ 48738, "integer" ],
                "USR-Call-Reference-Number"        => [ 48765, "integer" ],
                "USR-Call-Start-Date-Time"         => [ 49143, "date" ],
                "USR-Call-Terminate-in-GMT"        => [ 48720, "date" ],
                "USR-Call-Type"                    => [ 2193,  "integer" ],
                "USR-Callback-Type"                => [ 39018, "integer" ],
                "USR-Called-Party-Number"          => [ 2192,  "string" ],
                "USR-Calling-Party-Number"         => [ 2191,  "string" ],
                "USR-Card-Type"                    => [ 48773, "integer" ],
                "USR-CCP-Algorithm"                => [ 36897, "integer" ],
                "USR-CDMA-Call-Reference-Number"   => [ 387,   "integer" ],
                "USR-CDMA-PktData-Network-ID"      => [ 39053, "integer" ],
                "USR-Channel"                      => [ 48952, "integer" ],
                "USR-Channel-Connected-To"         => [ 48733, "integer" ],
                "USR-Channel-Decrement"            => [ 38916, "integer" ],
                "USR-Channel-Expansion"            => [ 38915, "integer" ],
                "USR-Characters-Received"          => [ 114,   "integer" ],
                "USR-Characters-Sent"              => [ 113,   "integer" ],
                "USR-Chassis-Call-Channel"         => [ 36891, "integer" ],
                "USR-Chassis-Call-Slot"            => [ 36889, "integer" ],
                "USR-Chassis-Call-Span"            => [ 36890, "integer" ],
                "USR-Chassis-Slot"                 => [ 48953, "integer" ],
                "USR-Chassis-Temp-Threshold"       => [ 48772, "integer" ],
                "USR-Chassis-Temperature"          => [ 48945, "integer" ],
                "USR-Chat-Script-Name"             => [ 39013, "string" ],
                "USR-Compression-Algorithm"        => [ 38918, "integer" ],
                "USR-Compression-Reset-Mode"       => [ 38922, "integer" ],
                "USR-Compression-Type"             => [ 2202,  "integer" ],
                "USR-Connect-Speed"                => [ 36899, "integer" ],
                "USR-Connect-Term-Reason"          => [ 155,   "integer" ],
                "USR-Connect-Time"                 => [ 2206,  "integer" ],
                "USR-Connect-Time-Limit"           => [ 49127, "integer" ],
                "USR-CUSR-hat-Script-Rules"        => [ 39014, "string" ],
                "USR-Default-DTE-Data-Rate"        => [ 94,    "integer" ],
                "USR-Device-Connected-To"          => [ 48735, "integer" ],
                "USR-Disconnect-Cause-Indicator"   => [ 2198,  "integer" ],
                "USR-DNIS-ReAuthentication"        => [ 39029, "integer" ],
                "USR-DS0"                          => [ 48739, "integer" ],
                "USR-DS0s"                         => [ 48740, "string" ],
                "USR-DTE-Data-Idle-Timout"         => [ 72,    "integer" ],
                "USR-DTE-Ring-No-Answer-Limit"     => [ 48919, "integer" ],
                "USR-DTR-False-Timeout"            => [ 190,   "integer" ],
                "USR-DTR-True-Timeout"             => [ 218,   "integer" ],
                "USR-Dvmrp-Advertised-Metric"      => [ 39034, "integer" ],
                "USR-Dvmrp-Initial-Flooding"       => [ 39050, "integer" ],
                "USR-Dvmrp-Input-Filter"           => [ 39038, "string" ],
                "USR-Dvmrp-Non-Pruners"            => [ 39036, "integer" ],
                "USR-Dvmrp-Output-Filter"          => [ 39040, "string" ],
                "USR-Dvmrp-Prune-Lifetime"         => [ 39032, "integer" ],
                "USR-Dvmrp-Retransmit-Prunes"      => [ 39035, "integer" ],
                "USR-Dvmrp-Route-Transit"          => [ 39037, "integer" ],
                "USR-End-Time"                     => [ 38934, "integer" ],
                "USR-Equalization-Type"            => [ 111,   "integer" ],
                "USR-ESN"                          => [ 2194,  "string" ],
                "USR-ET-Bridge-Call-Output-Filte"  => [ 38975, "string" ],
                "USR-ET-Bridge-Input-Filter"       => [ 38965, "string" ],
                "USR-ET-Bridge-Output-Filter"      => [ 38974, "string" ],
                "USR-Event-Date-Time"              => [ 48943, "date" ],
                "USR-Event-Id"                     => [ 49086, "integer" ],
                "USR-Expansion-Algorithm"          => [ 38917, "integer" ],
                "USR-Expected-Voltage"             => [ 48947, "integer" ],
                "USR-Failure-to-Connect-Reason"    => [ 105,   "integer" ],
                "USR-Fallback-Enabled"             => [ 112,   "integer" ],
                "USR-Fallback-Limit"               => [ 191,   "integer" ],
                "USR-Filter-Zones"                 => [ 38926, "integer" ],
                "USR-Final-Rx-Link-Data-Rate"      => [ 48940, "integer" ],
                "USR-Final-Tx-Link-Data-Rate"      => [ 107,   "integer" ],
                "USR-FQ-Default-Priority"          => [ 39025, "integer" ],
                "USR-Framed-IPX-Route"             => [ 36903, "ipaddr" ],
                "USR-Framed_IP_Address_Pool_Name"  => [ 36900, "string" ],
                "USR-Gateway-IP-Address"           => [ 48742, "ipaddr" ],
                "USR-HARC-Disconnect-Code"         => [ 39051, "integer" ],
                "USR-Host-Type"                    => [ 38930, "integer" ],
                "USR-IDS0-Call-Type"               => [ 48719, "integer" ],
                "USR-IGMP-Maximum-Response-Time"   => [ 38994, "integer" ],
                "USR-IGMP-Query-Interval"          => [ 38993, "integer" ],
                "USR-IGMP-Robustness"              => [ 38995, "integer" ],
                "USR-IGMP-Routing"                 => [ 38997, "integer" ],
                "USR-IGMP-Version"                 => [ 38996, "integer" ],
                "USR-IMSI"                         => [ 2196,  "string" ],
                "USR-Init-Reg-Server-Addr"         => [ 39069, "ipaddr" ],
                "USR-Initial-Rx-Link-Data-Rate"    => [ 48941, "integer" ],
                "USR-Initial-Tx-Link-Data-Rate"    => [ 106,   "integer" ],
                "USR-Interface-Index"              => [ 38979, "integer" ],
                "USR-IP"                           => [ 38924, "integer" ],
                "USR-IP-Call-Input-Filter"         => [ 38957, "string" ],
                "USR-IP-Call-Output-Filter"        => [ 38967, "string" ],
                "USR-IP-Default-Route-Option"      => [ 38976, "integer" ],
                "USR-IP-RIP-Input-Filter"          => [ 38956, "string" ],
                "USR-IP-RIP-Output-Filter"         => [ 38966, "string" ],
                "USR-IP-RIP-Policies"              => [ 38954, "integer" ],
                "USR-IP-RIP-Simple-Auth-Password"  => [ 38955, "string" ],
                "USR-IP-SAA-Filter"                => [ 39024, "integer" ],
                "USR-IPP-Enable"                   => [ 39026, "integer" ],
                "USR-IPX"                          => [ 38925, "integer" ],
                "USR-IPX-Call-Input-Filter"        => [ 38960, "string" ],
                "USR-IPX-Call-Output-Filter"       => [ 38969, "string" ],
                "USR-IPX-RIP-Input-Filter"         => [ 38958, "string" ],
                "USR-IPX-RIP-Output-Filter"        => [ 38968, "string" ],
                "USR-IPX-Routing"                  => [ 38952, "integer" ],
                "USR-IPX-WAN"                      => [ 38953, "integer" ],
                "USR-IWF-Call-Identifier"          => [ 2195,  "integer" ],
                "USR-IWF-IP-Address"               => [ 1012,  "ipaddr" ],
                "USR-Keep-Alive-Interval"          => [ 39059, "integer" ],
                "USR-Keypress-Timeout"             => [ 36892, "integer" ],
                "USR-Last-Callers-Number-ANI"      => [ 233,   "string" ],
                "USR-Last-Number-Dialed-In-DNIS"   => [ 232,   "string" ],
                "USR-Last-Number-Dialed-Out"       => [ 102,   "string" ],
                "USR-Line-Reversals"               => [ 122,   "integer" ],
                "USR-Local-Framed-IP-Addr"         => [ 36902, "ipaddr" ],
                "USR-Local-IP-Address"             => [ 38949, "string" ],
                "USR-Log-Filter-Packets"           => [ 36887, "string" ],
                "USR-Max-Channels"                 => [ 38914, "integer" ],
                "USR-Mbi_Ct_BChannel_Used"         => [ 391,   "integer" ],
                "USR-Mbi_Ct_PRI_Card_Slot"         => [ 388,   "integer" ],
                "USR-Mbi_Ct_PRI_Card_Span_Line"    => [ 390,   "integer" ],
                "USR-Mbi_Ct_TDM_Time_Slot"         => [ 389,   "integer" ],
                "USR-MIC"                          => [ 36884, "string" ],
                "USR-Min-Compression-Size"         => [ 38923, "integer" ],
                "USR-MIP-NAI"                      => [ 39028, "integer" ],
                "USR-MLPPP-Fragmentation-Threshld" => [ 39056, "integer" ],
                "USR-Mobile-Accounting-Type"       => [ 39046, "integer" ],
                "USR-Mobile-IP-Address"            => [ 2190,  "ipaddr" ],
                "USR-Mobile-NumBytes-Rxed"         => [ 2200,  "integer" ],
                "USR-Mobile-NumBytes-Txed"         => [ 2199,  "integer" ],
                "USR-Mobile-Service-Option"        => [ 39047, "integer" ],
                "USR-Mobile-Session-ID"            => [ 39045, "integer" ],
                "USR-MobileIP-Home-Agent-Address"  => [ 38987, "ipaddr" ],
                "USR-Modem-Group"                  => [ 38951, "integer" ],
                "USR-Modem-Setup-Time"             => [ 2204,  "integer" ],
                "USR-Modem-Training-Time"          => [ 38978, "integer" ],
                "USR-Modulation-Type"              => [ 108,   "integer" ],
                "USR-MP-EDO"                       => [ 36901, "string" ],
                "USR-MP-EDO-HIPER"                 => [ 38977, "string" ],
                "USR-MP-MRRU"                      => [ 38959, "integer" ],
                "USR-MPIP-Tunnel-Originator"       => [ 36904, "ipaddr" ],
                "USR-Multicast-Forwarding"         => [ 38992, "integer" ],
                "USR-Multicast-Proxy"              => [ 38989, "integer" ],
                "USR-Multicast-Receive"            => [ 38990, "integer" ],
                "USR-Nailed-B-Channel-Indicator"   => [ 39067, "integer" ],
                "USR-NAS-Type"                     => [ 61442, "integer" ],
                "USR-NFAS-ID"                      => [ 48736, "integer" ],
                "USR-Num-Fax-Pages-Processed"      => [ 2201,  "integer" ],
                "USR-Number-of-Blers"              => [ 125,   "integer" ],
                "USR-Number-Of-Characters-Lost"    => [ 123,   "integer" ],
                "USR-Number-of-Fallbacks"          => [ 127,   "integer" ],
                "USR-Number-of-Link-NAKs"          => [ 129,   "integer" ],
                "USR-Number-of-Link-Timeouts"      => [ 126,   "integer" ],
                "USR-Number-of-Rings-Limit"        => [ 49126, "integer" ],
                "USR-Number-of-Upshifts"           => [ 128,   "integer" ],
                "USR-Orig-NAS-Type"                => [ 38999, "string" ],
                "USR-Originate-Answer-Mode"        => [ 104,   "integer" ],
                "USR-OSPF-Addressless-Index"       => [ 39017, "integer" ],
                "USR-Packet-Bus-Session"           => [ 48916, "integer" ],
                "USR-Physical-State"               => [ 48759, "integer" ],
                "USR-Policy-Access"                => [ 39041, "integer" ],
                "USR-Policy-Configuration"         => [ 39042, "integer" ],
                "USR-Policy-Filename"              => [ 39043, "string" ],
                "USR-Policy-Type"                  => [ 39044, "integer" ],
                "USR-Port-Tap"                     => [ 38981, "integer" ],
                "USR-Port-Tap-Address"             => [ 38986, "ipaddr" ],
                "USR-Port-Tap-Facility"            => [ 38984, "integer" ],
                "USR-Port-Tap-Format"              => [ 38982, "integer" ],
                "USR-Port-Tap-Output"              => [ 38983, "integer" ],
                "USR-Port-Tap-Priority"            => [ 38985, "integer" ],
                "USR-Power-Supply-Number"          => [ 48948, "integer" ],
                "USR-PQ-Default-Priority"          => [ 39022, "integer" ],
                "USR-PQ-Parameters"                => [ 39031, "integer" ],
                "USR-Pre-Paid-Enabled"             => [ 39074, "integer" ],
                "USR-Pre-Shared-MN-Key"            => [ 39027, "string" ],
                "USR-Primary_DNS_Server"           => [ 36879, "ipaddr" ],
                "USR-Primary_NBNS_Server"          => [ 36881, "ipaddr" ],
                "USR-PW_Cutoff"                    => [ 36877, "string" ],
                "USR-PW_Framed_Routing_V2"         => [ 36873, "string" ],
                "USR-PW_Index"                     => [ 36876, "string" ],
                "USR-PW_Packet"                    => [ 36878, "string" ],
                "USR-PW_Tunnel_Authentication"     => [ 36875, "string" ],
                "USR-PW_USR_IFilter_IP"            => [ 36864, "string" ],
                "USR-PW_USR_IFilter_IPX"           => [ 36865, "string" ],
                "USR-PW_USR_OFilter_IP"            => [ 36867, "string" ],
                "USR-PW_USR_OFilter_IPX"           => [ 36868, "string" ],
                "USR-PW_USR_OFilter_SAP"           => [ 36869, "string" ],
                "USR-PW_VPN_Gateway"               => [ 36874, "string" ],
                "USR-PW_VPN_ID"                    => [ 36870, "string" ],
                "USR-PW_VPN_Name"                  => [ 36871, "string" ],
                "USR-PW_VPN_Neighbor"              => [ 36872, "ipaddr" ],
                "USR-Q931-Call-Reference-Value"    => [ 48737, "integer" ],
                "USR-QNC1-Service-Destination"     => [ 2292,  "ipaddr" ],
                "USR-QoS-Queuing-Mehtod"           => [ 39021, "integer" ],
                "USR-Rad-Dvmrp-Metric"             => [ 39012, "integer" ],
                "USR-Rad-IP-Pool-Definition"       => [ 39078, "string" ],
                "USR-Rad-Location-Type"            => [ 39015, "integer" ],
                "USR-Rad-Multicast-Routing-Bound"  => [ 39011, "string" ],
                "USR-Rad-Multicast-Routing-Proto"  => [ 39010, "integer" ],
                "USR-Rad-Multicast-Routing-RtLim"  => [ 39009, "integer" ],
                "USR-Rad-Multicast-Routing-Ttl"    => [ 39008, "integer" ],
                "USR-Rad-NMC-Blocks_RX"            => [ 39080, "integer" ],
                "USR-Rad-NMC-Call-Progress-Status" => [ 39079, "integer" ],
                "USR-Re-Chap-Timeout"              => [ 36896, "integer" ],
                "USR-Re-Reg-Server-Addr"           => [ 39070, "ipaddr" ],
                "USR-Receive-Acc-Map"              => [ 38919, "integer" ],
                "USR-Redirect"                     => [ 39076, "integer" ],
                "USR-Reg-Server-Prov-Timeout"      => [ 39075, "integer" ],
                "USR-Reply-Script1"                => [ 38936, "string" ],
                "USR-Reply-Script2"                => [ 38938, "string" ],
                "USR-Reply-Script3"                => [ 38940, "string" ],
                "USR-Reply-Script4"                => [ 38942, "string" ],
                "USR-Reply-Script5"                => [ 38944, "string" ],
                "USR-Reply-Script6"                => [ 38946, "string" ],
                "USR-Request-Type"                 => [ 61441, "integer" ],
                "USR-Retrains-Granted"             => [ 121,   "integer" ],
                "USR-Retrains-Requested"           => [ 120,   "integer" ],
                "USR-RMMIE-Firmware-Build-Date"    => [ 483,   "string" ],
                "USR-RMMIE-Firmware-Version"       => [ 482,   "string" ],
                "USR-RMMIE-Last-Update-Event"      => [ 2305,  "integer" ],
                "USR-RMMIE-Last-Update-Time"       => [ 2304,  "integer" ],
                "USR-RMMIE-Manufacturer-ID"        => [ 479,   "integer" ],
                "USR-RMMIE-Num-Of-Updates"         => [ 462,   "integer" ],
                "USR-RMMIE-Planned-Disconnect"     => [ 2314,  "integer" ],
                "USR-RMMIE-Product-Code"           => [ 480,   "string" ],
                "USR-RMMIE-PwrLvl-FarEcho-Canc"    => [ 2310,  "integer" ],
                "USR-RMMIE-PwrLvl-NearEcho-Canc"   => [ 2309,  "integer" ],
                "USR-RMMIE-PwrLvl-Noise-Lvl"       => [ 2311,  "integer" ],
                "USR-RMMIE-PwrLvl-Xmit-Lvl"        => [ 2312,  "integer" ],
                "USR-RMMIE-Rcv-PwrLvl-3300Hz"      => [ 2307,  "integer" ],
                "USR-RMMIE-Rcv-PwrLvl-3750Hz"      => [ 2308,  "integer" ],
                "USR-RMMIE-Rcv-Tot-PwrLvl"         => [ 2306,  "integer" ],
                "USR-RMMIE-Serial-Number"          => [ 481,   "string" ],
                "USR-RMMIE-Status"                 => [ 461,   "integer" ],
                "USR-RMMIE-x2-Status"              => [ 2313,  "integer" ],
                "USR-Routing-Protocol"             => [ 38950, "integer" ],
                "USR-SAP-Filter-In"                => [ 36866, "string" ],
                "USR-Secondary_DNS_Server"         => [ 36880, "ipaddr" ],
                "USR-Secondary_NBNS_Server"        => [ 36882, "ipaddr" ],
                "USR-Security-Login-Limit"         => [ 48862, "integer" ],
                "USR-Security-Resp-Limit"          => [ 48890, "integer" ],
                "USR-Send-Name"                    => [ 38931, "string" ],
                "USR-Send-Password"                => [ 38932, "string" ],
                "USR-Send-Script1"                 => [ 38935, "string" ],
                "USR-Send-Script2"                 => [ 38937, "string" ],
                "USR-Send-Script3"                 => [ 38939, "string" ],
                "USR-Send-Script4"                 => [ 38941, "string" ],
                "USR-Send-Script5"                 => [ 38943, "string" ],
                "USR-Send-Script6"                 => [ 38945, "string" ],
                "USR-Server-Time"                  => [ 61440, "date" ],
                "USR-Service-Option"               => [ 2197,  "integer" ],
                "USR-Session-Time-Remain"          => [ 39073, "integer" ],
                "USR-Simplified-MNP-Levels"        => [ 153,   "integer" ],
                "USR-Simplified-V42bis-Usage"      => [ 199,   "integer" ],
                "USR-Slot-Connected-To"            => [ 48734, "integer" ],
                "USR-Special-Xon-Xoff-Flow"        => [ 39033, "integer" ],
                "USR-Speed-Of-Connection"          => [ 38913, "integer" ],
                "USR-Spoofing"                     => [ 38929, "integer" ],
                "USR-Start-Time"                   => [ 38933, "integer" ],
                "USR-Supports-Tags"                => [ 39049, "integer" ],
                "USR-Sync-Async-Mode"              => [ 103,   "integer" ],
                "USR-Syslog-Tap"                   => [ 36883, "integer" ],
                "USR-Telnet-Options"               => [ 39052, "integer" ],
                "USR-Terminal-Type"                => [ 38947, "string" ],
                "USR-Traffic-Threshold"            => [ 39058, "integer" ],
                "USR-Transmit-Acc-Map"             => [ 38920, "integer" ],
                "USR-Tunnel-Auth-Hostname"         => [ 39019, "string" ],
                "USR-Tunnel-Challenge-Outgoing"    => [ 39060, "integer" ],
                "USR-Tunnel-Security"              => [ 38980, "integer" ],
                "USR-Tunnel-Switch-Endpoint"       => [ 39016, "string" ],
                "USR-Tunneled-MLPP"                => [ 38988, "integer" ],
                "USR-Unauthenticated-Time"         => [ 36893, "integer" ],
                "USR-Unnumbered-Local-IP-Address"  => [ 39057, "ipaddr" ],
                "USR-User-PPP-AODI-Type"           => [ 39055, "integer" ],
                "USR-VLAN-Tag"                     => [ 39077, "integer" ],
                "USR-VPN-Encrypter"                => [ 36894, "integer" ],
                "USR-VPN-GW-Location-Id"           => [ 36895, "string" ],
                "USR-VTS-Session-Key"              => [ 38998, "string" ],
                "USR-Wallclock-Timestamp"          => [ 39048, "integer" ],
                "USR-X25-Acct-Input-Segment-Count" => [ 39062, "integer" ],
                "USR-X25-Acct-Output-Segment-Coun" => [ 39063, "integer" ],
                "USR-X25-Acct-Segment-Size"        => [ 39064, "integer" ],
                "USR-X25-Acct-Termination-Code"    => [ 39065, "integer" ],
                "USR-X25-SVC-Call-Attributes"      => [ 39068, "integer" ],
                "USR-X25-SVC-Logical-Channel-Numb" => [ 39066, "integer" ],
                "USR-X25-Trunk-Profile"            => [ 39061, "string" ],
            },
            529 => {
                "Ascend-Access-Intercept-LEA"    => [ 52,  "string" ],
                "Ascend-Access-Intercept-Log"    => [ 53,  "string" ],
                "Ascend-Add-Seconds"             => [ 240, "integer" ],
                "Ascend-Appletalk-Peer-Mode"     => [ 117, "integer" ],
                "Ascend-Appletalk-Route"         => [ 116, "string" ],
                "Ascend-Ara-PW"                  => [ 181, "string" ],
                "Ascend-Assign-IP-Client"        => [ 144, "ipaddr" ],
                "Ascend-Assign-IP-Global-Pool"   => [ 146, "string" ],
                "Ascend-Assign-IP-Pool"          => [ 218, "integer" ],
                "Ascend-Assign-IP-Server"        => [ 145, "ipaddr" ],
                "Ascend-ATM-Connect-Group"       => [ 63,  "integer" ],
                "Ascend-ATM-Connect-Vci"         => [ 62,  "integer" ],
                "Ascend-ATM-Connect-Vpi"         => [ 61,  "integer" ],
                "Ascend-ATM-Direct"              => [ 76,  "integer" ],
                "Ascend-ATM-Direct-Profile"      => [ 77,  "string" ],
                "Ascend-ATM-Fault-Management"    => [ 14,  "integer" ],
                "Ascend-ATM-Group"               => [ 64,  "integer" ],
                "Ascend-ATM-Loopback-Cell-Loss"  => [ 15,  "integer" ],
                "Ascend-ATM-Vci"                 => [ 95,  "integer" ],
                "Ascend-ATM-Vpi"                 => [ 94,  "integer" ],
                "Ascend-Auth-Delay"              => [ 28,  "integer" ],
                "Ascend-Auth-Type"               => [ 81,  "integer" ],
                "Ascend-Authen-Alias"            => [ 203, "string" ],
                "Ascend-Backup"                  => [ 176, "string" ],
                "Ascend-BACP-Enable"             => [ 133, "integer" ],
                "Ascend-Base-Channel-Count"      => [ 172, "integer" ],
                "Ascend-Bi-Directional-Auth"     => [ 46,  "integer" ],
                "Ascend-Billing-Number"          => [ 249, "string" ],
                "Ascend-BIR-Bridge-Group"        => [ 72,  "integer" ],
                "Ascend-BIR-Enable"              => [ 70,  "integer" ],
                "Ascend-BIR-Proxy"               => [ 71,  "integer" ],
                "Ascend-Bridge"                  => [ 230, "integer" ],
                "Ascend-Bridge-Address"          => [ 168, "string" ],
                "Ascend-Bridge-Non-PPPoE"        => [ 75,  "integer" ],
                "Ascend-Cache-Refresh"           => [ 56,  "integer" ],
                "Ascend-Cache-Time"              => [ 57,  "integer" ],
                "Ascend-Call-Attempt-Limit"      => [ 123, "integer" ],
                "Ascend-Call-Block-Duration"     => [ 124, "integer" ],
                "Ascend-Call-By-Call"            => [ 250, "integer" ],
                "Ascend-Call-Direction"          => [ 48,  "integer" ],
                "Ascend-Call-Filter"             => [ 243, "abinary" ],
                "Ascend-Call-Type"               => [ 177, "integer" ],
                "Ascend-Callback"                => [ 246, "integer" ],
                "Ascend-Callback-Delay"          => [ 108, "integer" ],
                "Ascend-Calling-Id-Number-Plan"  => [ 67,  "integer" ],
                "Ascend-Calling-Id-Presentatn"   => [ 68,  "integer" ],
                "Ascend-Calling-Id-Screening"    => [ 69,  "integer" ],
                "Ascend-Calling-Id-Type-Of-Num"  => [ 66,  "integer" ],
                "Ascend-Calling-Subaddress"      => [ 107, "string" ],
                "Ascend-CBCP-Delay"              => [ 114, "integer" ],
                "Ascend-CBCP-Enable"             => [ 112, "integer" ],
                "Ascend-CBCP-Mode"               => [ 113, "integer" ],
                "Ascend-CBCP-Trunk-Group"        => [ 115, "integer" ],
                "Ascend-CIR-Timer"               => [ 9,   "integer" ],
                "Ascend-Ckt-Type"                => [ 16,  "integer" ],
                "Ascend-Client-Assign-DNS"       => [ 137, "integer" ],
                "Ascend-Client-Assign-WINS"      => [ 80,  "integer" ],
                "Ascend-Client-Gateway"          => [ 132, "ipaddr" ],
                "Ascend-Client-Primary-DNS"      => [ 135, "ipaddr" ],
                "Ascend-Client-Primary-WINS"     => [ 78,  "ipaddr" ],
                "Ascend-Client-Secondary-DNS"    => [ 136, "ipaddr" ],
                "Ascend-Client-Secondary-WINS"   => [ 79,  "ipaddr" ],
                "Ascend-Connect-Progress"        => [ 196, "integer" ],
                "Ascend-Data-Filter"             => [ 242, "abinary" ],
                "Ascend-Data-Rate"               => [ 197, "integer" ],
                "Ascend-Data-Svc"                => [ 247, "integer" ],
                "Ascend-DBA-Monitor"             => [ 171, "integer" ],
                "Ascend-Dec-Channel-Count"       => [ 237, "integer" ],
                "Ascend-Destination-Nas-Port"    => [ 11,  "integer" ],
                "Ascend-DHCP-Maximum-Leases"     => [ 134, "integer" ],
                "Ascend-DHCP-Pool-Number"        => [ 148, "integer" ],
                "Ascend-DHCP-Reply"              => [ 147, "integer" ],
                "Ascend-Dial-Number"             => [ 227, "string" ],
                "Ascend-Dialed-Number"           => [ 24,  "string" ],
                "Ascend-Dialout-Allowed"         => [ 131, "integer" ],
                "Ascend-Disconnect-Cause"        => [ 195, "integer" ],
                "Ascend-Dropped-Octets"          => [ 26,  "integer" ],
                "Ascend-Dropped-Packets"         => [ 27,  "integer" ],
                "Ascend-Dsl-CIR-Recv-Limit"      => [ 100, "integer" ],
                "Ascend-Dsl-CIR-Xmit-Limit"      => [ 101, "integer" ],
                "Ascend-Dsl-Downstream-Limit"    => [ 99,  "integer" ],
                "Ascend-Dsl-Rate-Mode"           => [ 97,  "integer" ],
                "Ascend-Dsl-Rate-Type"           => [ 92,  "integer" ],
                "Ascend-Dsl-Upstream-Limit"      => [ 98,  "integer" ],
                "Ascend-Egress-Enabled"          => [ 58,  "integer" ],
                "Ascend-Endpoint-Disc"           => [ 109, "string" ],
                "Ascend-Event-Type"              => [ 150, "integer" ],
                "Ascend-Expect-Callback"         => [ 149, "integer" ],
                "Ascend-FCP-Parameter"           => [ 119, "string" ],
                "Ascend-Filter"                  => [ 90,  "string" ],
                "Ascend-Filter-Required"         => [ 50,  "integer" ],
                "Ascend-First-Dest"              => [ 189, "ipaddr" ],
                "Ascend-Force-56"                => [ 248, "integer" ],
                "Ascend-FR-08-Mode"              => [ 10,  "integer" ],
                "Ascend-FR-Circuit-Name"         => [ 156, "string" ],
                "Ascend-FR-DCE-N392"             => [ 162, "integer" ],
                "Ascend-FR-DCE-N393"             => [ 164, "integer" ],
                "Ascend-FR-Direct"               => [ 219, "integer" ],
                "Ascend-FR-Direct-DLCI"          => [ 221, "integer" ],
                "Ascend-FR-Direct-Profile"       => [ 220, "string" ],
                "Ascend-FR-DLCI"                 => [ 179, "integer" ],
                "Ascend-FR-DTE-N392"             => [ 163, "integer" ],
                "Ascend-FR-DTE-N393"             => [ 165, "integer" ],
                "Ascend-FR-Link-Mgt"             => [ 160, "integer" ],
                "Ascend-FR-Link-Status-DLCI"     => [ 106, "integer" ],
                "Ascend-FR-LinkUp"               => [ 157, "integer" ],
                "Ascend-FR-N391"                 => [ 161, "integer" ],
                "Ascend-FR-Nailed-Grp"           => [ 158, "integer" ],
                "Ascend-FR-Profile-Name"         => [ 180, "string" ],
                "Ascend-FR-SVC-Addr"             => [ 12,  "string" ],
                "Ascend-FR-T391"                 => [ 166, "integer" ],
                "Ascend-FR-T392"                 => [ 167, "integer" ],
                "Ascend-FR-Type"                 => [ 159, "integer" ],
                "Ascend-FT1-Caller"              => [ 175, "integer" ],
                "Ascend-Global-Call-Id"          => [ 20,  "string" ],
                "Ascend-Group"                   => [ 178, "string" ],
                "Ascend-H323-Conference-Id"      => [ 21,  "integer" ],
                "Ascend-H323-Dialed-Time"        => [ 23,  "integer" ],
                "Ascend-H323-Fegw-Address"       => [ 22,  "ipaddr" ],
                "Ascend-H323-Gatekeeper"         => [ 19,  "ipaddr" ],
                "Ascend-Handle-IPX"              => [ 222, "integer" ],
                "Ascend-History-Weigh-Type"      => [ 239, "integer" ],
                "Ascend-Home-Agent-IP-Addr"      => [ 183, "ipaddr" ],
                "Ascend-Home-Agent-Password"     => [ 184, "string" ],
                "Ascend-Home-Agent-UDP-Port"     => [ 186, "integer" ],
                "Ascend-Home-Network-Name"       => [ 185, "string" ],
                "Ascend-Host-Info"               => [ 252, "string" ],
                "Ascend-Idle-Limit"              => [ 244, "integer" ],
                "Ascend-IF-Netmask"              => [ 153, "ipaddr" ],
                "Ascend-Inc-Channel-Count"       => [ 236, "integer" ],
                "Ascend-Inter-Arrival-Jitter"    => [ 25,  "integer" ],
                "Ascend-IP-Direct"               => [ 209, "ipaddr" ],
                "Ascend-IP-Pool-Chaining"        => [ 85,  "integer" ],
                "Ascend-IP-Pool-Definition"      => [ 217, "string" ],
                "Ascend-IP-TOS"                  => [ 87,  "integer" ],
                "Ascend-IP-TOS-Apply-To"         => [ 89,  "integer" ],
                "Ascend-IP-TOS-Precedence"       => [ 88,  "integer" ],
                "Ascend-IPSEC-Profile"           => [ 73,  "string" ],
                "Ascend-IPX-Alias"               => [ 224, "integer" ],
                "Ascend-IPX-Header-Compression"  => [ 65,  "integer" ],
                "Ascend-IPX-Node-Addr"           => [ 182, "string" ],
                "Ascend-IPX-Peer-Mode"           => [ 216, "integer" ],
                "Ascend-IPX-Route"               => [ 174, "string" ],
                "Ascend-Link-Compression"        => [ 233, "integer" ],
                "Ascend-Max-Shared-Users"        => [ 2,   "integer" ],
                "Ascend-Maximum-Call-Duration"   => [ 125, "integer" ],
                "Ascend-Maximum-Channels"        => [ 235, "integer" ],
                "Ascend-Maximum-Time"            => [ 194, "integer" ],
                "Ascend-Menu-Item"               => [ 206, "string" ],
                "Ascend-Menu-Selector"           => [ 205, "string" ],
                "Ascend-Metric"                  => [ 225, "integer" ],
                "Ascend-Minimum-Channels"        => [ 173, "integer" ],
                "Ascend-Modem-PortNo"            => [ 120, "integer" ],
                "Ascend-Modem-ShelfNo"           => [ 122, "integer" ],
                "Ascend-Modem-SlotNo"            => [ 121, "integer" ],
                "Ascend-MPP-Idle-Percent"        => [ 254, "integer" ],
                "Ascend-MTU"                     => [ 47,  "integer" ],
                "Ascend-Multicast-Client"        => [ 155, "integer" ],
                "Ascend-Multicast-GLeave-Delay"  => [ 111, "integer" ],
                "Ascend-Multicast-Rate-Limit"    => [ 152, "integer" ],
                "Ascend-Multilink-ID"            => [ 187, "integer" ],
                "Ascend-NAS-Port-Format"         => [ 13,  "integer" ],
                "Ascend-Netware-timeout"         => [ 223, "integer" ],
                "Ascend-Num-In-Multilink"        => [ 188, "integer" ],
                "Ascend-Number-Sessions"         => [ 202, "string" ],
                "Ascend-Numbering-Plan-ID"       => [ 105, "integer" ],
                "Ascend-Owner-IP-Addr"           => [ 86,  "ipaddr" ],
                "Ascend-Port-Redir-Portnum"      => [ 83,  "integer" ],
                "Ascend-Port-Redir-Protocol"     => [ 82,  "integer" ],
                "Ascend-Port-Redir-Server"       => [ 84,  "ipaddr" ],
                "Ascend-PPP-Address"             => [ 253, "ipaddr" ],
                "Ascend-PPP-Async-Map"           => [ 212, "integer" ],
                "Ascend-PPP-VJ-1172"             => [ 211, "integer" ],
                "Ascend-PPP-VJ-Slot-Comp"        => [ 210, "integer" ],
                "Ascend-PPPoE-Enable"            => [ 74,  "integer" ],
                "Ascend-Pre-Input-Octets"        => [ 190, "integer" ],
                "Ascend-Pre-Input-Packets"       => [ 192, "integer" ],
                "Ascend-Pre-Output-Octets"       => [ 191, "integer" ],
                "Ascend-Pre-Output-Packets"      => [ 193, "integer" ],
                "Ascend-Preempt-Limit"           => [ 245, "integer" ],
                "Ascend-PreSession-Time"         => [ 198, "integer" ],
                "Ascend-PRI-Number-Type"         => [ 226, "integer" ],
                "Ascend-Primary-Home-Agent"      => [ 129, "string" ],
                "Ascend-Private-Route"           => [ 104, "string" ],
                "Ascend-Private-Route-Required"  => [ 55,  "integer" ],
                "Ascend-Private-Route-Table-ID"  => [ 54,  "string" ],
                "Ascend-PW-Lifetime"             => [ 208, "integer" ],
                "Ascend-PW-Warntime"             => [ 207, "integer" ],
                "Ascend-QOS-Downstream"          => [ 60,  "string" ],
                "Ascend-QOS-Upstream"            => [ 59,  "string" ],
                "Ascend-Receive-Secret"          => [ 215, "string" ],
                "Ascend-Recv-Name"               => [ 45,  "string" ],
                "Ascend-Redirect-Number"         => [ 93,  "string" ],
                "Ascend-Remote-Addr"             => [ 154, "ipaddr" ],
                "Ascend-Remote-FW"               => [ 110, "string" ],
                "Ascend-Remove-Seconds"          => [ 241, "integer" ],
                "Ascend-Require-Auth"            => [ 201, "integer" ],
                "Ascend-Route-Appletalk"         => [ 118, "integer" ],
                "Ascend-Route-IP"                => [ 228, "integer" ],
                "Ascend-Route-IPX"               => [ 229, "integer" ],
                "Ascend-Secondary-Home-Agent"    => [ 130, "string" ],
                "Ascend-Seconds-Of-History"      => [ 238, "integer" ],
                "Ascend-Send-Auth"               => [ 231, "integer" ],
                "Ascend-Send-Passwd"             => [ 232, "string" ],
                "Ascend-Send-Secret"             => [ 214, "string" ],
                "Ascend-Service-Type"            => [ 49,  "integer" ],
                "Ascend-Session-Svr-Key"         => [ 151, "string" ],
                "Ascend-Session-Type"            => [ 18,  "integer" ],
                "Ascend-Shared-Profile-Enable"   => [ 128, "integer" ],
                "Ascend-Source-Auth"             => [ 103, "string" ],
                "Ascend-Source-IP-Check"         => [ 96,  "integer" ],
                "Ascend-SVC-Enabled"             => [ 17,  "integer" ],
                "Ascend-Target-Util"             => [ 234, "integer" ],
                "Ascend-Telnet-Profile"          => [ 91,  "string" ],
                "Ascend-Temporary-Rtes"          => [ 126, "integer" ],
                "Ascend-Third-Prompt"            => [ 213, "string" ],
                "Ascend-Token-Expiry"            => [ 204, "integer" ],
                "Ascend-Token-Idle"              => [ 199, "integer" ],
                "Ascend-Token-Immediate"         => [ 200, "integer" ],
                "Ascend-Traffic-Shaper"          => [ 51,  "integer" ],
                "Ascend-Transit-Number"          => [ 251, "string" ],
                "Ascend-TS-Idle-Limit"           => [ 169, "integer" ],
                "Ascend-TS-Idle-Mode"            => [ 170, "integer" ],
                "Ascend-Tunnel-VRouter-Name"     => [ 31,  "string" ],
                "Ascend-Tunneling-Protocol"      => [ 127, "integer" ],
                "Ascend-User-Acct-Base"          => [ 142, "integer" ],
                "Ascend-User-Acct-Host"          => [ 139, "ipaddr" ],
                "Ascend-User-Acct-Key"           => [ 141, "string" ],
                "Ascend-User-Acct-Port"          => [ 140, "integer" ],
                "Ascend-User-Acct-Time"          => [ 143, "integer" ],
                "Ascend-User-Acct-Type"          => [ 138, "integer" ],
                "Ascend-UU-Info"                 => [ 7,   "string" ],
                "Ascend-VRouter-Name"            => [ 102, "string" ],
                "Ascend-X25-Cug"                 => [ 35,  "string" ],
                "Ascend-X25-Nui"                 => [ 40,  "string" ],
                "Ascend-X25-Nui-Password-Prompt" => [ 34,  "string" ],
                "Ascend-X25-Nui-Prompt"          => [ 33,  "string" ],
                "Ascend-X25-Pad-Alias-1"         => [ 36,  "string" ],
                "Ascend-X25-Pad-Alias-2"         => [ 37,  "string" ],
                "Ascend-X25-Pad-Alias-3"         => [ 38,  "string" ],
                "Ascend-X25-Pad-Banner"          => [ 43,  "string" ],
                "Ascend-X25-Pad-Prompt"          => [ 42,  "string" ],
                "Ascend-X25-Pad-X3-Parameters"   => [ 30,  "string" ],
                "Ascend-X25-Pad-X3-Profile"      => [ 29,  "integer" ],
                "Ascend-X25-Profile-Name"        => [ 44,  "string" ],
                "Ascend-X25-Reverse-Charging"    => [ 32,  "integer" ],
                "Ascend-X25-Rpoa"                => [ 41,  "string" ],
                "Ascend-X25-X121-Address"        => [ 39,  "string" ],
                "Ascend-Xmit-Rate"               => [ 255, "integer" ],
            },
            562 => {
                "Fabric-Attach-Client-Id"              => [ 181, "string" ],
                "Fabric-Attach-Client-PSK"             => [ 183, "integer" ],
                "Fabric-Attach-Client-Trust"           => [ 184, "integer" ],
                "Fabric-Attach-Client-Trusted-Binding" => [ 185, "string" ],
                "Fabric-Attach-Client-Type"            => [ 182, "string" ],
                "Fabric-Attach-Service-Request"        => [ 186, "string" ],
                "Fabric-Attach-Switch-Mode"            => [ 180, "integer" ],
                "Fabric-Attach-VLAN-Create"            => [ 170, "integer" ],
                "Fabric-Attach-VLAN-ISID"              => [ 171, "string" ],
                "Fabric-Attach-VLAN-PVID"              => [ 172, "integer" ],
                "Nortel-Privilege-Level"               => [ 166, "integer" ],
                "Nortel-User-Role"                     => [ 110, "string" ],
                "Passport-Allowed-Access"              => [ 203, "integer" ],
                "Passport-AllowedOut-Access"           => [ 204, "integer" ],
                "Passport-Command-Impact"              => [ 201, "integer" ],
                "Passport-Command-Scope"               => [ 200, "integer" ],
                "Passport-Customer-Identifier"         => [ 202, "integer" ],
                "Passport-Login-Directory"             => [ 205, "string" ],
                "Passport-Role"                        => [ 207, "string" ],
                "Passport-Timeout-Protocol"            => [ 206, "integer" ],
            },
            594 => { "SID-Auth" => [ 1, "string" ] },
            637 => {
                "A-AL-AAA"                   => [ 1801, "integer" ],
                "A-AL-Alarm"                 => [ 1803, "integer" ],
                "A-AL-ATM"                   => [ 1802, "integer" ],
                "A-AL-Cluster"               => [ 1816, "integer" ],
                "A-AL-CPEProxy"              => [ 1807, "integer" ],
                "A-AL-Description"           => [ 1819, "string" ],
                "A-AL-DHCP"                  => [ 1804, "integer" ],
                "A-AL-EQP"                   => [ 1805, "integer" ],
                "A-AL-IGMP"                  => [ 1806, "integer" ],
                "A-AL-IP"                    => [ 1808, "integer" ],
                "A-AL-Maintenance"           => [ 1536, "integer" ],
                "A-AL-MAINTENANCE-BACKWARD"  => [ 1797, "integer" ],
                "A-AL-PPPoE"                 => [ 1809, "integer" ],
                "A-AL-Prompt"                => [ 1817, "string" ],
                "A-AL-Provisioning"          => [ 1537, "integer" ],
                "A-AL-PROVISIONING-BACKWARD" => [ 1798, "integer" ],
                "A-AL-Pwd-Timeout"           => [ 1818, "integer" ],
                "A-AL-QoS"                   => [ 1810, "integer" ],
                "A-AL-Security"              => [ 1815, "integer" ],
                "A-AL-SLOT-NUMBERING"        => [ 1820, "integer" ],
                "A-AL-SWMgt"                 => [ 1811, "integer" ],
                "A-AL-Test"                  => [ 1539, "integer" ],
                "A-AL-TEST-BACKWARD"         => [ 1800, "integer" ],
                "A-AL-TL1-Security"          => [ 1538, "integer" ],
                "A-AL-TL1-SECURITY-BACKWARD" => [ 1799, "integer" ],
                "A-AL-Transport"             => [ 1812, "integer" ],
                "A-AL-VLAN"                  => [ 1813, "integer" ],
                "A-AL-XDSL"                  => [ 1814, "integer" ],
                "A-ESAM-QOS-Params"          => [ 1795, "string" ],
                "A-ESAM-QOS-Profile-Name"    => [ 1794, "string" ],
                "A-ESAM-Termination-Cause"   => [ 1796, "integer" ],
                "A-ESAM-Vlan-Id"             => [ 1793, "integer" ],
                "A-ESAM-VRF-Name"            => [ 1792, "string" ],
            },
            664 => {
                "Adtran-AP-IP"       => [ 101, "ipaddr" ],
                "Adtran-AP-Name"     => [ 100, "string" ],
                "Adtran-AP-Template" => [ 102, "string" ],
                "Adtran-Role"        => [ 104, "string" ],
                "Adtran-SSID"        => [ 103, "string" ],
            },
            674 => {
                "DellEMC-AVpair"     => [ 1, "string" ],
                "DellEMC-Group-Name" => [ 2, "string" ],
            },
            762 => {
                "KarlNet-TurboCell-Name"    => [ 151, "string" ],
                "KarlNet-TurboCell-OpMode"  => [ 154, "integer" ],
                "KarlNet-TurboCell-OpState" => [ 153, "integer" ],
                "KarlNet-TurboCell-TxRate"  => [ 152, "integer" ],
            },
            800 => {
                "Xylan-Acce-Priv-F-R1"       => [ 39,  "octets" ],
                "Xylan-Acce-Priv-F-R2"       => [ 40,  "octets" ],
                "Xylan-Acce-Priv-F-W1"       => [ 41,  "octets" ],
                "Xylan-Acce-Priv-F-W2"       => [ 42,  "octets" ],
                "Xylan-Acce-Priv-G1"         => [ 37,  "octets" ],
                "Xylan-Acce-Priv-G2"         => [ 38,  "octets" ],
                "Xylan-Acce-Priv-R1"         => [ 33,  "octets" ],
                "Xylan-Acce-Priv-R2"         => [ 34,  "octets" ],
                "Xylan-Acce-Priv-W1"         => [ 35,  "octets" ],
                "Xylan-Acce-Priv-W2"         => [ 36,  "octets" ],
                "Xylan-Access-Priv"          => [ 16,  "integer" ],
                "Xylan-Asa-Access"           => [ 9,   "string" ],
                "Xylan-Auth-Group"           => [ 1,   "integer" ],
                "Xylan-Auth-Group-Protocol"  => [ 8,   "string" ],
                "Xylan-Client-IP-Addr"       => [ 4,   "ipaddr" ],
                "Xylan-Device-Location"      => [ 153, "string" ],
                "Xylan-Device-Name"          => [ 152, "string" ],
                "Xylan-End-User-Profile"     => [ 10,  "integer" ],
                "Xylan-Group-Desc"           => [ 5,   "string" ],
                "Xylan-Home-Agent-Password"  => [ 14,  "string" ],
                "Xylan-Home-Network-Name"    => [ 15,  "string" ],
                "Xylan-Nms-Description"      => [ 23,  "string" ],
                "Xylan-Nms-First-Name"       => [ 21,  "string" ],
                "Xylan-Nms-Group"            => [ 20,  "string" ],
                "Xylan-Nms-Last-Name"        => [ 22,  "string" ],
                "Xylan-Policy-List"          => [ 100, "string" ],
                "Xylan-Port-Desc"            => [ 6,   "string" ],
                "Xylan-Primary-Home-Agent"   => [ 12,  "string" ],
                "Xylan-Profil-Numb"          => [ 7,   "integer" ],
                "Xylan-Redirect-Url"         => [ 101, "string" ],
                "Xylan-Secondary-Home-Agent" => [ 13,  "string" ],
                "Xylan-Slot-Port"            => [ 2,   "string" ],
                "Xylan-Time-of-Day"          => [ 3,   "string" ],
            },
            831 => {
                "ALU-AAA-Access-Rule"                => [ 1,   "string" ],
                "ALU-AAA-AKA-AUTS"                   => [ 8,   "octets" ],
                "ALU-AAA-AKA-Quintet"                => [ 6,   "octets" ],
                "ALU-AAA-AKA-Quintets-Needed"        => [ 5,   "integer" ],
                "ALU-AAA-AKA-RAND"                   => [ 7,   "octets" ],
                "ALU-AAA-AV-Pair"                    => [ 2,   "string" ],
                "ALU-AAA-Called-Station-Id"          => [ 202, "string" ],
                "ALU-AAA-Civic-Location"             => [ 211, "octets" ],
                "ALU-AAA-Client-Error-Action"        => [ 14,  "integer" ],
                "ALU-AAA-Client-OS"                  => [ 15,  "string" ],
                "ALU-AAA-Client-Program"             => [ 13,  "string" ],
                "ALU-AAA-Client-Version"             => [ 16,  "string" ],
                "ALU-AAA-Delta-Session"              => [ 210, "integer" ],
                "ALU-AAA-DF-CC-Address"              => [ 11,  "ipaddr" ],
                "ALU-AAA-DF-CC-Port"                 => [ 12,  "short" ],
                "ALU-AAA-Eval-0"                     => [ 124, "string" ],
                "ALU-AAA-Eval-1"                     => [ 125, "string" ],
                "ALU-AAA-Eval-2"                     => [ 126, "string" ],
                "ALU-AAA-Eval-3"                     => [ 127, "string" ],
                "ALU-AAA-Event"                      => [ 207, "string" ],
                "ALU-AAA-Exec-0"                     => [ 128, "string" ],
                "ALU-AAA-Exec-1"                     => [ 129, "string" ],
                "ALU-AAA-Exec-2"                     => [ 130, "string" ],
                "ALU-AAA-Exec-3"                     => [ 131, "string" ],
                "ALU-AAA-Femto-Associated-User-Name" => [ 19,  "string" ],
                "ALU-AAA-Femto-Public-Key-Hash"      => [ 18,  "octets" ],
                "ALU-AAA-Geospatial-Location"        => [ 212, "octets" ],
                "ALU-AAA-GSM-Triplet"                => [ 4,   "octets" ],
                "ALU-AAA-GSM-Triplets-Needed"        => [ 3,   "integer" ],
                "ALU-AAA-Integer-0"                  => [ 104, "integer" ],
                "ALU-AAA-Integer-1"                  => [ 105, "integer" ],
                "ALU-AAA-Integer-2"                  => [ 106, "integer" ],
                "ALU-AAA-Integer-3"                  => [ 107, "integer" ],
                "ALU-AAA-Key-0"                      => [ 116, "octets" ],
                "ALU-AAA-Key-1"                      => [ 117, "octets" ],
                "ALU-AAA-Key-2"                      => [ 118, "octets" ],
                "ALU-AAA-Key-3"                      => [ 119, "octets" ],
                "ALU-AAA-Lawful-Intercept-Status"    => [ 10,  "byte" ],
                "ALU-AAA-NAS-IP-Address"             => [ 203, "ipaddr" ],
                "ALU-AAA-NAS-Port"                   => [ 204, "integer" ],
                "ALU-AAA-New-State"                  => [ 206, "string" ],
                "ALU-AAA-New-Timestamp"              => [ 209, "date" ],
                "ALU-AAA-Nonce"                      => [ 17,  "octets" ],
                "ALU-AAA-Old-State"                  => [ 205, "string" ],
                "ALU-AAA-Old-Timestamp"              => [ 208, "date" ],
                "ALU-AAA-Opaque-0"                   => [ 120, "octets" ],
                "ALU-AAA-Opaque-1"                   => [ 121, "octets" ],
                "ALU-AAA-Opaque-2"                   => [ 122, "octets" ],
                "ALU-AAA-Opaque-3"                   => [ 123, "octets" ],
                "ALU-AAA-Original-Receipt-Time"      => [ 199, "octets" ],
                "ALU-AAA-Reply-Message"              => [ 201, "string" ],
                "ALU-AAA-Service-Profile"            => [ 9,   "string" ],
                "ALU-AAA-String-0"                   => [ 100, "string" ],
                "ALU-AAA-String-1"                   => [ 101, "string" ],
                "ALU-AAA-String-2"                   => [ 102, "string" ],
                "ALU-AAA-String-3"                   => [ 103, "string" ],
                "ALU-AAA-Value-0"                    => [ 112, "octets" ],
                "ALU-AAA-Value-1"                    => [ 113, "octets" ],
                "ALU-AAA-Value-2"                    => [ 114, "octets" ],
                "ALU-AAA-Value-3"                    => [ 115, "octets" ],
            },
            838 => {
                "Xedia-Address-Pool"            => [ 3, "string" ],
                "Xedia-Client-Access-Network"   => [ 6, "string" ],
                "Xedia-Client-Firewall-Setting" => [ 7, "integer" ],
                "Xedia-DNS-Server"              => [ 1, "ipaddr" ],
                "Xedia-NetBios-Server"          => [ 2, "ipaddr" ],
                "Xedia-PPP-Echo-Interval"       => [ 4, "integer" ],
                "Xedia-Save-Password"           => [ 8, "integer" ],
                "Xedia-SSH-Privileges"          => [ 5, "integer" ],
            },
            841 => {
                Proxim_E1_Access_VLAN_ID      => [ 6,  "integer" ],
                Proxim_E1_Access_VLAN_Pri     => [ 7,  "integer" ],
                Proxim_E1_Allow_Untag         => [ 63, "integer" ],
                Proxim_E1_Port_VLAN_ID        => [ 61, "integer" ],
                Proxim_E1_Port_VLAN_Pri       => [ 62, "integer" ],
                Proxim_E1_SU_Allow_Untag_Mgmt => [ 68, "integer" ],
                Proxim_E1_TrunkID_01          => [ 10, "integer" ],
                Proxim_E1_TrunkID_02          => [ 11, "integer" ],
                Proxim_E1_TrunkID_03          => [ 12, "integer" ],
                Proxim_E1_TrunkID_04          => [ 13, "integer" ],
                Proxim_E1_TrunkID_05          => [ 14, "integer" ],
                Proxim_E1_TrunkID_06          => [ 15, "integer" ],
                Proxim_E1_TrunkID_07          => [ 16, "integer" ],
                Proxim_E1_TrunkID_08          => [ 17, "integer" ],
                Proxim_E1_TrunkID_09          => [ 18, "integer" ],
                Proxim_E1_TrunkID_10          => [ 19, "integer" ],
                Proxim_E1_TrunkID_11          => [ 20, "integer" ],
                Proxim_E1_TrunkID_12          => [ 21, "integer" ],
                Proxim_E1_TrunkID_13          => [ 22, "integer" ],
                Proxim_E1_TrunkID_14          => [ 23, "integer" ],
                Proxim_E1_TrunkID_15          => [ 24, "integer" ],
                Proxim_E1_TrunkID_16          => [ 25, "integer" ],
                Proxim_E1_VLAN_MODE           => [ 4,  "integer" ],
                Proxim_E2_Access_VLAN_ID      => [ 41, "integer" ],
                Proxim_E2_Access_VLAN_Pri     => [ 42, "integer" ],
                Proxim_E2_Allow_Untag         => [ 66, "integer" ],
                Proxim_E2_Port_VLAN_ID        => [ 64, "integer" ],
                Proxim_E2_Port_VLAN_Pri       => [ 65, "integer" ],
                Proxim_E2_SU_Allow_Untag_Mgmt => [ 69, "integer" ],
                Proxim_E2_TrunkID_01          => [ 43, "integer" ],
                Proxim_E2_TrunkID_02          => [ 44, "integer" ],
                Proxim_E2_TrunkID_03          => [ 45, "integer" ],
                Proxim_E2_TrunkID_04          => [ 46, "integer" ],
                Proxim_E2_TrunkID_05          => [ 47, "integer" ],
                Proxim_E2_TrunkID_06          => [ 48, "integer" ],
                Proxim_E2_TrunkID_07          => [ 49, "integer" ],
                Proxim_E2_TrunkID_08          => [ 50, "integer" ],
                Proxim_E2_TrunkID_09          => [ 51, "integer" ],
                Proxim_E2_TrunkID_10          => [ 52, "integer" ],
                Proxim_E2_TrunkID_11          => [ 53, "integer" ],
                Proxim_E2_TrunkID_12          => [ 54, "integer" ],
                Proxim_E2_TrunkID_13          => [ 55, "integer" ],
                Proxim_E2_TrunkID_14          => [ 56, "integer" ],
                Proxim_E2_TrunkID_15          => [ 57, "integer" ],
                Proxim_E2_TrunkID_16          => [ 58, "integer" ],
                Proxim_E2_VLAN_MODE           => [ 40, "integer" ],
                Proxim_Mgmt_VLAN_ID           => [ 8,  "integer" ],
                Proxim_Mgmt_VLAN_Pri          => [ 9,  "integer" ],
                Proxim_QinQ_Status            => [ 59, "integer" ],
                Proxim_QoS_Class_Index        => [ 34, "integer" ],
                Proxim_QoS_Class_SU_Status    => [ 35, "integer" ],
                Proxim_Service_VLAN_ID        => [ 32, "integer" ],
                Proxim_Service_VLAN_Pri       => [ 33, "integer" ],
                Proxim_Service_VLAN_TPID      => [ 60, "integer" ],
                Proxim_SU_VLAN_NAME           => [ 5,  "string" ],
                Proxim_SU_VLAN_Table_Status   => [ 26, "integer" ],
            },
            850 => {
                "TrippLite-Authorization" => [ 1, "string" ],
                "TrippLite-Message"       => [ 3, "string" ],
                "TrippLite-Outlet-Realms" => [ 2, "string" ],
                "TrippLite-User-Role"     => [ 4, "string" ],
            },
            890 => {
                "Zyxel-Callback-Option"       => [ 192, "integer" ],
                "Zyxel-Callback-Phone-Source" => [ 193, "integer" ],
                "Zyxel-Privilege-AVPair"      => [ 3,   "string" ],
            },
            969 => {
                "UserLogon-Acct-TerminateCause" => [ 50, "string" ],
                "UserLogon-DriveNames"          => [ 19, "string" ],
                "UserLogon-Expiration"          => [ 25, "string" ],
                "UserLogon-Gid"                 => [ 11, "integer" ],
                "UserLogon-GroupNames"          => [ 18, "string" ],
                "UserLogon-HomeDir"             => [ 12, "string" ],
                "UserLogon-LogoffTask"          => [ 24, "string" ],
                "UserLogon-LogonTask"           => [ 23, "string" ],
                "UserLogon-QuotaBytes"          => [ 14, "integer" ],
                "UserLogon-QuotaFiles"          => [ 15, "integer" ],
                "UserLogon-Restriction"         => [ 17, "integer" ],
                "UserLogon-Shell"               => [ 16, "string" ],
                "UserLogon-Type"                => [ 13, "integer" ],
                "UserLogon-Uid"                 => [ 10, "integer" ],
                "UserLogon-UserDescription"     => [ 20, "string" ],
                "UserLogon-UserDomain"          => [ 22, "string" ],
                "UserLogon-UserFullName"        => [ 21, "string" ],
                "UserLogon-UserProfile"         => [ 26, "string" ],
            },
            1076 => {
                "Surfnet-AVPair"             => [ 1, "string" ],
                "Surfnet-Service-Identifier" => [ 2, "string" ],
                "Surfnet-Service-Provider"   => [ 3, "string" ],
            },
            1195 => {
                "ITK-Acct-Serv-IP"           => [ 112, "ipaddr" ],
                "ITK-Acct-Serv-Prot"         => [ 113, "integer" ],
                "ITK-Auth-Req-Type"          => [ 124, "string" ],
                "ITK-Auth-Serv-IP"           => [ 100, "ipaddr" ],
                "ITK-Auth-Serv-Prot"         => [ 101, "integer" ],
                "ITK-Banner"                 => [ 104, "string" ],
                "ITK-Channel-Binding"        => [ 115, "integer" ],
                "ITK-DDI"                    => [ 131, "string" ],
                "ITK-Dest-No"                => [ 130, "string" ],
                "ITK-Dialout-Type"           => [ 120, "integer" ],
                "ITK-Filter-Rule"            => [ 114, "string" ],
                "ITK-Ftp-Auth-IP"            => [ 121, "ipaddr" ],
                "ITK-IP-Pool"                => [ 109, "integer" ],
                "ITK-ISDN-Prot"              => [ 118, "integer" ],
                "ITK-Modem-Init-String"      => [ 126, "string" ],
                "ITK-Modem-Pool-Id"          => [ 125, "integer" ],
                "ITK-NAS-Name"               => [ 117, "string" ],
                "ITK-Password-Prompt"        => [ 106, "string" ],
                "ITK-PPP-Auth-Type"          => [ 119, "integer" ],
                "ITK-PPP-Client-Server-Mode" => [ 127, "integer" ],
                "ITK-PPP-Compression-Prot"   => [ 128, "string" ],
                "ITK-Prompt"                 => [ 108, "string" ],
                "ITK-Provider-Id"            => [ 102, "integer" ],
                "ITK-Start-Delay"            => [ 116, "integer" ],
                "ITK-Tunnel-IP"              => [ 110, "ipaddr" ],
                "ITK-Tunnel-Prot"            => [ 111, "integer" ],
                "ITK-Usergroup"              => [ 103, "integer" ],
                "ITK-Username"               => [ 129, "string" ],
                "ITK-Username-Prompt"        => [ 105, "string" ],
                "ITK-Users-Default-Entry"    => [ 122, "string" ],
                "ITK-Users-Default-Pw"       => [ 123, "string" ],
                "ITK-Welcome-Message"        => [ 107, "string" ],
            },
            1271 => {
                "Ciena-BP-Role"           => [ 220, "string" ],
                "Ciena-CES-NACM-Groups"   => [ 11,  "string" ],
                "Ciena-CES-Priv-Level"    => [ 10,  "integer" ],
                "Ciena-CN4200-Priv-Level" => [ 1,   "integer" ],
                "Ciena-CS-Acc-Level"      => [ 254, "integer" ],
                "Ciena-CS-Client-IP"      => [ 253, "ipaddr" ],
                "Ciena-CS-Priv-Level"     => [ 255, "integer" ],
                "Ciena-NCS-Role"          => [ 240, "integer" ],
                "Ciena-OC-Role"           => [ 250, "string" ],
            },
            1431 => {
                "Telkom-Access-Type"   => [ 1,   "string" ],
                "Telkom-Degrade-Token" => [ 200, "string" ],
                "Telkom-Service-Type"  => [ 2,   "string" ],
            },
            1584 => {
                "Annex-Acct-Servers"             => [ 41,  "string" ],
                "Annex-Addr-Resolution-Protocol" => [ 47,  "integer" ],
                "Annex-Addr-Resolution-Servers"  => [ 48,  "string" ],
                "Annex-Audit-Level"              => [ 101, "integer" ],
                "Annex-Authen-Servers"           => [ 40,  "string" ],
                "Annex-Begin-Modulation"         => [ 96,  "string" ],
                "Annex-Begin-Receive-Line-Level" => [ 94,  "integer" ],
                "Annex-Callback-Portlist"        => [ 36,  "integer" ],
                "Annex-CLI-Command"              => [ 29,  "string" ],
                "Annex-Cli-Commands"             => [ 193, "string" ],
                "Annex-CLI-Filter"               => [ 30,  "string" ],
                "Annex-Command-Access"           => [ 194, "integer" ],
                "Annex-Compression-Protocol"     => [ 86,  "string" ],
                "Annex-Connect-Progress"         => [ 69,  "integer" ],
                "Annex-Disconnect-Reason"        => [ 46,  "integer" ],
                "Annex-Domain-Name"              => [ 49,  "string" ],
                "Annex-EDO"                      => [ 63,  "string" ],
                "Annex-End-Modulation"           => [ 98,  "string" ],
                "Annex-End-Receive-Line-Level"   => [ 95,  "integer" ],
                "Annex-Error-Correction-Prot"    => [ 97,  "string" ],
                "Annex-Filter"                   => [ 28,  "string" ],
                "Annex-Gwy-Selection-Mode"       => [ 80,  "integer" ],
                "Annex-Host-Allow"               => [ 32,  "string" ],
                "Annex-Host-Restrict"            => [ 31,  "string" ],
                "Annex-Input-Filter"             => [ 52,  "string" ],
                "Annex-Keypress-Timeout"         => [ 59,  "integer" ],
                "Annex-Local-IP-Address"         => [ 35,  "ipaddr" ],
                "Annex-Local-Username"           => [ 43,  "string" ],
                "Annex-Logical-Channel-Number"   => [ 81,  "integer" ],
                "Annex-Maximum-Call-Duration"    => [ 74,  "integer" ],
                "Annex-Modem-Disc-Reason"        => [ 45,  "integer" ],
                "Annex-MRRU"                     => [ 62,  "integer" ],
                "Annex-Multicast-Rate-Limit"     => [ 73,  "integer" ],
                "Annex-Multilink-Id"             => [ 75,  "integer" ],
                "Annex-Num-In-Multilink"         => [ 76,  "integer" ],
                "Annex-Output-Filter"            => [ 53,  "string" ],
                "Annex-Pool-Id"                  => [ 85,  "integer" ],
                "Annex-Port"                     => [ 83,  "integer" ],
                "Annex-PPP-Trace-Level"          => [ 64,  "integer" ],
                "Annex-Pre-Input-Octets"         => [ 65,  "integer" ],
                "Annex-Pre-Input-Packets"        => [ 67,  "integer" ],
                "Annex-Pre-Output-Octets"        => [ 66,  "integer" ],
                "Annex-Pre-Output-Packets"       => [ 68,  "integer" ],
                "Annex-Primary-DNS-Server"       => [ 54,  "ipaddr" ],
                "Annex-Primary-NBNS-Server"      => [ 56,  "ipaddr" ],
                "Annex-Product-Name"             => [ 33,  "string" ],
                "Annex-Rate-Reneg-Req-Rcvd"      => [ 93,  "integer" ],
                "Annex-Rate-Reneg-Req-Sent"      => [ 92,  "integer" ],
                "Annex-Re-CHAP-Timeout"          => [ 61,  "integer" ],
                "Annex-Receive-Speed"            => [ 51,  "integer" ],
                "Annex-Retrain-Requests-Rcvd"    => [ 91,  "integer" ],
                "Annex-Retrain-Requests-Sent"    => [ 90,  "integer" ],
                "Annex-Retransmitted-Packets"    => [ 88,  "integer" ],
                "Annex-Sec-Profile-Index"        => [ 37,  "integer" ],
                "Annex-Secondary-DNS-Server"     => [ 55,  "ipaddr" ],
                "Annex-Secondary-NBNS-Server"    => [ 57,  "ipaddr" ],
                "Annex-Secondary-Srv-Endpoint"   => [ 79,  "string" ],
                "Annex-Signal-to-Noise-Ratio"    => [ 89,  "integer" ],
                "Annex-SW-Version"               => [ 34,  "string" ],
                "Annex-Syslog-Tap"               => [ 58,  "integer" ],
                "Annex-System-Disc-Reason"       => [ 44,  "integer" ],
                "Annex-Transmit-Speed"           => [ 50,  "integer" ],
                "Annex-Transmitted-Packets"      => [ 87,  "integer" ],
                "Annex-Tunnel-Authen-Mode"       => [ 39,  "integer" ],
                "Annex-Tunnel-Authen-Type"       => [ 38,  "integer" ],
                "Annex-Unauthenticated-Time"     => [ 60,  "integer" ],
                "Annex-User-Level"               => [ 100, "integer" ],
                "Annex-User-Server-Location"     => [ 42,  "integer" ],
                "Annex-Wan-Number"               => [ 82,  "integer" ],
                "CES-Group"                      => [ 102, "string" ],
                "Commands"                       => [ 195, "string" ],
                "Passport-Access-Priority"       => [ 192, "integer" ],
            },
            1588 => {
                "Brocade-Auth-Role"         => [ 1, "string" ],
                "Brocade-AVPairs1"          => [ 2, "string" ],
                "Brocade-AVPairs2"          => [ 3, "string" ],
                "Brocade-AVPairs3"          => [ 4, "string" ],
                "Brocade-AVPairs4"          => [ 5, "string" ],
                "Brocade-Passwd-ExpiryDate" => [ 6, "string" ],
                "Brocade-Passwd-WarnPeriod" => [ 7, "string" ],
            },
            1768 => {
                "Patton-Called-Codec"                   => [ 72,  "string" ],
                "Patton-Called-IP-Address"              => [ 49,  "ipaddr" ],
                "Patton-Called-Local-Udp-Port"          => [ 75,  "integer" ],
                "Patton-Called-MOS"                     => [ 77,  "integer" ],
                "Patton-Called-Name"                    => [ 52,  "string" ],
                "Patton-Called-Numbering-Plan"          => [ 50,  "string" ],
                "Patton-Called-Qos"                     => [ 76,  "integer" ],
                "Patton-Called-Remote-Ip"               => [ 73,  "integer" ],
                "Patton-Called-Remote-Udp-Port"         => [ 74,  "integer" ],
                "Patton-Called-Round-Trip-Time"         => [ 78,  "integer" ],
                "Patton-Called-Rx-Jitter"               => [ 70,  "integer" ],
                "Patton-Called-Rx-Lost-Packets"         => [ 68,  "integer" ],
                "Patton-Called-Rx-Octets"               => [ 64,  "integer" ],
                "Patton-Called-Rx-Packets"              => [ 66,  "integer" ],
                "Patton-Called-Station-Id"              => [ 53,  "string" ],
                "Patton-Called-Tx-Jitter"               => [ 71,  "integer" ],
                "Patton-Called-Tx-Lost-Packets"         => [ 69,  "integer" ],
                "Patton-Called-Tx-Octets"               => [ 65,  "integer" ],
                "Patton-Called-Tx-Packets"              => [ 67,  "integer" ],
                "Patton-Called-Type-Of-Number"          => [ 51,  "string" ],
                "Patton-Called-Unique-Id"               => [ 48,  "string" ],
                "Patton-Calling-Codec"                  => [ 104, "string" ],
                "Patton-Calling-IP-Address"             => [ 81,  "ipaddr" ],
                "Patton-Calling-Local-Udp-Port"         => [ 107, "integer" ],
                "Patton-Calling-Lost-Rx-Packets"        => [ 101, "integer" ],
                "Patton-Calling-Lost-Tx-Packets"        => [ 100, "integer" ],
                "Patton-Calling-MOS"                    => [ 109, "integer" ],
                "Patton-Calling-Name"                   => [ 84,  "string" ],
                "Patton-Calling-Numbering-Plan"         => [ 82,  "string" ],
                "Patton-Calling-Presentation-Indicator" => [ 88,  "string" ],
                "Patton-Calling-Qos"                    => [ 108, "integer" ],
                "Patton-Calling-Remote-Ip"              => [ 105, "integer" ],
                "Patton-Calling-Remote-Udp-Port"        => [ 106, "integer" ],
                "Patton-Calling-Round-Trip-Time"        => [ 110, "integer" ],
                "Patton-Calling-Rx-Jitter"              => [ 102, "integer" ],
                "Patton-Calling-Rx-Octets"              => [ 96,  "integer" ],
                "Patton-Calling-Rx-Packets"             => [ 98,  "integer" ],
                "Patton-Calling-Screening-Indicator"    => [ 89,  "string" ],
                "Patton-Calling-Station-Id"             => [ 85,  "string" ],
                "Patton-Calling-Tx-Jitter"              => [ 103, "integer" ],
                "Patton-Calling-Tx-Octets"              => [ 97,  "integer" ],
                "Patton-Calling-Tx-Packets"             => [ 99,  "integer" ],
                "Patton-Calling-Type-Of-Number"         => [ 83,  "string" ],
                "Patton-Calling-Unique-Id"              => [ 80,  "string" ],
                "Patton-Connect-Time"                   => [ 33,  "string" ],
                "Patton-Disconnect-Cause"               => [ 35,  "integer" ],
                "Patton-Disconnect-Reason"              => [ 37,  "string" ],
                "Patton-Disconnect-Source"              => [ 36,  "string" ],
                "Patton-Disconnect-Time"                => [ 34,  "string" ],
                "Patton-Group"                          => [ 17,  "string" ],
                "Patton-Protocol"                       => [ 16,  "string" ],
                "Patton-Setup-Time"                     => [ 32,  "string" ],
                "Patton-Web-Privilege-Level"            => [ 18,  "string" ],
            },
            1872 => {
                "Alteon-Client-IP-Address"     => [ 4,  "ipaddr" ],
                "Alteon-Client-Netmask"        => [ 5,  "ipaddr" ],
                "Alteon-Domain-Name"           => [ 10, "string" ],
                "Alteon-Group-Mapping"         => [ 1,  "string" ],
                "Alteon-Primary-DNS-Server"    => [ 8,  "ipaddr" ],
                "Alteon-Primary-NBNS-Server"   => [ 6,  "ipaddr" ],
                "Alteon-Secondary-DNS-Server"  => [ 9,  "ipaddr" ],
                "Alteon-Secondary-NBNS-Server" => [ 7,  "ipaddr" ],
                "Alteon-Service-Type"          => [ 26, "integer" ],
                "Alteon-VPN-Id"                => [ 3,  "integer" ],
            },
            1916 => {
                "Extreme-CLI-Authorization"      => [ 201, "integer" ],
                "Extreme-Netlogin-Extended-Vlan" => [ 211, "string" ],
                "Extreme-Netlogin-Only"          => [ 206, "integer" ],
                "Extreme-Netlogin-Url"           => [ 204, "string" ],
                "Extreme-Netlogin-Url-Desc"      => [ 205, "string" ],
                "Extreme-Netlogin-Vlan"          => [ 203, "string" ],
                "Extreme-Netlogin-Vlan-Tag"      => [ 209, "integer" ],
                "Extreme-Security-Profile"       => [ 212, "string" ],
                "Extreme-Shell-Command"          => [ 202, "string" ],
                "Extreme-User-Location"          => [ 208, "string" ],
                "Extreme-VM-IP-Addr"             => [ 215, "ipaddr" ],
                "Extreme-VM-Name"                => [ 213, "string" ],
                "Extreme-VM-VLAN-ID"             => [ 216, "integer" ],
                "Extreme-VM-VPP-Name"            => [ 214, "string" ],
                "Extreme-VM-VR-Name"             => [ 217, "string" ],
            },
            1958 => {
                "RedCreek-Tunneled-DNS-Server"   => [ 8,  "string" ],
                "RedCreek-Tunneled-DomainName"   => [ 12, "string" ],
                "RedCreek-Tunneled-Gateway"      => [ 7,  "ipaddr" ],
                "RedCreek-Tunneled-HostName"     => [ 11, "string" ],
                "RedCreek-Tunneled-IP-Addr"      => [ 5,  "ipaddr" ],
                "RedCreek-Tunneled-IP-Netmask"   => [ 6,  "ipaddr" ],
                "RedCreek-Tunneled-Search-List"  => [ 13, "string" ],
                "RedCreek-Tunneled-WINS-Server1" => [ 9,  "string" ],
                "RedCreek-Tunneled-WINS-Server2" => [ 10, "string" ],
            },
            1966 => {
                "Perle-Clustered-Port-Access" => [ 99,  "integer" ],
                "Perle-Line-Access-Port-1"    => [ 101, "integer" ],
                "Perle-Line-Access-Port-10"   => [ 110, "integer" ],
                "Perle-Line-Access-Port-11"   => [ 111, "integer" ],
                "Perle-Line-Access-Port-12"   => [ 112, "integer" ],
                "Perle-Line-Access-Port-13"   => [ 113, "integer" ],
                "Perle-Line-Access-Port-14"   => [ 114, "integer" ],
                "Perle-Line-Access-Port-15"   => [ 115, "integer" ],
                "Perle-Line-Access-Port-16"   => [ 116, "integer" ],
                "Perle-Line-Access-Port-17"   => [ 117, "integer" ],
                "Perle-Line-Access-Port-18"   => [ 118, "integer" ],
                "Perle-Line-Access-Port-19"   => [ 119, "integer" ],
                "Perle-Line-Access-Port-2"    => [ 102, "integer" ],
                "Perle-Line-Access-Port-20"   => [ 120, "integer" ],
                "Perle-Line-Access-Port-21"   => [ 121, "integer" ],
                "Perle-Line-Access-Port-22"   => [ 122, "integer" ],
                "Perle-Line-Access-Port-23"   => [ 123, "integer" ],
                "Perle-Line-Access-Port-24"   => [ 124, "integer" ],
                "Perle-Line-Access-Port-25"   => [ 125, "integer" ],
                "Perle-Line-Access-Port-26"   => [ 126, "integer" ],
                "Perle-Line-Access-Port-27"   => [ 127, "integer" ],
                "Perle-Line-Access-Port-28"   => [ 128, "integer" ],
                "Perle-Line-Access-Port-29"   => [ 129, "integer" ],
                "Perle-Line-Access-Port-3"    => [ 103, "integer" ],
                "Perle-Line-Access-Port-30"   => [ 130, "integer" ],
                "Perle-Line-Access-Port-31"   => [ 131, "integer" ],
                "Perle-Line-Access-Port-32"   => [ 132, "integer" ],
                "Perle-Line-Access-Port-33"   => [ 133, "integer" ],
                "Perle-Line-Access-Port-34"   => [ 134, "integer" ],
                "Perle-Line-Access-Port-35"   => [ 135, "integer" ],
                "Perle-Line-Access-Port-36"   => [ 136, "integer" ],
                "Perle-Line-Access-Port-37"   => [ 137, "integer" ],
                "Perle-Line-Access-Port-38"   => [ 138, "integer" ],
                "Perle-Line-Access-Port-39"   => [ 139, "integer" ],
                "Perle-Line-Access-Port-4"    => [ 104, "integer" ],
                "Perle-Line-Access-Port-40"   => [ 140, "integer" ],
                "Perle-Line-Access-Port-41"   => [ 141, "integer" ],
                "Perle-Line-Access-Port-42"   => [ 142, "integer" ],
                "Perle-Line-Access-Port-43"   => [ 143, "integer" ],
                "Perle-Line-Access-Port-44"   => [ 144, "integer" ],
                "Perle-Line-Access-Port-45"   => [ 145, "integer" ],
                "Perle-Line-Access-Port-46"   => [ 146, "integer" ],
                "Perle-Line-Access-Port-47"   => [ 147, "integer" ],
                "Perle-Line-Access-Port-48"   => [ 148, "integer" ],
                "Perle-Line-Access-Port-49"   => [ 149, "integer" ],
                "Perle-Line-Access-Port-5"    => [ 105, "integer" ],
                "Perle-Line-Access-Port-6"    => [ 106, "integer" ],
                "Perle-Line-Access-Port-7"    => [ 107, "integer" ],
                "Perle-Line-Access-Port-8"    => [ 108, "integer" ],
                "Perle-Line-Access-Port-9"    => [ 109, "integer" ],
                "Perle-User-Level"            => [ 100, "integer" ],
            },
            1991 => {
                "Foundry-802.1x-Valid-Lookup"      => [ 7,  "integer" ],
                "Foundry-Access-List"              => [ 5,  "string" ],
                "Foundry-COA-Command"              => [ 10, "string" ],
                "Foundry-Command-Exception-Flag"   => [ 3,  "integer" ],
                "Foundry-Command-String"           => [ 2,  "string" ],
                "Foundry-INM-Privilege"            => [ 4,  "integer" ],
                "Foundry-INM-Role-Aor-List"        => [ 9,  "string" ],
                "Foundry-MAC-Authent-needs-802.1x" => [ 6,  "integer" ],
                "Foundry-MAC-Based-Vlan-QoS"       => [ 8,  "integer" ],
                "Foundry-Privilege-Level"          => [ 1,  "integer" ],
                "Foundry-SI-Context-Role"          => [ 10, "string" ],
                "Foundry-SI-Role-Template"         => [ 11, "string" ],
                "Foundry-Voice-Phone-Config"       => [ 11, "string" ],
            },
            2004 => {
                "WB-Auth-Accum-BW"       => [ 2,  "integer" ],
                "WB-Auth-BW-Count"       => [ 4,  "integer" ],
                "WB-Auth-BW-Quota"       => [ 3,  "integer" ],
                "WB-Auth-BW-Usage"       => [ 10, "integer" ],
                "WB-Auth-Download-Limit" => [ 6,  "integer" ],
                "WB-Auth-Login-Time"     => [ 7,  "integer" ],
                "WB-Auth-Logout-Time"    => [ 8,  "integer" ],
                "WB-Auth-Time-Diff"      => [ 9,  "integer" ],
                "WB-AUTH-Time-Left"      => [ 1,  "integer" ],
                "WB-Auth-Upload-Limit"   => [ 5,  "integer" ],
            },
            2011 => {
                "Huawei-Access-Num"                  => [ 127, "string" ],
                "Huawei-Access-Service"              => [ 83,  "string" ],
                "Huawei-Account-Info"                => [ 184, "string" ],
                "Huawei-Accounting-Level"            => [ 84,  "integer" ],
                "Huawei-Acct-Connection-Time"        => [ 110, "integer" ],
                "Huawei-Acct-IPv6-Input-Gigawords"   => [ 148, "integer" ],
                "Huawei-Acct-IPv6-Input-Octets"      => [ 144, "integer" ],
                "Huawei-Acct-IPv6-Input-Packets"     => [ 146, "integer" ],
                "Huawei-Acct-IPv6-Output-Gigawords"  => [ 149, "integer" ],
                "Huawei-Acct-IPv6-Output-Octets"     => [ 145, "integer" ],
                "Huawei-Acct-IPv6-Output-Packets"    => [ 147, "integer" ],
                "Huawei-Acct-Packet-Type"            => [ 106, "integer" ],
                "Huawei-Acct-Terminate-Subcause"     => [ 181, "string" ],
                "Huawei-Acct-Update-Address"         => [ 159, "integer" ],
                "Huawei-ACS-Url"                     => [ 219, "string" ],
                "Huawei-ANCP-Profile"                => [ 139, "string" ],
                "Huawei-Application-Scene"           => [ 221, "octets" ],
                "Huawei-Application-Type"            => [ 215, "integer" ],
                "Huawei-Auth-Type"                   => [ 180, "integer" ],
                "Huawei-AVpair"                      => [ 188, "string" ],
                "Huawei-Call-Reference"              => [ 107, "integer" ],
                "Huawei-Codec-Type"                  => [ 131, "integer" ],
                "Huawei-Command"                     => [ 20,  "integer" ],
                "Huawei-Command-Mode"                => [ 34,  "string" ],
                "Huawei-Connect-ID"                  => [ 26,  "integer" ],
                "Huawei-Control-Identifier"          => [ 24,  "integer" ],
                "Huawei-Data-Filter"                 => [ 82,  "string" ],
                "Huawei-Delegated-IPv6-Prefix-Pool"  => [ 191, "string" ],
                "Huawei-Destnation-IP-Addr"          => [ 39,  "string" ],
                "Huawei-Destnation-Volume"           => [ 40,  "string" ],
                "Huawei-DHCP-Option"                 => [ 187, "octets" ],
                "Huawei-DHCP-Server-IP"              => [ 214, "ipaddr" ],
                "Huawei-DHCPv4-Option121"            => [ 155, "string" ],
                "Huawei-DHCPv4-Option43"             => [ 156, "string" ],
                "Huawei-DHCPv6-Option37"             => [ 150, "string" ],
                "Huawei-DHCPv6-Option38"             => [ 151, "string" ],
                "Huawei-DNS-Server-IPv6-address"     => [ 154, "ipv6addr" ],
                "Huawei-Domain-Name"                 => [ 138, "string" ],
                "Huawei-Down-Priority"               => [ 62,  "integer" ],
                "Huawei-Down-QOS-Profile-Name"       => [ 182, "string" ],
                "Huawei-DPI-Policy-Name"             => [ 86,  "string" ],
                "Huawei-DPSK-Info"                   => [ 206, "string" ],
                "Huawei-DS-Lite-Tunnel-Name"         => [ 166, "string" ],
                "Huawei-Dst-GK-ipaddr"               => [ 125, "ipaddr" ],
                "Huawei-Dst-GW-ipaddr"               => [ 126, "ipaddr" ],
                "Huawei-Error-Reason"                => [ 112, "integer" ],
                "Huawei-Exec-Privilege"              => [ 29,  "integer" ],
                "Huawei-Ext-Specific"                => [ 238, "string" ],
                "Huawei-Flow-Id"                     => [ 212, "integer" ],
                "Huawei-Flow-Info"                   => [ 211, "string" ],
                "Huawei-Framed-IPv6-Address"         => [ 158, "ipv6addr" ],
                "Huawei-Framed-Pool"                 => [ 88,  "string" ],
                "Huawei-Framed-Pool-Group"           => [ 157, "string" ],
                "Huawei-FTP-Directory"               => [ 28,  "string" ],
                "Huawei-Gateway-Address"             => [ 73,  "ipaddr" ],
                "Huawei-GGSN-Vendor"                 => [ 232, "string" ],
                "Huawei-GGSN-Version"                => [ 233, "string" ],
                "Huawei-HTTP-Redirect-URL"           => [ 140, "string" ],
                "Huawei-IGMP-Enable"                 => [ 37,  "integer" ],
                "Huawei-In-Kb-After-T-Switch"        => [ 11,  "integer" ],
                "Huawei-In-Kb-Before-T-Switch"       => [ 7,   "integer" ],
                "Huawei-In-Pkt-After-T-Switch"       => [ 13,  "integer" ],
                "Huawei-In-Pkt-Before-T-Switch"      => [ 9,   "integer" ],
                "Huawei-Indication-Flag"             => [ 216, "octets" ],
                "Huawei-Input-Average-Rate"          => [ 2,   "integer" ],
                "Huawei-Input-Burst-Size"            => [ 1,   "integer" ],
                "Huawei-Input-Peak-Burst-Size"       => [ 77,  "integer" ],
                "Huawei-Input-Peak-Rate"             => [ 3,   "integer" ],
                "Huawei-IP-Address"                  => [ 30,  "integer" ],
                "Huawei-IPHost-Addr"                 => [ 60,  "string" ],
                "Huawei-IPv6-Address-Lease"          => [ 193, "octets" ],
                "Huawei-IPv6-Policy-Route"           => [ 194, "ipv6prefix" ],
                "Huawei-IPv6-Prefix-Lease"           => [ 192, "octets" ],
                "Huawei-ISP-ID"                      => [ 17,  "string" ],
                "Huawei-L2TP-Terminate-Cause"        => [ 89,  "string" ],
                "Huawei-Layer4-Session-Limit"        => [ 92,  "integer" ],
                "Huawei-Lease-Time"                  => [ 74,  "integer" ],
                "Huawei-LI-ID"                       => [ 101, "string" ],
                "Huawei-LI-Md-Address"               => [ 102, "ipaddr" ],
                "Huawei-LI-Md-Port"                  => [ 103, "integer" ],
                "Huawei-LI-Md-VpnInstance"           => [ 104, "string" ],
                "Huawei-Loopback-Address"            => [ 141, "string" ],
                "Huawei-Max-List-Num"                => [ 143, "integer" ],
                "Huawei-Max-Users-Per-Logic-Port"    => [ 18,  "integer" ],
                "Huawei-MNG-IPv6"                    => [ 196, "integer" ],
                "Huawei-MS-Maximum-MAC-Study-Number" => [ 222, "octets" ],
                "Huawei-Multi-Account-Mode"          => [ 90,  "integer" ],
                "Huawei-Multicast-Profile"           => [ 93,  "string" ],
                "Huawei-Multicast-Receive-Group"     => [ 98,  "ipaddr" ],
                "Huawei-Multicast-Source-Group"      => [ 97,  "string" ],
                "Huawei-NAT-End-Port"                => [ 163, "integer" ],
                "Huawei-NAT-Policy-Name"             => [ 160, "string" ],
                "Huawei-NAT-Port-Forwarding"         => [ 164, "integer" ],
                "Huawei-NAT-Port-Range-Update"       => [ 165, "integer" ],
                "Huawei-NAT-Public-Address"          => [ 161, "ipaddr" ],
                "Huawei-NAT-Start-Port"              => [ 162, "integer" ],
                "Huawei-New-User-Name"               => [ 133, "string" ],
                "Huawei-ONLY-Account-Type"           => [ 137, "integer" ],
                "Huawei-Org-GK-ipaddr"               => [ 123, "ipaddr" ],
                "Huawei-Org-GW-ipaddr"               => [ 124, "ipaddr" ],
                "Huawei-Original_NAS-IP_Address"     => [ 217, "ipaddr" ],
                "Huawei-Out-Kb-After-T-Switch"       => [ 12,  "integer" ],
                "Huawei-Out-Kb-Before-T-Switch"      => [ 8,   "integer" ],
                "Huawei-Out-Pkt-After-T-Switch"      => [ 14,  "integer" ],
                "Huawei-Out-Pkt-Before-T-Switch"     => [ 10,  "integer" ],
                "Huawei-Output-Average-Rate"         => [ 5,   "integer" ],
                "Huawei-Output-Burst-Size"           => [ 4,   "integer" ],
                "Huawei-Output-Peak-Burst-Size"      => [ 78,  "integer" ],
                "Huawei-Output-Peak-Rate"            => [ 6,   "integer" ],
                "Huawei-PCP-Server-Name"             => [ 167, "string" ],
                "Huawei-Policy-Name"                 => [ 95,  "string" ],
                "huawei-Policy-Route"                => [ 87,  "ipaddr" ],
                "Huawei-Port-Mirror"                 => [ 183, "integer" ],
                "Huawei-Portal-Mode"                 => [ 85,  "integer" ],
                "Huawei-PortalURL"                   => [ 27,  "string" ],
                "Huawei-PPP-NCP-Type"                => [ 70,  "integer" ],
                "Huawei-Primary-DNS"                 => [ 135, "ipaddr" ],
                "Huawei-Primary-WINS"                => [ 75,  "ipaddr" ],
                "Huawei-Priority"                    => [ 22,  "integer" ],
                "Huawei-Product-ID"                  => [ 255, "string" ],
                "Huawei-Provision-Code"              => [ 220, "string" ],
                "Huawei-PSTN-Port"                   => [ 108, "integer" ],
                "Huawei-Public-IP-Addr-State"        => [ 168, "integer" ],
                "Huawei-Qos-Profile-Name"            => [ 31,  "string" ],
                "Huawei-QoS-Profile-Type"            => [ 142, "integer" ],
                "Huawei-Queue-Profile"               => [ 91,  "string" ],
                "Huawei-Rebinding-Time"              => [ 36,  "integer" ],
                "Huawei-Reduced-CIR"                 => [ 79,  "integer" ],
                "Huawei-Reduced-PIR"                 => [ 100, "integer" ],
                "Huawei-Remain-Monney"               => [ 113, "integer" ],
                "Huawei-Remain-Time"                 => [ 128, "integer" ],
                "Huawei-Remanent-Volume"             => [ 15,  "integer" ],
                "Huawei-Renewal-Time"                => [ 35,  "integer" ],
                "Huawei-Result-Code"                 => [ 25,  "integer" ],
                "Huawei-Secondary-DNS"               => [ 136, "ipaddr" ],
                "Huawei-Secondary-WINS"              => [ 76,  "ipaddr" ],
                "Huawei-Service-Chg-Cmd"             => [ 105, "integer" ],
                "Huawei-Service-Info"                => [ 185, "string" ],
                "Huawei-SIP-Server"                  => [ 32,  "string" ],
                "Huawei-Startup-Stamp"               => [ 59,  "integer" ],
                "Huawei-Subnet-Mask"                 => [ 72,  "ipaddr" ],
                "Huawei-Tariff-Switch-Interval"      => [ 16,  "integer" ],
                "Huawei-Transfer-Num"                => [ 132, "string" ],
                "Huawei-Transfer-Station-Id"         => [ 134, "string" ],
                "Huawei-Tunnel-Group-Name"           => [ 96,  "string" ],
                "Huawei-Tunnel-Session-Limit"        => [ 80,  "integer" ],
                "Huawei-Tunnel-VPN-Instance"         => [ 63,  "string" ],
                "Huawei-Up-Priority"                 => [ 61,  "integer" ],
                "Huawei-User-Class"                  => [ 66,  "string" ],
                "Huawei-User-Date"                   => [ 65,  "string" ],
                "Huawei-User-Mac"                    => [ 153, "string" ],
                "Huawei-User-Multicast-Type"         => [ 99,  "integer" ],
                "Huawei-User-Password"               => [ 33,  "string" ],
                "Huawei-User-Priority"               => [ 218, "integer" ],
                "Huawei-Version"                     => [ 254, "string" ],
                "Huawei-Voip-Service-Type"           => [ 109, "integer" ],
                "Huawei-VPN-Instance"                => [ 94,  "string" ],
                "Huawei-VSI-Name"                    => [ 71,  "string" ],
                "Huawei-VT-Name"                     => [ 64,  "integer" ],
                "Huawei-Web-URL"                     => [ 253, "string" ],
                "Huawei-Zone-Name"                   => [ 81,  "string" ],
            },
            2167 => {
                "Avaya-PortPriority-Type" => [ 13, "integer" ],
                "Avaya-StaticVlan-Type"   => [ 12, "string" ],
                "Cajun-Service-Type"      => [ 1,  "integer" ],
            },
            2180 => { "Versanet-Termination-Cause" => [ 1, "integer" ] },
            2334 => {
                "Packeteer-AVPair"    => [ 1, "string" ],
                "Packeteer-PC-AVPair" => [ 2, "string" ],
            },
            2352 => {
                "Acct-Alt-Session-ID"             => [ 197, "string" ],
                "Acct-Dyn-Ac-Ent"                 => [ 141, "string" ],
                "Acct-Input-IPv4-Gigawords"       => [ 218, "integer" ],
                "Acct-Input-IPv4-Octets"          => [ 214, "integer" ],
                "Acct-Input-IPv4-Packets"         => [ 216, "integer" ],
                "Acct-Input-IPv6-Gigawords"       => [ 224, "integer" ],
                "Acct-Input-IPv6-Octets"          => [ 220, "integer" ],
                "Acct-Input-IPv6-Packets"         => [ 222, "integer" ],
                "Acct-Input-Octets-64"            => [ 128, "integer64" ],
                "Acct-Input-Packets-64"           => [ 130, "integer64" ],
                "Acct-Mcast-In-Octets"            => [ 147, "integer" ],
                "Acct-Mcast-In-Octets-64"         => [ 133, "integer64" ],
                "Acct-Mcast-In-Packets"           => [ 149, "integer" ],
                "Acct-Mcast-In-Packets-64"        => [ 135, "integer64" ],
                "Acct-Mcast-Out-Octets"           => [ 148, "integer" ],
                "Acct-Mcast-Out-Octets-64"        => [ 134, "integer64" ],
                "Acct-Mcast-Out-Packets"          => [ 150, "integer" ],
                "Acct-Mcast-Out-Packets-64"       => [ 136, "integer64" ],
                "Acct-Output-IPv4-Gigawords"      => [ 219, "integer" ],
                "Acct-Output-IPv4-Octets"         => [ 215, "integer" ],
                "Acct-Output-IPv4-Packets"        => [ 217, "integer" ],
                "Acct-Output-IPv6-Gigawords"      => [ 225, "integer" ],
                "Acct-Output-IPv6-Octets"         => [ 221, "integer" ],
                "Acct-Output-IPv6-Packets"        => [ 223, "integer" ],
                "Acct-Output-Octets-64"           => [ 129, "integer64" ],
                "Acct-Output-Packets-64"          => [ 131, "integer64" ],
                "Acct-Update-Reason"              => [ 144, "integer" ],
                "ACL-Definition"                  => [ 70,  "string" ],
                "Agent-Circuit-Id"                => [ 97,  "octets" ],
                "Agent-Remote-Id"                 => [ 96,  "octets" ],
                "Assigned-IP-Address"             => [ 132, "ipaddr" ],
                "BG-Aging-Time"                   => [ 6,   "string" ],
                "BG-Cct-Addr-Max"                 => [ 103, "integer" ],
                "BG-Path-Cost"                    => [ 7,   "string" ],
                "BG-Span-Dis"                     => [ 8,   "string" ],
                "BG-Trans-BPDU"                   => [ 9,   "string" ],
                "Bind-Auth-Context"               => [ 46,  "string" ],
                "Bind-Auth-Max-Sessions"          => [ 44,  "integer" ],
                "Bind-Auth-Protocol"              => [ 43,  "integer" ],
                "Bind-Auth-Service-Grp"           => [ 47,  "string" ],
                "Bind-Auto-Sub-Context"           => [ 109, "string" ],
                "Bind-Auto-Sub-Password"          => [ 110, "string" ],
                "Bind-Auto-Sub-User"              => [ 108, "string" ],
                "Bind-Bypass-Bypass"              => [ 45,  "string" ],
                "Bind-Bypass-Context"             => [ 48,  "string" ],
                "Bind-Dot1q-Port"                 => [ 53,  "integer" ],
                "Bind-Dot1q-Slot"                 => [ 52,  "integer" ],
                "Bind-Dot1q-Vlan-Tag-Id"          => [ 54,  "integer" ],
                "Bind-Int-Context"                => [ 49,  "string" ],
                "Bind-Int-Interface-Name"         => [ 55,  "string" ],
                "Bind-L2TP-Flow-Control"          => [ 57,  "integer" ],
                "Bind-L2TP-Tunnel-Name"           => [ 56,  "string" ],
                "Bind-Ses-Context"                => [ 51,  "string" ],
                "Bind-Sub-Password"               => [ 59,  "string" ],
                "Bind-Sub-User-At-Context"        => [ 58,  "string" ],
                "Bind-Tun-Context"                => [ 50,  "string" ],
                "Bind-Type"                       => [ 42,  "integer" ],
                "Bridge-Group"                    => [ 5,   "string" ],
                "Circuit-Group-Member"            => [ 210, "string" ],
                "Circuit-Protocol-Encap"          => [ 111, "integer" ],
                "Class-Volume-In-Counter"         => [ 187, "string" ],
                "Class-Volume-limit"              => [ 186, "string" ],
                "Class-Volume-Out-Counter"        => [ 188, "string" ],
                "Client-DNS-Pri"                  => [ 1,   "ipaddr" ],
                "Client-DNS-Sec"                  => [ 2,   "ipaddr" ],
                "Client-NBNS-Pri"                 => [ 99,  "ipaddr" ],
                "Client-NBNS-Sec"                 => [ 100, "ipaddr" ],
                "Cluster-Partition-ID"            => [ 209, "string" ],
                "Context-Name"                    => [ 4,   "string" ],
                "Deactivate-Service-Name"         => [ 194, "string" ],
                "Delegated-Max-Prefix"            => [ 212, "integer" ],
                "DHCP-Field"                      => [ 201, "octets" ],
                "DHCP-Max-Leases"                 => [ 3,   "integer" ],
                "DHCP-Option"                     => [ 202, "octets" ],
                "DHCP-Vendor-Class-ID"            => [ 125, "string" ],
                "DHCP-Vendor-Encap-Option"        => [ 127, "string" ],
                "Double-Authentication"           => [ 199, "integer" ],
                "DSL-Actual-Inter-Delay-Down"     => [ 179, "integer" ],
                "DSL-Actual-Inter-Delay-Up"       => [ 177, "integer" ],
                "DSL-Actual-Rate-Down"            => [ 167, "integer" ],
                "DSL-Actual-Rate-Down-Factor"     => [ 185, "integer" ],
                "DSL-Actual-Rate-Up"              => [ 166, "integer" ],
                "DSL-Attainable-Rate-Down"        => [ 171, "integer" ],
                "DSL-Attainable-Rate-Up"          => [ 170, "integer" ],
                "DSL-Combined-Line-Info"          => [ 184, "string" ],
                "DSL-L2-Encapsulation"            => [ 181, "integer" ],
                "DSL-Line-State"                  => [ 180, "integer" ],
                "DSL-Max-Inter-Delay-Down"        => [ 178, "integer" ],
                "DSL-Max-Inter-Delay-Up"          => [ 176, "integer" ],
                "DSL-Max-Rate-Down"               => [ 173, "integer" ],
                "DSL-Max-Rate-Up"                 => [ 172, "integer" ],
                "DSL-Min-Low-Power-Rate-Down"     => [ 175, "integer" ],
                "DSL-Min-Low-Power-Rate-Up"       => [ 174, "integer" ],
                "DSL-Min-Rate-Down"               => [ 169, "integer" ],
                "DSL-Min-Rate-Up"                 => [ 168, "integer" ],
                "DSL-PPPOA-PPPOE-Inter-Work-Flag" => [ 183, "integer" ],
                "DSL-Transmission-System"         => [ 182, "integer" ],
                "Dynamic-Policy-Filter"           => [ 164, "string" ],
                "Dynamic-QoS-Param"               => [ 196, "string" ],
                "Flow-FAC-Profile"                => [ 189, "string" ],
                "Flow-IP-Profile"                 => [ 205, "string" ],
                "Forward-Policy"                  => [ 92,  "string" ],
                "HTTP-Redirect-Profile-Name"      => [ 107, "string" ],
                "HTTP-Redirect-URL"               => [ 165, "string" ],
                "Idle-Timeout-Threshold"          => [ 198, "integer" ],
                "IGMP-Service-Profile-Name"       => [ 90,  "string" ],
                "Ip-Address-Pool-Name"            => [ 36,  "string" ],
                "Ip-Host-Addr"                    => [ 60,  "string" ],
                "IP-Interface-Name"               => [ 104, "string" ],
                "IP-TOS-Field"                    => [ 61,  "integer" ],
                "IPv4-Address-Release-Control"    => [ 213, "string" ],
                "LAC-Port"                        => [ 137, "integer" ],
                "LAC-Port-Type"                   => [ 139, "integer" ],
                "LAC-Real-Port"                   => [ 138, "integer" ],
                "LAC-Real-Port-Type"              => [ 140, "integer" ],
                "LI-Action"                       => [ 162, "integer" ],
                "LI-Id"                           => [ 159, "integer" ],
                "LI-Md-Address"                   => [ 160, "ipaddr" ],
                "LI-Md-Port"                      => [ 161, "integer" ],
                "LI-Profile"                      => [ 163, "string" ],
                "Mac-Addr"                        => [ 145, "string" ],
                "Mcast-MaxGroups"                 => [ 35,  "integer" ],
                "Mcast-Receive"                   => [ 34,  "integer" ],
                "Mcast-Send"                      => [ 33,  "integer" ],
                "Medium-Type"                     => [ 38,  "integer" ],
                "NAS-Real-Port"                   => [ 62,  "integer" ],
                "NAT-Policy-Name"                 => [ 105, "string" ],
                "OS-Version"                      => [ 112, "string" ],
                "Platform-Type"                   => [ 98,  "integer" ],
                "Police-Burst"                    => [ 13,  "integer" ],
                "Police-Excess-Burst"             => [ 122, "octets" ],
                "Police-Rate"                     => [ 12,  "integer" ],
                "PPP-Compression"                 => [ 84,  "integer" ],
                "PPPoE-IP-Route-Add"              => [ 71,  "string" ],
                "PPPOE-MOTM"                      => [ 28,  "string" ],
                "PPPOE-URL"                       => [ 27,  "string" ],
                "PVC-Circuit-Padding"             => [ 41,  "integer" ],
                "PVC-Encapsulation-Type"          => [ 39,  "integer" ],
                "PVC-Profile-Name"                => [ 40,  "string" ],
                "Qos-Metering-Profile-Name"       => [ 88,  "string" ],
                "Qos-Policing-Profile-Name"       => [ 87,  "string" ],
                "Qos-Policy-Queuing"              => [ 89,  "string" ],
                "Qos-Profile-Overhead"            => [ 195, "string" ],
                "Qos-Rate"                        => [ 126, "string" ],
                "QOS-Rate-Inbound"                => [ 156, "string" ],
                "QOS-Rate-Outbound"               => [ 157, "string" ],
                "QOS-Reference"                   => [ 114, "string" ],
                "Radius-Throttle-Watermark"       => [ 206, "integer" ],
                "Rate-Limit-Burst"                => [ 11,  "integer" ],
                "Rate-Limit-Excess-Burst"         => [ 121, "octets" ],
                "Rate-Limit-Rate"                 => [ 10,  "integer" ],
                "RB-IPV6-DNS"                     => [ 207, "string" ],
                "RB-IPv6-Option"                  => [ 208, "string" ],
                "RB-NPM-Service-Id"               => [ 106, "string" ],
                "Reauth"                          => [ 94,  "string" ],
                "Reauth-More"                     => [ 95,  "integer" ],
                "Reauth-Service-Name"             => [ 204, "string" ],
                "Reauth-Session-Id"               => [ 151, "string" ],
                "Redback-Reason"                  => [ 86,  "integer" ],
                "Remote-Port"                     => [ 93,  "string" ],
                "Route-Tag"                       => [ 158, "integer" ],
                "SBC-Adjacency"                   => [ 200, "string" ],
                "Security-Service"                => [ 203, "string" ],
                "Service-Action"                  => [ 191, "integer" ],
                "Service-Error-Cause"             => [ 193, "integer" ],
                "Service-Name"                    => [ 190, "string" ],
                "Service-Parameter"               => [ 192, "string" ],
                "Session-Error-Code"              => [ 142, "integer" ],
                "Session-Error-Msg"               => [ 143, "string" ],
                "Session-Traffic-Limit"           => [ 113, "string" ],
                "Shaping-Profile-Name"            => [ 101, "string" ],
                "Source-Validation"               => [ 14,  "integer" ],
                "Subscriber-Profile-Name"         => [ 91,  "string" ],
                "TTY-Level-Max"                   => [ 72,  "integer" ],
                "TTY-Level-Start"                 => [ 73,  "integer" ],
                "Tunnel-Algorithm"                => [ 31,  "integer" ],
                "Tunnel-Checksum"                 => [ 74,  "integer" ],
                "Tunnel-Client-Int-Addr"          => [ 82,  "ipaddr" ],
                "Tunnel-Client-Rhost"             => [ 80,  "string" ],
                "Tunnel-Client-VPN"               => [ 78,  "string" ],
                "Tunnel-Cmd-Timeout"              => [ 26,  "integer" ],
                "Tunnel-Context"                  => [ 30,  "string" ],
                "Tunnel-Deadtime"                 => [ 32,  "integer" ],
                "Tunnel-DNIS"                     => [ 37,  "integer" ],
                "Tunnel-Domain"                   => [ 15,  "integer" ],
                "Tunnel-Flow-Control"             => [ 19,  "integer" ],
                "Tunnel-Function"                 => [ 18,  "integer" ],
                "Tunnel-Group"                    => [ 29,  "integer" ],
                "Tunnel-Hello-Timer"              => [ 85,  "integer" ],
                "Tunnel-L2F-Second-Password"      => [ 69,  "string" ],
                "Tunnel-Local-Name"               => [ 16,  "string" ],
                "Tunnel-Max-Sessions"             => [ 21,  "integer" ],
                "Tunnel-Max-Tunnels"              => [ 22,  "integer" ],
                "Tunnel-Police-Burst"             => [ 68,  "integer" ],
                "Tunnel-Police-Excess-Burst"      => [ 124, "octets" ],
                "Tunnel-Police-Rate"              => [ 67,  "integer" ],
                "Tunnel-Profile"                  => [ 75,  "string" ],
                "Tunnel-Rate-Limit-Burst"         => [ 66,  "integer" ],
                "Tunnel-Rate-Limit-Excess-Burst"  => [ 123, "octets" ],
                "Tunnel-Rate-Limit-Rate"          => [ 65,  "integer" ],
                "Tunnel-Remote-Name"              => [ 17,  "string" ],
                "Tunnel-Retransmit"               => [ 25,  "integer" ],
                "Tunnel-Server-Int-Addr"          => [ 83,  "ipaddr" ],
                "Tunnel-Server-Rhost"             => [ 81,  "string" ],
                "Tunnel-Server-VPN"               => [ 79,  "string" ],
                "Tunnel-Session-Auth"             => [ 23,  "integer" ],
                "Tunnel-Session-Auth-Ctx"         => [ 63,  "string" ],
                "Tunnel-Session-Auth-Service-Grp" => [ 64,  "string" ],
                "Tunnel-Static"                   => [ 20,  "integer" ],
                "Tunnel-Window"                   => [ 24,  "integer" ],
                "Vlan-Source-Info"                => [ 146, "string" ],
            },
            2356 => {
                "LCS-Access-Rights"           => [ 11, "integer" ],
                "LCS-Account-End"             => [ 5,  "integer" ],
                "LCS-Advertisement-Interval"  => [ 14, "integer" ],
                "LCS-Advertisement-URL"       => [ 13, "string" ],
                "LCS-Comment"                 => [ 4,  "string" ],
                "LCS-DNS-Server-IPv4-Address" => [ 21, "ipaddr" ],
                "LCS-Function-Rights"         => [ 12, "integer" ],
                "LCS-IKEv2-DNS-Domain"        => [ 27, "string" ],
                "LCS-IKEv2-IPv4-Route"        => [ 25, "string" ],
                "LCS-IKEv2-IPv6-Route"        => [ 26, "string" ],
                "LCS-IKEv2-Local-Password"    => [ 19, "string" ],
                "LCS-IKEv2-Remote-Password"   => [ 20, "string" ],
                "LCS-Load-Balancer"           => [ 28, "string" ],
                "LCS-Mac-Address"             => [ 2,  "string" ],
                "LCS-Orig-NAS-Identifier"     => [ 16, "string" ],
                "LCS-Orig-NAS-IP-Address"     => [ 17, "ipaddr" ],
                "LCS-Orig-NAS-IPv6-Address"   => [ 18, "ipv6addr" ],
                "LCS-PbSpotUserName"          => [ 7,  "string" ],
                "LCS-Redirection-URL"         => [ 3,  "string" ],
                "LCS-Routing-Tag"             => [ 24, "integer" ],
                "LCS-RxRateLimit"             => [ 9,  "integer" ],
                "LCS-Traffic-Limit"           => [ 1,  "integer" ],
                "LCS-Traffic-Limit-Gigawords" => [ 15, "integer" ],
                "LCS-TxRateLimit"             => [ 8,  "integer" ],
                "LCS-VPN-IPv4-Rule"           => [ 22, "string" ],
                "LCS-VPN-IPv6-Rule"           => [ 23, "string" ],
                "LCS-WPA-Passphrase"          => [ 6,  "string" ],
            },
            2440 => {
                "EfficientIP-Admin-Group"      => [ 35, "string" ],
                "EfficientIP-Email"            => [ 20, "string" ],
                "EfficientIP-Extra-Blob"       => [ 64, "string" ],
                "EfficientIP-First-Login-Path" => [ 32, "string" ],
                "EfficientIP-First-Name"       => [ 16, "string" ],
                "EfficientIP-Groups"           => [ 34, "string" ],
                "EfficientIP-Identity-Type"    => [ 3,  "integer" ],
                "EfficientIP-IP-Host"          => [ 19, "string" ],
                "EfficientIP-Last-Name"        => [ 17, "string" ],
                "EfficientIP-Maintainer-Group" => [ 33, "string" ],
                "EfficientIP-Pseudonym"        => [ 18, "string" ],
                "EfficientIP-Service-Class"    => [ 2,  "integer" ],
                "EfficientIP-Version"          => [ 1,  "integer" ],
            },
            2454 => {
                "SG-Accounting"                          => [ 10,  "integer" ],
                "SG-Acl-Data-Quota"                      => [ 55,  "string" ],
                "SG-Acl-Data-Quota-Used"                 => [ 58,  "string" ],
                "SG-Acl-Down-Mean-Rate"                  => [ 93,  "string" ],
                "SG-Acl-Eds-Action"                      => [ 62,  "string" ],
                "SG-Acl-Idle-Ignore"                     => [ 63,  "string" ],
                "SG-Acl-Next-Hop"                        => [ 76,  "string" ],
                "SG-Acl-Packet-Quota"                    => [ 59,  "string" ],
                "SG-Acl-Packet-Quota-Used"               => [ 60,  "string" ],
                "SG-Acl-Priority"                        => [ 95,  "string" ],
                "SG-Acl-Tcp-Nat-Redirect"                => [ 75,  "string" ],
                "SG-Acl-Up-Mean-Rate"                    => [ 92,  "string" ],
                "SG-Action"                              => [ 14,  "integer" ],
                "SG-Advertise-Protocol"                  => [ 73,  "integer" ],
                "SG-Auth-Source"                         => [ 53,  "integer" ],
                "SG-Auth-Type"                           => [ 13,  "integer" ],
                "SG-Auto-Service-Name"                   => [ 52,  "string" ],
                "SG-Burst-Size"                          => [ 96,  "integer" ],
                "SG-Class"                               => [ 21,  "string" ],
                "SG-Cos"                                 => [ 94,  "string" ],
                "SG-Data-Quota"                          => [ 54,  "string" ],
                "SG-Data-Quota-Used"                     => [ 57,  "string" ],
                "SG-Dhcp-Server"                         => [ 30,  "ipaddr" ],
                "SG-Discover-Action"                     => [ 32,  "integer" ],
                "SG-Down-Mean-Rate"                      => [ 91,  "string" ],
                "SG-Eds-Cookie"                          => [ 23,  "string" ],
                "SG-Eds-Enc-Key"                         => [ 22,  "string" ],
                "SG-Filter-Redirect-Gw"                  => [ 1,   "ipaddr" ],
                "SG-Fixed-Ip-Address"                    => [ 34,  "string" ],
                "SG-Forward-Addr"                        => [ 74,  "ipaddr" ],
                "SG-Ip-Address"                          => [ 82,  "string" ],
                "SG-Ip-Primary"                          => [ 100, "ipaddr" ],
                "SG-Ip-Secondary"                        => [ 101, "ipaddr" ],
                "SG-Ip-Tunnel"                           => [ 86,  "string" ],
                "SG-L2tp-Tunnel-Password"                => [ 81,  "string" ],
                "SG-Lease-Time"                          => [ 36,  "integer" ],
                "SG-Mac-Address"                         => [ 18,  "string" ],
                "SG-Max-Allowed-Nodes"                   => [ 25,  "integer" ],
                "SG-Max-Allowed-Sessions"                => [ 20,  "integer" ],
                "SG-Nativeip"                            => [ 85,  "integer" ],
                "SG-Next-Hop"                            => [ 71,  "ipaddr" ],
                "SG-Next-Service-Name"                   => [ 51,  "string" ],
                "SG-Nip-Pipe-Next-Hop"                   => [ 72,  "ipaddr" ],
                "SG-Node-Acct-Username"                  => [ 130, "string" ],
                "SG-Node-Default-Service"                => [ 28,  "string" ],
                "SG-Node-Dynamic-Service"                => [ 29,  "string" ],
                "SG-Node-Fixed-Ip-Address"               => [ 35,  "string" ],
                "SG-Node-Group"                          => [ 27,  "integer" ],
                "SG-Opt82-Relay-Remote-Id"               => [ 31,  "string" ],
                "SG-Orig-Name"                           => [ 12,  "string" ],
                "SG-Original-Url-Prefix"                 => [ 24,  "string" ],
                "SG-Parent-User-Name"                    => [ 26,  "string" ],
                "SG-Personal-Site"                       => [ 17,  "string" ],
                "SG-Protocol-Type"                       => [ 40,  "integer" ],
                "SG-Release-Action"                      => [ 33,  "integer" ],
                "SG-Remote-Filter-Redirect-Gw"           => [ 70,  "string" ],
                "SG-Roaming"                             => [ 61,  "integer" ],
                "SG-Service-Acl-Quota-Ignore"            => [ 66,  "string" ],
                "SG-Service-Acl-Quota-Indication"        => [ 67,  "string" ],
                "SG-Service-Cache"                       => [ 56,  "integer" ],
                "SG-Service-Name"                        => [ 16,  "string" ],
                "SG-Service-Quota-Ignore"                => [ 65,  "string" ],
                "SG-Service-Timeout"                     => [ 50,  "integer" ],
                "SG-SSC-Host"                            => [ 15,  "ipaddr" ],
                "SG-Tunnel-Assignment-Id"                => [ 83,  "integer" ],
                "SG-Tunnel-Client-Ip-Address"            => [ 84,  "ipaddr" ],
                "SG-Tunnel-Id"                           => [ 80,  "string" ],
                "SG-Up-Mean-Rate"                        => [ 90,  "string" ],
                "SG-User-Group"                          => [ 19,  "integer" ],
                "SG-Wimax-Acl-ARQ-Enable"                => [ 121, "string" ],
                "SG-Wimax-Acl-Maximum-Latency"           => [ 115, "string" ],
                "SG-Wimax-Acl-Maximum-Traffic-Burst"     => [ 113, "string" ],
                "SG-Wimax-Acl-Min-Reserved-Traffic-Rate" => [ 112, "string" ],
                "SG-Wimax-Acl-Schedule-Type"             => [ 111, "string" ],
                "SG-Wimax-Acl-Sdu-Size"                  => [ 117, "string" ],
                "SG-Wimax-Acl-Tolerated-Jitter"          => [ 114, "string" ],
                "SG-Wimax-Acl-Unsolicited-Grant-Int"     => [ 116, "string" ],
                "SG-Wimax-Acl-Unsolicited-Polling-Int"   => [ 118, "string" ],
                "SG-Wimax-Bsid-Next-Hop"                 => [ 122, "ipaddr" ],
                "SG-Wimax-DM-Action-Code"                => [ 120, "integer" ],
                "SG-Wimax-Mobility-Features-Supported"   => [ 123, "integer" ],
                "SG-Wimax-MSK-Lifetime"                  => [ 119, "integer" ],
                "SG-Wimax-Node-Disconnect"               => [ 124, "integer" ],
                "SG-Wimax-Reduced-Resources"             => [ 110, "integer" ],
                "SG-Wimax-Service-Flow-Down"             => [ 126, "string" ],
                "SG-Wimax-Service-Flow-Modification"     => [ 125, "integer" ],
            },
            2544 => {
                "Adva-Auth-Level-NM"  => [ 101, "string" ],
                "Adva-User-Level"     => [ 100, "integer" ],
                "Adva-UUM-User-Level" => [ 102, "integer" ],
            },
            2620 => {
                "CP-Gaia-SuperUser-Access" => [ 230, "integer" ],
                "CP-Gaia-User-Role"        => [ 229, "string" ],
            },
            2636 => {
                "Juniper-Allow-Commands"              => [ 2,   "string" ],
                "Juniper-Allow-Configuration"         => [ 4,   "string" ],
                "Juniper-AV-Pair"                     => [ 52,  "string" ],
                "Juniper-cell-overhead"               => [ 41,  "integer" ],
                "Juniper-Configuration-Change"        => [ 9,   "string" ],
                "Juniper-CoS-Parameter"               => [ 39,  "string" ],
                "Juniper-CoS-Traffic-Control-Profile" => [ 38,  "string" ],
                "Juniper-CTP-Group"                   => [ 21,  "integer" ],
                "Juniper-CTPView-APP-Group"           => [ 22,  "integer" ],
                "Juniper-CTPView-OS-Group"            => [ 23,  "integer" ],
                "Juniper-CWA-Redirect"                => [ 50,  "string" ],
                "Juniper-Deny-Commands"               => [ 3,   "string" ],
                "Juniper-Deny-Configuration"          => [ 5,   "string" ],
                "Juniper-DHCPv4-Options"              => [ 55,  "octets" ],
                "Juniper-DHCPv4-Packet-Header"        => [ 208, "octets" ],
                "Juniper-DHCPv6-Options"              => [ 207, "octets" ],
                "Juniper-DHCPv6-Packet-Header"        => [ 209, "octets" ],
                "Juniper-encapsulation-overhead"      => [ 40,  "integer" ],
                "Juniper-Firewall-filter-name"        => [ 44,  "string" ],
                "Juniper-Interactive-Command"         => [ 8,   "string" ],
                "Juniper-Interface-id"                => [ 35,  "string" ],
                "Juniper-Ip-Pool-Name"                => [ 36,  "string" ],
                "Juniper-Junosspace-Profile"          => [ 11,  "string" ],
                "Juniper-Junosspace-Profiles"         => [ 11,  "string" ],
                "Juniper-Keep-Alive"                  => [ 37,  "integer" ],
                "Juniper-Local-Group-Name"            => [ 46,  "string" ],
                "Juniper-Local-Interface"             => [ 47,  "string" ],
                "Juniper-Local-User-Name"             => [ 1,   "string" ],
                "Juniper-Policer-Parameter"           => [ 45,  "string" ],
                "Juniper-Primary-Dns"                 => [ 31,  "ipaddr" ],
                "Juniper-Primary-Wins"                => [ 32,  "ipaddr" ],
                "Juniper-rx-connect-speed"            => [ 43,  "integer" ],
                "Juniper-Secondary-Dns"               => [ 33,  "ipaddr" ],
                "Juniper-Secondary-Wins"              => [ 34,  "ipaddr" ],
                "Juniper-Switching-Filter"            => [ 48,  "string" ],
                "Juniper-tx-connect-speed"            => [ 42,  "integer" ],
                "Juniper-User-Permissions"            => [ 10,  "string" ],
                "Juniper-VoIP-Vlan"                   => [ 49,  "string" ],
            },
            2637 => {
                "CVX-Assign-IP-Pool"            => [ 218, "integer" ],
                "CVX-Client-Assign-DNS"         => [ 137, "integer" ],
                "CVX-Data-Filter"               => [ 242, "string" ],
                "CVX-Data-Rate"                 => [ 197, "integer" ],
                "CVX-Disconnect-Cause"          => [ 195, "integer" ],
                "CVX-Identification"            => [ 1,   "string" ],
                "CVX-Idle-Limit"                => [ 244, "integer" ],
                "CVX-IPSVC-AZNLVL"              => [ 5,   "integer" ],
                "CVX-IPSVC-Mask"                => [ 6,   "integer" ],
                "CVX-Maximum-Channels"          => [ 235, "integer" ],
                "CVX-Modem-Begin-Modulation"    => [ 10,  "string" ],
                "CVX-Modem-Begin-Recv-Line-Lvl" => [ 21,  "integer" ],
                "CVX-Modem-Data-Compression"    => [ 13,  "string" ],
                "CVX-Modem-End-Modulation"      => [ 11,  "string" ],
                "CVX-Modem-End-Recv-Line-Lvl"   => [ 22,  "integer" ],
                "CVX-Modem-Error-Correction"    => [ 12,  "string" ],
                "CVX-Modem-Local-Rate-Negs"     => [ 19,  "integer" ],
                "CVX-Modem-Local-Retrains"      => [ 17,  "integer" ],
                "CVX-Modem-Remote-Rate-Negs"    => [ 20,  "integer" ],
                "CVX-Modem-Remote-Retrains"     => [ 18,  "integer" ],
                "CVX-Modem-ReTx-Packets"        => [ 15,  "integer" ],
                "CVX-Modem-SNR"                 => [ 16,  "integer" ],
                "CVX-Modem-Tx-Packets"          => [ 14,  "integer" ],
                "CVX-Multicast-Client"          => [ 155, "integer" ],
                "CVX-Multicast-Rate-Limit"      => [ 152, "integer" ],
                "CVX-Multilink-Group-Number"    => [ 8,   "integer" ],
                "CVX-Multilink-Match-Info"      => [ 7,   "integer" ],
                "CVX-PPP-Address"               => [ 253, "ipaddr" ],
                "CVX-PPP-Log-Mask"              => [ 9,   "integer" ],
                "CVX-PreSession-Time"           => [ 198, "integer" ],
                "CVX-Primary-DNS"               => [ 135, "ipaddr" ],
                "CVX-Radius-Redirect"           => [ 4,   "integer" ],
                "CVX-Reject-Reason"             => [ 25,  "integer" ],
                "CVX-Secondary-DNS"             => [ 136, "ipaddr" ],
                "CVX-SS7-Session-ID-Type"       => [ 3,   "integer" ],
                "CVX-Terminate-Cause"           => [ 24,  "integer" ],
                "CVX-Terminate-Component"       => [ 23,  "integer" ],
                "CVX-VPOP-ID"                   => [ 2,   "integer" ],
                "CVX-Xmit-Rate"                 => [ 255, "integer" ],
            },
            2979 => {
                "Waverider-Authentication-Key"   => [ 3,  "string" ],
                "Waverider-Current-Password"     => [ 5,  "string" ],
                "Waverider-Grade-Of-Service"     => [ 1,  "integer" ],
                "Waverider-Max-Customers"        => [ 14, "integer" ],
                "Waverider-New-Password"         => [ 6,  "string" ],
                "Waverider-Priority-Enabled"     => [ 2,  "integer" ],
                "Waverider-Radio-Frequency"      => [ 7,  "integer" ],
                "Waverider-Rf-Power"             => [ 15, "integer" ],
                "Waverider-SNMP-Contact"         => [ 11, "string" ],
                "Waverider-SNMP-Location"        => [ 12, "string" ],
                "Waverider-SNMP-Name"            => [ 13, "string" ],
                "Waverider-SNMP-Read-Community"  => [ 8,  "string" ],
                "Waverider-SNMP-Trap-Server"     => [ 10, "string" ],
                "Waverider-SNMP-Write-Community" => [ 9,  "string" ],
            },
            3041 => {
                "AAT-Assign-IP-Pool"             => [ 64,  "integer" ],
                "AAT-ATM-Direct"                 => [ 21,  "string" ],
                "AAT-ATM-Traffic-Profile"        => [ 133, "string" ],
                "AAT-ATM-VCI"                    => [ 129, "integer" ],
                "AAT-ATM-VPI"                    => [ 128, "integer" ],
                "AAT-Auth-Type"                  => [ 68,  "integer" ],
                "AAT-Client-Assign-DNS"          => [ 72,  "integer" ],
                "AAT-Client-Primary-DNS"         => [ 5,   "ipaddr" ],
                "AAT-Client-Primary-WINS-NBNS"   => [ 6,   "ipaddr" ],
                "AAT-Client-Secondary-DNS"       => [ 8,   "ipaddr" ],
                "AAT-Client-Secondary-WINS-NBNS" => [ 7,   "ipaddr" ],
                "AAT-Data-Filter"                => [ 65,  "string" ],
                "AAT-Filter"                     => [ 60,  "string" ],
                "AAT-FR-Direct"                  => [ 18,  "integer" ],
                "AAT-FR-Direct-DLCI"             => [ 20,  "integer" ],
                "AAT-FR-Direct-Profile"          => [ 19,  "string" ],
                "AAT-Home-Agent-Password"        => [ 14,  "string" ],
                "AAT-Home-Agent-UDP-Port"        => [ 16,  "integer" ],
                "AAT-Home-Network-Name"          => [ 15,  "string" ],
                "AAT-Input-Octets-Diff"          => [ 130, "integer" ],
                "AAT-IP-Direct"                  => [ 17,  "ipaddr" ],
                "AAT-IP-Pool-Definition"         => [ 63,  "string" ],
                "AAT-IP-TOS"                     => [ 22,  "integer" ],
                "AAT-IP-TOS-Apply-To"            => [ 24,  "integer" ],
                "AAT-IP-TOS-Precedence"          => [ 23,  "integer" ],
                "AAT-MCast-Client"               => [ 27,  "integer" ],
                "AAT-Modem-Answer-String"        => [ 67,  "string" ],
                "AAT-Modem-Port-No"              => [ 28,  "integer" ],
                "AAT-Modem-Shelf-No"             => [ 30,  "integer" ],
                "AAT-Modem-Slot-No"              => [ 29,  "integer" ],
                "AAT-Output-Octets-Diff"         => [ 131, "integer" ],
                "AAT-PPP-Address"                => [ 9,   "ipaddr" ],
                "AAT-PPP-Netmask"                => [ 10,  "ipaddr" ],
                "AAT-Primary-Home-Agent"         => [ 12,  "string" ],
                "AAT-Qoa"                        => [ 71,  "integer" ],
                "AAT-Qos"                        => [ 70,  "integer" ],
                "AAT-Require-Auth"               => [ 62,  "integer" ],
                "AAT-Secondary-Home-Agent"       => [ 13,  "string" ],
                "AAT-Source-IP-Check"            => [ 66,  "integer" ],
                "AAT-User-MAC-Address"           => [ 132, "string" ],
                "AAT-Vrouter-Name"               => [ 61,  "string" ],
            },
            3076 => {},
            3085 => {
                "Cosine-Address-Pool-Name"       => [ 3, "string" ],
                "Cosine-CLI-User-Permission-ID"  => [ 8, "string" ],
                "Cosine-Connection-Profile-Name" => [ 1, "string" ],
                "Cosine-DLCI"                    => [ 6, "integer" ],
                "Cosine-DS-Byte"                 => [ 4, "integer" ],
                "Cosine-Enterprise-ID"           => [ 2, "string" ],
                "Cosine-LNS-IP-Address"          => [ 7, "ipaddr" ],
                "Cosine-VPI-VCI"                 => [ 5, "octets" ],
            },
            3199 => {
                "Shasta-Service-Profile" => [ 2, "string" ],
                "Shasta-User-Privilege"  => [ 1, "integer" ],
                "Shasta-VPN-Name"        => [ 3, "string" ],
            },
            3224 => {
                "NS-Admin-Privilege"       => [ 1,   "integer" ],
                "NS-NSM-User-Domain-Name"  => [ 220, "string" ],
                "NS-NSM-User-Role-Mapping" => [ 221, "string" ],
                "NS-Primary-DNS"           => [ 4,   "ipaddr" ],
                "NS-Primary-WINS"          => [ 6,   "ipaddr" ],
                "NS-Secondary-DNS"         => [ 5,   "ipaddr" ],
                "NS-Secondary-WINS"        => [ 7,   "ipaddr" ],
                "NS-User-Group"            => [ 3,   "string" ],
                "NS-VSYS-Name"             => [ 2,   "string" ],
            },
            3309 => {
                "Nomadix-Bw-Down"           => [ 2,  "integer" ],
                "Nomadix-Bw-Up"             => [ 1,  "integer" ],
                "Nomadix-Centralized-Mgmt"  => [ 18, "string" ],
                "Nomadix-Config-URL"        => [ 12, "string" ],
                "Nomadix-EndofSession"      => [ 9,  "integer" ],
                "Nomadix-Expiration"        => [ 5,  "string" ],
                "Nomadix-Goodbye-URL"       => [ 13, "string" ],
                "Nomadix-Group-Bw-Max-Down" => [ 21, "integer" ],
                "Nomadix-Group-Bw-Max-Up"   => [ 20, "integer" ],
                "Nomadix-Group-Policy-Id"   => [ 19, "integer" ],
                "Nomadix-IP-Upsell"         => [ 4,  "integer" ],
                "Nomadix-Logoff-URL"        => [ 10, "string" ],
                "Nomadix-MaxBytesDown"      => [ 8,  "integer" ],
                "Nomadix-MaxBytesUp"        => [ 7,  "integer" ],
                "Nomadix-Net-VLAN"          => [ 11, "integer" ],
                "Nomadix-Qos-Policy"        => [ 14, "string" ],
                "Nomadix-SMTP-Redirect"     => [ 17, "integer" ],
                "Nomadix-Subnet"            => [ 6,  "string" ],
                "Nomadix-URL-Redirection"   => [ 3,  "string" ],
            },
            3375 => {
                "F5-LTM-Audit-Msg"           => [ 14, "string" ],
                "F5-LTM-User-Console"        => [ 4,  "integer" ],
                "F5-LTM-User-Context-1"      => [ 10, "integer" ],
                "F5-LTM-User-Context-2"      => [ 11, "integer" ],
                "F5-LTM-User-Info-1"         => [ 12, "string" ],
                "F5-LTM-User-Info-2"         => [ 13, "string" ],
                "F5-LTM-User-Partition"      => [ 3,  "string" ],
                "F5-LTM-User-Role"           => [ 1,  "integer" ],
                "F5-LTM-User-Role-Universal" => [ 2,  "integer" ],
                "F5-LTM-User-Shell"          => [ 5,  "string" ],
            },
            3551 => {
                "ST-Acct-VC-Connection-Id" => [ 1,  "string" ],
                "ST-IPSec-Client-Firewall" => [ 15, "integer" ],
                "ST-IPSec-Client-Subnet"   => [ 16, "string" ],
                "ST-IPSec-Pfs-Group"       => [ 14, "integer" ],
                "ST-Physical-Port"         => [ 9,  "integer" ],
                "ST-Physical-Slot"         => [ 10, "integer" ],
                "ST-Policy-Name"           => [ 4,  "string" ],
                "ST-Primary-DNS-Server"    => [ 5,  "ipaddr" ],
                "ST-Primary-NBNS-Server"   => [ 7,  "ipaddr" ],
                "ST-Realm-Name"            => [ 13, "string" ],
                "ST-Secondary-DNS-Server"  => [ 6,  "ipaddr" ],
                "ST-Secondary-NBNS-Server" => [ 8,  "ipaddr" ],
                "ST-Service-Domain"        => [ 3,  "integer" ],
                "ST-Service-Name"          => [ 2,  "string" ],
                "ST-Virtual-Circuit-ID"    => [ 12, "integer" ],
                "ST-Virtual-Path-ID"       => [ 11, "integer" ],
            },
            3561 => {
                "Access-Loop-Encapsulation"              => [ 144, "octets" ],
                "Actual-Data-Rate-Downstream"            => [ 130, "integer" ],
                "Actual-Data-Rate-Upstream"              => [ 129, "integer" ],
                "Actual-Interleaving-Delay-Downstream"   => [ 142, "integer" ],
                "Actual-Interleaving-Delay-Upstream"     => [ 140, "integer" ],
                "ADSL-Agent-Circuit-Id"                  => [ 1,   "octets" ],
                "ADSL-Agent-Remote-Id"                   => [ 2,   "octets" ],
                "ADSL-Forum-Device-Manufacturer-OUI"     => [ 255, "octets" ],
                "ADSL-Forum-Device-Product-Class"        => [ 255, "string" ],
                "ADSL-Forum-Device-Serial-Number"        => [ 255, "string" ],
                "ADSL-Forum-DHCP-Vendor-Specific"        => [ 255, "tlv" ],
                "ADSL-Forum-Gateway-Manufacturer-OUI"    => [ 255, "octets" ],
                "Attainable-Data-Rate-Downstream"        => [ 134, "integer" ],
                "Attainable-Data-Rate-Upstream"          => [ 133, "integer" ],
                "IWF-Session"                            => [ 254, "octets" ],
                "Maximum-Data-Rate-Downstream"           => [ 136, "integer" ],
                "Maximum-Data-Rate-Upstream"             => [ 135, "integer" ],
                "Maximum-Interleaving-Delay-Downstream"  => [ 141, "integer" ],
                "Maximum-Interleaving-Delay-Upstream"    => [ 139, "integer" ],
                "Minimum-Data-Rate-Downstream"           => [ 132, "integer" ],
                "Minimum-Data-Rate-Downstream-Low-Power" => [ 138, "integer" ],
                "Minimum-Data-Rate-Upstream"             => [ 131, "integer" ],
                "Minimum-Data-Rate-Upstream-Low-Power"   => [ 137, "integer" ],
            },
            3902 => {
                "ZTE-Access-Domain"               => [ 151, "string" ],
                "ZTE-Access-Type"                 => [ 74,  "integer" ],
                "ZTE-Client-DNS-Pri"              => [ 1,   "ipaddr" ],
                "ZTE-Client-DNS-Sec"              => [ 2,   "ipaddr" ],
                "ZTE-Context-Name"                => [ 4,   "integer" ],
                "ZTE-IGMP-Service-Profile-Num"    => [ 97,  "integer" ],
                "ZTE-Mcast-MaxGroups"             => [ 35,  "integer" ],
                "ZTE-Mcast-Receive"               => [ 34,  "integer" ],
                "ZTE-Mcast-Send"                  => [ 33,  "integer" ],
                "ZTE-PPP-Sservice-Type"           => [ 101, "integer" ],
                "ZTE-PPPOE-MOTM"                  => [ 28,  "string" ],
                "ZTE-PPPOE-URL"                   => [ 27,  "string" ],
                "ZTE-Priority-Level"              => [ 90,  "integer" ],
                "ZTE-QoS-Profile-Down"            => [ 82,  "string" ],
                "ZTE-QoS-Profile-Down-v6"         => [ 237, "string" ],
                "ZTE-QOS-Profile-Up"              => [ 94,  "string" ],
                "ZTE-QoS-Profile-Up-v6"           => [ 232, "string" ],
                "ZTE-QoS-Type"                    => [ 81,  "integer" ],
                "ZTE-Rate-Ctrl-Burst-Down"        => [ 84,  "integer" ],
                "ZTE-Rate-Ctrl-Burst-Down-v6"     => [ 234, "integer" ],
                "ZTE-Rate-Ctrl-Burst-Max-Down"    => [ 92,  "integer" ],
                "ZTE-Rate-Ctrl-Burst-Max-Down-v6" => [ 235, "integer" ],
                "ZTE-Rate-Ctrl-Burst-Max-Up"      => [ 93,  "integer" ],
                "ZTE-Rate-Ctrl-Burst-Max-Up-v6"   => [ 230, "integer" ],
                "ZTE-Rate-Ctrl-Burst-Up"          => [ 91,  "integer" ],
                "ZTE-Rate-Ctrl-Burst-Up-v6"       => [ 229, "integer" ],
                "ZTE-Rate-Ctrl-PBS-Down"          => [ 202, "integer" ],
                "ZTE-Rate-Ctrl-PBS-Down-v6"       => [ 236, "integer" ],
                "ZTE-Rate-Ctrl-PBS-Up"            => [ 203, "integer" ],
                "ZTE-Rate-Ctrl-PBS-Up-v6"         => [ 231, "integer" ],
                "ZTE-Rate-Ctrl-PCR"               => [ 86,  "integer" ],
                "ZTE-Rate-Ctrl-SCR-Down"          => [ 83,  "integer" ],
                "ZTE-Rate-Ctrl-SCR-Down-v6"       => [ 233, "integer" ],
                "ZTE-Rate-Ctrl-SCR-Up"            => [ 89,  "integer" ],
                "ZTE-Rate-Ctrl-SCR-Up-v6"         => [ 228, "integer" ],
                "ZTE-SW-Privilege"                => [ 104, "integer" ],
                "ZTE-TCP-Limit-Mode"              => [ 96,  "integer" ],
                "ZTE-TCP-Limit-Num"               => [ 95,  "integer" ],
                "ZTE-TCP-Syn-Rate"                => [ 88,  "integer" ],
                "ZTE-Tunnel-Algorithm"            => [ 31,  "integer" ],
                "ZTE-Tunnel-Cmd-Timeout"          => [ 26,  "integer" ],
                "ZTE-Tunnel-Deadtime"             => [ 32,  "integer" ],
                "ZTE-Tunnel-Max-Sessions"         => [ 21,  "integer" ],
                "ZTE-Tunnel-Max-Tunnels"          => [ 22,  "integer" ],
                "ZTE-Tunnel-Retransmit"           => [ 25,  "integer" ],
                "ZTE-Tunnel-Window"               => [ 24,  "integer" ],
                "ZTE-VPN-ID"                      => [ 190, "string" ],
                "ZTE_Rate-Bust-DPIR"              => [ 191, "integer" ],
                "ZTE_Rate-Bust-UPIR"              => [ 192, "integer" ],
            },
            4329 => {
                "Siemens-AP-Name"         => [ 2,  "string" ],
                "Siemens-AP-Serial"       => [ 3,  "string" ],
                "Siemens-BSS-MAC"         => [ 6,  "string" ],
                "Siemens-Egress-RC-Name"  => [ 10, "string" ],
                "Siemens-Ingress-RC-Name" => [ 9,  "string" ],
                "Siemens-Policy-Name"     => [ 7,  "string" ],
                "Siemens-SSID"            => [ 5,  "string" ],
                "Siemens-Topology-Name"   => [ 8,  "string" ],
                "Siemens-URL-Redirection" => [ 1,  "string" ],
                "Siemens-VNS-Name"        => [ 4,  "string" ],
            },
            4363 => {
                "NN-Data-Rate"         => [ 1, "integer" ],
                "NN-Data-Rate-Ceiling" => [ 2, "integer" ],
                "NN-Homenode"          => [ 3, "ipaddr" ],
                "NN-Homeservice"       => [ 4, "ipaddr" ],
                "NN-Homeservice-Name"  => [ 5, "string" ],
            },
            4453 => {
                "Infonet-Account-Number"     => [ 247, "string" ],
                "Infonet-Config"             => [ 239, "string" ],
                "Infonet-LoginHost-Dest"     => [ 250, "string" ],
                "Infonet-MCS-Country"        => [ 240, "string" ],
                "Infonet-MCS-Off-Peak"       => [ 242, "string" ],
                "Infonet-MCS-Overflow"       => [ 243, "string" ],
                "Infonet-MCS-Port"           => [ 244, "string" ],
                "Infonet-MCS-Port-Count"     => [ 245, "string" ],
                "Infonet-MCS-Region"         => [ 241, "string" ],
                "Infonet-NAS-Location"       => [ 255, "string" ],
                "Infonet-Pool-Request"       => [ 252, "string" ],
                "Infonet-Proxy"              => [ 238, "string" ],
                "Infonet-Random-IP-Pool"     => [ 246, "string" ],
                "Infonet-Realm-Type"         => [ 249, "string" ],
                "Infonet-Surcharge-Type"     => [ 254, "integer" ],
                "Infonet-Tunnel-Decision-IP" => [ 251, "string" ],
                "Infonet-Type"               => [ 248, "string" ],
            },
            4491 => {
                "CableLabs-Account-Code"                  => [ 80, "string" ],
                "CableLabs-Alerting-Signal"               => [ 52, "integer" ],
                "CableLabs-AM-Opaque-Data"                => [ 61, "integer" ],
                "CableLabs-Application-Manager-ID"        => [ 71, "integer" ],
                "CableLabs-Authorization-Code"            => [ 81, "string" ],
                "CableLabs-Call-Termination-Cause"        => [ 11, "octets" ],
                "CableLabs-Called-Party-Number"           => [ 5,  "string" ],
                "CableLabs-Calling-Party-Number"          => [ 4,  "string" ],
                "CableLabs-Carrier-Identification-Code"   => [ 23, "string" ],
                "CableLabs-CCC-ID"                        => [ 48, "octets" ],
                "CableLabs-Channel-State"                 => [ 29, "integer" ],
                "CableLabs-Charge-Number"                 => [ 16, "string" ],
                "CableLabs-Database-ID"                   => [ 6,  "string" ],
                "CableLabs-Dial-Around-Code"              => [ 21, "string" ],
                "CableLabs-Dialed-Digits"                 => [ 56, "string" ],
                "CableLabs-Direction-indicator"           => [ 37, "integer" ],
                "CableLabs-El-Surveillance-DF-Security"   => [ 47, "octets" ],
                "CableLabs-Electronic-Surveillance-Ind"   => [ 44, "octets" ],
                "CableLabs-Element-Requesting-QoS"        => [ 65, "integer" ],
                "CableLabs-Error-Description"             => [ 31, "string" ],
                "CableLabs-Event-Message"                 => [ 1,  "octets" ],
                "CableLabs-Financial-Entity-ID"           => [ 49, "string" ],
                "CableLabs-First-Call-Calling-Party-Num"  => [ 14, "string" ],
                "CableLabs-Flow-Direction"                => [ 50, "integer" ],
                "CableLabs-Forwarded-Number"              => [ 17, "string" ],
                "CableLabs-Gate-Time-Info"                => [ 73, "integer" ],
                "CableLabs-Gate-Usage-Info"               => [ 64, "integer" ],
                "CableLabs-Intl-Code"                     => [ 20, "string" ],
                "CableLabs-Location-Routing-Number"       => [ 22, "string" ],
                "CableLabs-Misc-Signaling-Information"    => [ 57, "string" ],
                "CableLabs-MTA-Endpoint-Name"             => [ 3,  "string" ],
                "CableLabs-MTA-UDP-Portnum"               => [ 26, "integer" ],
                "CableLabs-Policy-Decision-Status"        => [ 70, "integer" ],
                "CableLabs-Policy-Deleted-Reason"         => [ 68, "integer" ],
                "CableLabs-Policy-Denied-Reason"          => [ 67, "integer" ],
                "CableLabs-Policy-Update-Reason"          => [ 69, "integer" ],
                "CableLabs-QoS-Descriptor"                => [ 32, "octets" ],
                "CableLabs-QoS-Release-Reason"            => [ 66, "integer" ],
                "CableLabs-Query-Type"                    => [ 7,  "integer" ],
                "CableLabs-Redirected-From-Info"          => [ 43, "octets" ],
                "CableLabs-Redirected-From-Party-Number"  => [ 45, "string" ],
                "CableLabs-Redirected-To-Party-Number"    => [ 46, "string" ],
                "CableLabs-Related-Call-Billing-Crl-ID"   => [ 13, "octets" ],
                "CableLabs-Reserved"                      => [ 0,  "octets" ],
                "CableLabs-Returned-Number"               => [ 9,  "string" ],
                "CableLabs-Routing-Number"                => [ 25, "string" ],
                "CableLabs-SDP-Downstream"                => [ 40, "string" ],
                "CableLabs-SDP-Upstream"                  => [ 39, "string" ],
                "CableLabs-Second-Call-Calling-Party-Num" => [ 15, "string" ],
                "CableLabs-Service-Name"                  => [ 18, "string" ],
                "CableLabs-SF-ID"                         => [ 30, "integer" ],
                "CableLabs-Signal-Type"                   => [ 51, "integer" ],
                "CableLabs-Subject-Audible-Signal"        => [ 53, "integer" ],
                "CableLabs-Subscriber-ID"                 => [ 62, "integer" ],
                "CableLabs-Switch-Hook-Flash"             => [ 55, "string" ],
                "CableLabs-Terminal-Display-Info"         => [ 54, "octets" ],
                "CableLabs-Time-Adjustment"               => [ 38, "octets" ],
                "CableLabs-Time-Usage-Limit"              => [ 72, "integer" ],
                "CableLabs-Translation-Input"             => [ 42, "string" ],
                "CableLabs-Trunk-Group-ID"                => [ 24, "octets" ],
                "CableLabs-User-Input"                    => [ 41, "string" ],
                "CableLabs-Volume-Usage-Limit"            => [ 63, "integer" ],
            },
            4735 => {
                "Prosoft-ATM-Interface"            => [ 9,  "integer" ],
                "Prosoft-ATM-VCI"                  => [ 11, "integer" ],
                "Prosoft-ATM-VPI"                  => [ 10, "integer" ],
                "Prosoft-Auth-Role"                => [ 16, "integer" ],
                "Prosoft-Authentication-Reason"    => [ 8,  "integer" ],
                "Prosoft-Default-Gateway"          => [ 1,  "ipaddr" ],
                "Prosoft-Home-Agent-Address"       => [ 0,  "ipaddr" ],
                "Prosoft-MAC-Address"              => [ 7,  "string" ],
                "Prosoft-NPM-Identifier"           => [ 13, "string" ],
                "Prosoft-NPM-IP"                   => [ 14, "string" ],
                "Prosoft-Primary-DNS"              => [ 2,  "ipaddr" ],
                "Prosoft-RSC-Identifier"           => [ 12, "string" ],
                "Prosoft-Secondary-DNS"            => [ 3,  "ipaddr" ],
                "Prosoft-Sector-ID"                => [ 15, "string" ],
                "Prosoft-Security-Key"             => [ 5,  "string" ],
                "Prosoft-Security-Parameter-Index" => [ 4,  "integer" ],
            },
            4846 => {
                "Lucent-Absolute-Time"                => [ 10032, "integer" ],
                "Lucent-Access-Intercept-LEA"         => [ 52,    "string" ],
                "Lucent-Access-Intercept-Log"         => [ 53,    "string" ],
                "Lucent-Add-Seconds"                  => [ 240,   "integer" ],
                "Lucent-Appletalk-Peer-Mode"          => [ 117,   "integer" ],
                "Lucent-Appletalk-Route"              => [ 116,   "string" ],
                "Lucent-Ara-PW"                       => [ 181,   "string" ],
                "Lucent-Assign-IP-Client"             => [ 144,   "ipaddr" ],
                "Lucent-Assign-IP-Global-Pool"        => [ 146,   "string" ],
                "Lucent-Assign-IP-Pool"               => [ 218,   "integer" ],
                "Lucent-Assign-IP-Server"             => [ 145,   "ipaddr" ],
                "Lucent-AT-Answer-String"             => [ 269,   "string" ],
                "Lucent-ATM-Circuit-Name"             => [ 262,   "string" ],
                "Lucent-ATM-Connect-Group"            => [ 63,    "integer" ],
                "Lucent-ATM-Connect-Vci"              => [ 62,    "integer" ],
                "Lucent-ATM-Connect-Vpi"              => [ 61,    "integer" ],
                "Lucent-ATM-Direct"                   => [ 76,    "integer" ],
                "Lucent-ATM-Direct-Profile"           => [ 77,    "string" ],
                "Lucent-ATM-Fault-Management"         => [ 14,    "integer" ],
                "Lucent-ATM-Group"                    => [ 64,    "integer" ],
                "Lucent-ATM-Loopback-Cell-Loss"       => [ 15,    "integer" ],
                "Lucent-ATM-Vci"                      => [ 95,    "integer" ],
                "Lucent-ATM-Vpi"                      => [ 94,    "integer" ],
                "Lucent-Auth-Delay"                   => [ 28,    "integer" ],
                "Lucent-Auth-Type"                    => [ 81,    "integer" ],
                "Lucent-Authen-Alias"                 => [ 203,   "string" ],
                "Lucent-Backup"                       => [ 176,   "string" ],
                "Lucent-BACP-Enable"                  => [ 133,   "integer" ],
                "Lucent-Base-Channel-Count"           => [ 172,   "integer" ],
                "Lucent-Bi-Directional-Auth"          => [ 46,    "integer" ],
                "Lucent-Billing-Number"               => [ 249,   "string" ],
                "Lucent-BIR-Bridge-Group"             => [ 72,    "integer" ],
                "Lucent-BIR-Enable"                   => [ 70,    "integer" ],
                "Lucent-BIR-Proxy"                    => [ 71,    "integer" ],
                "Lucent-Bridge"                       => [ 230,   "integer" ],
                "Lucent-Bridge-Address"               => [ 168,   "string" ],
                "Lucent-Bridge-Non-PPPoE"             => [ 75,    "integer" ],
                "Lucent-Cache-Refresh"                => [ 56,    "integer" ],
                "Lucent-Cache-Time"                   => [ 57,    "integer" ],
                "Lucent-Call-Attempt-Limit"           => [ 123,   "integer" ],
                "Lucent-Call-Block-Duration"          => [ 124,   "integer" ],
                "Lucent-Call-By-Call"                 => [ 250,   "integer" ],
                "Lucent-Call-Direction"               => [ 48,    "integer" ],
                "Lucent-Call-Filter"                  => [ 243,   "abinary" ],
                "Lucent-Call-Type"                    => [ 177,   "integer" ],
                "Lucent-Callback"                     => [ 246,   "integer" ],
                "Lucent-Callback-Delay"               => [ 108,   "integer" ],
                "Lucent-Calling-Id-Numbering-Plan"    => [ 67,    "integer" ],
                "Lucent-Calling-Id-Presentation"      => [ 68,    "integer" ],
                "Lucent-Calling-Id-Screening"         => [ 69,    "integer" ],
                "Lucent-Calling-Id-Type-Of-Number"    => [ 66,    "integer" ],
                "Lucent-Calling-Subaddress"           => [ 107,   "string" ],
                "Lucent-CBCP-Delay"                   => [ 114,   "integer" ],
                "Lucent-CBCP-Enable"                  => [ 112,   "integer" ],
                "Lucent-CBCP-Mode"                    => [ 113,   "integer" ],
                "Lucent-CBCP-Trunk-Group"             => [ 115,   "integer" ],
                "Lucent-CIR-Timer"                    => [ 9,     "integer" ],
                "Lucent-Ckt-Type"                     => [ 16,    "integer" ],
                "Lucent-Client-Assign-DNS"            => [ 137,   "integer" ],
                "Lucent-Client-Assign-WINS"           => [ 80,    "integer" ],
                "Lucent-Client-Gateway"               => [ 132,   "ipaddr" ],
                "Lucent-Client-Primary-DNS"           => [ 135,   "ipaddr" ],
                "Lucent-Client-Primary-WINS"          => [ 78,    "ipaddr" ],
                "Lucent-Client-Secondary-DNS"         => [ 136,   "ipaddr" ],
                "Lucent-Client-Secondary-WINS"        => [ 79,    "ipaddr" ],
                "Lucent-Compression-Protocol"         => [ 20105, "integer" ],
                "Lucent-Configured-Rate-Dn-Max"       => [ 10036, "integer" ],
                "Lucent-Configured-Rate-Dn-Min"       => [ 10035, "integer" ],
                "Lucent-Configured-Rate-Up-Max"       => [ 10034, "integer" ],
                "Lucent-Configured-Rate-Up-Min"       => [ 10033, "integer" ],
                "Lucent-Connect-Progress"             => [ 196,   "integer" ],
                "Lucent-Connection-Time"              => [ 20117, "integer" ],
                "Lucent-Cumulative-Hold-Time"         => [ 304,   "integer" ],
                "Lucent-Current-Line-Quality"         => [ 20111, "integer" ],
                "Lucent-Current-Recv-Level"           => [ 20110, "integer" ],
                "Lucent-Current-SNR"                  => [ 20112, "integer" ],
                "Lucent-Current-Xmit-Level"           => [ 20109, "integer" ],
                "Lucent-Data-Filter"                  => [ 242,   "abinary" ],
                "Lucent-Data-Rate"                    => [ 197,   "integer" ],
                "Lucent-Data-Svc"                     => [ 247,   "integer" ],
                "Lucent-DBA-Monitor"                  => [ 171,   "integer" ],
                "Lucent-Dec-Channel-Count"            => [ 237,   "integer" ],
                "Lucent-Destination-NAS-Port"         => [ 11,    "integer" ],
                "Lucent-DHCP-Maximum-Leases"          => [ 134,   "integer" ],
                "Lucent-DHCP-Pool-Number"             => [ 148,   "integer" ],
                "Lucent-DHCP-Reply"                   => [ 147,   "integer" ],
                "Lucent-Dial-Number"                  => [ 227,   "string" ],
                "Lucent-Dialed-Number"                => [ 24,    "string" ],
                "Lucent-Dialout-Allowed"              => [ 131,   "integer" ],
                "Lucent-Disconnect-Cause"             => [ 195,   "integer" ],
                "Lucent-Dropped-Octets"               => [ 26,    "integer" ],
                "Lucent-Dropped-Packets"              => [ 27,    "integer" ],
                "Lucent-Ds3-CCVs"                     => [ 10202, "integer" ],
                "Lucent-Ds3-CESs"                     => [ 10210, "integer" ],
                "Lucent-Ds3-CSESs"                    => [ 10211, "integer" ],
                "Lucent-Ds3-F-Bit-Err"                => [ 10200, "integer" ],
                "Lucent-Ds3-LCVs"                     => [ 10207, "integer" ],
                "Lucent-Ds3-LESs"                     => [ 10209, "integer" ],
                "Lucent-Ds3-P-Bit-Err"                => [ 10201, "integer" ],
                "Lucent-Ds3-PCVs"                     => [ 10208, "integer" ],
                "Lucent-Ds3-PESs"                     => [ 10203, "integer" ],
                "Lucent-Ds3-PSESs"                    => [ 10204, "integer" ],
                "Lucent-Ds3-SEFs"                     => [ 10205, "integer" ],
                "Lucent-Ds3-UASs"                     => [ 10206, "integer" ],
                "Lucent-Dsl-Atuc-Chan-Corrected-Blks" => [ 10001, "integer" ],
                "Lucent-Dsl-Atuc-Chan-Recd-Blks"      => [ 10003, "integer" ],
                "Lucent-Dsl-Atuc-Chan-Uncorrect-Blks" => [ 10000, "integer" ],
                "Lucent-Dsl-Atuc-Chan-Xmit-Blks"      => [ 10002, "integer" ],
                "Lucent-Dsl-Atuc-Curr-Atn-Dn"         => [ 10027, "integer" ],
                "Lucent-Dsl-Atuc-Curr-Atn-Up"         => [ 10012, "integer" ],
                "Lucent-Dsl-Atuc-Curr-Attainable-Rate-Dn" =>
                  [ 10010, "integer" ],
                "Lucent-Dsl-Atuc-Curr-Attainable-Rate-Up" =>
                  [ 10025, "integer" ],
                "Lucent-Dsl-Atuc-Curr-Output-Pwr-Dn" => [ 10011, "integer" ],
                "Lucent-Dsl-Atuc-Curr-Output-Pwr-Up" => [ 10026, "integer" ],
                "Lucent-Dsl-Atuc-Curr-Snr-Mgn-D"     => [ 10028, "integer" ],
                "Lucent-Dsl-Atuc-Curr-Snr-Mgn-Up"    => [ 10013, "integer" ],
                "Lucent-Dsl-Atuc-Perf-ESs"           => [ 10005, "integer" ],
                "Lucent-Dsl-Atuc-Perf-Inits"         => [ 10004, "integer" ],
                "Lucent-Dsl-Atuc-Perf-Lofs"          => [ 10009, "integer" ],
                "Lucent-Dsl-Atuc-Perf-Lols"          => [ 10007, "integer" ],
                "Lucent-Dsl-Atuc-Perf-Loss"          => [ 10008, "integer" ],
                "Lucent-Dsl-Atuc-Perf-Lprs"          => [ 10006, "integer" ],
                "Lucent-Dsl-Atuc-PS-Failed-Fast-Retrains" =>
                  [ 10015, "integer" ],
                "Lucent-Dsl-Atuc-PS-Fast-Retrains"      => [ 10014, "integer" ],
                "Lucent-Dsl-CIR-Recv-Limit"             => [ 100,   "integer" ],
                "Lucent-Dsl-CIR-Xmit-Limit"             => [ 101,   "integer" ],
                "Lucent-Dsl-Code-Violations"            => [ 10016, "integer" ],
                "Lucent-Dsl-Curr-Dn-Rate"               => [ 10019, "integer" ],
                "Lucent-Dsl-Curr-Up-Rate"               => [ 10018, "integer" ],
                "Lucent-Dsl-Downstream-Limit"           => [ 99,    "integer" ],
                "Lucent-Dsl-If-Index"                   => [ 10022, "integer" ],
                "Lucent-Dsl-Oper-Status"                => [ 10023, "integer" ],
                "Lucent-Dsl-Physical-Channel"           => [ 10037, "integer" ],
                "Lucent-Dsl-Physical-Line"              => [ 10021, "integer" ],
                "Lucent-Dsl-Physical-Slot"              => [ 10020, "integer" ],
                "Lucent-Dsl-Rate-Mode"                  => [ 97,    "integer" ],
                "Lucent-Dsl-Rate-Type"                  => [ 92,    "integer" ],
                "Lucent-Dsl-Related-If-Index"           => [ 10024, "integer" ],
                "Lucent-Dsl-Related-Port"               => [ 10030, "integer" ],
                "Lucent-Dsl-Related-Slot"               => [ 10029, "integer" ],
                "Lucent-Dsl-Sparing-Role"               => [ 10031, "integer" ],
                "Lucent-Dsl-Upstream-Limit"             => [ 98,    "integer" ],
                "Lucent-Egress-Enabled"                 => [ 58,    "integer" ],
                "Lucent-Endpoint-Disc"                  => [ 109,   "octets" ],
                "Lucent-Error-Correction-Protocol"      => [ 20104, "integer" ],
                "Lucent-Event-Type"                     => [ 150,   "integer" ],
                "Lucent-Expect-Callback"                => [ 149,   "integer" ],
                "Lucent-FCP-Parameter"                  => [ 119,   "string" ],
                "Lucent-Filter"                         => [ 90,    "string" ],
                "Lucent-Filter-Required"                => [ 50,    "integer" ],
                "Lucent-First-Dest"                     => [ 189,   "ipaddr" ],
                "Lucent-First-Level-User"               => [ 308,   "string" ],
                "Lucent-Force-56"                       => [ 248,   "integer" ],
                "Lucent-FR-08-Mode"                     => [ 10,    "integer" ],
                "Lucent-FR-Circuit-Name"                => [ 156,   "string" ],
                "Lucent-FR-DCE-N392"                    => [ 162,   "integer" ],
                "Lucent-FR-DCE-N393"                    => [ 164,   "integer" ],
                "Lucent-FR-Direct"                      => [ 219,   "integer" ],
                "Lucent-FR-Direct-DLCI"                 => [ 221,   "integer" ],
                "Lucent-FR-Direct-Profile"              => [ 220,   "string" ],
                "Lucent-FR-DLCI"                        => [ 179,   "integer" ],
                "Lucent-FR-DTE-N392"                    => [ 163,   "integer" ],
                "Lucent-FR-DTE-N393"                    => [ 165,   "integer" ],
                "Lucent-FR-Link-Mgt"                    => [ 160,   "integer" ],
                "Lucent-FR-Link-Status-DLCI"            => [ 106,   "integer" ],
                "Lucent-FR-LinkUp"                      => [ 157,   "integer" ],
                "Lucent-FR-N391"                        => [ 161,   "integer" ],
                "Lucent-FR-Nailed-Grp"                  => [ 158,   "integer" ],
                "Lucent-FR-Profile-Name"                => [ 180,   "string" ],
                "Lucent-FR-SVC-Addr"                    => [ 12,    "string" ],
                "Lucent-FR-T391"                        => [ 166,   "integer" ],
                "Lucent-FR-T392"                        => [ 167,   "integer" ],
                "Lucent-FR-Type"                        => [ 159,   "integer" ],
                "Lucent-Fr05-Enabled"                   => [ 259,   "integer" ],
                "Lucent-Fr05-Traffic-Shaper"            => [ 256,   "integer" ],
                "Lucent-Fr05-Vci"                       => [ 258,   "integer" ],
                "Lucent-Fr05-Vpi"                       => [ 257,   "integer" ],
                "Lucent-FT1-Caller"                     => [ 175,   "integer" ],
                "Lucent-Global-Call-Id"                 => [ 20,    "string" ],
                "Lucent-Group"                          => [ 178,   "string" ],
                "Lucent-H323-Conference-Id"             => [ 21,    "integer" ],
                "Lucent-H323-Destination-NAS-ID"        => [ 22,    "ipaddr" ],
                "Lucent-H323-Dialed-Time"               => [ 23,    "integer" ],
                "Lucent-H323-Gatekeeper"                => [ 19,    "ipaddr" ],
                "Lucent-Handle-IPX"                     => [ 222,   "integer" ],
                "Lucent-History-Weigh-Type"             => [ 239,   "integer" ],
                "Lucent-Home-Agent-IP-Addr"             => [ 183,   "ipaddr" ],
                "Lucent-Home-Agent-Password"            => [ 184,   "string" ],
                "Lucent-Home-Agent-UDP-Port"            => [ 186,   "integer" ],
                "Lucent-Home-Network-Name"              => [ 185,   "string" ],
                "Lucent-Host-Info"                      => [ 252,   "string" ],
                "Lucent-Http-Redirect-Port"             => [ 288,   "integer" ],
                "Lucent-Http-Redirect-URL"              => [ 287,   "string" ],
                "Lucent-Idle-Limit"                     => [ 244,   "integer" ],
                "Lucent-IF-Netmask"                     => [ 153,   "ipaddr" ],
                "Lucent-Inc-Channel-Count"              => [ 236,   "integer" ],
                "Lucent-Inter-Arrival-Jitter"           => [ 25,    "integer" ],
                "Lucent-IP-Direct"                      => [ 209,   "ipaddr" ],
                "Lucent-IP-DSCP"                        => [ 3,     "integer" ],
                "Lucent-IP-OUTGOING-DSCP"               => [ 272,   "integer" ],
                "Lucent-IP-OUTGOING-TOS"                => [ 270,   "integer" ],
                "Lucent-IP-OUTGOING-TOS-Precedence"     => [ 271,   "integer" ],
                "Lucent-IP-Pool-Chaining"               => [ 85,    "integer" ],
                "Lucent-IP-Pool-Definition"             => [ 217,   "string" ],
                "Lucent-IP-Source-If"                   => [ 309,   "string" ],
                "Lucent-IP-TOS"                         => [ 87,    "integer" ],
                "Lucent-IP-TOS-Apply-To"                => [ 89,    "integer" ],
                "Lucent-IP-TOS-Precedence"              => [ 88,    "integer" ],
                "Lucent-IPSEC-Profile"                  => [ 73,    "string" ],
                "Lucent-IPX-Alias"                      => [ 224,   "integer" ],
                "Lucent-IPX-Header-Compression"         => [ 65,    "integer" ],
                "Lucent-IPX-Node-Addr"                  => [ 182,   "string" ],
                "Lucent-IPX-Peer-Mode"                  => [ 216,   "integer" ],
                "Lucent-IPX-Route"                      => [ 174,   "string" ],
                "Lucent-L2TP-DCI-Direction"             => [ 291,   "integer" ],
                "Lucent-L2TP-DCI-Disconnect-Code"       => [ 289,   "integer" ],
                "Lucent-L2TP-DCI-Message"               => [ 292,   "string" ],
                "Lucent-L2TP-DCI-Protocol-Number"       => [ 290,   "integer" ],
                "Lucent-L2TP-Disconnect-Scenario"       => [ 299,   "integer" ],
                "Lucent-L2TP-Peer-Connect-Progress"     => [ 301,   "integer" ],
                "Lucent-L2TP-Peer-Disconnect-Cause"     => [ 300,   "integer" ],
                "Lucent-L2TP-Q931-Advisory-Message"     => [ 295,   "string" ],
                "Lucent-L2TP-Q931-Cause-Code"           => [ 293,   "integer" ],
                "Lucent-L2TP-Q931-Cause-Message"        => [ 294,   "integer" ],
                "Lucent-L2TP-RC-Error-Code"             => [ 297,   "integer" ],
                "Lucent-L2TP-RC-Error-Message"          => [ 298,   "string" ],
                "Lucent-L2TP-RC-Result-Code"            => [ 296,   "integer" ],
                "Lucent-LCP-Keepalive-Missed-Limit"     => [ 322,   "integer" ],
                "Lucent-LCP-Keepalive-Period"           => [ 321,   "integer" ],
                "Lucent-Line-Type"                      => [ 10017, "integer" ],
                "Lucent-Link-Compression"               => [ 233,   "integer" ],
                "Lucent-Local-Retrain-Requested"        => [ 20115, "integer" ],
                "Lucent-Max-Recv-Rate"                  => [ 20103, "integer" ],
                "Lucent-Max-RTP-Delay"                  => [ 264,   "integer" ],
                "Lucent-Max-Shared-Users"               => [ 2,     "integer" ],
                "Lucent-Max-SNR"                        => [ 20114, "integer" ],
                "Lucent-Max-Xmit-Rate"                  => [ 20101, "integer" ],
                "Lucent-Maximum-Call-Duration"          => [ 125,   "integer" ],
                "Lucent-Maximum-Channels"               => [ 235,   "integer" ],
                "Lucent-Maximum-Time"                   => [ 194,   "integer" ],
                "Lucent-Menu-Item"                      => [ 206,   "string" ],
                "Lucent-Menu-Selector"                  => [ 205,   "string" ],
                "Lucent-Metric"                         => [ 225,   "integer" ],
                "Lucent-Min-Recv-Rate"                  => [ 20102, "integer" ],
                "Lucent-Min-SNR"                        => [ 20113, "integer" ],
                "Lucent-Min-Xmit-Rate"                  => [ 20100, "integer" ],
                "Lucent-Minimum-Channels"               => [ 173,   "integer" ],
                "Lucent-Modem-Disconnect-Reason"        => [ 20118, "integer" ],
                "Lucent-Modem-Modulation"               => [ 305,   "integer" ],
                "Lucent-Modem-PortNo"                   => [ 120,   "integer" ],
                "Lucent-Modem-ShelfNo"                  => [ 122,   "integer" ],
                "Lucent-Modem-SlotNo"                   => [ 121,   "integer" ],
                "Lucent-Modulation"                     => [ 20106, "integer" ],
                "Lucent-MOH-Timeout"                    => [ 261,   "integer" ],
                "Lucent-MPP-Idle-Percent"               => [ 254,   "integer" ],
                "Lucent-MTU"                            => [ 47,    "integer" ],
                "Lucent-Multi-Packet-Separator"         => [ 20000, "integer" ],
                "Lucent-Multicast-Client"               => [ 155,   "integer" ],
                "Lucent-Multicast-Filter-Active"        => [ 280,   "integer" ],
                "Lucent-Multicast-Filter-Address"       => [ 281,   "ipaddr" ],
                "Lucent-Multicast-GLeave-Delay"         => [ 111,   "integer" ],
                "Lucent-Multicast-Max-Groups"           => [ 275,   "integer" ],
                "Lucent-Multicast-Rate-Limit"           => [ 152,   "integer" ],
                "Lucent-Multicast-Service-Active"       => [ 277,   "integer" ],
                "Lucent-Multicast-Service-Filter-Type"  => [ 279,   "integer" ],
                "Lucent-Multicast-Service-Name"         => [ 276,   "string" ],
                "Lucent-Multicast-Service-Profile-Name" => [ 274,   "string" ],
                "Lucent-Multicast-Service-Snmp-Trap"    => [ 278,   "integer" ],
                "Lucent-Multilink-ID"                   => [ 187,   "integer" ],
                "Lucent-NAS-Port-Format"                => [ 13,    "integer" ],
                "Lucent-Netware-timeout"                => [ 223,   "integer" ],
                "Lucent-No-High-Prio-Pkt-Duratio"       => [ 268,   "integer" ],
                "Lucent-Num-In-Multilink"               => [ 188,   "integer" ],
                "Lucent-Num-Moh-Sessions"               => [ 303,   "integer" ],
                "Lucent-Number-Sessions"                => [ 202,   "string" ],
                "Lucent-Numbering-Plan-ID"              => [ 105,   "integer" ],
                "Lucent-Owner-IP-Addr"                  => [ 86,    "ipaddr" ],
                "Lucent-Packet-Classification"          => [ 267,   "integer" ],
                "Lucent-Port-Redir-Portnum"             => [ 83,    "integer" ],
                "Lucent-Port-Redir-Protocol"            => [ 82,    "integer" ],
                "Lucent-Port-Redir-Server"              => [ 84,    "ipaddr" ],
                "Lucent-PPP-Address"                    => [ 253,   "ipaddr" ],
                "Lucent-PPP-Async-Map"                  => [ 212,   "integer" ],
                "Lucent-PPP-Circuit"                    => [ 5,     "integer" ],
                "Lucent-PPP-Circuit-Name"               => [ 6,     "string" ],
                "Lucent-PPP-VJ-1172"                    => [ 211,   "integer" ],
                "Lucent-PPP-VJ-Slot-Comp"               => [ 210,   "integer" ],
                "Lucent-PPPoE-Enable"                   => [ 74,    "integer" ],
                "Lucent-Pre-Input-Octets"               => [ 190,   "integer" ],
                "Lucent-Pre-Input-Packets"              => [ 192,   "integer" ],
                "Lucent-Pre-Output-Octets"              => [ 191,   "integer" ],
                "Lucent-Pre-Output-Packets"             => [ 193,   "integer" ],
                "Lucent-Preempt-Limit"                  => [ 245,   "integer" ],
                "Lucent-PreSession-Time"                => [ 198,   "integer" ],
                "Lucent-PRI-Number-Type"                => [ 226,   "integer" ],
                "Lucent-Primary-Home-Agent"             => [ 129,   "string" ],
                "Lucent-Priority-For-PPP"               => [ 263,   "integer" ],
                "Lucent-Private-Route"                  => [ 104,   "string" ],
                "Lucent-Private-Route-Required"         => [ 55,    "integer" ],
                "Lucent-Private-Route-Table-ID"         => [ 54,    "string" ],
                "Lucent-PW-Lifetime"                    => [ 208,   "integer" ],
                "Lucent-PW-Warntime"                    => [ 207,   "integer" ],
                "Lucent-QOS-Downstream"                 => [ 60,    "string" ],
                "Lucent-QOS-Upstream"                   => [ 59,    "string" ],
                "Lucent-QuickConnect-Attempted"         => [ 302,   "integer" ],
                "Lucent-Receive-Secret"                 => [ 215,   "string" ],
                "Lucent-Recv-Name"                      => [ 45,    "string" ],
                "Lucent-Recv-Symbol-Rate"               => [ 20108, "integer" ],
                "Lucent-Redirect-Number"                => [ 93,    "string" ],
                "Lucent-Remote-Addr"                    => [ 154,   "ipaddr" ],
                "Lucent-Remote-FW"                      => [ 110,   "string" ],
                "Lucent-Remote-Retrain-Requested"       => [ 20116, "integer" ],
                "Lucent-Remove-Seconds"                 => [ 241,   "integer" ],
                "Lucent-Require-Auth"                   => [ 201,   "integer" ],
                "Lucent-Retrain-Reason"                 => [ 20119, "integer" ],
                "Lucent-Reverse-Path-Check"             => [ 310,   "integer" ],
                "Lucent-Route-Appletalk"                => [ 118,   "integer" ],
                "Lucent-Route-IP"                       => [ 228,   "integer" ],
                "Lucent-Route-IPX"                      => [ 229,   "integer" ],
                "Lucent-Route-Preference"               => [ 126,   "integer" ],
                "Lucent-Rtp-Local-Bytes-Sent"           => [ 10313, "integer" ],
                "Lucent-Rtp-Local-Delay-Maximum"        => [ 10307, "integer" ],
                "Lucent-Rtp-Local-Delay-Mean"           => [ 10308, "integer" ],
                "Lucent-Rtp-Local-Delay-Minimum"        => [ 10306, "integer" ],
                "Lucent-Rtp-Local-Delay-Variance"       => [ 10309, "integer" ],
                "Lucent-Rtp-Local-Jitter-Maximum"       => [ 10303, "integer" ],
                "Lucent-Rtp-Local-Jitter-Mean"          => [ 10304, "integer" ],
                "Lucent-Rtp-Local-Jitter-Minimum"       => [ 10302, "integer" ],
                "Lucent-Rtp-Local-Jitter-Variance"      => [ 10305, "integer" ],
                "Lucent-Rtp-Local-Number-Of-Samples"    => [ 10300, "integer" ],
                "Lucent-Rtp-Local-Packets-Late"         => [ 10312, "integer" ],
                "Lucent-Rtp-Local-Packets-Lost"         => [ 10311, "integer" ],
                "Lucent-Rtp-Local-Packets-Sent"         => [ 10310, "integer" ],
                "Lucent-Rtp-Local-Silence-Percent"      => [ 10314, "integer" ],
                "Lucent-RTP-Port-Range"                 => [ 265,   "string" ],
                "Lucent-Rtp-Remote-Bytes-Sent"          => [ 10326, "integer" ],
                "Lucent-Rtp-Remote-Delay-Maximum"       => [ 10320, "integer" ],
                "Lucent-Rtp-Remote-Delay-Mean"          => [ 10321, "integer" ],
                "Lucent-Rtp-Remote-Delay-Minimum"       => [ 10319, "integer" ],
                "Lucent-Rtp-Remote-Delay-Variance"      => [ 10322, "integer" ],
                "Lucent-Rtp-Remote-Jitter-Maximum"      => [ 10316, "integer" ],
                "Lucent-Rtp-Remote-Jitter-Mean"         => [ 10317, "integer" ],
                "Lucent-Rtp-Remote-Jitter-Minimum"      => [ 10315, "integer" ],
                "Lucent-Rtp-Remote-Jitter-Variance"     => [ 10318, "integer" ],
                "Lucent-Rtp-Remote-Number-Of-Samples"   => [ 10301, "integer" ],
                "Lucent-Rtp-Remote-Packets-Late"        => [ 10325, "integer" ],
                "Lucent-Rtp-Remote-Packets-Lost"        => [ 10324, "integer" ],
                "Lucent-Rtp-Remote-Packets-Sent"        => [ 10323, "integer" ],
                "Lucent-Rtp-Remote-Silence-Percent"     => [ 10327, "integer" ],
                "Lucent-Secondary-Home-Agent"           => [ 130,   "string" ],
                "Lucent-Seconds-Of-History"             => [ 238,   "integer" ],
                "Lucent-Send-Auth"                      => [ 231,   "integer" ],
                "Lucent-Send-Passwd"                    => [ 232,   "string" ],
                "Lucent-Send-Secret"                    => [ 214,   "string" ],
                "Lucent-Service-Type"                   => [ 49,    "integer" ],
                "Lucent-Session-Svr-Key"                => [ 151,   "string" ],
                "Lucent-Session-Type"                   => [ 18,    "integer" ],
                "Lucent-Shared-Profile-Enable"          => [ 128,   "integer" ],
                "Lucent-Sonet-Line-CVs-Far"             => [ 10110, "integer" ],
                "Lucent-Sonet-Line-CVs-Near"            => [ 10106, "integer" ],
                "Lucent-Sonet-Line-ESs-Far"             => [ 10108, "integer" ],
                "Lucent-Sonet-Line-ESs-Near"            => [ 10104, "integer" ],
                "Lucent-Sonet-Line-SESs-Far"            => [ 10109, "integer" ],
                "Lucent-Sonet-Line-SESs-Near"           => [ 10105, "integer" ],
                "Lucent-Sonet-Line-USs-Far"             => [ 10111, "integer" ],
                "Lucent-Sonet-Line-USs-Near"            => [ 10107, "integer" ],
                "Lucent-Sonet-Path-CVs-Far"             => [ 10118, "integer" ],
                "Lucent-Sonet-Path-CVs-Near"            => [ 10114, "integer" ],
                "Lucent-Sonet-Path-ESs-Far"             => [ 10116, "integer" ],
                "Lucent-Sonet-Path-ESs-Near"            => [ 10112, "integer" ],
                "Lucent-Sonet-Path-SESs-Far"            => [ 10117, "integer" ],
                "Lucent-Sonet-Path-SESs-Near"           => [ 10113, "integer" ],
                "Lucent-Sonet-Path-USs-Far"             => [ 10119, "integer" ],
                "Lucent-Sonet-Path-USs-Near"            => [ 10115, "integer" ],
                "Lucent-Sonet-Section-CVs"              => [ 10103, "integer" ],
                "Lucent-Sonet-Section-ESs"              => [ 10100, "integer" ],
                "Lucent-Sonet-Section-SEFSs"            => [ 10102, "integer" ],
                "Lucent-Sonet-Section-SESs"             => [ 10101, "integer" ],
                "Lucent-Source-Auth"                    => [ 103,   "string" ],
                "Lucent-Source-IP-Check"                => [ 96,    "integer" ],
                "Lucent-SVC-Enabled"                    => [ 17,    "integer" ],
                "Lucent-Target-Util"                    => [ 234,   "integer" ],
                "Lucent-Telnet-Profile"                 => [ 91,    "string" ],
                "Lucent-TermSrv-Login-Prompt"           => [ 273,   "string" ],
                "Lucent-Third-Prompt"                   => [ 213,   "string" ],
                "Lucent-Token-Expiry"                   => [ 204,   "integer" ],
                "Lucent-Token-Idle"                     => [ 199,   "integer" ],
                "Lucent-Token-Immediate"                => [ 200,   "integer" ],
                "Lucent-TOS-Copying"                    => [ 266,   "integer" ],
                "Lucent-Traffic-Shaper"                 => [ 51,    "integer" ],
                "Lucent-Transit-Number"                 => [ 251,   "string" ],
                "Lucent-TS-Idle-Limit"                  => [ 169,   "integer" ],
                "Lucent-TS-Idle-Mode"                   => [ 170,   "integer" ],
                "Lucent-Tunnel-Auth-Type"               => [ 260,   "octets" ],
                "Lucent-Tunnel-Auth-Type2"              => [ 19999, "integer" ],
                "Lucent-Tunnel-DSCP"                    => [ 284,   "integer" ],
                "Lucent-Tunnel-TOS"                     => [ 282,   "integer" ],
                "Lucent-Tunnel-TOS-Copy"                => [ 286,   "integer" ],
                "Lucent-Tunnel-TOS-Filter"              => [ 285,   "string" ],
                "Lucent-Tunnel-TOS-Precedence"          => [ 283,   "integer" ],
                "Lucent-Tunnel-VRouter-Name"            => [ 31,    "string" ],
                "Lucent-Tunneling-Protocol"             => [ 127,   "integer" ],
                "Lucent-User-Acct-Base"                 => [ 142,   "integer" ],
                "Lucent-User-Acct-Expiration"           => [ 306,   "date" ],
                "Lucent-User-Acct-Host"                 => [ 139,   "ipaddr" ],
                "Lucent-User-Acct-Key"                  => [ 141,   "string" ],
                "Lucent-User-Acct-Port"                 => [ 140,   "integer" ],
                "Lucent-User-Acct-Time"                 => [ 143,   "integer" ],
                "Lucent-User-Acct-Type"                 => [ 138,   "integer" ],
                "Lucent-User-Login-Level"               => [ 307,   "integer" ],
                "Lucent-User-Priority"                  => [ 8,     "integer" ],
                "Lucent-UU-Info"                        => [ 7,     "string" ],
                "Lucent-VRouter-Name"                   => [ 102,   "string" ],
                "Lucent-X25-Cug"                        => [ 35,    "string" ],
                "Lucent-X25-Nui"                        => [ 40,    "string" ],
                "Lucent-X25-Nui-Password-Prompt"        => [ 34,    "string" ],
                "Lucent-X25-Nui-Prompt"                 => [ 33,    "string" ],
                "Lucent-X25-Pad-Alias-1"                => [ 36,    "string" ],
                "Lucent-X25-Pad-Alias-2"                => [ 37,    "string" ],
                "Lucent-X25-Pad-Alias-3"                => [ 38,    "string" ],
                "Lucent-X25-Pad-Banner"                 => [ 43,    "string" ],
                "Lucent-X25-Pad-Prompt"                 => [ 42,    "string" ],
                "Lucent-X25-Pad-X3-Parameters"          => [ 30,    "string" ],
                "Lucent-X25-Pad-X3-Profile"             => [ 29,    "integer" ],
                "Lucent-X25-Profile-Name"               => [ 44,    "string" ],
                "Lucent-X25-Reverse-Charging"           => [ 32,    "integer" ],
                "Lucent-X25-Rpoa"                       => [ 41,    "string" ],
                "Lucent-X25-X121-Address"               => [ 39,    "string" ],
                "Lucent-X25-X121-Source-Address"        => [ 4,     "string" ],
                "Lucent-Xmit-Rate"                      => [ 255,   "integer" ],
                "Lucent-Xmit-Symbol-Rate"               => [ 20107, "integer" ],
            },
            4874 => {
                "ERX-Acc-Aggr-Cir-Id-Asc"        => [ 112, "string" ],
                "ERX-Acc-Aggr-Cir-Id-Bin"        => [ 111, "octets" ],
                "ERX-Acc-Loop-Cir-Id"            => [ 110, "string" ],
                "ERX-Acc-Loop-Encap"             => [ 183, "octets" ],
                "ERX-Acc-Loop-Remote-Id"         => [ 182, "string" ],
                "ERX-Acct-Request-Reason"        => [ 210, "integer" ],
                "ERX-Act-Data-Rate-Dn"           => [ 114, "integer" ],
                "ERX-Act-Data-Rate-Up"           => [ 113, "integer" ],
                "ERX-Act-Interlv-Delay-Dn"       => [ 126, "integer" ],
                "ERX-Act-Interlv-Delay-Up"       => [ 124, "integer" ],
                "ERX-Action-Reason"              => [ 178, "string" ],
                "ERX-Address-Pool-Name"          => [ 2,   "string" ],
                "ERX-Adv-Pcef-Profile-Name"      => [ 204, "string" ],
                "ERX-Adv-Pcef-Rule-Name"         => [ 205, "string" ],
                "ERX-Alternate-Cli-Access-Level" => [ 20,  "string" ],
                "ERX-Alternate-Cli-Vrouter-Name" => [ 21,  "string" ],
                "ERX-APN-Name"                   => [ 176, "string" ],
                "ERX-Atm-MBS"                    => [ 17,  "integer" ],
                "ERX-Atm-PCR"                    => [ 15,  "integer" ],
                "ERX-Atm-SCR"                    => [ 16,  "integer" ],
                "ERX-Atm-Service-Category"       => [ 14,  "integer" ],
                "ERX-Att-Data-Rate-Dn"           => [ 118, "integer" ],
                "ERX-Att-Data-Rate-Up"           => [ 117, "integer" ],
                "ERX-Attainable-Expected-Throughput-Downstream" =>
                  [ 229, "integer" ],
                "ERX-Attainable-Expected-Throughput-Upstream" =>
                  [ 228, "integer" ],
                "ERX-Attainable-Gamma-Data-Rate-Downstream" =>
                  [ 233, "integer" ],
                "ERX-Attainable-Gamma-Data-Rate-Upstream" => [ 232, "integer" ],
                "ERX-Backup-Address-Pool"                 => [ 147, "string" ],
                "ERX-Bearer-Type"                         => [ 41,  "integer" ],
                "ERX-Bulk-CoA-Identifier"                 => [ 195, "integer" ],
                "ERX-Bulk-CoA-Transaction-Id"             => [ 194, "integer" ],
                "ERX-Cli-Allow-All-VR-Access"             => [ 19,  "integer" ],
                "ERX-Cli-Initial-Access-Level"            => [ 18,  "string" ],
                "ERX-Client-Profile-Name"                 => [ 174, "string" ],
                "ERX-Core-Facing-Interface"               => [ 185, "string" ],
                "ERX-CoS-Scheduler-Pmt-Type"              => [ 146, "string" ],
                "ERX-CoS-Shaping-Pmt-Type"                => [ 108, "string" ],
                "ERX-Cos-Shaping-Rate"                    => [ 177, "string" ],
                "ERX-DF-Bit"                              => [ 70,  "integer" ],
                "ERX-DHCP-First-Relay-IPv4-Address"       => [ 189, "ipaddr" ],
                "ERX-DHCP-First-Relay-IPv6-Address"      => [ 190, "ipv6addr" ],
                "ERX-Dhcp-Gi-Address"                    => [ 57,  "ipaddr" ],
                "ERX-DHCP-Guided-Relay-Server"           => [ 109, "ipaddr" ],
                "ERX-DHCP-Header"                        => [ 208, "octets" ],
                "ERX-Dhcp-Mac-Addr"                      => [ 56,  "string" ],
                "ERX-Dhcp-Option-82"                     => [ 159, "octets" ],
                "ERX-Dhcp-Options"                       => [ 55,  "octets" ],
                "ERX-DHCPv6-Guided-Relay-Server"         => [ 181, "ipv6addr" ],
                "ERX-DHCPv6-Header"                      => [ 209, "octets" ],
                "ERX-DHCPv6-Options"                     => [ 207, "octets" ],
                "ERX-Dial-Out-Number"                    => [ 35,  "string" ],
                "ERX-DownStream-Calc-Rate"               => [ 141, "integer" ],
                "ERX-DSL-Line-State"                     => [ 127, "integer" ],
                "ERX-DSL-Type"                           => [ 128, "integer" ],
                "ERX-Egress-Policy-Name"                 => [ 11,  "string" ],
                "ERX-Egress-Statistics"                  => [ 13,  "integer" ],
                "ERX-Expected-Throughput-Downstream"     => [ 227, "integer" ],
                "ERX-Expected-Throughput-Upstream"       => [ 226, "integer" ],
                "ERX-Framed-Ip-Route-Tag"                => [ 34,  "string" ],
                "ERX-Gamma-Data-Rate-Downstream"         => [ 231, "integer" ],
                "ERX-Gamma-Data-Rate-Upstream"           => [ 230, "integer" ],
                "ERX-Hybrid-Access-DSL-Downstream-Speed" => [ 216, "integer" ],
                "ERX-Hybrid-Access-LTE-Downstream-Speed" => [ 217, "integer" ],
                "ERX-ICR-Partition-Id"                   => [ 150, "string" ],
                "ERX-IGMP-Access-Name"                   => [ 71,  "string" ],
                "ERX-IGMP-Access-Src-Name"               => [ 72,  "string" ],
                "ERX-Igmp-Enable"                        => [ 23,  "integer" ],
                "ERX-IGMP-Explicit-Tracking"             => [ 102, "integer" ],
                "ERX-IGMP-Immediate-Leave"               => [ 97,  "integer" ],
                "ERX-IGMP-Max-Resp-Time"                 => [ 96,  "integer" ],
                "ERX-IGMP-No-Tracking-V2-Grps"           => [ 103, "integer" ],
                "ERX-IGMP-OIF-Map-Name"                  => [ 73,  "string" ],
                "ERX-IGMP-Query-Interval"                => [ 95,  "integer" ],
                "ERX-IGMP-Version"                       => [ 78,  "integer" ],
                "ERX-Ingress-Policy-Name"                => [ 10,  "string" ],
                "ERX-Ingress-Statistics"                 => [ 12,  "integer" ],
                "ERX-Inner-Tag-Protocol-Id"              => [ 211, "string" ],
                "ERX-Inner-Vlan-Map-Id"                  => [ 184, "integer" ],
                "ERX-Input-Gigapkts"                     => [ 42,  "integer" ],
                "ERX-Input-Interface-Filter"             => [ 191, "string" ],
                "ERX-Interface-Desc"                     => [ 63,  "string" ],
                "ERX-Interface-Set-Targeting-Weight"     => [ 213, "integer" ],
                "ERX-Interface-Targeting-Weight"         => [ 214, "integer" ],
                "ERX-IP-Block-Multicast"                 => [ 101, "integer" ],
                "ERX-IP-Mcast-Adm-Bw-Limit"              => [ 79,  "integer" ],
                "ERX-IPv4-Input-Service-Filter"          => [ 198, "string" ],
                "ERX-IPv4-Input-Service-Set"             => [ 196, "string" ],
                "ERX-IPv4-Output-Service-Filter"         => [ 199, "string" ],
                "ERX-IPv4-Output-Service-Set"            => [ 197, "string" ],
                "ERX-IPv6-Acct-Input-Gigawords"          => [ 155, "integer" ],
                "ERX-IPv6-Acct-Input-Octets"             => [ 151, "integer" ],
                "ERX-IPv6-Acct-Input-Packets"            => [ 153, "integer" ],
                "ERX-IPv6-Acct-Output-Gigawords"         => [ 156, "integer" ],
                "ERX-IPv6-Acct-Output-Octets"            => [ 152, "integer" ],
                "ERX-IPv6-Acct-Output-Packets"           => [ 154, "integer" ],
                "ERX-IPv6-Delegated-Pool-Name"           => [ 161, "string" ],
                "ERX-IPv6-Egress-Policy-Name"            => [ 107, "string" ],
                "ERX-IPv6-Ingress-Policy-Name"           => [ 106, "string" ],
                "ERX-IPv6-Input-Service-Filter"          => [ 202, "string" ],
                "ERX-IPv6-Input-Service-Set"             => [ 200, "string" ],
                "ERX-IpV6-Local-Interface"               => [ 46,  "string" ],
                "ERX-IPv6-Mcast-Adm-Bw-Limit"            => [ 80,  "integer" ],
                "ERX-IPv6-NdRa-Pool-Name"                => [ 157, "string" ],
                "ERX-IPv6-NdRa-Prefix"           => [ 129, "ipv6prefix" ],
                "ERX-IPv6-Output-Service-Filter" => [ 203, "string" ],
                "ERX-IPv6-Output-Service-Set"    => [ 201, "string" ],
                "ERX-Ipv6-Primary-Dns"           => [ 47,  "ipv6addr" ],
                "ERX-Ipv6-Secondary-Dns"         => [ 48,  "ipv6addr" ],
                "ERX-IpV6-Virtual-Router"        => [ 45,  "string" ],
                "ERX-L2c-Down-Stream-Data"       => [ 93,  "string" ],
                "ERX-L2c-Up-Stream-Data"         => [ 92,  "string" ],
                "ERX-L2tp-Recv-Window-Size"      => [ 54,  "integer" ],
                "ERX-L2TP-Resynch-Method"        => [ 90,  "integer" ],
                "ERX-LI-Action"                  => [ 58,  "integer" ],
                "ERX-Local-Loopback-Interface"   => [ 3,   "string" ],
                "ERX-Max-Clients-Per-Interface"  => [ 143, "integer" ],
                "ERX-Max-Data-Rate-Dn"           => [ 120, "integer" ],
                "ERX-Max-Data-Rate-Up"           => [ 119, "integer" ],
                "ERX-Max-Interlv-Delay-Dn"       => [ 125, "integer" ],
                "ERX-Max-Interlv-Delay-Up"       => [ 123, "integer" ],
                "ERX-Maximum-BPS"                => [ 40,  "integer" ],
                "ERX-Med-Dev-Handle"             => [ 59,  "octets" ],
                "ERX-Med-Ip-Address"             => [ 60,  "ipaddr" ],
                "ERX-Med-Port-Number"            => [ 61,  "integer" ],
                "ERX-Min-Data-Rate-Dn"           => [ 116, "integer" ],
                "ERX-Min-Data-Rate-Up"           => [ 115, "integer" ],
                "ERX-Min-LP-Data-Rate-Dn"        => [ 122, "integer" ],
                "ERX-Min-LP-Data-Rate-Up"        => [ 121, "integer" ],
                "ERX-Minimum-BPS"                => [ 39,  "integer" ],
                "ERX-MLD-Access-Name"            => [ 74,  "string" ],
                "ERX-MLD-Access-Src-Name"        => [ 75,  "string" ],
                "ERX-MLD-Explicit-Tracking"      => [ 104, "integer" ],
                "ERX-MLD-Immediate-Leave"        => [ 100, "integer" ],
                "ERX-MLD-Max-Resp-Time"          => [ 99,  "integer" ],
                "ERX-MLD-No-Tracking-V1-Grps"    => [ 105, "integer" ],
                "ERX-MLD-OIF-Map-Name"           => [ 76,  "string" ],
                "ERX-MLD-Query-Interval"         => [ 98,  "integer" ],
                "ERX-MLD-Version"                => [ 77,  "integer" ],
                "ERX-MLPPP-Bundle-Name"          => [ 62,  "string" ],
                "ERX-Mobile-IP-Access-Control"   => [ 88,  "string" ],
                "ERX-Mobile-IP-Algorithm"        => [ 84,  "integer" ],
                "ERX-Mobile-IP-Key"              => [ 86,  "string" ],
                "ERX-Mobile-IP-Lifetime"         => [ 89,  "integer" ],
                "ERX-Mobile-IP-Replay"           => [ 87,  "integer" ],
                "ERX-Mobile-IP-SPI"              => [ 85,  "integer" ],
                "ERX-ONT-ONU-Assured-Data-Rate-Upstream" => [ 223, "integer" ],
                "ERX-ONT-ONU-Average-Data-Rate-Downstream" =>
                  [ 220, "integer" ],
                "ERX-ONT-ONU-Maximum-Data-Rate-Upstream" => [ 222, "integer" ],
                "ERX-ONT-ONU-Peak-Data-Rate-Downstream"  => [ 221, "integer" ],
                "ERX-Output-Gigapkts"                    => [ 43,  "integer" ],
                "ERX-Output-Interface-Filter"            => [ 192, "string" ],
                "ERX-Pim-Enable"                         => [ 193, "integer" ],
                "ERX-PON-Access-Type"                    => [ 219, "integer" ],
                "ERX-PON-Tree-Maximum-Data-Rate-Downstream" =>
                  [ 225, "integer" ],
                "ERX-PON-Tree-Maximum-Data-Rate-Upstream" => [ 224, "integer" ],
                "ERX-PPP-Auth-Protocol"                   => [ 38,  "integer" ],
                "ERX-PPP-Monitor-Ingress-Only"            => [ 144, "integer" ],
                "ERX-PPP-Password"                        => [ 37,  "string" ],
                "ERX-PPP-Username"                        => [ 36,  "string" ],
                "ERX-Pppoe-Description"                   => [ 24,  "string" ],
                "ERX-Pppoe-Max-Sessions"                  => [ 27,  "integer" ],
                "ERX-PppoE-Padn"                          => [ 158, "string" ],
                "ERX-Pppoe-Url"                           => [ 28,  "string" ],
                "ERX-Primary-Dns"                         => [ 4,   "ipaddr" ],
                "ERX-Primary-Wins"                        => [ 6,   "ipaddr" ],
                "ERX-Qos-Parameters"                      => [ 82,  "string" ],
                "ERX-Qos-Profile-Interface-Type"          => [ 29,  "integer" ],
                "ERX-Qos-Profile-Name"                    => [ 26,  "string" ],
                "ERX-Qos-Set-Name"                        => [ 130, "string" ],
                "ERX-Radius-Client-Address"               => [ 52,  "ipaddr" ],
                "ERX-Re-Authentication-Catalyst"          => [ 206, "integer" ],
                "ERX-Redirect-GW-Address"                 => [ 175, "ipaddr" ],
                "ERX-Redirect-VR-Name"                    => [ 25,  "string" ],
                "ERX-Routing-Services"                    => [ 212, "integer" ],
                "ERX-Rx-Connect-Speed"                    => [ 163, "integer" ],
                "ERX-Sa-Validate"                         => [ 22,  "integer" ],
                "ERX-Secondary-Dns"                       => [ 5,   "ipaddr" ],
                "ERX-Secondary-Wins"                      => [ 7,   "ipaddr" ],
                "ERX-Service-Acct-Interval"               => [ 140, "integer" ],
                "ERX-Service-Activate"                    => [ 65,  "string" ],
                "ERX-Service-Activate-Type"               => [ 173, "integer" ],
                "ERX-Service-Bundle"                      => [ 31,  "string" ],
                "ERX-Service-Deactivate"                  => [ 66,  "string" ],
                "ERX-Service-Description"                 => [ 53,  "string" ],
                "ERX-Service-Session"                     => [ 83,  "string" ],
                "ERX-Service-Statistics"                  => [ 69,  "integer" ],
                "ERX-Service-Timeout"                     => [ 68,  "integer" ],
                "ERX-Service-Volume"                      => [ 67,  "integer" ],
                "ERX-Service-Volume-Gigawords"            => [ 179, "integer" ],
                "ERX-Tunnel-Group"                        => [ 64,  "string" ],
                "ERX-Tunnel-Interface-Id"                 => [ 44,  "string" ],
                "ERX-Tunnel-Maximum-Sessions"             => [ 33,  "integer" ],
                "ERX-Tunnel-Nas-Port-Method"              => [ 30,  "integer" ],
                "ERX-Tunnel-Password"                     => [ 9,   "string" ],
                "ERX-Tunnel-Switch-Profile"               => [ 91,  "string" ],
                "ERX-Tunnel-Tos"                          => [ 32,  "integer" ],
                "ERX-Tunnel-Tx-Speed-Method"              => [ 94,  "integer" ],
                "ERX-Tunnel-Virtual-Router"               => [ 8,   "string" ],
                "ERX-Tx-Connect-Speed"                    => [ 162, "integer" ],
                "ERX-Update-Service"                      => [ 180, "string" ],
                "ERX-UpStream-Calc-Rate"                  => [ 142, "integer" ],
                "ERX-Virtual-Router-Name"                 => [ 1,   "string" ],
                "ERX-Vlan-Map-Id"                         => [ 160, "integer" ],
                "Sdx-Service-Name"                        => [ 49,  "string" ],
                "Sdx-Session-Volume-Quota"                => [ 50,  "string" ],
                "Sdx-Tunnel-Disconnect-Cause-Info"        => [ 51,  "string" ],
            },
            5003 => { "ACL-Auth-Level"       => [ 35, "integer" ] },
            5089 => { "Clavister-User-Group" => [ 1,  "string" ] },
            5263 => { "CBBSM-Bandwidth"      => [ 1,  "integer" ] },
            5323 => {
                "Telrad-C-VLAN-ID"                  => [ 1, "integer" ],
                "Telrad-C-VLAN-ID-Retag"            => [ 1, "integer" ],
                "Telrad-Item-Identity"              => [ 1, "byte" ],
                "Telrad-Reference-QOS-Profile-Name" => [ 1, "string" ],
                "Telrad-Reference-VPWS-PDN-Name"    => [ 1, "octets" ],
                "Telrad-S-VLAN-ID"                  => [ 1, "integer" ],
                "Telrad-TSDF-Parameters"            => [ 1, "tlv" ],
                "Telrad-TSDF-Table"                 => [ 1, "tlv" ],
            },
            5468 => { "Actelis-Privilege" => [ 1, "string" ] },
            5535 => {
                "3GGP2-Hot-Line-Capability"              => [ 127, "integer" ],
                "3GPP2-Accounting-Container"             => [ 6,   "octets" ],
                "3GPP2-Acct-Stop-Trigger"                => [ 93,  "integer" ],
                "3GPP2-Active-Time"                      => [ 49,  "integer" ],
                "3GPP2-Airlink-Priority"                 => [ 39,  "integer" ],
                "3GPP2-Airlink-Record-Type"              => [ 40,  "integer" ],
                "3GPP2-Airlink-Sequence-Number"          => [ 42,  "integer" ],
                "3GPP2-Allowed-Diffserv-Marking"         => [ 73,  "tlv" ],
                "3GPP2-Allowed-Diffserv-Marking-Allowed" => [ 73,  "short" ],
                "3GPP2-Allowed-Diffserv-Marking-Max-Class" => [ 73, "short" ],
                "3GPP2-Allowed-Diffserv-Marking-Reverse-Runnel" =>
                  [ 73, "short" ],
                "3GPP2-Allowed-Persistent-TFTs"           => [ 89,  "integer" ],
                "3GPP2-Always-On"                         => [ 78,  "integer" ],
                "3GPP2-AT-Hardware-Identifier"            => [ 61,  "tlv" ],
                "3GPP2-AT-Hardware-Identifier-Type"       => [ 61,  "integer" ],
                "3GPP2-AT-Hardware-Identifier-Value"      => [ 61,  "octets" ],
                "3GPP2-Auth-Flow-Profile-ID"              => [ 131, "tlv" ],
                "3GPP2-Auth-Flow-Profile-ID-Bi-Direction" => [ 131, "short" ],
                "3GPP2-Auth-Flow-Profile-ID-Forward"      => [ 131, "short" ],
                "3GPP2-Auth-Flow-Profile-ID-Reverse"      => [ 131, "short" ],
                "3GPP2-Bad-PPP-Frame-Count"               => [ 25,  "integer" ],
                "3GPP2-Begin-Session"                     => [ 51,  "integer" ],
                "3GPP2-BSID"                              => [ 10,  "string" ],
                "3GPP2-Carrier-ID"                        => [ 142, "string" ],
                "3GPP2-Compulsory-Tunnel-Indicator"       => [ 23,  "integer" ],
                "3GPP2-Correlation-Id"                    => [ 44,  "string" ],
                "3GPP2-DCCH-Frame-Size"                   => [ 50,  "integer" ],
                "3GPP2-Diffserv-Class-Option"             => [ 5,   "integer" ],
                "3GPP2-Disconnect-Reason"                 => [ 96,  "integer" ],
                "3GPP2-DNS-Server-Entity-Type"            => [ 117, "byte" ],
                "3GPP2-DNS-Server-Flag"                   => [ 117, "byte" ],
                "3GPP2-DNS-Server-IP-Address"             => [ 117, "tlv" ],
                "3GPP2-DNS-Server-IPv6-Address"           => [ 214, "tlv" ],
                "3GPP2-DNS-Server-IPv6-Address-Entity-Type" => [ 214, "byte" ],
                "3GPP2-DNS-Server-IPv6-Address-Flag"        => [ 214, "byte" ],
                "3GPP2-DNS-Server-IPv6-Address-Primary" => [ 214, "ipv6addr" ],
                "3GPP2-DNS-Server-IPv6-Address-Secondary" =>
                  [ 214, "ipv6addr" ],
                "3GPP2-DNS-Server-Primary-IP-Address"    => [ 117, "ipaddr" ],
                "3GPP2-DNS-Server-Secondary-IP-Address"  => [ 117, "ipaddr" ],
                "3GPP2-DNS-Update-Capability"            => [ 95,  "integer" ],
                "3GPP2-DNS-Update-Required"              => [ 75,  "integer" ],
                "3GPP2-ESN"                              => [ 52,  "string" ],
                "3GPP2-FCH-Frame-Size"                   => [ 19,  "integer" ],
                "3GPP2-Filter-Rule"                      => [ 124, "string" ],
                "3GPP2-Filtered-Octet-Count-Originating" => [ 147, "integer" ],
                "3GPP2-Filtered-Octet-Count-Terminating" => [ 146, "integer" ],
                "3GPP2-Flow-ID"                          => [ 144, "tlv" ],
                "3GPP2-Flow-ID-Direction"                => [ 144, "short" ],
                "3GPP2-Flow-ID-Flow-ID"                  => [ 144, "short" ],
                "3GPP2-Flow-Status"                      => [ 145, "integer" ],
                "3GPP2-Foreign-Agent-Address"            => [ 79,  "ipaddr" ],
                "3GPP2-Forward-DCCH-Mux-Option"          => [ 84,  "integer" ],
                "3GPP2-Forward-DCCH-RC"                  => [ 86,  "integer" ],
                "3GPP2-Forward-FCH-Mux-Option"           => [ 12,  "integer" ],
                "3GPP2-Forward-FCH-RC"                   => [ 20,  "integer" ],
                "3GPP2-Forward-PDCH-RC"                  => [ 83,  "integer" ],
                "3GPP2-Forward-Traffic-Type"             => [ 17,  "integer" ],
                "3GPP2-GMT-Time-Zone-Offset"             => [ 143, "signed" ],
                "3GPP2-Granted-QoS-Params"               => [ 132, "tlv" ],
                "3GPP2-Granted-QoS-Params-Bucket-Size"   => [ 132, "short" ],
                "3GPP2-Granted-QoS-Params-Delay-Var-Sensitive" =>
                  [ 132, "short" ],
                "3GPP2-Granted-QoS-Params-Direction"       => [ 132, "short" ],
                "3GPP2-Granted-QoS-Params-Flow-Id"         => [ 132, "short" ],
                "3GPP2-Granted-QoS-Params-Flow-Profile-ID" => [ 132, "short" ],
                "3GPP2-Granted-QoS-Params-Max-IP-Packet-Loss-Rate" =>
                  [ 132, "short" ],
                "3GPP2-Granted-QoS-Params-Max-Latency"   => [ 132, "short" ],
                "3GPP2-Granted-QoS-Params-Packet-Size"   => [ 132, "short" ],
                "3GPP2-Granted-QoS-Params-Peak-Rate"     => [ 132, "short" ],
                "3GPP2-Granted-QoS-Params-Token-Rate"    => [ 132, "short" ],
                "3GPP2-Granted-QoS-Params-Traffic-Class" => [ 132, "short" ],
                "3GPP2-HA-Authorised"                    => [ 169, "integer" ],
                "3GPP2-HA-Request"                       => [ 168, "integer" ],
                "3GPP2-HAAA-MIP6-HA-Protocol-Capability-Indication" =>
                  [ 203, "integer" ],
                "3GPP2-Home-Agent-IP-Address"        => [ 7,   "ipaddr" ],
                "3GPP2-HRPD-Access-Authorization"    => [ 60,  "integer" ],
                "3GPP2-HTTP-Redirection-Rule"        => [ 125, "string" ],
                "3GPP2-Ike-Preshared-Secret-Request" => [ 1,   "integer" ],
                "3GPP2-Inbound-Mobile-IP-Sig-Octets" => [ 46,  "integer" ],
                "3GPP2-Inter-User-Priority"          => [ 139, "integer" ],
                "3GPP2-IP-QoS"                       => [ 36,  "integer" ],
                "3GPP2-IP-Redirection-Rule"          => [ 126, "string" ],
                "3GPP2-IP-Technology"                => [ 22,  "integer" ],
                "3GPP2-IP-Ver-Authorised"            => [ 172, "integer" ],
                "3GPP2-KeyID"                        => [ 8,   "string" ],
                "3GPP2-Last-User-Activity-Time"      => [ 80,  "integer" ],
                "3GPP2-Max-Auth-Aggregate-Bandwidth" => [ 130, "integer" ],
                "3GPP2-Max-Per-Flow-Priority"        => [ 133, "integer" ],
                "3GPP2-MEID"                         => [ 116, "octets" ],
                "3GPP2-MIP-Lifetime"                 => [ 92,  "octets" ],
                "3GPP2-MIP6-Accounting-Indication"   => [ 122, "string" ],
                "3GPP2-MIP6-Authenticator"           => [ 134, "octets" ],
                "3GPP2-MIP6-CoA"                     => [ 119, "ipv6addr" ],
                "3GPP2-MIP6-HA-Local-Assigment-Capability" =>
                  [ 179, "integer" ],
                "3GPP2-MIP6-HoA"                      => [ 141, "ipv6addr" ],
                "3GPP2-MIP6-HoA-Not-Authorized"       => [ 120, "integer" ],
                "3GPP2-MIP6-Home-Agent"               => [ 118, "ipv6addr" ],
                "3GPP2-MIP6-Home-Agent-Attr-B"        => [ 140, "ipv6addr" ],
                "3GPP2-MIP6-Home-Link-Prefix"         => [ 128, "octets" ],
                "3GPP2-MIP6-MAC-Mobility-Data"        => [ 138, "octets" ],
                "3GPP2-MIP6-Mesg-ID"                  => [ 123, "octets" ],
                "3GPP2-MIP6-Session-Key"              => [ 121, "octets" ],
                "3GPP2-MIPv4-Mesg-Id"                 => [ 173, "string" ],
                "3GPP2-MN-AAA-Removal-Indication"     => [ 81,  "integer" ],
                "3GPP2-MN-HA-Shared-Key"              => [ 58,  "string" ],
                "3GPP2-MN-HA-SPI"                     => [ 57,  "integer" ],
                "3GPP2-Module-Orig-Term-Indicator"    => [ 45,  "octets" ],
                "3GPP2-Number-Active-Transitions"     => [ 30,  "integer" ],
                "3GPP2-Originating-Number-SDBs"       => [ 34,  "integer" ],
                "3GPP2-Originating-SDB-OCtet-Count"   => [ 32,  "integer" ],
                "3GPP2-Outbound-Mobile-IP-Sig-Octets" => [ 47,  "integer" ],
                "3GPP2-PCF-IP-Address"                => [ 9,   "ipaddr" ],
                "3GPP2-Pre-Shared-Secret"             => [ 3,   "string" ],
                "3GPP2-Prepaid-acct-Capability"       => [ 91,  "octets" ],
                "3GPP2-Prepaid-Acct-Quota"            => [ 90,  "tlv" ],
                "3GPP2-Prepaid-Acct-Quota-QuotaIDentifier" => [ 90, "integer" ],
                "3GPP2-Prepaid-Acct-Quota-UpdateReason"    => [ 90, "short" ],
                "3GPP2-Prepaid-Acct-Quota-VolumeQuota"     => [ 90, "integer" ],
                "3GPP2-Prepaid-Acct-Quota-VolumeQuotaOverflow" =>
                  [ 90, "integer" ],
                "3GPP2-Prepaid-Acct-Quota-VolumeThreshold" => [ 90, "integer" ],
                "3GPP2-Prepaid-Acct-Quota-VolumeThresholdOverflow" =>
                  [ 90, "integer" ],
                "3GPP2-Prepaid-Quota-Identifier"       => [ 98, "integer" ],
                "3GPP2-Prepaid-Tariff-Switch-Interval" => [ 98, "integer" ],
                "3GPP2-PrePaid-Tariff-Switching"       => [ 98, "tlv" ],
                "3GPP2-Prepaid-Time-Interval-After-Tariff-Switch-Update" =>
                  [ 98, "integer" ],
                "3GPP2-Prepaid-Volume-Used-After-Tariff-Switch" =>
                  [ 98, "integer" ],
                "3GPP2-Prepaid-Volume-Used-ATS-Overflow" => [ 98, "short" ],
                "3GPP2-R-P-Session-ID"                   => [ 41, "octets" ],
                "3GPP2-Received-HDLC-Octets"             => [ 43, "integer" ],
                "3GPP2-Release-Indicator"                => [ 24, "integer" ],
                "3GPP2-Remote-Address-Table-Index"       => [ 71, "tlv" ],
                "3GPP2-Remote-Address-Table-Index-Qualifier" => [ 71, "short" ],
                "3GPP2-Remote-Address-Table-Index-Value"     => [ 71, "short" ],
                "3GPP2-Remote-IP-Address"                    => [ 59, "tlv" ],
                "3GPP2-Remote-IP-Address-Mask"       => [ 59, "integer" ],
                "3GPP2-Remote-IP-Address-Value"      => [ 59, "ipaddr" ],
                "3GPP2-Remote-IP-Qualifier"          => [ 59, "short" ],
                "3GPP2-Remote-IPv4-Addr-Octet-Count" => [ 72, "tlv" ],
                "3GPP2-Remote-IPv4-Addr-Octet-Count-Address" =>
                  [ 72, "ipaddr" ],
                "3GPP2-Remote-IPv4-Addr-Octet-Count-Forward" =>
                  [ 72, "integer" ],
                "3GPP2-Remote-IPv4-Addr-Octet-Count-Forward-Overflow" =>
                  [ 72, "short" ],
                "3GPP2-Remote-IPv4-Addr-Octet-Count-Mask" => [ 72, "integer" ],
                "3GPP2-Remote-IPv4-Addr-Octet-Count-Reverse" =>
                  [ 72, "integer" ],
                "3GPP2-Remote-IPv4-Addr-Octet-Count-Reverse-Overflow" =>
                  [ 72, "short" ],
                "3GPP2-Remote-IPv4-Addr-Octet-Count-Table-Index" =>
                  [ 72, "short" ],
                "3GPP2-Remote-IPv6-Address"               => [ 70, "tlv" ],
                "3GPP2-Remote-IPv6-Address-Prefix-Length" => [ 70, "integer" ],
                "3GPP2-Remote-IPv6-Address-Qualifier"     => [ 70, "tlv" ],
                "3GPP2-Remote-IPv6-Address-Value"         => [ 70, "ipv6addr" ],
                "3GPP2-Remote-IPv6-Count-Address"         => [ 97, "ipv6addr" ],
                "3GPP2-Remote-IPv6-Forward-Octet-Count"   => [ 97, "integer" ],
                "3GPP2-Remote-IPv6-Octet-Count"           => [ 97, "tlv" ],
                "3GPP2-Remote-IPv6-Prefix-Length"         => [ 97, "short" ],
                "3GPP2-Remote-IPv6-Reverse-Octet-Count"   => [ 97, "integer" ],
                "3GPP2-Remote-IPv6-Reverse-Octet-Count-Overflow" =>
                  [ 97, "short" ],
                "3GPP2-Remote-IPv6-Table-Index"         => [ 97,  "short" ],
                "3GPP2-Reverse-DCCH-Mux-Option"         => [ 85,  "integer" ],
                "3GPP2-Reverse-DHHC-RC"                 => [ 87,  "integer" ],
                "3GPP2-Reverse-FCH-Mux-Option"          => [ 13,  "integer" ],
                "3GPP2-Reverse-FCH-RC"                  => [ 21,  "integer" ],
                "3GPP2-Reverse-Traffic-Type"            => [ 18,  "integer" ],
                "3GPP2-Reverse-Tunnel-Spec"             => [ 4,   "integer" ],
                "3GPP2-RN-Packet-Data-Inactivity-Timer" => [ 82,  "integer" ],
                "3GPP2-RSVP-Inbound-Octet-Count"        => [ 164, "integer" ],
                "3GPP2-RSVP-Outbound-Octet-Count"       => [ 163, "integer" ],
                "3GPP2-RSVP-Outbound-Packet-Count"      => [ 165, "integer" ],
                "3GPP2-S-Key"                           => [ 54,  "octets" ],
                "3GPP2-S-Lifetime"                      => [ 56,  "date" ],
                "3GPP2-S-Request"                       => [ 55,  "integer" ],
                "3GPP2-Security-Level"                  => [ 2,   "integer" ],
                "3GPP2-Service-Option"                  => [ 16,  "integer" ],
                "3GPP2-Service-Option-Profile"          => [ 74,  "tlv" ],
                "3GPP2-Service-Option-Profile-Option"   => [ 74,  "short" ],
                "3GPP2-Service-Reference-Id"            => [ 94,  "tlv" ],
                "3GPP2-Service-Reference-Id-Value"      => [ 94,  "short" ],
                "3GPP2-Service-Reference-Main-SC-Indicator" => [ 94, "short" ],
                "3GPP2-Session-Continue"               => [ 48,  "integer" ],
                "3GPP2-Session-Termination-Capability" => [ 88,  "integer" ],
                "3GPP2-Subnet"                         => [ 108, "tlv" ],
                "3GPP2-Subnet-Sector-ID"               => [ 108, "octets" ],
                "3GPP2-Subnet-Subnet"                  => [ 108, "octets" ],
                "3GPP2-Terminating-Number-SDBs"        => [ 33,  "integer" ],
                "3GPP2-Terminating-SDB-Octet-Count"    => [ 31,  "integer" ],
                "3GPP2-User-Id"                        => [ 11,  "integer" ],
                "3GPP2-VAAA-Assigned-MIP6-HA"          => [ 205, "ipv6addr" ],
                "3GPP2-VAAA-Assigned-MIP6-HL"          => [ 206, "octets" ],
                "3GPP2-VAAA-MIP6-HA-Protocol-Capability-Indication" =>
                  [ 207, "integer" ],
            },
            5567 => {
                "Riverstone-Command"            => [ 1, "string" ],
                "Riverstone-SNMP-Config-Change" => [ 3, "string" ],
                "Riverstone-System-Event"       => [ 2, "string" ],
                "Riverstone-User-Level"         => [ 4, "integer" ],
            },
            5597 => { "MBG-Management-Privilege-Level" => [ 1, "integer" ] },
            5925 => {
                "IPU-IKE-Auth"        => [ 63, "string" ],
                "IPU-IKE-Cmd"         => [ 65, "string" ],
                "IPU-IKE-Conf-Name"   => [ 64, "string" ],
                "IPU-IKE-Local-Addr"  => [ 62, "ipaddr" ],
                "IPU-IKE-Remote-Addr" => [ 61, "ipaddr" ],
                "IPU-MIP-Alg-Mode"    => [ 54, "integer" ],
                "IPU-MIP-Alg-Type"    => [ 53, "integer" ],
                "IPU-MIP-Key"         => [ 52, "string" ],
                "IPU-MIP-Replay-Prot" => [ 55, "integer" ],
                "IPU-MIP-Spi"         => [ 51, "integer" ],
            },
            5948 => {
                "Issanni-Interface-Name"    => [ 17, "string" ],
                "Issanni-IP-Pool-Name"      => [ 5,  "string" ],
                "Issanni-NAT-Support"       => [ 2,  "string" ],
                "Issanni-NAT-Type"          => [ 15, "integer" ],
                "Issanni-PPPoE-MOTM"        => [ 7,  "string" ],
                "Issanni-PPPoE-URL"         => [ 6,  "string" ],
                "Issanni-Pri-DNS"           => [ 9,  "ipaddr" ],
                "Issanni-Pri-NBNS"          => [ 11, "ipaddr" ],
                "Issanni-QOS-Class"         => [ 16, "string" ],
                "Issanni-Routing-Context"   => [ 3,  "string" ],
                "Issanni-Sec-DNS"           => [ 10, "ipaddr" ],
                "Issanni-Sec-NBNS"          => [ 12, "ipaddr" ],
                "Issanni-Service"           => [ 8,  "string" ],
                "Issanni-SoftFlow-Template" => [ 1,  "string" ],
                "Issanni-Traffic-Class"     => [ 13, "string" ],
                "Issanni-Tunnel-Name"       => [ 4,  "string" ],
                "Issanni-Tunnel-Type"       => [ 14, "integer" ],
            },
            6027 => { "Force10-AVPair" => [ 1, "string" ] },
            6321 => {
                "Calix-CMS-Alarm-Filter"           => [ 221, "integer" ],
                "Calix-CMS-Event-Filter"           => [ 222, "integer" ],
                "Calix-CMS-Threshold-Event-Filter" => [ 223, "integer" ],
                "Calix-CMS-User-Group"             => [ 220, "string" ],
                "Calix-Role"                       => [ 1,   "string" ],
            },
            6431 => {
                "BroadSoft-Attr-255"            => [ 255, "string" ],
                "BWAS-Acb-Act-Fac-Result"       => [ 66,  "string" ],
                "BWAS-Acb-Act-Invoke-Time"      => [ 65,  "string" ],
                "BWAS-Acb-Deact-Fac-Result"     => [ 68,  "string" ],
                "BWAS-Acb-Deact-Invoke-Time"    => [ 67,  "string" ],
                "BWAS-Acc-Per-Call-Fac-Result"  => [ 64,  "string" ],
                "BWAS-Acc-Per-Call-Invoke-Time" => [ 63,  "string" ],
                "BWAS-Access-Callid"            => [ 28,  "string" ],
                "BWAS-Access-Device-Address"    => [ 27,  "string" ],
                "BWAS-Access-Network-Info"      => [ 144, "string" ],
                "BWAS-Account-Code"             => [ 34,  "string" ],
                "BWAS-Acr-Act-Fac-Result"       => [ 203, "string" ],
                "BWAS-Acr-Act-Invoke-Time"      => [ 202, "string" ],
                "BWAS-Acr-Deact-Fac-Result"     => [ 205, "string" ],
                "BWAS-Acr-Deact-Invoke-Time"    => [ 204, "string" ],
                "BWAS-AHR-Action"               => [ 143, "string" ],
                "BWAS-AHR-Invoke-Time"          => [ 142, "string" ],
                "BWAS-Answer-Indic"             => [ 12,  "string" ],
                "BWAS-Answer-Time"              => [ 13,  "string" ],
                "BWAS-AOC-Activation-Time"      => [ 229, "string" ],
                "BWAS-AOC-Charge"               => [ 225, "string" ],
                "BWAS-AOC-Currency"             => [ 226, "string" ],
                "BWAS-AOC-Result"               => [ 230, "string" ],
                "BWAS-AOC-Sum"                  => [ 228, "string" ],
                "BWAS-AOC-Time"                 => [ 227, "string" ],
                "BWAS-AOC-Type"                 => [ 224, "string" ],
                "BWAS-AS-Call-Type"             => [ 231, "string" ],
                "BWAS-Authorization-Code"       => [ 35,  "string" ],
                "BWAS-BA-Related-Call-Id"       => [ 201, "string" ],
                "BWAS-Body-Content-Disposition" => [ 218, "string" ],
                "BWAS-Body-Content-Length"      => [ 217, "string" ],
                "BWAS-Body-Content-Type"        => [ 216, "string" ],
                "BWAS-Body-Originator"          => [ 219, "string" ],
                "BWAS-Call-Bridge-Result"       => [ 243, "string" ],
                "BWAS-Call-Category"            => [ 19,  "string" ],
                "BWAS-Call-Center-Forced-Forwarding-Act-Result" =>
                  [ 250, "string" ],
                "BWAS-Call-Center-Forced-Forwarding-Deact-Result" =>
                  [ 251, "string" ],
                "BWAS-Call-Center-Night-Service-Act-Result" =>
                  [ 248, "string" ],
                "BWAS-Call-Center-Night-Service-Deact-Result" =>
                  [ 249, "string" ],
                "BWAS-Call-Center-Outgoing-Call-Fac-Result" =>
                  [ 252, "string" ],
                "BWAS-Call-Center-Outgoing-Personal-Call-Fac-Result" =>
                  [ 253, "string" ],
                "BWAS-Call-Center-Outgoing-Phone-Number"  => [ 254, "string" ],
                "BWAS-Call-Park-Fac-Result"               => [ 70,  "string" ],
                "BWAS-Call-Park-Invoke-Time"              => [ 69,  "string" ],
                "BWAS-Call-Park-Retr-Fac-Result"          => [ 72,  "string" ],
                "BWAS-Call-Park-Retr-Invoke-Time"         => [ 71,  "string" ],
                "BWAS-Call-Parked-Invoke-Time"            => [ 200, "string" ],
                "BWAS-Call-Pickup-Fac-Result"             => [ 74,  "string" ],
                "BWAS-Call-Pickup-Invoke-Time"            => [ 73,  "string" ],
                "BWAS-Call-Retrieve-Result"               => [ 197, "string" ],
                "BWAS-Call-Waiting-Act-Fac-Result"        => [ 177, "string" ],
                "BWAS-Call-Waiting-Act-Invoke-Time"       => [ 176, "string" ],
                "BWAS-Call-Waiting-Deact-Fac-Result"      => [ 179, "string" ],
                "BWAS-Call-Waiting-Deact-Invoke-Time"     => [ 178, "string" ],
                "BWAS-Called-Asserted-Identity"           => [ 208, "string" ],
                "BWAS-Called-Asserted-Pres-Indicator"     => [ 209, "string" ],
                "BWAS-Called-Number"                      => [ 9,   "string" ],
                "BWAS-Called-Number-Context"              => [ 190, "string" ],
                "BWAS-Calling-Number"                     => [ 7,   "string" ],
                "BWAS-Calling-Number-Context"             => [ 192, "string" ],
                "BWAS-Calling-Party-Category"             => [ 47,  "string" ],
                "BWAS-Calling-Presentation-Indic"         => [ 8,   "string" ],
                "BWAS-Cancel-Cwt-Per-Call-Fac-Result"     => [ 80,  "string" ],
                "BWAS-Cancel-Cwt-Per-Call-Invoke-Time"    => [ 79,  "string" ],
                "BWAS-Carrier-Identification-Code"        => [ 17,  "string" ],
                "BWAS-CBF-Auth-Code"                      => [ 242, "string" ],
                "BWAS-Cfa-Act-Fac-Result"                 => [ 82,  "string" ],
                "BWAS-Cfa-Act-Invoke-Time"                => [ 81,  "string" ],
                "BWAS-Cfa-Deact-Fac-Result"               => [ 84,  "string" ],
                "BWAS-Cfa-Deact-Invoke-Time"              => [ 83,  "string" ],
                "BWAS-Cfa-Inter-Fac-Result"               => [ 237, "string" ],
                "BWAS-Cfa-Inter-Invoke-Time"              => [ 236, "string" ],
                "BWAS-Cfb-Act-Fac-Result"                 => [ 86,  "string" ],
                "BWAS-Cfb-Act-Invoke-Time"                => [ 85,  "string" ],
                "BWAS-Cfb-Deact-Fac-Result"               => [ 88,  "string" ],
                "BWAS-Cfb-Deact-Invoke-Time"              => [ 87,  "string" ],
                "BWAS-Cfb-Inter-Fac-Result"               => [ 241, "string" ],
                "BWAS-Cfb-Inter-Invoke-Time"              => [ 240, "string" ],
                "BWAS-Cfna-Act-Fac-Result"                => [ 90,  "string" ],
                "BWAS-Cfna-Act-Invoke-Time"               => [ 89,  "string" ],
                "BWAS-Cfna-Deact-Fac-Result"              => [ 92,  "string" ],
                "BWAS-Cfna-Deact-Invoke-Time"             => [ 91,  "string" ],
                "BWAS-Cfna-Inter-Fac-Result"              => [ 239, "string" ],
                "BWAS-Cfna-Inter-Invoke-Time"             => [ 238, "string" ],
                "BWAS-Cfnrc-Act-Fac-Result"               => [ 185, "string" ],
                "BWAS-Cfnrc-Act-Invoke-Time"              => [ 184, "string" ],
                "BWAS-Cfnrc-Deact-Fac-Result"             => [ 187, "string" ],
                "BWAS-Cfnrc-Deact-Invoke-Time"            => [ 186, "string" ],
                "BWAS-Charge-Indic"                       => [ 42,  "string" ],
                "BWAS-Charge-Number"                      => [ 146, "string" ],
                "BWAS-Charging-Function-Addresses"        => [ 145, "string" ],
                "BWAS-Charging-Vection-Creator"           => [ 60,  "string" ],
                "BWAS-Charging-Vection-Orig"              => [ 61,  "string" ],
                "BWAS-Charging-Vection-Term"              => [ 62,  "string" ],
                "BWAS-Charging-Vector-Key"                => [ 59,  "string" ],
                "BWAS-Clear-Mwi-Fac-Result"               => [ 120, "string" ],
                "BWAS-Clear-Mwi-Invoke-Time"              => [ 119, "string" ],
                "BWAS-Clid-Blocking-Act-Fac-Result"       => [ 173, "string" ],
                "BWAS-Clid-Blocking-Act-Invoke-Time"      => [ 172, "string" ],
                "BWAS-Clid-Blocking-Deact-Fac-Result"     => [ 175, "string" ],
                "BWAS-Clid-Blocking-Deact-Invoke-Time"    => [ 174, "string" ],
                "BWAS-Clid-Blocking-Per-Call-Fac-Result"  => [ 96,  "string" ],
                "BWAS-Clid-Blocking-Per-Call-Invoke-Time" => [ 95,  "string" ],
                "BWAS-Clid-Delivery-Per-Call-Fac-Result"  => [ 94,  "string" ],
                "BWAS-Clid-Delivery-Per-Call-Invoke-Time" => [ 93,  "string" ],
                "BWAS-CLID-Permitted"                     => [ 141, "string" ],
                "BWAS-Codec"                              => [ 26,  "string" ],
                "BWAS-Codec-Usage"                        => [ 157, "string" ],
                "BWAS-Conf-Id"                            => [ 155, "string" ],
                "BWAS-Conf-Start-Time"                    => [ 153, "string" ],
                "BWAS-Conf-Stop-Time"                     => [ 154, "string" ],
                "BWAS-Conf-Type"                          => [ 156, "string" ],
                "BWAS-Conference-Bridge"                  => [ 54,  "string" ],
                "BWAS-Conference-Callid"                  => [ 49,  "string" ],
                "BWAS-Conference-From"                    => [ 51,  "string" ],
                "BWAS-Conference-Id"                      => [ 52,  "string" ],
                "BWAS-Conference-Invoke-Time"             => [ 48,  "string" ],
                "BWAS-Conference-Owner"                   => [ 55,  "string" ],
                "BWAS-Conference-Owner-Dn"                => [ 56,  "string" ],
                "BWAS-Conference-Project-Code"            => [ 58,  "string" ],
                "BWAS-Conference-Role"                    => [ 53,  "string" ],
                "BWAS-Conference-Title"                   => [ 57,  "string" ],
                "BWAS-Conference-To"                      => [ 50,  "string" ],
                "BWAS-Configurable-CLID"                  => [ 247, "string" ],
                "BWAS-Cot-Fac-Result"                     => [ 98,  "string" ],
                "BWAS-Cot-Invoke-Time"                    => [ 97,  "string" ],
                "BWAS-CustomRingback-Invoke-Time"         => [ 140, "string" ],
                "BWAS-CustomRingback-Media-Selection"     => [ 223, "string" ],
                "BWAS-Department"                         => [ 33,  "string" ],
                "BWAS-Dialed-Digits"                      => [ 18,  "string" ],
                "BWAS-Dialed-Digits-Context"              => [ 189, "string" ],
                "BWAS-Direct-Vm-Xfer-Fac-Result"          => [ 100, "string" ],
                "BWAS-Direct-Vm-Xfer-Invoke-Time"         => [ 99,  "string" ],
                "BWAS-Directed-Call-Pickup-Fac-Result"    => [ 76,  "string" ],
                "BWAS-Directed-Call-Pickup-Invoke-Time"   => [ 75,  "string" ],
                "BWAS-Direction"                          => [ 6,   "string" ],
                "BWAS-Diversion-Inhibitor-Fac-Result"     => [ 134, "string" ],
                "BWAS-Diversion-Inhibitor-Invoke-time"    => [ 133, "string" ],
                "BWAS-Dnd-Act-Fac-Result"                 => [ 102, "string" ],
                "BWAS-Dnd-Act-Invoke-Time"                => [ 101, "string" ],
                "BWAS-Dnd-Deact-Fac-Result"               => [ 104, "string" ],
                "BWAS-Dnd-Deact-Invoke-Time"              => [ 103, "string" ],
                "BWAS-Dpubi-Fac-Result"                   => [ 78,  "string" ],
                "BWAS-Dpubi-Invoke-Time"                  => [ 77,  "string" ],
                "BWAS-Early-Media-Initiator-Flag"         => [ 215, "string" ],
                "BWAS-Early-Media-SDP"                    => [ 214, "string" ],
                "BWAS-Failover-Correlation-Id"            => [ 30,  "string" ],
                "BWAS-Fax-Messaging"                      => [ 180, "string" ],
                "BWAS-Flash-Call-Hold-Fac-Result"         => [ 110, "string" ],
                "BWAS-Flash-Call-Hold-Invoke-Time"        => [ 109, "string" ],
                "BWAS-Group"                              => [ 32,  "string" ],
                "BWAS-Group-Number"                       => [ 5,   "string" ],
                "BWAS-Hoteling-Group"                     => [ 129, "string" ],
                "BWAS-Hoteling-Group-Number"              => [ 132, "string" ],
                "BWAS-Hoteling-Invoke-Time"               => [ 128, "string" ],
                "BWAS-Hoteling-User-Number"               => [ 131, "string" ],
                "BWAS-Hoteling-UserId"                    => [ 130, "string" ],
                "BWAS-InstantGroupCall-Invoke-Time"       => [ 137, "string" ],
                "BWAS-InstantGroupCall-PushToTalk"        => [ 138, "string" ],
                "BWAS-InstantGroupCall-Related-Callid"    => [ 139, "string" ],
                "BWAS-Last-Number-Redial-Fac-Result"      => [ 112, "string" ],
                "BWAS-Last-Number-Redial-Invoke-Time"     => [ 111, "string" ],
                "BWAS-Local-Callid"                       => [ 45,  "string" ],
                "BWAS-Location-Control-Act-Result"        => [ 195, "string" ],
                "BWAS-Location-Control-Deact-Result"      => [ 196, "string" ],
                "BWAS-Media-Initiator-Flag"               => [ 211, "string" ],
                "BWAS-Moh-Deact-Fac-Result"               => [ 125, "string" ],
                "BWAS-Network-Call-Type"                  => [ 20,  "string" ],
                "BWAS-Network-Callid"                     => [ 25,  "string" ],
                "BWAS-Network-Translated-Group"           => [ 22,  "string" ],
                "BWAS-Network-Translated-Number"          => [ 21,  "string" ],
                "BWAS-Network-Translated-Number-Context"  => [ 191, "string" ],
                "BWAS-Network-Type"                       => [ 16,  "string" ],
                "BWAS-No-Answer-Set-Fac-Result"           => [ 171, "string" ],
                "BWAS-No-Answer-Set-Invoke-Time"          => [ 170, "string" ],
                "BWAS-Original-Called-Number"             => [ 36,  "string" ],
                "BWAS-Original-Called-Number-Context"     => [ 193, "string" ],
                "BWAS-Original-Called-Presentation-Indic" => [ 37,  "string" ],
                "BWAS-Original-Called-Reason"             => [ 38,  "string" ],
                "BWAS-Origination-Method"                 => [ 199, "string" ],
                "BWAS-Other-Party-Name"                   => [ 122, "string" ],
                "BWAS-Other-Party-Name-Pres-Indic"        => [ 123, "string" ],
                "BWAS-OtherInfoInPCV"                     => [ 221, "string" ],
                "BWAS-Outside-Access-Code"                => [ 206, "string" ],
                "BWAS-Prepaid-Status"                     => [ 246, "string" ],
                "BWAS-Primary-Device-Line-Port"           => [ 207, "string" ],
                "BWAS-Push-to-Talk-Fac-Result"            => [ 127, "string" ],
                "BWAS-Push-to-Talk-Invoke-Time"           => [ 126, "string" ],
                "BWAS-Q850-Cause"                         => [ 188, "string" ],
                "BWAS-Recall-Type"                        => [ 183, "string" ],
                "BWAS-Received-Calling-Number"            => [ 222, "string" ],
                "BWAS-Record-id"                          => [ 1,   "string" ],
                "BWAS-Redirecting-Number"                 => [ 39,  "string" ],
                "BWAS-Redirecting-Number-Context"         => [ 194, "string" ],
                "BWAS-Redirecting-Presentation-Indic"     => [ 40,  "string" ],
                "BWAS-Redirecting-Reason"                 => [ 41,  "string" ],
                "BWAS-Related-CallId"                     => [ 147, "string" ],
                "BWAS-Related-CallId-Reason"              => [ 148, "string" ],
                "BWAS-Release-Time"                       => [ 14,  "string" ],
                "BWAS-Releasing-Party"                    => [ 23,  "string" ],
                "BWAS-Remote-Callid"                      => [ 46,  "string" ],
                "BWAS-Return-Call-Fac-Result"             => [ 114, "string" ],
                "BWAS-Return-Call-Invoke-Time"            => [ 113, "string" ],
                "BWAS-Return-Call-Number-Deletion-Fac-Result" =>
                  [ 245, "string" ],
                "BWAS-Return-Call-Number-Deletion-Invoke-Time" =>
                  [ 244, "string" ],
                "BWAS-Route"                         => [ 24,  "string" ],
                "BWAS-Routing-Number"                => [ 198, "string" ],
                "BWAS-Sac-Lock-Fac-Result"           => [ 106, "string" ],
                "BWAS-Sac-Lock-Invoke-Time"          => [ 105, "string" ],
                "BWAS-Sac-Unlock-Fac-Result"         => [ 108, "string" ],
                "BWAS-Sac-Unlock-Invoke-Time"        => [ 107, "string" ],
                "BWAS-Scf-Act-Fac-Result"            => [ 233, "string" ],
                "BWAS-Scf-Act-Invoke-Time"           => [ 232, "string" ],
                "BWAS-Scf-Deact-Fac-Result"          => [ 235, "string" ],
                "BWAS-Scf-Deact-Invoke-Time"         => [ 234, "string" ],
                "BWAS-Sd100-Programming-Fac-Result"  => [ 116, "string" ],
                "BWAS-Sd100-Programming-Invoke-Time" => [ 115, "string" ],
                "BWAS-Sd8-Programming-Fac-Result"    => [ 118, "string" ],
                "BWAS-Sd8-Programming-Invoke-Time"   => [ 117, "string" ],
                "BWAS-SDP"                           => [ 210, "string" ],
                "BWAS-SDP-Answer-Timestamp"          => [ 213, "string" ],
                "BWAS-SDP-Offer-Timestamp"           => [ 212, "string" ],
                "BWAS-Service-provider"              => [ 2,   "string" ],
                "BWAS-SIP-Error-Code"                => [ 220, "string" ],
                "BWAS-Spare-136"                     => [ 136, "string" ],
                "BWAS-Spare-29"                      => [ 29,  "string" ],
                "BWAS-Spare-31"                      => [ 31,  "string" ],
                "BWAS-Start-Time"                    => [ 10,  "string" ],
                "BWAS-Termination-Cause"             => [ 15,  "string" ],
                "BWAS-Transfer-Invoke-Time"          => [ 149, "string" ],
                "BWAS-Transfer-Related-CallId"       => [ 151, "string" ],
                "BWAS-Transfer-Result"               => [ 150, "string" ],
                "BWAS-Transfer-Type"                 => [ 152, "string" ],
                "BWAS-Trunk-Group-Info"              => [ 182, "string" ],
                "BWAS-Trunk-Group-Name"              => [ 135, "string" ],
                "BWAS-TSD-Digits"                    => [ 181, "string" ],
                "BWAS-Type"                          => [ 3,   "string" ],
                "BWAS-Type-Of-Network"               => [ 43,  "string" ],
                "BWAS-User-Number"                   => [ 4,   "string" ],
                "BWAS-User-Timezone"                 => [ 11,  "string" ],
                "BWAS-UserId"                        => [ 121, "string" ],
                "BWAS-Vma-Act-Fac-Result"            => [ 167, "string" ],
                "BWAS-Vma-Act-Invoke-Time"           => [ 166, "string" ],
                "BWAS-Vma-Deact-Fac-Result"          => [ 169, "string" ],
                "BWAS-Vma-Deact-Invoke-Time"         => [ 168, "string" ],
                "BWAS-Vmb-Act-Fac-Result"            => [ 159, "string" ],
                "BWAS-Vmb-Act-Invoke-Time"           => [ 158, "string" ],
                "BWAS-Vmb-Deact-Fac-Result"          => [ 161, "string" ],
                "BWAS-Vmb-Deact-Invoke-Time"         => [ 160, "string" ],
                "BWAS-Vmna-Act-Fac-Result"           => [ 163, "string" ],
                "BWAS-Vmna-Act-Invoke-Time"          => [ 162, "string" ],
                "BWAS-Vmna-Deact-Fac-Result"         => [ 165, "string" ],
                "BWAS-Vmna-Deact-Invoke-Time"        => [ 164, "string" ],
                "BWAS-VP-Calling-Invoke-Time"        => [ 44,  "string" ],
            },
            6504 => { "Navini-AVPair" => [ 1, "string" ] },
            6527 => {
                "Alc-AA-Group-Partition-Isa-Id"          => [ 156, "string" ],
                "Alc-AA-Peer-Identifier"                 => [ 157, "string" ],
                "Alc-AA-Transit-IP"                      => [ 130, "integer" ],
                "Alc-Access-Loop-Encap-Offset"           => [ 133, "octets" ],
                "Alc-Access-Loop-Rate-Down"              => [ 132, "integer" ],
                "Alc-Acct-I-All-Octets-Offer_64"         => [ 79,  "octets" ],
                "Alc-Acct-I-All-Octets_64"               => [ 116, "octets" ],
                "Alc-Acct-I-All-Pack-Offer_64"           => [ 80,  "octets" ],
                "Alc-Acct-I-All-Packets_64"              => [ 118, "octets" ],
                "Alc-Acct-I-High-Octets-Drop_64"         => [ 69,  "octets" ],
                "Alc-Acct-I-High-Octets-Offer_64"        => [ 73,  "octets" ],
                "Alc-Acct-I-High-Pack-Drop_64"           => [ 71,  "octets" ],
                "Alc-Acct-I-High-Pack-Offer_64"          => [ 75,  "octets" ],
                "Alc-Acct-I-Hiprio-Octets_64"            => [ 108, "octets" ],
                "Alc-Acct-I-Hiprio-Packets_64"           => [ 112, "octets" ],
                "Alc-Acct-I-Inprof-Octets-64"            => [ 19,  "octets" ],
                "Alc-Acct-I-Inprof-Pkts-64"              => [ 23,  "octets" ],
                "Alc-Acct-I-Low-Octets-Drop_64"          => [ 70,  "octets" ],
                "Alc-Acct-I-Low-Octets-Offer_64"         => [ 74,  "octets" ],
                "Alc-Acct-I-Low-Pack-Drop_64"            => [ 72,  "octets" ],
                "Alc-Acct-I-Low-Pack-Offer_64"           => [ 76,  "octets" ],
                "Alc-Acct-I-Lowprio-Octets_64"           => [ 109, "octets" ],
                "Alc-Acct-I-Lowprio-Packets_64"          => [ 113, "octets" ],
                "Alc-Acct-I-Outprof-Octets-64"           => [ 20,  "octets" ],
                "Alc-Acct-I-Outprof-Pkts-64"             => [ 24,  "octets" ],
                "Alc-Acct-I-statmode"                    => [ 107, "string" ],
                "Alc-Acct-I-Unc-Octets-Offer_64"         => [ 77,  "octets" ],
                "Alc-Acct-I-Unc-Pack-Offer_64"           => [ 78,  "octets" ],
                "Alc-Acct-Interim-Level"                 => [ 232, "integer" ],
                "Alc-Acct-O-All-Octets_64"               => [ 117, "octets" ],
                "Alc-Acct-O-All-Packets_64"              => [ 119, "octets" ],
                "Alc-Acct-O-Hiprio-Octets_64"            => [ 110, "octets" ],
                "Alc-Acct-O-Hiprio-Packets_64"           => [ 114, "octets" ],
                "Alc-Acct-O-Inprof-Octets-64"            => [ 21,  "octets" ],
                "Alc-Acct-O-Inprof-Octs-Drop_64"         => [ 83,  "octets" ],
                "Alc-Acct-O-Inprof-Pack-Drop_64"         => [ 81,  "octets" ],
                "Alc-Acct-O-Inprof-Pkts-64"              => [ 25,  "octets" ],
                "Alc-Acct-O-Lowprio-Octets_64"           => [ 111, "octets" ],
                "Alc-Acct-O-Lowprio-Packets_64"          => [ 115, "octets" ],
                "Alc-Acct-O-Outprof-Octets-64"           => [ 22,  "octets" ],
                "Alc-Acct-O-Outprof-Octs-Drop_64"        => [ 84,  "octets" ],
                "Alc-Acct-O-Outprof-Pack-Drop_64"        => [ 82,  "octets" ],
                "Alc-Acct-O-Outprof-Pkts-64"             => [ 26,  "octets" ],
                "Alc-Acct-O-statmode"                    => [ 127, "string" ],
                "Alc-Acct-OC-I-All-Octs-Offer_64"        => [ 85,  "octets" ],
                "Alc-Acct-OC-I-All-Pack-Offer_64"        => [ 86,  "octets" ],
                "Alc-Acct-OC-I-Inpr-Octs-Drop_64"        => [ 87,  "octets" ],
                "Alc-Acct-OC-I-Inpr-Pack-Drop_64"        => [ 89,  "octets" ],
                "Alc-Acct-OC-I-Inprof-Octets-64"         => [ 37,  "octets" ],
                "Alc-Acct-OC-I-Inprof-Pkts-64"           => [ 41,  "octets" ],
                "Alc-Acct-OC-I-Outpr-Octs-Drop_64"       => [ 88,  "octets" ],
                "Alc-Acct-OC-I-Outpr-Pack-Drop_64"       => [ 90,  "octets" ],
                "Alc-Acct-OC-I-Outprof-Octets-64"        => [ 38,  "octets" ],
                "Alc-Acct-OC-I-Outprof-Pkts-64"          => [ 42,  "octets" ],
                "Alc-Acct-OC-O-Inpr-Octs-Drop_64"        => [ 93,  "octets" ],
                "Alc-Acct-OC-O-Inpr-Pack-Drop_64"        => [ 91,  "octets" ],
                "Alc-Acct-OC-O-Inprof-Octets-64"         => [ 39,  "octets" ],
                "Alc-Acct-OC-O-Inprof-Pkts-64"           => [ 43,  "octets" ],
                "Alc-Acct-OC-O-Outpr-Octs-Drop_64"       => [ 94,  "octets" ],
                "Alc-Acct-OC-O-Outpr-Pack-Drop_64"       => [ 92,  "octets" ],
                "Alc-Acct-OC-O-Outprof-Octets-64"        => [ 40,  "octets" ],
                "Alc-Acct-OC-O-Outprof-Pkts-64"          => [ 44,  "octets" ],
                "Alc-Acct-Triggered-Reason"              => [ 163, "integer" ],
                "Alc-ANCP-Str"                           => [ 16,  "string" ],
                "Alc-APN-Name"                           => [ 143, "string" ],
                "Alc-APN-Password"                       => [ 142, "string" ],
                "Alc-App-Prof-Str"                       => [ 45,  "string" ],
                "Alc-Ascend-Data-Filter-Host-Spec"       => [ 159, "abinary" ],
                "Alc-ATM-Egress-TD-Profile"              => [ 129, "integer" ],
                "Alc-ATM-Ingress-TD-Profile"             => [ 128, "integer" ],
                "Alc-Authentication-Policy-Name"         => [ 137, "string" ],
                "Alc-BGP-Auth-Key"                       => [ 57,  "octets" ],
                "Alc-BGP-Auth-Keychain"                  => [ 56,  "string" ],
                "Alc-BGP-Export-Policy"                  => [ 58,  "string" ],
                "Alc-BGP-Import-Policy"                  => [ 59,  "string" ],
                "Alc-BGP-PeerAS"                         => [ 60,  "integer" ],
                "Alc-BGP-Policy"                         => [ 55,  "string" ],
                "Alc-Charging-Prof-ID"                   => [ 150, "integer" ],
                "Alc-Client-Hardware-Addr"               => [ 27,  "string" ],
                "Alc-Create-Host"                        => [ 15,  "string" ],
                "Alc-Credit-Control-CategoryMap"         => [ 95,  "string" ],
                "Alc-Credit-Control-Quota"               => [ 96,  "string" ],
                "Alc-Default-Router"                     => [ 18,  "ipaddr" ],
                "Alc-Delegated-IPv6-Pool"                => [ 131, "string" ],
                "Alc-DHCP-Vendor-Class-Id"               => [ 36,  "string" ],
                "Alc-Dhcp6-Rebind-Time"                  => [ 203, "integer" ],
                "Alc-Dhcp6-Renew-Time"                   => [ 202, "integer" ],
                "Alc-DNAT-Override"                      => [ 234, "string" ],
                "Alc-DSL-Line-State"                     => [ 175, "integer" ],
                "Alc-DSL-Type"                           => [ 176, "integer" ],
                "Alc-Force-DHCP-Relay"                   => [ 244, "string" ],
                "Alc-Force-Nak"                          => [ 98,  "string" ],
                "Alc-Force-Renew"                        => [ 14,  "string" ],
                "Alc-Int-Dest-Id-Str"                    => [ 28,  "string" ],
                "Alc-Interface"                          => [ 101, "string" ],
                "Alc-IPsec-Interface"                    => [ 62,  "string" ],
                "Alc-IPsec-SA-Auth-Algorithm"            => [ 67,  "integer" ],
                "Alc-IPsec-SA-Encr-Algorithm"            => [ 66,  "integer" ],
                "Alc-IPsec-SA-Lifetime"                  => [ 64,  "integer" ],
                "Alc-IPsec-SA-PFS-Group"                 => [ 65,  "integer" ],
                "Alc-IPsec-SA-Replay-Window"             => [ 68,  "integer" ],
                "Alc-IPsec-Serv-Id"                      => [ 61,  "integer" ],
                "Alc-IPsec-Tunnel-Template-Id"           => [ 63,  "integer" ],
                "Alc-Ipv6-Address"                       => [ 99,  "ipv6addr" ],
                "Alc-Ipv6-Portal-Url"                    => [ 178, "string" ],
                "Alc-Ipv6-Primary-Dns"                   => [ 105, "ipv6addr" ],
                "Alc-Ipv6-Secondary-Dns"                 => [ 106, "ipv6addr" ],
                "Alc-Lease-Time"                         => [ 174, "integer" ],
                "Alc-LI-Action"                          => [ 122, "integer" ],
                "Alc-LI-Destination"                     => [ 123, "string" ],
                "Alc-LI-Direction"                       => [ 125, "integer" ],
                "Alc-LI-FC"                              => [ 124, "integer" ],
                "Alc-LI-Intercept-Id"                    => [ 138, "integer" ],
                "Alc-LI-Session-Id"                      => [ 139, "integer" ],
                "Alc-Mgw-Interface-Type"                 => [ 145, "integer" ],
                "Alc-MSAP-Interface"                     => [ 33,  "string" ],
                "Alc-MSAP-Policy"                        => [ 32,  "string" ],
                "Alc-MSAP-Serv-Id"                       => [ 31,  "integer" ],
                "Alc-MsIsdn"                             => [ 147, "string" ],
                "Alc-Nas-Filter-Rule-Shared"             => [ 158, "string" ],
                "Alc-Nat-Outside-Ip-Addr"                => [ 141, "ipaddr" ],
                "Alc-Nat-Outside-Serv-Id"                => [ 140, "integer" ],
                "Alc-Nat-Port-Range"                     => [ 121, "string" ],
                "Alc-Num-Attached-UEs"                   => [ 149, "integer" ],
                "Alc-Onetime-Http-Redirect-Reactivate"   => [ 185, "string" ],
                "Alc-Onetime-Http-Redirection-Filter-Id" => [ 136, "string" ],
                "Alc-Portal-Url"                         => [ 177, "string" ],
                "Alc-PPP-Force-IPv6CP"                   => [ 135, "integer" ],
                "Alc-PPPoE-PADO-Delay"                   => [ 34,  "integer" ],
                "Alc-PPPoE-Service-Name"                 => [ 35,  "string" ],
                "Alc-Primary-Dns"                        => [ 9,   "ipaddr" ],
                "Alc-Primary-Nbns"                       => [ 29,  "ipaddr" ],
                "Alc-Radius-Py"                          => [ 242, "octets" ],
                "Alc-Relative-Session-Timeout"           => [ 160, "integer" ],
                "Alc-Remove-Override"                    => [ 238, "string" ],
                "Alc-Retail-Serv-Id"                     => [ 17,  "integer" ],
                "Alc-RSSI"                               => [ 148, "integer" ],
                "Alc-SAP-Session-Index"                  => [ 180, "integer" ],
                "Alc-Secondary-Dns"                      => [ 10,  "ipaddr" ],
                "Alc-Secondary-Nbns"                     => [ 30,  "ipaddr" ],
                "Alc-Serv-Id"                            => [ 100, "integer" ],
                "Alc-SLA-Prof-Str"                       => [ 13,  "string" ],
                "Alc-SLAAC-IPv6-Pool"                    => [ 181, "string" ],
                "Alc-Subsc-ID-Str"                       => [ 11,  "string" ],
                "Alc-Subsc-Prof-Str"                     => [ 12,  "string" ],
                "Alc-Subscriber-Filter"                  => [ 134, "string" ],
                "Alc-Subscriber-QoS-Override"            => [ 126, "string" ],
                "Alc-ToClient-Dhcp-Options"              => [ 103, "octets" ],
                "Alc-ToClient-Dhcp6-Options"             => [ 192, "octets" ],
                "Alc-ToServer-Dhcp-Options"              => [ 102, "octets" ],
                "Alc-ToServer-Dhcp6-Options"             => [ 191, "octets" ],
                "Alc-Trigger-Acct-Interim"               => [ 228, "string" ],
                "Alc-Tunnel-Acct-Policy"                 => [ 144, "string" ],
                "Alc-Tunnel-Algorithm"                   => [ 47,  "integer" ],
                "Alc-Tunnel-AVP-Hiding"                  => [ 54,  "integer" ],
                "Alc-Tunnel-Challenge"                   => [ 97,  "integer" ],
                "Alc-Tunnel-Destruct-Timeout"            => [ 51,  "integer" ],
                "Alc-Tunnel-Group"                       => [ 46,  "string" ],
                "Alc-Tunnel-Hello-Interval"              => [ 50,  "integer" ],
                "Alc-Tunnel-Idle-Timeout"                => [ 49,  "integer" ],
                "Alc-Tunnel-Max-Retries-Estab"           => [ 52,  "integer" ],
                "Alc-Tunnel-Max-Retries-Not-Estab"       => [ 53,  "integer" ],
                "Alc-Tunnel-Max-Sessions"                => [ 48,  "integer" ],
                "Alc-Tunnel-Rx-Window-Size"              => [ 120, "integer" ],
                "Alc-Tunnel-Serv-Id"                     => [ 104, "integer" ],
                "Alc-UPnP-Sub-Override-Policy"           => [ 217, "string" ],
                "Alc-v6-Preferred-Lifetime"              => [ 200, "integer" ],
                "Alc-v6-Valid-Lifetime"                  => [ 201, "integer" ],
                "Alc-Wlan-APN-Name"                      => [ 146, "string" ],
                "Alc-Wlan-Portal-Redirect"               => [ 172, "string" ],
                "Alc-Wlan-Portal-Url"                    => [ 173, "string" ],
                "Alc-Wlan-SSID-VLAN"                     => [ 206, "string" ],
                "Alc-WPP-ErrorCode"                      => [ 183, "integer" ],
                "Timetra-Access"                         => [ 1,   "integer" ],
                "Timetra-Action"                         => [ 7,   "integer" ],
                "Timetra-Cmd"                            => [ 6,   "string" ],
                "Timetra-Default-Action"                 => [ 5,   "integer" ],
                "Timetra-Exec-File"                      => [ 8,   "string" ],
                "Timetra-Home-Directory"                 => [ 2,   "string" ],
                "Timetra-Profile"                        => [ 4,   "string" ],
                "Timetra-Restrict-To-Home"               => [ 3,   "integer" ],
            },
            6618 => {
                "Quintum-AVPair"                   => [ 1,   "string" ],
                "Quintum-h323-billing-model"       => [ 109, "string" ],
                "Quintum-h323-call-origin"         => [ 26,  "string" ],
                "Quintum-h323-call-type"           => [ 27,  "string" ],
                "Quintum-h323-conf-id"             => [ 24,  "string" ],
                "Quintum-h323-connect-time"        => [ 28,  "string" ],
                "Quintum-h323-credit-amount"       => [ 101, "string" ],
                "Quintum-h323-credit-time"         => [ 102, "string" ],
                "Quintum-h323-currency-type"       => [ 110, "string" ],
                "Quintum-h323-disconnect-cause"    => [ 30,  "string" ],
                "Quintum-h323-disconnect-time"     => [ 29,  "string" ],
                "Quintum-h323-gw-id"               => [ 33,  "string" ],
                "Quintum-h323-incoming-conf-id"    => [ 35,  "string" ],
                "Quintum-h323-preferred-lang"      => [ 107, "string" ],
                "Quintum-h323-prompt-id"           => [ 104, "string" ],
                "Quintum-h323-redirect-ip-address" => [ 108, "string" ],
                "Quintum-h323-redirect-number"     => [ 106, "string" ],
                "Quintum-h323-remote-address"      => [ 23,  "string" ],
                "Quintum-h323-return-code"         => [ 103, "string" ],
                "Quintum-h323-setup-time"          => [ 25,  "string" ],
                "Quintum-h323-time-and-day"        => [ 105, "string" ],
                "Quintum-h323-voice-quality"       => [ 31,  "string" ],
                "Quintum-NAS-Port"                 => [ 2,   "string" ],
                "Quintum-Trunkid-In"               => [ 230, "string" ],
                "Quintum-Trunkid-Out"              => [ 231, "string" ],
            },
            6983 => {
                "SofaWare-Admin"   => [ 1, "string" ],
                "SofaWare-Hotspot" => [ 3, "string" ],
                "SofaWare-UFP"     => [ 4, "string" ],
                "SofaWare-VPN"     => [ 2, "string" ],
            },
            7000 => { "Slipstream-Auth" => [ 1, "string" ] },
            7064 => {
                "UTStarcom-Act-Input-Frames"     => [ 182, "string" ],
                "UTStarcom-Act-Input-Octets"     => [ 180, "string" ],
                "UTStarcom-Act-Output-Frames"    => [ 183, "string" ],
                "UTStarcom-Act-Output-Octets"    => [ 181, "string" ],
                "UTStarcom-CLI-Access-Level"     => [ 171, "integer" ],
                "UTStarcom-CommittedBandwidth"   => [ 142, "integer" ],
                "UTStarcom-Default-Gateway"      => [ 170, "integer" ],
                "UTStarcom-DeviceId"             => [ 165, "string" ],
                "UTStarcom-Error-Reason"         => [ 147, "integer" ],
                "UTStarcom-Logical-Port-No"      => [ 168, "integer" ],
                "UTStarcom-MaxBandwidth"         => [ 143, "integer" ],
                "UTStarcom-MaxBurstSize"         => [ 161, "integer" ],
                "UTStarcom-MaxDelay"             => [ 162, "integer" ],
                "UTStarcom-MaxJitter"            => [ 163, "integer" ],
                "UTStarcom-Module-Id"            => [ 166, "integer" ],
                "UTStarcom-ONU-Admin_status"     => [ 188, "integer" ],
                "UTStarcom-ONU-FW-SC-Upgrade"    => [ 189, "integer" ],
                "UTStarcom-Onu-MC-Filter-Enable" => [ 184, "integer" ],
                "UTStarcom-Port-No"              => [ 167, "integer" ],
                "UTStarcom-PrimaryDNS"           => [ 152, "integer" ],
                "UTStarcom-Priority"             => [ 145, "integer" ],
                "UTStarcom-SecondaryDNS"         => [ 153, "integer" ],
                "UTStarcom-UNI-Auto-Negotiation" => [ 185, "integer" ],
                "UTStarcom-UNI-Duplex"           => [ 187, "integer" ],
                "UTStarcom-UNI-MAX-MAC"          => [ 169, "integer" ],
                "UTStarcom-UNI-Speed"            => [ 186, "integer" ],
                "UTStarcom-VLAN-ID"              => [ 140, "integer" ],
            },
            7119 => { "NetSensory-Privilege"       => [ 33, "string" ] },
            7146 => { "Zeus-ZXTM-Group"            => [ 1,  "string" ] },
            7262 => { "DragonWave-Privilege-Level" => [ 1,  "integer" ] },
            7751 => {
                "Azaire-APN"                => [ 4,  "string" ],
                "Azaire-APN-OI"             => [ 11, "string" ],
                "Azaire-APN-Resolution-Req" => [ 7,  "integer" ],
                "Azaire-Auth-Type"          => [ 12, "integer" ],
                "Azaire-Brand-Code"         => [ 14, "string" ],
                "Azaire-Client-Local-IP"    => [ 16, "ipaddr" ],
                "Azaire-Gn-User-Name"       => [ 13, "string" ],
                "Azaire-IMSI"               => [ 2,  "octets" ],
                "Azaire-MSISDN"             => [ 3,  "octets" ],
                "Azaire-NAS-Type"           => [ 9,  "integer" ],
                "Azaire-Policy-Name"        => [ 15, "string" ],
                "Azaire-QoS"                => [ 5,  "octets" ],
                "Azaire-Selection-Mode"     => [ 6,  "integer" ],
                "Azaire-Start-Time"         => [ 8,  "octets" ],
                "Azaire-Status"             => [ 10, "integer" ],
                "Azaire-Triplets"           => [ 1,  "octets" ],
            },
            7779 => {
                "Infoblox-Group-Info"    => [ 9, "string" ],
                "Infoblox-Product-Name"  => [ 8, "string" ],
                "Infoblox-variable-1"    => [ 2, "string" ],
                "Infoblox-variable-2"    => [ 3, "string" ],
                "Infoblox-variable-3"    => [ 4, "string" ],
                "Infoblox-variable-4"    => [ 5, "string" ],
                "Infoblox-variable-5"    => [ 6, "string" ],
                "Infoblox-Version"       => [ 7, "string" ],
                "Infoblox-windows-group" => [ 1, "string" ],
            },
            8164 => {
                "SN-Access-link-IP-Frag"          => [ 63,    "integer" ],
                "SN-Acct-Input-Giga-Dropped"      => [ 230,   "integer" ],
                "SN-Acct-Input-Octets-Dropped"    => [ 228,   "integer64" ],
                "SN-Acct-Input-Packets-Dropped"   => [ 226,   "integer" ],
                "SN-Acct-Output-Giga-Dropped"     => [ 231,   "integer" ],
                "SN-Acct-Output-Octets-Dropped"   => [ 229,   "integer64" ],
                "SN-Acct-Output-Packets-Dropped"  => [ 227,   "integer" ],
                "SN-Acs-Credit-Control-Group"     => [ 301,   "string" ],
                "SN-Admin-Expiry"                 => [ 204,   "integer" ],
                "SN-Admin-Permission"             => [ 21,    "integer" ],
                "SN-ANID"                         => [ 178,   "octets" ],
                "SN-Assigned-VLAN-ID"             => [ 152,   "short" ],
                "SN-Authorised-Qos"               => [ 266,   "string" ],
                "SN-Bandwidth-Policy"             => [ 300,   "string" ],
                "SN-Call-Id"                      => [ 251,   "integer" ],
                "SN-Cause-Code"                   => [ 267,   "integer" ],
                "SN-Cause-For-Rec-Closing"        => [ 139,   "integer" ],
                "SN-CBB-Policy"                   => [ 302,   "string" ],
                "SN-CF-Call-International"        => [ 293,   "integer" ],
                "SN-CF-Call-Local"                => [ 291,   "integer" ],
                "SN-CF-Call-LongDistance"         => [ 292,   "integer" ],
                "SN-CF-Call-Premium"              => [ 294,   "integer" ],
                "SN-CF-Call-RoamingInternatnl"    => [ 298,   "integer" ],
                "SN-CF-Call-Transfer"             => [ 285,   "integer" ],
                "SN-CF-Call-Waiting"              => [ 284,   "integer" ],
                "SN-CF-CId-Display"               => [ 282,   "integer" ],
                "SN-CF-CId-Display-Blocked"       => [ 283,   "integer" ],
                "SN-CF-Follow-Me"                 => [ 281,   "string" ],
                "SN-CF-Forward-Busy-Line"         => [ 279,   "string" ],
                "SN-CF-Forward-No-Answer"         => [ 278,   "string" ],
                "SN-CF-Forward-Not-Regd"          => [ 280,   "string" ],
                "SN-CF-Forward-Unconditional"     => [ 277,   "string" ],
                "SN-CFPolicy-ID"                  => [ 220,   "integer" ],
                "SN-Change-Condition"             => [ 140,   "integer" ],
                "SN-Charging-VPN-Name"            => [ 137,   "string" ],
                "SN-Chrg-Char-Selection-Mode"     => [ 138,   "integer" ],
                "SN-Congestion-Mgmt-Policy"       => [ 315,   "string" ],
                "SN-Content-Disposition"          => [ 272,   "string" ],
                "SN-Content-Length"               => [ 271,   "string" ],
                "SN-Content-Type"                 => [ 270,   "string" ],
                "SN-CR-International-Cid"         => [ 295,   "integer" ],
                "SN-CR-LongDistance-Cid"          => [ 296,   "integer" ],
                "SN-CSCF-App-Server-Info"         => [ 275,   "octets" ],
                "SN-CSCF-Rf-SDP-Media-Components" => [ 273,   "octets" ],
                "SN-Cscf-Subscriber-Ip-Address"   => [ 287,   "ipaddr" ],
                "SN-Data-Tunnel-Ignore-DF-Bit"    => [ 49,    "integer" ],
                "SN-DHCP-Lease-Expiry-Policy"     => [ 157,   "integer" ],
                "SN-DHCP-Options"                 => [ 309,   "octets" ],
                "SN-Direction"                    => [ 153,   "integer" ],
                "SN-Disconnect-Reason"            => [ 3,     "integer" ],
                "SN-DNS-Proxy-Intercept-List"     => [ 214,   "string" ],
                "SN-DNS-Proxy-Use-Subscr-Addr"    => [ 25,    "integer" ],
                "SN-Dynamic-Addr-Alloc-Ind-Flag"  => [ 141,   "octets" ],
                "SN-Ecs-Data-Volume"              => [ 176,   "octets" ],
                "SN-Enable-QoS-Renegotiation"     => [ 144,   "integer" ],
                "SN-Event"                        => [ 255,   "string" ],
                "SN-Ext-Inline-Srvr-Context"      => [ 41,    "string" ],
                "SN-Ext-Inline-Srvr-Down-Addr"    => [ 56,    "ipaddr" ],
                "SN-Ext-Inline-Srvr-Down-VLAN"    => [ 59,    "octets" ],
                "SN-Ext-Inline-Srvr-Preference"   => [ 57,    "integer" ],
                "SN-Ext-Inline-Srvr-Up-Addr"      => [ 55,    "ipaddr" ],
                "SN-Ext-Inline-Srvr-Up-VLAN"      => [ 58,    "octets" ],
                "SN-Fast-Reauth-Username"         => [ 304,   "octets" ],
                "SN-Firewall-Enabled"             => [ 198,   "integer" ],
                "SN-Firewall-Policy"              => [ 239,   "octets" ],
                "SN-FMC-Location"                 => [ 171,   "octets" ],
                "SN-GGSN-Address"                 => [ 264,   "ipaddr" ],
                "SN-GGSN-MIP-Required"            => [ 68,    "integer" ],
                "SN-Gratuitous-ARP-Aggressive"    => [ 54,    "integer" ],
                "SN-GTP-Version"                  => [ 62,    "integer" ],
                "SN-HA-Send-DNS-ADDRESS"          => [ 47,    "integer" ],
                "SN-Handoff-Indicator"            => [ 310,   "integer" ],
                "SN-Home-Behavior"                => [ 119,   "integer" ],
                "SN-Home-Profile"                 => [ 109,   "integer" ],
                "SN-Home-Sub-Use-GGSN"            => [ 106,   "integer" ],
                "SN-IMS-AM-Address"               => [ 167,   "ipaddr" ],
                "SN-IMS-AM-Domain-Name"           => [ 168,   "octets" ],
                "SN-IMS-Charging-Identifier"      => [ 260,   "string" ],
                "SN-IMSI"                         => [ 252,   "octets" ],
                "SN-Internal-SM-Index"            => [ 122,   "integer" ],
                "SN-IP-Alloc-Method"              => [ 53,    "integer" ],
                "SN-IP-Filter-In"                 => [ 10,    "string" ],
                "SN-IP-Filter-Out"                => [ 11,    "string" ],
                "SN-IP-Header-Compression"        => [ 150,   "integer" ],
                "SN-IP-Hide-Service-Address"      => [ 60,    "integer" ],
                "SN-IP-In-ACL"                    => [ 17,    "string" ],
                "SN-IP-In-Plcy-Grp"               => [ 193,   "string" ],
                "SN-IP-Out-ACL"                   => [ 18,    "string" ],
                "SN-IP-Out-Plcy-Grp"              => [ 194,   "string" ],
                "SN-IP-Pool-Name"                 => [ 8,     "string" ],
                "SN-IP-Source-Validation"         => [ 14,    "integer" ],
                "SN-IP-Source-Violate-No-Acct"    => [ 196,   "integer" ],
                "SN-IP-Src-Validation-Drop-Limit" => [ 110,   "integer" ],
                "SN-IPv6-Alloc-Method"            => [ 314,   "integer" ],
                "SN-IPv6-DNS-Proxy"               => [ 126,   "integer" ],
                "SN-IPv6-Egress-Filtering"        => [ 103,   "integer" ],
                "SN-IPv6-Min-Link-MTU"            => [ 136,   "integer" ],
                "SN-IPv6-num-rtr-advt"            => [ 97,    "integer" ],
                "SN-IPv6-Primary-DNS"             => [ 101,   "ipv6addr" ],
                "SN-IPv6-rtr-advt-interval"       => [ 96,    "integer" ],
                "SN-IPv6-Sec-Pool"                => [ 124,   "string" ],
                "SN-IPv6-Sec-Prefix"              => [ 125,   "octets" ],
                "SN-IPv6-Secondary-DNS"           => [ 102,   "octets" ],
                "SN-Is-Unregistered-Subscriber"   => [ 269,   "string" ],
                "SN-ISC-Template-Name"            => [ 276,   "string" ],
                "SN-L3-to-L2-Tun-Addr-Policy"     => [ 43,    "integer" ],
                "SN-Local-IP-Address"             => [ 13,    "ipaddr" ],
                "SN-Long-Duration-Action"         => [ 45,    "integer" ],
                "SN-Long-Duration-Notification"   => [ 253,   "integer" ],
                "SN-Long-Duration-Timeout"        => [ 44,    "integer" ],
                "SN-Max-Sec-Contexts-Per-Subs"    => [ 290,   "integer" ],
                "SN-Mediation-Acct-Rsp-Action"    => [ 105,   "integer" ],
                "SN-Mediation-Enabled"            => [ 123,   "integer" ],
                "SN-Mediation-No-Interims"        => [ 146,   "integer" ],
                "SN-Mediation-VPN-Name"           => [ 104,   "string" ],
                "SN-Min-Compress-Size"            => [ 23,    "integer" ],
                "SN-MIP-AAA-Assign-Addr"          => [ 50,    "integer" ],
                "SN-MIP-ANCID"                    => [ 166,   "octets" ],
                "SN-MIP-Dual-Anchor"              => [ 165,   "integer" ],
                "SN-MIP-HA-Assignment-Table"      => [ 154,   "string" ],
                "SN-MIP-Match-AAA-Assign-Addr"    => [ 51,    "integer" ],
                "SN-MIP-Reg-Lifetime-Realm"       => [ 175,   "integer" ],
                "SN-MIP-Send-Ancid"               => [ 163,   "integer" ],
                "SN-MIP-Send-Correlation-Info"    => [ 188,   "integer" ],
                "SN-MIP-Send-Imsi"                => [ 164,   "integer" ],
                "SN-MIP-Send-Term-Verification"   => [ 48,    "integer" ],
                "SN-MN-HA-Hash-Algorithm"         => [ 99,    "integer" ],
                "SN-MN-HA-Timestamp-Tolerance"    => [ 30,    "integer" ],
                "SN-Mode"                         => [ 151,   "integer" ],
                "SN-MS-ISDN"                      => [ 248,   "octets" ],
                "SN-NAI-Construction-Domain"      => [ 37,    "string" ],
                "SN-NAT-IP-Address"               => [ 297,   "ipaddr" ],
                "SN-Node-Functionality"           => [ 268,   "integer" ],
                "SN-NPU-Qos-Priority"             => [ 98,    "integer" ],
                "SN-Ntk-Initiated-Ctx-Ind-Flag"   => [ 142,   "octets" ],
                "SN-Ntk-Session-Disconnect-Flag"  => [ 143,   "integer" ],
                "SN-Nw-Reachability-Server-Name"  => [ 65,    "string" ],
                "SN-Originating-IOI"              => [ 261,   "string" ],
                "SN-Overload-Disc-Connect-Time"   => [ 233,   "integer" ],
                "SN-Overload-Disconnect"          => [ 235,   "integer" ],
                "SN-PDG-TTG-Required"             => [ 299,   "integer" ],
                "SN-PDIF-MIP-Release-TIA"         => [ 172,   "integer" ],
                "SN-PDIF-MIP-Required"            => [ 170,   "integer" ],
                "SN-PDIF-MIP-Simple-IP-Fallback"  => [ 173,   "integer" ],
                "SN-PDSN-Correlation-Id"          => [ 189,   "octets" ],
                "SN-PDSN-Handoff-Req-IP-Addr"     => [ 46,    "integer" ],
                "SN-PDSN-NAS-Id"                  => [ 190,   "string" ],
                "SN-PDSN-NAS-IP-Address"          => [ 191,   "ipaddr" ],
                "SN-Permit-User-Mcast-PDUs"       => [ 134,   "integer" ],
                "SN-PPP-Accept-Peer-v6Ifid"       => [ 95,    "integer" ],
                "SN-PPP-Always-On-Vse"            => [ 130,   "integer" ],
                "SN-PPP-Data-Compression"         => [ 9,     "integer" ],
                "SN-PPP-Data-Compression-Mode"    => [ 19,    "integer" ],
                "SN-PPP-Keepalive"                => [ 16,    "integer" ],
                "SN-PPP-NW-Layer-IPv4"            => [ 92,    "integer" ],
                "SN-PPP-NW-Layer-IPv6"            => [ 93,    "integer" ],
                "SN-PPP-Outbound-Password"        => [ 15,    "string" ],
                "SN-PPP-Outbound-Username"        => [ 61,    "string" ],
                "SN-PPP-Progress-Code"            => [ 4,     "integer" ],
                "SN-PPP-Reneg-Disc"               => [ 187,   "integer" ],
                "SN-Prepaid"                      => [ 128,   "integer" ],
                "SN-Prepaid-Compressed-Count"     => [ 31,    "integer" ],
                "SN-Prepaid-Final-Duration-Alg"   => [ 135,   "integer" ],
                "SN-Prepaid-Inbound-Octets"       => [ 32,    "integer" ],
                "SN-Prepaid-Outbound-Octets"      => [ 33,    "integer" ],
                "SN-Prepaid-Preference"           => [ 129,   "integer" ],
                "SN-Prepaid-Timeout"              => [ 35,    "integer" ],
                "SN-Prepaid-Total-Octets"         => [ 34,    "integer" ],
                "SN-Prepaid-Watermark"            => [ 36,    "integer" ],
                "SN-Primary-DCCA-Peer"            => [ 223,   "string" ],
                "SN-Primary-DNS-Server"           => [ 5,     "ipaddr" ],
                "SN-Primary-NBNS-Server"          => [ 148,   "ipaddr" ],
                "SN-Proxy-MIP"                    => [ 52,    "integer" ],
                "SN-Proxy-MIPV6"                  => [ 65530, "integer" ],
                "SN-Pseudonym-Username"           => [ 305,   "octets" ],
                "SN-QoS-Background-Class"         => [ 91,    "octets" ],
                "SN-QoS-Class-Background-PHB"     => [ 113,   "integer" ],
                "SN-QoS-Class-Conversational-PHB" => [ 111,   "integer" ],
                "SN-QoS-Class-Interactive-1-PHB"  => [ 114,   "integer" ],
                "SN-QoS-Class-Interactive-2-PHB"  => [ 115,   "integer" ],
                "SN-QoS-Class-Interactive-3-PHB"  => [ 116,   "integer" ],
                "SN-QoS-Class-Streaming-PHB"      => [ 112,   "integer" ],
                "SN-QoS-Conversation-Class"       => [ 86,    "octets" ],
                "SN-QOS-HLR-Profile"              => [ 303,   "octets" ],
                "SN-QoS-Interactive1-Class"       => [ 88,    "octets" ],
                "SN-QoS-Interactive2-Class"       => [ 89,    "octets" ],
                "SN-QoS-Interactive3-Class"       => [ 90,    "octets" ],
                "SN-QoS-Negotiated"               => [ 147,   "string" ],
                "SN-QoS-Renegotiation-Timeout"    => [ 145,   "integer" ],
                "SN-QoS-Streaming-Class"          => [ 87,    "octets" ],
                "SN-QoS-Tp-Dnlk"                  => [ 73,    "integer" ],
                "SN-QoS-Tp-Uplk"                  => [ 79,    "integer" ],
                "SN-QoS-Traffic-Policy"           => [ 177,   "octets" ],
                "SN-Rad-APN-Name"                 => [ 162,   "octets" ],
                "SN-Radius-Returned-Username"     => [ 236,   "integer" ],
                "SN-Re-CHAP-Interval"             => [ 7,     "integer" ],
                "SN-Roaming-Behavior"             => [ 121,   "integer" ],
                "SN-Roaming-Profile"              => [ 118,   "integer" ],
                "SN-Roaming-Sub-Use-GGSN"         => [ 108,   "integer" ],
                "SN-ROHC-Flow-Marking-Mode"       => [ 274,   "integer" ],
                "SN-ROHC-Profile-Name"            => [ 238,   "string" ],
                "SN-Role-Of-Node"                 => [ 256,   "integer" ],
                "SN-Routing-Area-Id"              => [ 249,   "string" ],
                "SN-Rulebase"                     => [ 250,   "string" ],
                "SN-SDP-Session-Description"      => [ 263,   "string" ],
                "SN-Sec-IP-Pool-Name"             => [ 265,   "string" ],
                "SN-Secondary-DCCA-Peer"          => [ 224,   "string" ],
                "SN-Secondary-DNS-Server"         => [ 6,     "ipaddr" ],
                "SN-Secondary-NBNS-Server"        => [ 149,   "ipaddr" ],
                "SN-Service-Address"              => [ 169,   "ipaddr" ],
                "SN-Service-Type"                 => [ 24,    "integer" ],
                "SN-Session-Id"                   => [ 257,   "string" ],
                "SN-Simultaneous-SIP-MIP"         => [ 22,    "integer" ],
                "SN-SIP-Method"                   => [ 254,   "integer" ],
                "SN-SIP-Request-Time-Stamp"       => [ 258,   "string" ],
                "SN-SIP-Response-Time-Stamp"      => [ 259,   "string" ],
                "SN-Software-Version"             => [ 288,   "string" ],
                "SN-Subs-Acc-Flow-Traffic-Valid"  => [ 225,   "integer" ],
                "SN-Subs-IMSA-Service-Name"       => [ 159,   "string" ],
                "SN-Subs-VJ-Slotid-Cmp-Neg-Mode"  => [ 221,   "integer" ],
                "SN-Subscriber-Accounting"        => [ 64,    "integer" ],
                "SN-Subscriber-Acct-Interim"      => [ 70,    "integer" ],
                "SN-Subscriber-Acct-Mode"         => [ 192,   "integer" ],
                "SN-Subscriber-Acct-Rsp-Action"   => [ 100,   "integer" ],
                "SN-Subscriber-Acct-Start"        => [ 69,    "integer" ],
                "SN-Subscriber-Acct-Stop"         => [ 71,    "integer" ],
                "SN-Subscriber-Class"             => [ 219,   "integer" ],
                "SN-Subscriber-IP-Hdr-Neg-Mode"   => [ 67,    "integer" ],
                "SN-Subscriber-IP-TOS-Copy"       => [ 85,    "integer" ],
                "SN-Subscriber-Nexthop-Address"   => [ 127,   "integer" ],
                "SN-Subscriber-No-Interims"       => [ 133,   "integer" ],
                "SN-Subscriber-Permission"        => [ 20,    "integer" ],
                "SN-Subscriber-Template-Name"     => [ 158,   "string" ],
                "SN-Terminating-IOI"              => [ 262,   "string" ],
                "SN-Tp-Dnlk-Burst-Size"           => [ 76,    "integer" ],
                "SN-Tp-Dnlk-Committed-Data-Rate"  => [ 74,    "integer" ],
                "SN-Tp-Dnlk-Exceed-Action"        => [ 77,    "integer" ],
                "SN-Tp-Dnlk-Peak-Data-Rate"       => [ 75,    "integer" ],
                "SN-Tp-Dnlk-Violate-Action"       => [ 78,    "integer" ],
                "SN-Tp-Uplk-Burst-Size"           => [ 82,    "integer" ],
                "SN-Tp-Uplk-Committed-Data-Rate"  => [ 80,    "integer" ],
                "SN-Tp-Uplk-Exceed-Action"        => [ 83,    "integer" ],
                "SN-Tp-Uplk-Peak-Data-Rate"       => [ 81,    "integer" ],
                "SN-Tp-Uplk-Violate-Action"       => [ 84,    "integer" ],
                "SN-Traffic-Group"                => [ 161,   "integer" ],
                "SN-TrafficSelector-Class"        => [ 307,   "integer" ],
                "SN-Transparent-Data"             => [ 247,   "octets" ],
                "SN-Tun-Addr-Policy"              => [ 156,   "integer" ],
                "SN-Tunnel-Gn"                    => [ 174,   "integer" ],
                "SN-Tunnel-ISAKMP-Crypto-Map"     => [ 38,    "string" ],
                "SN-Tunnel-ISAKMP-Secret"         => [ 39,    "string" ],
                "SN-Tunnel-Load-Balancing"        => [ 27,    "integer" ],
                "SN-Tunnel-Password"              => [ 26,    "octets" ],
                "SN-Unclassify-List-Name"         => [ 132,   "string" ],
                "SN-User-Privilege"               => [ 313,   "integer" ],
                "SN-Virtual-APN-Name"             => [ 94,    "string" ],
                "SN-Visiting-Behavior"            => [ 120,   "integer" ],
                "SN-Visiting-Profile"             => [ 117,   "integer" ],
                "SN-Visiting-Sub-Use-GGSN"        => [ 107,   "integer" ],
                "SN-Voice-Push-List-Name"         => [ 131,   "string" ],
                "SN-VPN-ID"                       => [ 1,     "integer" ],
                "SN-VPN-Name"                     => [ 2,     "string" ],
                "SN-WiMAX-Auth-Only"              => [ 306,   "integer" ],
                "SN-WLAN-AP-Identifier"           => [ 319,   "octets" ],
                "SN-WLAN-UE-Identifier"           => [ 320,   "octets" ],
                "SN-WSG-MIP-Release-TIA"          => [ 317,   "integer" ],
                "SN-WSG-MIP-Required"             => [ 316,   "integer" ],
                "SN-WSG-MIP-Simple-IP-Fallback"   => [ 318,   "integer" ],
                "SNA-Input-Gigawords"             => [ 206,   "integer" ],
                "SNA-Output-Gigawords"            => [ 207,   "integer" ],
                "SNA-PPP-Bad-Addr"                => [ 1011,  "integer" ],
                "SNA-PPP-Bad-Ctrl"                => [ 1012,  "integer" ],
                "SNA-PPP-Bad-FCS"                 => [ 1014,  "integer" ],
                "SNA-PPP-Ctrl-Input-Octets"       => [ 1001,  "integer" ],
                "SNA-PPP-Ctrl-Input-Packets"      => [ 1003,  "integer" ],
                "SNA-PPP-Ctrl-Output-Octets"      => [ 1002,  "integer" ],
                "SNA-PPP-Ctrl-Output-Packets"     => [ 1004,  "integer" ],
                "SNA-PPP-Discards-Input"          => [ 1007,  "integer" ],
                "SNA-PPP-Discards-Output"         => [ 1008,  "integer" ],
                "SNA-PPP-Echo-Req-Input"          => [ 1015,  "integer" ],
                "SNA-PPP-Echo-Req-Output"         => [ 1016,  "integer" ],
                "SNA-PPP-Echo-Rsp-Input"          => [ 1017,  "integer" ],
                "SNA-PPP-Echo-Rsp-Output"         => [ 1018,  "integer" ],
                "SNA-PPP-Errors-Input"            => [ 1009,  "integer" ],
                "SNA-PPP-Errors-Output"           => [ 1010,  "integer" ],
                "SNA-PPP-Framed-Input-Octets"     => [ 1005,  "integer" ],
                "SNA-PPP-Framed-Output-Octets"    => [ 1006,  "integer" ],
                "SNA-PPP-Packet-Too-Long"         => [ 1013,  "integer" ],
                "SNA-PPP-Unfr-Data-In-Gig"        => [ 202,   "integer" ],
                "SNA-PPP-Unfr-data-In-Oct"        => [ 200,   "integer" ],
                "SNA-PPP-Unfr-Data-Out-Gig"       => [ 203,   "integer" ],
                "SNA-PPP-Unfr-data-Out-Oct"       => [ 201,   "integer" ],
                "SNA-RP-Reg-Reply-Sent-Acc-Dereg" => [ 1033,  "integer" ],
                "SNA-RP-Reg-Reply-Sent-Acc-Reg"   => [ 1032,  "integer" ],
                "SNA-RP-Reg-Reply-Sent-Bad-Req"   => [ 1034,  "integer" ],
                "SNA-RP-Reg-Reply-Sent-Denied"    => [ 1035,  "integer" ],
                "SNA-RP-Reg-Reply-Sent-Mis-ID"    => [ 1036,  "integer" ],
                "SNA-RP-Reg-Reply-Sent-Send-Err"  => [ 1037,  "integer" ],
                "SNA-RP-Reg-Reply-Sent-Total"     => [ 1031,  "integer" ],
                "SNA-RP-Reg-Upd-Re-Sent"          => [ 1039,  "integer" ],
                "SNA-RP-Reg-Upd-Send-Err"         => [ 1040,  "integer" ],
                "SNA-RP-Reg-Upd-Sent"             => [ 1038,  "integer" ],
                "SNA-RPRAK-Rcvd-Acc-Ack"          => [ 1028,  "integer" ],
                "SNA-RPRAK-Rcvd-Mis-ID"           => [ 1030,  "integer" ],
                "SNA-RPRAK-Rcvd-Msg-Auth-Fail"    => [ 1029,  "integer" ],
                "SNA-RPRAK-Rcvd-Total"            => [ 1027,  "integer" ],
                "SNA-RPRRQ-Rcvd-Acc-Dereg"        => [ 1021,  "integer" ],
                "SNA-RPRRQ-Rcvd-Acc-Reg"          => [ 1020,  "integer" ],
                "SNA-RPRRQ-Rcvd-Badly-Formed"     => [ 1024,  "integer" ],
                "SNA-RPRRQ-Rcvd-Mis-ID"           => [ 1023,  "integer" ],
                "SNA-RPRRQ-Rcvd-Msg-Auth-Fail"    => [ 1022,  "integer" ],
                "SNA-RPRRQ-Rcvd-T-Bit-Not-Set"    => [ 1026,  "integer" ],
                "SNA-RPRRQ-Rcvd-Total"            => [ 1019,  "integer" ],
                "SNA-RPRRQ-Rcvd-VID-Unsupported"  => [ 1025,  "integer" ],
            },
            8708 => {
                "Infinera-ENM-User-Category" => [ 2, "string" ],
                "Infinera-User-Category"     => [ 1, "string" ],
            },
            8741 => {
                "SonicWall-User-Group"        => [ 3, "string" ],
                "SonicWall-User-Privilege"    => [ 1, "integer" ],
                "SS3-Firewall-User-Privilege" => [ 1, "integer" ],
            },
            8742 => {
                "Alphion-ACL-Server-Query-Info"      => [ 45, "string" ],
                "Alphion-Admin-Path"                 => [ 42, "string" ],
                "Alphion-Admin-Role"                 => [ 4,  "string" ],
                "Alphion-AirGroup-Device-Type"       => [ 27, "integer" ],
                "Alphion-AirGroup-Shared-Group"      => [ 35, "string" ],
                "Alphion-AirGroup-Shared-Role"       => [ 26, "string" ],
                "Alphion-AirGroup-Shared-User"       => [ 25, "string" ],
                "Alphion-AirGroup-User-Name"         => [ 24, "string" ],
                "Alphion-AirGroup-Version"           => [ 38, "integer" ],
                "Alphion-AP-Group"                   => [ 10, "string" ],
                "Alphion-AP-IP-Address"              => [ 34, "ipaddr" ],
                "Alphion-AS-Credential-Hash"         => [ 30, "string" ],
                "Alphion-AS-User-Name"               => [ 29, "string" ],
                "Alphion-Auth-Survivability"         => [ 28, "string" ],
                "Alphion-Calea-Server-Ip"            => [ 41, "ipaddr" ],
                "Alphion-Captive-Portal-URL"         => [ 43, "string" ],
                "Alphion-Command-String"             => [ 46, "string" ],
                "Alphion-CPPM-Role"                  => [ 23, "string" ],
                "Alphion-Device-Type"                => [ 12, "string" ],
                "Alphion-Essid-Name"                 => [ 5,  "string" ],
                "Alphion-Framed-IPv6-Address"        => [ 11, "string" ],
                "Alphion-Location-Id"                => [ 6,  "string" ],
                "Alphion-Mdps-Device-Iccid"          => [ 17, "string" ],
                "Alphion-Mdps-Device-Imei"           => [ 16, "string" ],
                "Alphion-Mdps-Device-Name"           => [ 19, "string" ],
                "Alphion-Mdps-Device-Product"        => [ 20, "string" ],
                "Alphion-Mdps-Device-Profile"        => [ 33, "string" ],
                "Alphion-Mdps-Device-Serial"         => [ 22, "string" ],
                "Alphion-Mdps-Device-Udid"           => [ 15, "string" ],
                "Alphion-Mdps-Device-Version"        => [ 21, "string" ],
                "Alphion-Mdps-Max-Devices"           => [ 18, "integer" ],
                "Alphion-Mdps-Provisioning-Settings" => [ 32, "string" ],
                "Alphion-MMS-User-Template"          => [ 8,  "string" ],
                "Alphion-MPSK-Passphrase"            => [ 44, "octets" ],
                "Alphion-Named-User-Vlan"            => [ 9,  "string" ],
                "Alphion-Network-SSO-Token"          => [ 37, "string" ],
                "Alphion-No-DHCP-Fingerprint"        => [ 14, "integer" ],
                "Alphion-Port-Bounce-Host"           => [ 40, "integer" ],
                "Alphion-Port-Identifier"            => [ 7,  "string" ],
                "Alphion-Priv-Admin-User"            => [ 3,  "integer" ],
                "Alphion-User-Group"                 => [ 36, "string" ],
                "Alphion-User-Role"                  => [ 1,  "string" ],
                "Alphion-User-Vlan"                  => [ 2,  "integer" ],
                "Alphion-WorkSpace-App-Name"         => [ 31, "string" ],
            },
            8744 => {
                "Colubris-AVPair"    => [ 0, "string" ],
                "Colubris-Intercept" => [ 1, "integer" ],
            },
            9148 => {
                "Acme-Called-MOS"                        => [ 154, "integer" ],
                "Acme-Called-Octets_FS1"                 => [ 44,  "integer" ],
                "Acme-Called-Octets_FS2"                 => [ 124, "integer" ],
                "Acme-Called-Packets_FS1"                => [ 45,  "integer" ],
                "Acme-Called-Packets_FS2"                => [ 125, "integer" ],
                "Acme-Called-R-Factor"                   => [ 153, "integer" ],
                "Acme-Called-RTCP-Avg-Jitter_FS1"        => [ 47,  "integer" ],
                "Acme-Called-RTCP-Avg-Jitter_FS2"        => [ 127, "integer" ],
                "Acme-Called-RTCP-Avg-Latency_FS1"       => [ 48,  "integer" ],
                "Acme-Called-RTCP-Avg-Latency_FS2"       => [ 128, "integer" ],
                "Acme-Called-RTCP-MaxJitter_FS1"         => [ 49,  "integer" ],
                "Acme-Called-RTCP-MaxJitter_FS2"         => [ 129, "integer" ],
                "Acme-Called-RTCP-MaxLatency_FS1"        => [ 50,  "integer" ],
                "Acme-Called-RTCP-MaxLatency_FS2"        => [ 130, "integer" ],
                "Acme-Called-RTCP-Packets-Lost_FS1"      => [ 46,  "integer" ],
                "Acme-Called-RTCP-Packets-Lost_FS2"      => [ 126, "integer" ],
                "Acme-Called-RTP-Avg-Jitter_FS1"         => [ 52,  "integer" ],
                "Acme-Called-RTP-Avg-Jitter_FS2"         => [ 132, "integer" ],
                "Acme-Called-RTP-MaxJitter_FS1"          => [ 53,  "integer" ],
                "Acme-Called-RTP-MaxJitter_FS2"          => [ 133, "integer" ],
                "Acme-Called-RTP-Packets-Lost_FS1"       => [ 51,  "integer" ],
                "Acme-Called-RTP-Packets-Lost_FS2"       => [ 131, "integer" ],
                "Acme-Calling-MOS"                       => [ 152, "integer" ],
                "Acme-Calling-Octets_FS1"                => [ 28,  "integer" ],
                "Acme-Calling-Octets_FS2"                => [ 102, "integer" ],
                "Acme-Calling-Packets_FS1"               => [ 29,  "integer" ],
                "Acme-Calling-Packets_FS2"               => [ 103, "integer" ],
                "Acme-Calling-R-Factor"                  => [ 151, "integer" ],
                "Acme-Calling-RTCP-Avg-Jitter_FS1"       => [ 33,  "integer" ],
                "Acme-Calling-RTCP-Avg-Jitter_FS2"       => [ 105, "integer" ],
                "Acme-Calling-RTCP-Avg-Latency_FS1"      => [ 34,  "integer" ],
                "Acme-Calling-RTCP-Avg-Latency_FS2"      => [ 106, "integer" ],
                "Acme-Calling-RTCP-MaxJitter_FS1"        => [ 35,  "integer" ],
                "Acme-Calling-RTCP-MaxJitter_FS2"        => [ 107, "integer" ],
                "Acme-Calling-RTCP-MaxLatency_FS1"       => [ 36,  "integer" ],
                "Acme-Calling-RTCP-MaxLatency_FS2"       => [ 108, "integer" ],
                "Acme-Calling-RTCP-Packets-Lost_FS1"     => [ 32,  "integer" ],
                "Acme-Calling-RTCP-Packets-Lost_FS2"     => [ 104, "integer" ],
                "Acme-Calling-RTP-Avg-Jitter_FS1"        => [ 38,  "integer" ],
                "Acme-Calling-RTP-Avg-Jitter_FS2"        => [ 110, "integer" ],
                "Acme-Calling-RTP-MaxJitter_FS1"         => [ 39,  "integer" ],
                "Acme-Calling-RTP-MaxJitter_FS2"         => [ 111, "integer" ],
                "Acme-Calling-RTP-Packets-Lost_FS1"      => [ 37,  "integer" ],
                "Acme-Calling-RTP-Packets-Lost_FS2"      => [ 109, "integer" ],
                "Acme-CDR-Sequence-Number"               => [ 59,  "integer" ],
                "Acme-Custom-VSA-200"                    => [ 200, "string" ],
                "Acme-Custom-VSA-201"                    => [ 201, "string" ],
                "Acme-Custom-VSA-202"                    => [ 202, "string" ],
                "Acme-Custom-VSA-203"                    => [ 203, "string" ],
                "Acme-Custom-VSA-204"                    => [ 204, "string" ],
                "Acme-Custom-VSA-205"                    => [ 205, "string" ],
                "Acme-Custom-VSA-206"                    => [ 206, "string" ],
                "Acme-Custom-VSA-207"                    => [ 207, "string" ],
                "Acme-Custom-VSA-208"                    => [ 208, "string" ],
                "Acme-Custom-VSA-209"                    => [ 209, "string" ],
                "Acme-Custom-VSA-210"                    => [ 210, "string" ],
                "Acme-Custom-VSA-211"                    => [ 211, "string" ],
                "Acme-Custom-VSA-212"                    => [ 212, "string" ],
                "Acme-Custom-VSA-213"                    => [ 213, "string" ],
                "Acme-Custom-VSA-214"                    => [ 214, "string" ],
                "Acme-Custom-VSA-215"                    => [ 215, "string" ],
                "Acme-Custom-VSA-216"                    => [ 216, "string" ],
                "Acme-Custom-VSA-217"                    => [ 217, "string" ],
                "Acme-Custom-VSA-218"                    => [ 218, "string" ],
                "Acme-Custom-VSA-219"                    => [ 219, "string" ],
                "Acme-Custom-VSA-220"                    => [ 220, "string" ],
                "Acme-Custom-VSA-221"                    => [ 221, "string" ],
                "Acme-Custom-VSA-222"                    => [ 222, "string" ],
                "Acme-Custom-VSA-223"                    => [ 223, "string" ],
                "Acme-Custom-VSA-224"                    => [ 224, "string" ],
                "Acme-Custom-VSA-225"                    => [ 225, "string" ],
                "Acme-Custom-VSA-226"                    => [ 226, "string" ],
                "Acme-Custom-VSA-227"                    => [ 227, "string" ],
                "Acme-Custom-VSA-228"                    => [ 228, "string" ],
                "Acme-Custom-VSA-229"                    => [ 229, "string" ],
                "Acme-Custom-VSA-230"                    => [ 230, "string" ],
                "Acme-Disconnect-Cause"                  => [ 62,  "integer" ],
                "Acme-Disconnect-Initiator"              => [ 61,  "integer" ],
                "Acme-Domain-Name"                       => [ 236, "string" ],
                "Acme-Egress-Final-Routing-Number"       => [ 134, "string" ],
                "Acme-Egress-Local-Addr"                 => [ 76,  "string" ],
                "Acme-Egress-Network-Interface-Id"       => [ 139, "string" ],
                "Acme-Egress-Remote-Addr"                => [ 77,  "string" ],
                "Acme-Egress-Vlan-Tag-Value"             => [ 140, "integer" ],
                "Acme-Firmware-Version"                  => [ 56,  "string" ],
                "Acme-Flow-Called-Media-Stop-Time-FS1"   => [ 232, "string" ],
                "Acme-Flow-Called-Media-Stop-Time-FS2"   => [ 234, "string" ],
                "Acme-Flow-Calling-Media-Stop-Time-FS1"  => [ 231, "string" ],
                "Acme-Flow-Calling-Media-Stop-Time-FS2"  => [ 233, "string" ],
                "Acme-Flow-In-Dst-Addr_FS1_F"            => [ 13,  "ipaddr" ],
                "Acme-Flow-In-Dst-Addr_FS1_R"            => [ 83,  "ipaddr" ],
                "Acme-Flow-In-Dst-Addr_FS2_F"            => [ 95,  "ipaddr" ],
                "Acme-Flow-In-Dst-Addr_FS2_R"            => [ 117, "ipaddr" ],
                "Acme-Flow-In-Dst-IPv6_Addr_FS1_F"       => [ 156, "ipv6addr" ],
                "Acme-Flow-In-Dst-IPv6_Addr_FS1_R"       => [ 160, "ipv6addr" ],
                "Acme-Flow-In-Dst-IPv6_Addr_FS2_F"       => [ 164, "ipv6addr" ],
                "Acme-Flow-In-Dst-IPv6_Addr_FS2_R"       => [ 168, "ipv6addr" ],
                "Acme-Flow-In-Dst-Port_FS1_F"            => [ 14,  "integer" ],
                "Acme-Flow-In-Dst-Port_FS1_R"            => [ 84,  "integer" ],
                "Acme-Flow-In-Dst-Port_FS2_F"            => [ 96,  "integer" ],
                "Acme-Flow-In-Dst-Port_FS2_R"            => [ 118, "integer" ],
                "Acme-Flow-In-Realm_FS1_F"               => [ 10,  "string" ],
                "Acme-Flow-In-Realm_FS1_R"               => [ 80,  "string" ],
                "Acme-Flow-In-Realm_FS2_F"               => [ 92,  "string" ],
                "Acme-Flow-In-Realm_FS2_R"               => [ 114, "string" ],
                "Acme-Flow-In-Src-Addr_FS1_F"            => [ 11,  "ipaddr" ],
                "Acme-Flow-In-Src-Addr_FS1_R"            => [ 81,  "ipaddr" ],
                "Acme-Flow-In-Src-Addr_FS2_F"            => [ 93,  "ipaddr" ],
                "Acme-Flow-In-Src-Addr_FS2_R"            => [ 115, "ipaddr" ],
                "Acme-Flow-In-Src-IPv6_Addr_FS1_F"       => [ 155, "ipv6addr" ],
                "Acme-Flow-In-Src-IPv6_Addr_FS1_R"       => [ 159, "ipv6addr" ],
                "Acme-Flow-In-Src-IPv6_Addr_FS2_F"       => [ 163, "ipv6addr" ],
                "Acme-Flow-In-Src-IPv6_Addr_FS2_R"       => [ 167, "ipv6addr" ],
                "Acme-Flow-In-Src-Port_FS1_F"            => [ 12,  "integer" ],
                "Acme-Flow-In-Src-Port_FS1_R"            => [ 82,  "integer" ],
                "Acme-Flow-In-Src-Port_FS2_F"            => [ 94,  "integer" ],
                "Acme-Flow-In-Src-Port_FS2_R"            => [ 116, "integer" ],
                "Acme-Flow-Out-Dst-Addr_FS1_F"           => [ 23,  "ipaddr" ],
                "Acme-Flow-Out-Dst-Addr_FS1_R"           => [ 88,  "ipaddr" ],
                "Acme-Flow-Out-Dst-Addr_FS2_F"           => [ 100, "ipaddr" ],
                "Acme-Flow-Out-Dst-Addr_FS2_R"           => [ 122, "ipaddr" ],
                "Acme-Flow-Out-Dst-IPv6_Addr_FS1_F"      => [ 158, "ipv6addr" ],
                "Acme-Flow-Out-Dst-IPv6_Addr_FS1_R"      => [ 162, "ipv6addr" ],
                "Acme-Flow-Out-Dst-IPv6_Addr_FS2_F"      => [ 166, "ipv6addr" ],
                "Acme-Flow-Out-Dst-IPv6_Addr_FS2_R"      => [ 170, "ipv6addr" ],
                "Acme-Flow-Out-Dst-Port_FS1_F"           => [ 24,  "integer" ],
                "Acme-Flow-Out-Dst-Port_FS1_R"           => [ 89,  "integer" ],
                "Acme-Flow-Out-Dst-Port_FS2_F"           => [ 101, "integer" ],
                "Acme-Flow-Out-Dst-Port_FS2_R"           => [ 123, "integer" ],
                "Acme-Flow-Out-Realm_FS1_F"              => [ 20,  "string" ],
                "Acme-Flow-Out-Realm_FS1_R"              => [ 85,  "string" ],
                "Acme-Flow-Out-Realm_FS2_F"              => [ 97,  "string" ],
                "Acme-Flow-Out-Realm_FS2_R"              => [ 119, "string" ],
                "Acme-Flow-Out-Src-Addr_FS1_F"           => [ 21,  "ipaddr" ],
                "Acme-Flow-Out-Src-Addr_FS1_R"           => [ 86,  "ipaddr" ],
                "Acme-Flow-Out-Src-Addr_FS2_F"           => [ 98,  "ipaddr" ],
                "Acme-Flow-Out-Src-Addr_FS2_R"           => [ 120, "ipaddr" ],
                "Acme-Flow-Out-Src-IPv6_Addr_FS1_F"      => [ 157, "ipv6addr" ],
                "Acme-Flow-Out-Src-IPv6_Addr_FS1_R"      => [ 161, "ipv6addr" ],
                "Acme-Flow-Out-Src-IPv6_Addr_FS2_F"      => [ 165, "ipv6addr" ],
                "Acme-Flow-Out-Src-IPv6_Addr_FS2_R"      => [ 169, "ipv6addr" ],
                "Acme-Flow-Out-Src-Port_FS1_F"           => [ 22,  "integer" ],
                "Acme-Flow-Out-Src-Port_FS1_R"           => [ 87,  "integer" ],
                "Acme-Flow-Out-Src-Port_FS2_F"           => [ 99,  "integer" ],
                "Acme-Flow-Out-Src-Port_FS2_R"           => [ 121, "integer" ],
                "Acme-Flow-PTime_FS1_F"                  => [ 146, "integer" ],
                "Acme-Flow-PTime_FS1_R"                  => [ 147, "integer" ],
                "Acme-Flow-PTime_FS2_F"                  => [ 148, "integer" ],
                "Acme-Flow-PTime_FS2_R"                  => [ 149, "integer" ],
                "Acme-FlowID_FS1_F"                      => [ 1,   "string" ],
                "Acme-FlowID_FS1_R"                      => [ 78,  "string" ],
                "Acme-FlowID_FS2_F"                      => [ 90,  "string" ],
                "Acme-FlowID_FS2_R"                      => [ 112, "string" ],
                "Acme-FlowMediaType_FS1_F"               => [ 142, "string" ],
                "Acme-FlowMediaType_FS1_R"               => [ 143, "string" ],
                "Acme-FlowMediaType_FS2_F"               => [ 144, "string" ],
                "Acme-FlowMediaType_FS2_R"               => [ 145, "string" ],
                "Acme-FlowType_FS1_F"                    => [ 2,   "string" ],
                "Acme-FlowType_FS1_R"                    => [ 79,  "string" ],
                "Acme-FlowType_FS2_F"                    => [ 91,  "string" ],
                "Acme-FlowType_FS2_R"                    => [ 113, "string" ],
                "Acme-Ingress-Local-Addr"                => [ 74,  "string" ],
                "Acme-Ingress-Network-Interface-Id"      => [ 137, "string" ],
                "Acme-Ingress-Remote-Addr"               => [ 75,  "string" ],
                "Acme-Ingress-Vlan-Tag-Value"            => [ 138, "integer" ],
                "Acme-Intermediate_Time"                 => [ 63,  "string" ],
                "Acme-Local-Time-Zone"                   => [ 57,  "string" ],
                "Acme-Originating-Trunk-Context"         => [ 67,  "string" ],
                "Acme-Originating-Trunk-Group"           => [ 65,  "string" ],
                "Acme-P-Asserted-ID"                     => [ 69,  "string" ],
                "Acme-Post-Dial-Delay"                   => [ 58,  "integer" ],
                "Acme-Primary-Routing-Number"            => [ 64,  "string" ],
                "Acme-Reason-Phrase"                     => [ 239, "string" ],
                "Acme-Refer-Call-Transfer-Id"            => [ 141, "string" ],
                "Acme-Session-Charging-Function_Address" => [ 55,  "string" ],
                "Acme-Session-Charging-Vector"           => [ 54,  "string" ],
                "Acme-Session-Disposition"               => [ 60,  "integer" ],
                "Acme-Session-Egress-CallId"             => [ 4,   "string" ],
                "Acme-Session-Egress-Realm"              => [ 42,  "string" ],
                "Acme-Session-Egress-RPH"                => [ 136, "string" ],
                "Acme-Session-Forked-Call-Id"            => [ 171, "string" ],
                "Acme-Session-Generic-Id"                => [ 40,  "string" ],
                "Acme-Session-Ingress-CallId"            => [ 3,   "string" ],
                "Acme-Session-Ingress-Realm"             => [ 41,  "string" ],
                "Acme-Session-Ingress-RPH"               => [ 135, "string" ],
                "Acme-Session-Media-Process"             => [ 150, "string" ],
                "Acme-Session-Protocol-Type"             => [ 43,  "string" ],
                "Acme-SIP-Contact"                       => [ 237, "string" ],
                "Acme-SIP-Diversion"                     => [ 70,  "string" ],
                "Acme-SIP-Expires"                       => [ 238, "integer" ],
                "Acme-SIP-Method-Type"                   => [ 235, "string" ],
                "Acme-SIP-Status"                        => [ 71,  "integer" ],
                "Acme-Terminating-Trunk-Context"         => [ 68,  "string" ],
                "Acme-Terminating-Trunk-Group"           => [ 66,  "string" ],
                "Acme-User-Class"                        => [ 254, "string" ],
                "Acme-User-Privilege"                    => [ 253, "string" ],
            },
            9694  => { "Arbor-Privilege-Level" => [ 1, "string" ] },
            10055 => {
                "RP-Downstream-Speed-Limit" => [ 2, "integer" ],
                "RP-HURL"                   => [ 3, "string" ],
                "RP-Max-Sessions-Per-User"  => [ 5, "integer" ],
                "RP-MOTM"                   => [ 4, "string" ],
                "RP-Upstream-Speed-Limit"   => [ 1, "integer" ],
            },
            10415 => {
                "3GPP-Allocate-IP-Type"              => [ 27, "byte" ],
                "3GPP-Camel-Charging-Info"           => [ 24, "octets" ],
                "3GPP-Charging-Characteristics"      => [ 13, "string" ],
                "3GPP-Charging-Gateway-Address"      => [ 4,  "ipaddr" ],
                "3GPP-Charging-Gateway-IPv6-Address" => [ 14, "ipv6addr" ],
                "3GPP-Charging-ID"                   => [ 2,  "integer" ],
                "3GPP-GGSN-Address"                  => [ 7,  "ipaddr" ],
                "3GPP-GGSN-IPv6-Address"             => [ 16, "ipv6addr" ],
                "3GPP-GGSN-MCC-MNC"                  => [ 9,  "string" ],
                "3GPP-GPRS-Negotiated-QoS-profile"   => [ 5,  "string" ],
                "3GPP-IMEISV"                        => [ 20, "string" ],
                "3GPP-IMSI"                          => [ 1,  "string" ],
                "3GPP-IMSI-MCC-MNC"                  => [ 8,  "string" ],
                "3GPP-IPv6-DNS-Servers"              => [ 17, "octets" ],
                "3GPP-Location-Info"                 => [ 22, "octets" ],
                "3GPP-MS-Time-Zone"                  => [ 23, "octets" ],
                "3GPP-Negotiated-DSCP"               => [ 26, "byte" ],
                "3GPP-NSAPI"                         => [ 10, "string" ],
                "3GPP-Packet-Filter"                 => [ 25, "octets" ],
                "3GPP-PDP-Type"                      => [ 3,  "integer" ],
                "3GPP-RAT-Type"                      => [ 21, "byte" ],
                "3GPP-Selection-Mode"                => [ 12, "string" ],
                "3GPP-Session-Stop-Indicator"        => [ 11, "byte" ],
                "3GPP-SGSN-Address"                  => [ 6,  "ipaddr" ],
                "3GPP-SGSN-IPv6-Address"             => [ 15, "ipv6addr" ],
                "3GPP-SGSN-MCC-MNC"                  => [ 18, "string" ],
                "3GPP-Teardown-Indicator"            => [ 19, "byte" ],
                "3GPP-User-Location-Info"            => [ 22, "octets" ],
            },
            10529 => {
                "Acct-Session-Gigawords"        => [ 26, "integer" ],
                "Acct-Session-Input-Gigawords"  => [ 22, "integer" ],
                "Acct-Session-Input-Octets"     => [ 21, "integer" ],
                "Acct-Session-Octets"           => [ 25, "integer" ],
                "Acct-Session-Output-Gigawords" => [ 24, "integer" ],
                "Acct-Session-Output-Octets"    => [ 23, "integer" ],
            },
            10923 => {
                "Suggested-Rule-Space"           => [ 30, "string" ],
                "Suggested-Secondary-Rule-Space" => [ 31, "string" ],
            },
            11344 => {
                "FreeRADIUS-802.1X-Anonce"                => [ 1,   "octets" ],
                "FreeRADIUS-802.1X-EAPoL-Key-Msg"         => [ 2,   "octets" ],
                "FreeRADIUS-Acct-Session-Start-Time"      => [ 2,   "date" ],
                "FreeRADIUS-EAP-FAST-Crypto-Binding"      => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-EAP-Payload"         => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-Error"               => [ 186, "integer" ],
                "FreeRADIUS-EAP-FAST-Intermediate-Result" => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-NAK"                 => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-PAC"                 => [ 186, "tlv" ],
                "FreeRADIUS-EAP-FAST-PAC-A-ID"            => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-PAC-A-ID-Info"       => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-PAC-Acknowledge"     => [ 186, "short" ],
                "FreeRADIUS-EAP-FAST-PAC-I-ID"            => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-PAC-Info-A-ID"       => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-PAC-Info-A-ID-Info"  => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-PAC-Info-I-ID"       => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-PAC-Info-PAC-Lifetime" =>
                  [ 186, "integer" ],
                "FreeRADIUS-EAP-FAST-PAC-Info-PAC-Type"  => [ 186, "short" ],
                "FreeRADIUS-EAP-FAST-PAC-Info-TLV"       => [ 186, "tlv" ],
                "FreeRADIUS-EAP-FAST-PAC-Key"            => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-PAC-Lifetime"       => [ 186, "integer" ],
                "FreeRADIUS-EAP-FAST-PAC-Opaque-I-ID"    => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-PAC-Opaque-PAC-Key" => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-PAC-Opaque-PAC-Lifetime" =>
                  [ 186, "integer" ],
                "FreeRADIUS-EAP-FAST-PAC-Opaque-PAC-Type" => [ 186, "short" ],
                "FreeRADIUS-EAP-FAST-PAC-Opaque-TLV"      => [ 186, "tlv" ],
                "FreeRADIUS-EAP-FAST-PAC-Type"            => [ 186, "short" ],
                "FreeRADIUS-EAP-FAST-PKCS"                => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-Request-Action"      => [ 186, "short" ],
                "FreeRADIUS-EAP-FAST-Result"              => [ 186, "short" ],
                "FreeRADIUS-EAP-FAST-TLV"                 => [ 186, "tlv" ],
                "FreeRADIUS-EAP-FAST-Trusted-Root"        => [ 186, "octets" ],
                "FreeRADIUS-EAP-FAST-Vendor-Specific"     => [ 186, "octets" ],
                "FreeRADIUS-EAP-TEAP-Authority-ID"        => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-Basic-Password-Auth-Req" =>
                  [ 190, "string" ],
                "FreeRADIUS-EAP-TEAP-Basic-Password-Auth-Resp" =>
                  [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-Channel-Binding"     => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-Crypto-Binding"      => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-EAP-Payload"         => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-Error"               => [ 190, "integer" ],
                "FreeRADIUS-EAP-TEAP-Intermediate-Result" => [ 190, "short" ],
                "FreeRADIUS-EAP-TEAP-NAK"                 => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-PAC"                 => [ 190, "tlv" ],
                "FreeRADIUS-EAP-TEAP-PAC-A-ID"            => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-PAC-A-ID-Info"       => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-PAC-Acknowledgement" => [ 190, "short" ],
                "FreeRADIUS-EAP-TEAP-PAC-I-ID"            => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-PAC-Info-A-ID"       => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-PAC-Info-A-ID-Info"  => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-PAC-Info-I-ID"       => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-PAC-Info-PAC-Lifetime" =>
                  [ 190, "integer" ],
                "FreeRADIUS-EAP-TEAP-PAC-Info-PAC-Type"   => [ 190, "short" ],
                "FreeRADIUS-EAP-TEAP-PAC-Info-TLV"        => [ 190, "tlv" ],
                "FreeRADIUS-EAP-TEAP-PAC-Key"             => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-PAC-Lifetime"        => [ 190, "integer" ],
                "FreeRADIUS-EAP-TEAP-PAC-Opaque"          => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-PAC-Type"            => [ 190, "short" ],
                "FreeRADIUS-EAP-TEAP-PKCS10"              => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-PKCS7"               => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-Request-Action"      => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-Result"              => [ 190, "short" ],
                "FreeRADIUS-EAP-TEAP-TLV"                 => [ 190, "tlv" ],
                "FreeRADIUS-EAP-TEAP-Trusted-Server-Root" => [ 190, "octets" ],
                "FreeRADIUS-EAP-TEAP-Vendor-Specific"     => [ 190, "octets" ],
                "FreeRADIUS-EAP-TRAP-PAC-Type"            => [ 186, "short" ],
                "FreeRADIUS-Proxied-To"                   => [ 1,   "ipaddr" ],
                "FreeRADIUS-Queue-Len-Acct"               => [ 165, "integer" ],
                "FreeRADIUS-Queue-Len-Auth"               => [ 164, "integer" ],
                "FreeRADIUS-Queue-Len-Detail"             => [ 166, "integer" ],
                "FreeRADIUS-Queue-Len-Internal"           => [ 162, "integer" ],
                "FreeRADIUS-Queue-Len-Proxy"              => [ 163, "integer" ],
                "FreeRADIUS-Queue-PPS-In"                 => [ 181, "integer" ],
                "FreeRADIUS-Queue-PPS-Out"                => [ 182, "integer" ],
                "FreeRADIUS-Queue-Use-Percentage"         => [ 183, "integer" ],
                "FreeRADIUS-Server-EMA-USEC-Window-1"     => [ 179, "integer" ],
                "FreeRADIUS-Server-EMA-USEC-Window-10"    => [ 180, "integer" ],
                "FreeRADIUS-Server-EMA-Window"            => [ 178, "integer" ],
                "FreeRADIUS-Statistics-Type"              => [ 127, "integer" ],
                "FreeRADIUS-Stats-Client-IP-Address"      => [ 167, "ipaddr" ],
                "FreeRADIUS-Stats-Client-IPv6-Address" => [ 188, "ipv6addr" ],
                "FreeRADIUS-Stats-Client-Netmask"      => [ 169, "integer" ],
                "FreeRADIUS-Stats-Client-Number"       => [ 168, "integer" ],
                "FreeRADIUS-Stats-Error"               => [ 187, "string" ],
                "FreeRADIUS-Stats-HUP-Time"            => [ 177, "date" ],
                "FreeRADIUS-Stats-Last-Packet-Recv"    => [ 184, "date" ],
                "FreeRADIUS-Stats-Last-Packet-Sent"    => [ 185, "date" ],
                "FreeRADIUS-Stats-Server-IP-Address"   => [ 170, "ipaddr" ],
                "FreeRADIUS-Stats-Server-IPv6-Address" => [ 189, "ipv6addr" ],
                "FreeRADIUS-Stats-Server-Outstanding-Requests" =>
                  [ 172, "integer" ],
                "FreeRADIUS-Stats-Server-Port"           => [ 171, "integer" ],
                "FreeRADIUS-Stats-Server-Src-IP-Address" => [ 176, "ipaddr" ],
                "FreeRADIUS-Stats-Server-Src-IPv6-Address" => [ 177, "ipaddr" ],
                "FreeRADIUS-Stats-Server-State"          => [ 173, "integer" ],
                "FreeRADIUS-Stats-Server-Time-Of-Death"  => [ 174, "date" ],
                "FreeRADIUS-Stats-Server-Time-Of-Life"   => [ 175, "date" ],
                "FreeRADIUS-Stats-Start-Time"            => [ 176, "date" ],
                "FreeRADIUS-Stats-Threads-Active"        => [ 193, "integer" ],
                "FreeRADIUS-Stats-Threads-Max"           => [ 195, "integer" ],
                "FreeRADIUS-Stats-Threads-Total"         => [ 194, "integer" ],
                "FreeRADIUS-Total-Access-Accepts"        => [ 129, "integer" ],
                "FreeRADIUS-Total-Access-Challenges"     => [ 131, "integer" ],
                "FreeRADIUS-Total-Access-Rejects"        => [ 130, "integer" ],
                "FreeRADIUS-Total-Access-Requests"       => [ 128, "integer" ],
                "FreeRADIUS-Total-Accounting-Requests"   => [ 148, "integer" ],
                "FreeRADIUS-Total-Accounting-Responses"  => [ 149, "integer" ],
                "FreeRADIUS-Total-Acct-Conflicts"        => [ 192, "integer" ],
                "FreeRADIUS-Total-Acct-Dropped-Requests" => [ 153, "integer" ],
                "FreeRADIUS-Total-Acct-Duplicate-Requests" =>
                  [ 150, "integer" ],
                "FreeRADIUS-Total-Acct-Invalid-Requests" => [ 152, "integer" ],
                "FreeRADIUS-Total-Acct-Malformed-Requests" =>
                  [ 151, "integer" ],
                "FreeRADIUS-Total-Acct-Unknown-Types"    => [ 154, "integer" ],
                "FreeRADIUS-Total-Auth-Conflicts"        => [ 191, "integer" ],
                "FreeRADIUS-Total-Auth-Dropped-Requests" => [ 136, "integer" ],
                "FreeRADIUS-Total-Auth-Duplicate-Requests" =>
                  [ 133, "integer" ],
                "FreeRADIUS-Total-Auth-Invalid-Requests" => [ 135, "integer" ],
                "FreeRADIUS-Total-Auth-Malformed-Requests" =>
                  [ 134, "integer" ],
                "FreeRADIUS-Total-Auth-Responses"       => [ 132, "integer" ],
                "FreeRADIUS-Total-Auth-Unknown-Types"   => [ 137, "integer" ],
                "FreeRADIUS-Total-Proxy-Access-Accepts" => [ 139, "integer" ],
                "FreeRADIUS-Total-Proxy-Access-Challenges" =>
                  [ 141, "integer" ],
                "FreeRADIUS-Total-Proxy-Access-Rejects"  => [ 140, "integer" ],
                "FreeRADIUS-Total-Proxy-Access-Requests" => [ 138, "integer" ],
                "FreeRADIUS-Total-Proxy-Accounting-Requests" =>
                  [ 155, "integer" ],
                "FreeRADIUS-Total-Proxy-Accounting-Responses" =>
                  [ 156, "integer" ],
                "FreeRADIUS-Total-Proxy-Acct-Dropped-Requests" =>
                  [ 160, "integer" ],
                "FreeRADIUS-Total-Proxy-Acct-Duplicate-Requests" =>
                  [ 157, "integer" ],
                "FreeRADIUS-Total-Proxy-Acct-Invalid-Requests" =>
                  [ 159, "integer" ],
                "FreeRADIUS-Total-Proxy-Acct-Malformed-Requests" =>
                  [ 158, "integer" ],
                "FreeRADIUS-Total-Proxy-Acct-Unknown-Types" =>
                  [ 161, "integer" ],
                "FreeRADIUS-Total-Proxy-Auth-Dropped-Requests" =>
                  [ 146, "integer" ],
                "FreeRADIUS-Total-Proxy-Auth-Duplicate-Requests" =>
                  [ 143, "integer" ],
                "FreeRADIUS-Total-Proxy-Auth-Invalid-Requests" =>
                  [ 145, "integer" ],
                "FreeRADIUS-Total-Proxy-Auth-Malformed-Requests" =>
                  [ 144, "integer" ],
                "FreeRADIUS-Total-Proxy-Auth-Responses" => [ 142, "integer" ],
                "FreeRADIUS-Total-Proxy-Auth-Unknown-Types" =>
                  [ 147, "integer" ],
            },
            11862 => {
                "Sip-From"                   => [ 1, "string" ],
                "Sip-Method"                 => [ 0, "integer" ],
                "Sip-To"                     => [ 2, "string" ],
                "Sip-Translated-Request-URI" => [ 4, "string" ],
            },
            11863 => {
                "TPLink-Authentication-FindKey"  => [ 3, "octets" ],
                "TPLink-Authentication-FoundKey" => [ 4, "octets" ],
                "TPLink-Omada"                   => [ 7, "string" ],
                "TPLink-Portal-Access-Status"    => [ 9, "integer" ],
                "TPLink-Recv-limit"              => [ 1, "integer" ],
                "TPLink-Redirect-Url"            => [ 8, "string" ],
                "TPLink-Site"                    => [ 6, "string" ],
                "TPLink-User-Command"            => [ 5, "string" ],
                "TPLink-Xmit-limit"              => [ 2, "integer" ],
            },
            12356 => {
                "Fortinet-Access-Profile"                => [ 6,  "string" ],
                "Fortinet-AP-Name"                       => [ 8,  "string" ],
                "Fortinet-AppCtrl-Category-Allow"        => [ 19, "octets" ],
                "Fortinet-AppCtrl-Category-Block"        => [ 20, "octets" ],
                "Fortinet-AppCtrl-Risk-Allow"            => [ 21, "octets" ],
                "Fortinet-AppCtrl-Risk-Block"            => [ 22, "octets" ],
                "Fortinet-Client-IP-Address"             => [ 2,  "ipaddr" ],
                "Fortinet-Client-IPv6-Address"           => [ 4,  "octets" ],
                "Fortinet-FAC-Auth-Status"               => [ 11, "string" ],
                "Fortinet-FAC-Challenge-Code"            => [ 15, "string" ],
                "Fortinet-FAC-Token-ID"                  => [ 12, "string" ],
                "Fortinet-FDD-Access-Profile"            => [ 30, "string" ],
                "Fortinet-FDD-Allow-API-Access"          => [ 36, "string" ],
                "Fortinet-FDD-Is-SPP-Admin"              => [ 34, "string" ],
                "Fortinet-FDD-Is-System-Admin"           => [ 33, "string" ],
                "Fortinet-FDD-SPP-Name"                  => [ 32, "string" ],
                "Fortinet-FDD-SPP-Policy-Group"          => [ 35, "string" ],
                "Fortinet-FDD-Trusted-Hosts"             => [ 31, "string" ],
                "Fortinet-FortiWAN-AVPair"               => [ 26, "string" ],
                "Fortinet-Fpc-User-Role"                 => [ 40, "string" ],
                "Fortinet-Group-Name"                    => [ 1,  "string" ],
                "Fortinet-Host-Port-AVPair"              => [ 42, "string" ],
                "Fortinet-Interface-Name"                => [ 5,  "string" ],
                "Fortinet-SSID"                          => [ 7,  "string" ],
                "Fortinet-Tenant-Identification"         => [ 41, "string" ],
                "Fortinet-Vdom-Name"                     => [ 3,  "string" ],
                "Fortinet-Webfilter-Category-Allow"      => [ 16, "octets" ],
                "Fortinet-Webfilter-Category-Block"      => [ 17, "octets" ],
                "Fortinet-Webfilter-Category-Monitor"    => [ 18, "octets" ],
                "Fortinet-WirelessController-Assoc-Time" => [ 25, "date" ],
                "Fortinet-WirelessController-Device-MAC" => [ 23, "ether" ],
                "Fortinet-WirelessController-WTP-ID"     => [ 24, "string" ],
            },
            12394 => {
                "Alvarion-VSA-1"   => [ 1,   "string" ],
                "Alvarion-VSA-10"  => [ 10,  "string" ],
                "Alvarion-VSA-100" => [ 100, "string" ],
                "Alvarion-VSA-101" => [ 101, "string" ],
                "Alvarion-VSA-102" => [ 102, "string" ],
                "Alvarion-VSA-103" => [ 103, "string" ],
                "Alvarion-VSA-104" => [ 104, "string" ],
                "Alvarion-VSA-105" => [ 105, "string" ],
                "Alvarion-VSA-106" => [ 106, "string" ],
                "Alvarion-VSA-107" => [ 107, "string" ],
                "Alvarion-VSA-108" => [ 108, "string" ],
                "Alvarion-VSA-109" => [ 109, "string" ],
                "Alvarion-VSA-11"  => [ 11,  "string" ],
                "Alvarion-VSA-110" => [ 110, "string" ],
                "Alvarion-VSA-111" => [ 111, "string" ],
                "Alvarion-VSA-112" => [ 112, "string" ],
                "Alvarion-VSA-113" => [ 113, "string" ],
                "Alvarion-VSA-114" => [ 114, "string" ],
                "Alvarion-VSA-115" => [ 115, "string" ],
                "Alvarion-VSA-116" => [ 116, "string" ],
                "Alvarion-VSA-117" => [ 117, "string" ],
                "Alvarion-VSA-118" => [ 118, "string" ],
                "Alvarion-VSA-119" => [ 119, "string" ],
                "Alvarion-VSA-12"  => [ 12,  "string" ],
                "Alvarion-VSA-120" => [ 120, "string" ],
                "Alvarion-VSA-121" => [ 121, "string" ],
                "Alvarion-VSA-122" => [ 122, "string" ],
                "Alvarion-VSA-123" => [ 123, "string" ],
                "Alvarion-VSA-124" => [ 124, "string" ],
                "Alvarion-VSA-125" => [ 125, "string" ],
                "Alvarion-VSA-126" => [ 126, "string" ],
                "Alvarion-VSA-127" => [ 127, "string" ],
                "Alvarion-VSA-128" => [ 128, "string" ],
                "Alvarion-VSA-129" => [ 129, "string" ],
                "Alvarion-VSA-13"  => [ 13,  "string" ],
                "Alvarion-VSA-130" => [ 130, "string" ],
                "Alvarion-VSA-131" => [ 131, "string" ],
                "Alvarion-VSA-132" => [ 132, "string" ],
                "Alvarion-VSA-133" => [ 133, "string" ],
                "Alvarion-VSA-134" => [ 134, "string" ],
                "Alvarion-VSA-135" => [ 135, "string" ],
                "Alvarion-VSA-136" => [ 136, "string" ],
                "Alvarion-VSA-137" => [ 137, "string" ],
                "Alvarion-VSA-138" => [ 138, "string" ],
                "Alvarion-VSA-139" => [ 139, "string" ],
                "Alvarion-VSA-14"  => [ 14,  "string" ],
                "Alvarion-VSA-140" => [ 140, "string" ],
                "Alvarion-VSA-141" => [ 141, "string" ],
                "Alvarion-VSA-142" => [ 142, "string" ],
                "Alvarion-VSA-143" => [ 143, "string" ],
                "Alvarion-VSA-144" => [ 144, "string" ],
                "Alvarion-VSA-145" => [ 145, "string" ],
                "Alvarion-VSA-146" => [ 146, "string" ],
                "Alvarion-VSA-147" => [ 147, "string" ],
                "Alvarion-VSA-148" => [ 148, "string" ],
                "Alvarion-VSA-149" => [ 149, "string" ],
                "Alvarion-VSA-15"  => [ 15,  "string" ],
                "Alvarion-VSA-150" => [ 150, "string" ],
                "Alvarion-VSA-151" => [ 151, "string" ],
                "Alvarion-VSA-152" => [ 152, "string" ],
                "Alvarion-VSA-153" => [ 153, "string" ],
                "Alvarion-VSA-154" => [ 154, "string" ],
                "Alvarion-VSA-155" => [ 155, "string" ],
                "Alvarion-VSA-156" => [ 156, "string" ],
                "Alvarion-VSA-157" => [ 157, "string" ],
                "Alvarion-VSA-158" => [ 158, "string" ],
                "Alvarion-VSA-159" => [ 159, "string" ],
                "Alvarion-VSA-16"  => [ 16,  "string" ],
                "Alvarion-VSA-160" => [ 160, "string" ],
                "Alvarion-VSA-161" => [ 161, "string" ],
                "Alvarion-VSA-162" => [ 162, "string" ],
                "Alvarion-VSA-163" => [ 163, "string" ],
                "Alvarion-VSA-164" => [ 164, "string" ],
                "Alvarion-VSA-165" => [ 165, "string" ],
                "Alvarion-VSA-166" => [ 166, "string" ],
                "Alvarion-VSA-167" => [ 167, "string" ],
                "Alvarion-VSA-168" => [ 168, "string" ],
                "Alvarion-VSA-169" => [ 169, "string" ],
                "Alvarion-VSA-17"  => [ 17,  "string" ],
                "Alvarion-VSA-170" => [ 170, "string" ],
                "Alvarion-VSA-171" => [ 171, "string" ],
                "Alvarion-VSA-172" => [ 172, "string" ],
                "Alvarion-VSA-173" => [ 173, "string" ],
                "Alvarion-VSA-174" => [ 174, "string" ],
                "Alvarion-VSA-175" => [ 175, "string" ],
                "Alvarion-VSA-176" => [ 176, "string" ],
                "Alvarion-VSA-177" => [ 177, "string" ],
                "Alvarion-VSA-178" => [ 178, "string" ],
                "Alvarion-VSA-179" => [ 179, "string" ],
                "Alvarion-VSA-18"  => [ 18,  "string" ],
                "Alvarion-VSA-180" => [ 180, "string" ],
                "Alvarion-VSA-181" => [ 181, "string" ],
                "Alvarion-VSA-182" => [ 182, "string" ],
                "Alvarion-VSA-183" => [ 183, "string" ],
                "Alvarion-VSA-184" => [ 184, "string" ],
                "Alvarion-VSA-185" => [ 185, "string" ],
                "Alvarion-VSA-186" => [ 186, "string" ],
                "Alvarion-VSA-187" => [ 187, "string" ],
                "Alvarion-VSA-188" => [ 188, "string" ],
                "Alvarion-VSA-189" => [ 189, "string" ],
                "Alvarion-VSA-19"  => [ 19,  "string" ],
                "Alvarion-VSA-190" => [ 190, "string" ],
                "Alvarion-VSA-191" => [ 191, "string" ],
                "Alvarion-VSA-192" => [ 192, "string" ],
                "Alvarion-VSA-193" => [ 193, "string" ],
                "Alvarion-VSA-194" => [ 194, "string" ],
                "Alvarion-VSA-195" => [ 195, "string" ],
                "Alvarion-VSA-196" => [ 196, "string" ],
                "Alvarion-VSA-197" => [ 197, "string" ],
                "Alvarion-VSA-198" => [ 198, "string" ],
                "Alvarion-VSA-199" => [ 199, "string" ],
                "Alvarion-VSA-2"   => [ 2,   "string" ],
                "Alvarion-VSA-20"  => [ 20,  "string" ],
                "Alvarion-VSA-200" => [ 200, "string" ],
                "Alvarion-VSA-201" => [ 201, "string" ],
                "Alvarion-VSA-202" => [ 202, "string" ],
                "Alvarion-VSA-203" => [ 203, "string" ],
                "Alvarion-VSA-204" => [ 204, "string" ],
                "Alvarion-VSA-205" => [ 205, "string" ],
                "Alvarion-VSA-206" => [ 206, "string" ],
                "Alvarion-VSA-207" => [ 207, "string" ],
                "Alvarion-VSA-208" => [ 208, "string" ],
                "Alvarion-VSA-209" => [ 209, "string" ],
                "Alvarion-VSA-21"  => [ 21,  "string" ],
                "Alvarion-VSA-210" => [ 210, "string" ],
                "Alvarion-VSA-211" => [ 211, "string" ],
                "Alvarion-VSA-212" => [ 212, "string" ],
                "Alvarion-VSA-213" => [ 213, "string" ],
                "Alvarion-VSA-214" => [ 214, "string" ],
                "Alvarion-VSA-215" => [ 215, "string" ],
                "Alvarion-VSA-216" => [ 216, "string" ],
                "Alvarion-VSA-217" => [ 217, "string" ],
                "Alvarion-VSA-218" => [ 218, "string" ],
                "Alvarion-VSA-219" => [ 219, "string" ],
                "Alvarion-VSA-22"  => [ 22,  "string" ],
                "Alvarion-VSA-220" => [ 220, "string" ],
                "Alvarion-VSA-221" => [ 221, "string" ],
                "Alvarion-VSA-222" => [ 222, "string" ],
                "Alvarion-VSA-223" => [ 223, "string" ],
                "Alvarion-VSA-224" => [ 224, "string" ],
                "Alvarion-VSA-225" => [ 225, "string" ],
                "Alvarion-VSA-226" => [ 226, "string" ],
                "Alvarion-VSA-227" => [ 227, "string" ],
                "Alvarion-VSA-228" => [ 228, "string" ],
                "Alvarion-VSA-229" => [ 229, "string" ],
                "Alvarion-VSA-23"  => [ 23,  "string" ],
                "Alvarion-VSA-230" => [ 230, "string" ],
                "Alvarion-VSA-231" => [ 231, "string" ],
                "Alvarion-VSA-232" => [ 232, "string" ],
                "Alvarion-VSA-233" => [ 233, "string" ],
                "Alvarion-VSA-234" => [ 234, "string" ],
                "Alvarion-VSA-235" => [ 235, "string" ],
                "Alvarion-VSA-236" => [ 236, "string" ],
                "Alvarion-VSA-237" => [ 237, "string" ],
                "Alvarion-VSA-238" => [ 238, "string" ],
                "Alvarion-VSA-239" => [ 239, "string" ],
                "Alvarion-VSA-24"  => [ 24,  "string" ],
                "Alvarion-VSA-240" => [ 240, "string" ],
                "Alvarion-VSA-241" => [ 241, "string" ],
                "Alvarion-VSA-242" => [ 242, "string" ],
                "Alvarion-VSA-243" => [ 243, "string" ],
                "Alvarion-VSA-244" => [ 244, "string" ],
                "Alvarion-VSA-245" => [ 245, "string" ],
                "Alvarion-VSA-246" => [ 246, "string" ],
                "Alvarion-VSA-247" => [ 247, "string" ],
                "Alvarion-VSA-248" => [ 248, "string" ],
                "Alvarion-VSA-249" => [ 249, "string" ],
                "Alvarion-VSA-25"  => [ 25,  "string" ],
                "Alvarion-VSA-250" => [ 250, "string" ],
                "Alvarion-VSA-251" => [ 251, "string" ],
                "Alvarion-VSA-252" => [ 252, "string" ],
                "Alvarion-VSA-253" => [ 253, "string" ],
                "Alvarion-VSA-254" => [ 254, "string" ],
                "Alvarion-VSA-255" => [ 255, "string" ],
                "Alvarion-VSA-26"  => [ 26,  "string" ],
                "Alvarion-VSA-27"  => [ 27,  "string" ],
                "Alvarion-VSA-28"  => [ 28,  "string" ],
                "Alvarion-VSA-29"  => [ 29,  "string" ],
                "Alvarion-VSA-3"   => [ 3,   "string" ],
                "Alvarion-VSA-30"  => [ 30,  "string" ],
                "Alvarion-VSA-31"  => [ 31,  "string" ],
                "Alvarion-VSA-32"  => [ 32,  "string" ],
                "Alvarion-VSA-33"  => [ 33,  "string" ],
                "Alvarion-VSA-34"  => [ 34,  "string" ],
                "Alvarion-VSA-35"  => [ 35,  "string" ],
                "Alvarion-VSA-36"  => [ 36,  "string" ],
                "Alvarion-VSA-37"  => [ 37,  "string" ],
                "Alvarion-VSA-38"  => [ 38,  "string" ],
                "Alvarion-VSA-39"  => [ 39,  "string" ],
                "Alvarion-VSA-4"   => [ 4,   "string" ],
                "Alvarion-VSA-40"  => [ 40,  "string" ],
                "Alvarion-VSA-41"  => [ 41,  "string" ],
                "Alvarion-VSA-42"  => [ 42,  "string" ],
                "Alvarion-VSA-43"  => [ 43,  "string" ],
                "Alvarion-VSA-44"  => [ 44,  "string" ],
                "Alvarion-VSA-45"  => [ 45,  "string" ],
                "Alvarion-VSA-46"  => [ 46,  "string" ],
                "Alvarion-VSA-47"  => [ 47,  "string" ],
                "Alvarion-VSA-48"  => [ 48,  "string" ],
                "Alvarion-VSA-49"  => [ 49,  "string" ],
                "Alvarion-VSA-5"   => [ 5,   "string" ],
                "Alvarion-VSA-50"  => [ 50,  "string" ],
                "Alvarion-VSA-51"  => [ 51,  "string" ],
                "Alvarion-VSA-52"  => [ 52,  "string" ],
                "Alvarion-VSA-53"  => [ 53,  "string" ],
                "Alvarion-VSA-54"  => [ 54,  "string" ],
                "Alvarion-VSA-55"  => [ 55,  "string" ],
                "Alvarion-VSA-56"  => [ 56,  "string" ],
                "Alvarion-VSA-57"  => [ 57,  "string" ],
                "Alvarion-VSA-58"  => [ 58,  "string" ],
                "Alvarion-VSA-59"  => [ 59,  "string" ],
                "Alvarion-VSA-6"   => [ 6,   "string" ],
                "Alvarion-VSA-60"  => [ 60,  "string" ],
                "Alvarion-VSA-61"  => [ 61,  "string" ],
                "Alvarion-VSA-62"  => [ 62,  "string" ],
                "Alvarion-VSA-63"  => [ 63,  "string" ],
                "Alvarion-VSA-64"  => [ 64,  "string" ],
                "Alvarion-VSA-65"  => [ 65,  "string" ],
                "Alvarion-VSA-66"  => [ 66,  "string" ],
                "Alvarion-VSA-67"  => [ 67,  "string" ],
                "Alvarion-VSA-68"  => [ 68,  "string" ],
                "Alvarion-VSA-69"  => [ 69,  "string" ],
                "Alvarion-VSA-7"   => [ 7,   "string" ],
                "Alvarion-VSA-70"  => [ 70,  "string" ],
                "Alvarion-VSA-71"  => [ 71,  "string" ],
                "Alvarion-VSA-72"  => [ 72,  "string" ],
                "Alvarion-VSA-73"  => [ 73,  "string" ],
                "Alvarion-VSA-74"  => [ 74,  "string" ],
                "Alvarion-VSA-75"  => [ 75,  "string" ],
                "Alvarion-VSA-76"  => [ 76,  "string" ],
                "Alvarion-VSA-77"  => [ 77,  "string" ],
                "Alvarion-VSA-78"  => [ 78,  "string" ],
                "Alvarion-VSA-79"  => [ 79,  "string" ],
                "Alvarion-VSA-8"   => [ 8,   "string" ],
                "Alvarion-VSA-80"  => [ 80,  "string" ],
                "Alvarion-VSA-81"  => [ 81,  "string" ],
                "Alvarion-VSA-82"  => [ 82,  "string" ],
                "Alvarion-VSA-83"  => [ 83,  "string" ],
                "Alvarion-VSA-84"  => [ 84,  "string" ],
                "Alvarion-VSA-85"  => [ 85,  "string" ],
                "Alvarion-VSA-86"  => [ 86,  "string" ],
                "Alvarion-VSA-87"  => [ 87,  "string" ],
                "Alvarion-VSA-88"  => [ 88,  "string" ],
                "Alvarion-VSA-89"  => [ 89,  "string" ],
                "Alvarion-VSA-9"   => [ 9,   "string" ],
                "Alvarion-VSA-90"  => [ 90,  "string" ],
                "Alvarion-VSA-91"  => [ 91,  "string" ],
                "Alvarion-VSA-92"  => [ 92,  "string" ],
                "Alvarion-VSA-93"  => [ 93,  "string" ],
                "Alvarion-VSA-94"  => [ 94,  "string" ],
                "Alvarion-VSA-95"  => [ 95,  "string" ],
                "Alvarion-VSA-96"  => [ 96,  "string" ],
                "Alvarion-VSA-97"  => [ 97,  "string" ],
                "Alvarion-VSA-98"  => [ 98,  "string" ],
                "Alvarion-VSA-99"  => [ 99,  "string" ],
                "Breezecom-Attr1"  => [ 1,   "string" ],
                "Breezecom-Attr10" => [ 10,  "string" ],
                "Breezecom-Attr11" => [ 11,  "string" ],
                "Breezecom-Attr2"  => [ 2,   "string" ],
                "Breezecom-Attr3"  => [ 3,   "string" ],
                "Breezecom-Attr4"  => [ 4,   "string" ],
                "Breezecom-Attr5"  => [ 5,   "string" ],
                "Breezecom-Attr6"  => [ 6,   "string" ],
                "Breezecom-Attr7"  => [ 7,   "string" ],
                "Breezecom-Attr8"  => [ 8,   "string" ],
                "Breezecom-Attr9"  => [ 9,   "string" ],
            },
            12740 => {
                "Equallogic-Admin-Account-Type"     => [ 9, "string" ],
                "Equallogic-Admin-Email"            => [ 2, "string" ],
                "Equallogic-Admin-Full-Name"        => [ 1, "string" ],
                "Equallogic-Admin-Mobile"           => [ 4, "string" ],
                "Equallogic-Admin-Phone"            => [ 3, "string" ],
                "Equallogic-Admin-Pool-Access"      => [ 7, "string" ],
                "Equallogic-Admin-Repl-Site-Access" => [ 8, "string" ],
                "Equallogic-EQL-Admin-Privilege"    => [ 6, "integer" ],
                "Equallogic-Poll-Interval"          => [ 5, "integer" ],
            },
            12951 => {
                "Acct-Interim-Record-Number" => [ 200, "integer" ],
                "Charging-Group-ID"          => [ 207, "string" ],
                "Dynamic-Address-Flag"       => [ 203, "integer" ],
                "Local-Seq-Number"           => [ 204, "integer" ],
                "Service-Data-Container"     => [ 211, "tlv" ],
                "Service-Data-Container-Bin" => [ 210, "octets" ],
                "Time-First-Usage"           => [ 205, "date" ],
                "Time-Last-Usage"            => [ 206, "date" ],
                "UE-Info-Type"               => [ 201, "integer" ],
                "UE-Info-Value"              => [ 202, "string" ],
            },
            13209 => {
                "Aptilo-Access-Profile"         => [ 21,  "string" ],
                "Aptilo-Access-Profile-ID"      => [ 53,  "integer" ],
                "Aptilo-Ap-ID"                  => [ 13,  "integer" ],
                "Aptilo-Apc-ID"                 => [ 9,   "string" ],
                "Aptilo-Auth-Param"             => [ 50,  "integer" ],
                "Aptilo-Auth-Result"            => [ 23,  "integer" ],
                "Aptilo-Auth-Type"              => [ 42,  "integer" ],
                "Aptilo-Automatic-Service"      => [ 41,  "string" ],
                "Aptilo-Bw-Max-Down"            => [ 39,  "integer" ],
                "Aptilo-Bw-Max-Up"              => [ 37,  "integer" ],
                "Aptilo-Bw-Min-Down"            => [ 38,  "integer" ],
                "Aptilo-Bw-Min-Up"              => [ 36,  "integer" ],
                "Aptilo-Circuit-ID"             => [ 74,  "octets" ],
                "Aptilo-Debug-Option"           => [ 57,  "integer" ],
                "Aptilo-Denied-Cause"           => [ 11,  "integer" ],
                "Aptilo-Duration-Balance"       => [ 66,  "integer" ],
                "Aptilo-Duration-Quota"         => [ 27,  "integer" ],
                "Aptilo-Duration-Request"       => [ 72,  "integer" ],
                "Aptilo-Duration-Threshold"     => [ 63,  "integer" ],
                "Aptilo-Duration-Used"          => [ 69,  "integer" ],
                "Aptilo-Email"                  => [ 19,  "string" ],
                "Aptilo-Exclusive-Count"        => [ 26,  "integer" ],
                "Aptilo-First-Name"             => [ 16,  "string" ],
                "Aptilo-Gigawords-Limit"        => [ 3,   "integer" ],
                "Aptilo-Hotline-Indicator"      => [ 24,  "string" ],
                "Aptilo-Input-Gigawords-Limit"  => [ 5,   "integer" ],
                "Aptilo-Input-Octets-Limit"     => [ 4,   "integer" ],
                "Aptilo-Key-Integer-1"          => [ 251, "integer" ],
                "Aptilo-Key-Integer-2"          => [ 252, "integer" ],
                "Aptilo-Key-Integer-3"          => [ 253, "integer" ],
                "Aptilo-Key-Integer-4"          => [ 254, "integer" ],
                "Aptilo-Key-Integer-5"          => [ 255, "integer" ],
                "Aptilo-Key-IP-1"               => [ 246, "ipaddr" ],
                "Aptilo-Key-IP-2"               => [ 247, "ipaddr" ],
                "Aptilo-Key-IP-3"               => [ 248, "ipaddr" ],
                "Aptilo-Key-IP-4"               => [ 249, "ipaddr" ],
                "Aptilo-Key-IP-5"               => [ 250, "ipaddr" ],
                "Aptilo-Key-IPv6-1"             => [ 231, "ipv6addr" ],
                "Aptilo-Key-IPv6-2"             => [ 232, "ipv6addr" ],
                "Aptilo-Key-IPv6-3"             => [ 233, "ipv6addr" ],
                "Aptilo-Key-IPv6-4"             => [ 234, "ipv6addr" ],
                "Aptilo-Key-IPv6-5"             => [ 235, "ipv6addr" ],
                "Aptilo-Key-Octets-1"           => [ 236, "octets" ],
                "Aptilo-Key-Octets-2"           => [ 237, "octets" ],
                "Aptilo-Key-Octets-3"           => [ 238, "octets" ],
                "Aptilo-Key-Octets-4"           => [ 239, "octets" ],
                "Aptilo-Key-Octets-5"           => [ 240, "octets" ],
                "Aptilo-Key-String-1"           => [ 241, "string" ],
                "Aptilo-Key-String-2"           => [ 242, "string" ],
                "Aptilo-Key-String-3"           => [ 243, "string" ],
                "Aptilo-Key-String-4"           => [ 244, "string" ],
                "Aptilo-Key-String-5"           => [ 245, "string" ],
                "Aptilo-Last-Name"              => [ 17,  "string" ],
                "Aptilo-Limit-Mode"             => [ 8,   "integer" ],
                "Aptilo-Location-Name"          => [ 76,  "string" ],
                "Aptilo-NAS-Capabilities"       => [ 43,  "integer" ],
                "Aptilo-NAS-Model"              => [ 56,  "string" ],
                "Aptilo-Octets-Balance"         => [ 64,  "octets" ],
                "Aptilo-Octets-Limit"           => [ 2,   "integer" ],
                "Aptilo-Octets-Quota"           => [ 60,  "octets" ],
                "Aptilo-Octets-Request"         => [ 70,  "octets" ],
                "Aptilo-Octets-Threshold"       => [ 61,  "octets" ],
                "Aptilo-Octets-Used"            => [ 67,  "octets" ],
                "Aptilo-Opaque-Key"             => [ 10,  "string" ],
                "Aptilo-Organization"           => [ 20,  "string" ],
                "Aptilo-Output-Gigawords-Limit" => [ 7,   "integer" ],
                "Aptilo-Output-Octets-Limit"    => [ 6,   "integer" ],
                "Aptilo-Phone"                  => [ 18,  "string" ],
                "Aptilo-Prepaid-Capabilities"   => [ 59,  "octets" ],
                "Aptilo-QoS-Indicator"          => [ 73,  "string" ],
                "Aptilo-Quota-ID"               => [ 32,  "string" ],
                "Aptilo-Realm-Concurrent-Login" => [ 22,  "integer" ],
                "Aptilo-Realm-ID"               => [ 12,  "integer" ],
                "Aptilo-Remote-ID"              => [ 75,  "octets" ],
                "Aptilo-Resource-Balance"       => [ 65,  "integer" ],
                "Aptilo-Resource-Quota"         => [ 31,  "integer" ],
                "Aptilo-Resource-Request"       => [ 71,  "integer" ],
                "Aptilo-Resource-Threshold"     => [ 62,  "integer" ],
                "Aptilo-Resource-Used"          => [ 68,  "integer" ],
                "Aptilo-RX-Limit"               => [ 33,  "integer" ],
                "Aptilo-RX-Volume-Quota"        => [ 29,  "string" ],
                "Aptilo-Service"                => [ 44,  "string" ],
                "Aptilo-Service-Profile"        => [ 40,  "string" ],
                "Aptilo-Service-Profile-ID"     => [ 45,  "integer" ],
                "Aptilo-Session-Id"             => [ 58,  "string" ],
                "Aptilo-Subnet-Name"            => [ 1,   "string" ],
                "Aptilo-TRX-Limit"              => [ 35,  "integer" ],
                "Aptilo-TX-Limit"               => [ 34,  "integer" ],
                "Aptilo-TX-Volume-Quota"        => [ 30,  "string" ],
                "Aptilo-User-ID"                => [ 14,  "integer" ],
                "Aptilo-User-Type"              => [ 25,  "integer" ],
                "Aptilo-Volume-Quota"           => [ 28,  "string" ],
                "Aptilo-Zone"                   => [ 15,  "string" ],
            },
            13644 => {
                "pfSense-Bandwidth-Max-Down" => [ 2, "integer" ],
                "pfSense-Bandwidth-Max-Up"   => [ 1, "integer" ],
                "pfSense-Max-Total-Octets"   => [ 3, "integer" ],
            },
            14122 => {
                "WBA-Custom-SLA"                     => [ 17, "string" ],
                "WBA-Data-Clearing-Provider"         => [ 14, "string" ],
                "WBA-Financial-Clearing-Provider"    => [ 13, "string" ],
                "WBA-Identity-Provider"              => [ 16, "string" ],
                "WBA-Linear-Volume-Rate"             => [ 15, "octets" ],
                "WBA-Offered-Service"                => [ 12, "string" ],
                "WISPr-Bandwidth-Max-Down"           => [ 8,  "integer" ],
                "WISPr-Bandwidth-Max-Up"             => [ 7,  "integer" ],
                "WISPr-Bandwidth-Min-Down"           => [ 6,  "integer" ],
                "WISPr-Bandwidth-Min-Up"             => [ 5,  "integer" ],
                "WISPr-Billing-Class-Of-Service"     => [ 11, "string" ],
                "WISPr-Location-ID"                  => [ 1,  "string" ],
                "WISPr-Location-Name"                => [ 2,  "string" ],
                "WISPr-Logoff-URL"                   => [ 3,  "string" ],
                "WISPr-Redirection-URL"              => [ 4,  "string" ],
                "WISPr-Session-Terminate-End-Of-Day" => [ 10, "string" ],
                "WISPr-Session-Terminate-Time"       => [ 9,  "string" ],
            },
            14179 => {
                "Airespace-8021p-Tag"                       => [ 4, "integer" ],
                "Airespace-ACL-Name"                        => [ 6, "string" ],
                "Airespace-Data-Bandwidth-Average-Contract" => [ 7, "integer" ],
                "Airespace-Data-Bandwidth-Average-Contract-Upstream" =>
                  [ 13, "integer" ],
                "Airespace-Data-Bandwidth-Burst-Contract" => [ 9, "integer" ],
                "Airespace-Data-Bandwidth-Burst-Contract-Upstream" =>
                  [ 15, "integer" ],
                "Airespace-DSCP"            => [ 3,  "integer" ],
                "Airespace-Guest-Role-Name" => [ 11, "string" ],
                "Airespace-Interface-Name"  => [ 5,  "string" ],
                "Airespace-QOS-Level"       => [ 2,  "integer" ],
                "Airespace-Real-Time-Bandwidth-Average-Contract" =>
                  [ 8, "integer" ],
                "Airespace-Real-Time-Bandwidth-Average-Contract-Upstream" =>
                  [ 14, "integer" ],
                "Airespace-Real-Time-Bandwidth-Burst-Contract" =>
                  [ 10, "integer" ],
                "Airespace-Real-Time-Bandwidth-Burst-Contract-Upstream" =>
                  [ 16, "integer" ],
                "Airespace-Wlan-Id" => [ 1, "integer" ],
            },
            14436 => {
                "Quiconnect-AVPair"          => [ 1, "string" ],
                "Quiconnect-HSP-Information" => [ 3, "string" ],
                "Quiconnect-VNP-Information" => [ 2, "string" ],
            },
            14501 => {
                "Blue-Coat-Authorization" => [ 2, "integer" ],
                "Blue-Coat-Group"         => [ 1, "string" ],
            },
            14525 => {
                "Trapeze-Audit"               => [ 13, "string" ],
                "Trapeze-CoA-Username"        => [ 12, "string" ],
                "Trapeze-Encryption-Type"     => [ 3,  "string" ],
                "Trapeze-End-Date"            => [ 6,  "string" ],
                "Trapeze-Mobility-Profile"    => [ 2,  "string" ],
                "Trapeze-QoS-Profile"         => [ 10, "string" ],
                "Trapeze-Simultaneous-Logins" => [ 11, "string" ],
                "Trapeze-SSID"                => [ 5,  "string" ],
                "Trapeze-Start-Date"          => [ 7,  "string" ],
                "Trapeze-Time-Of-Day"         => [ 4,  "string" ],
                "Trapeze-URL"                 => [ 8,  "string" ],
                "Trapeze-User-Group-Name"     => [ 9,  "string" ],
                "Trapeze-VLAN-Name"           => [ 1,  "string" ],
            },
            14529 => {
                "Tropos-Average-RSSI"         => [ 13, "integer" ],
                "Tropos-Capability-Info"      => [ 23, "octets" ],
                "Tropos-Cell-Location"        => [ 28, "string" ],
                "Tropos-Cell-Name"            => [ 27, "string" ],
                "Tropos-Channel"              => [ 15, "ifid" ],
                "Tropos-Class-Mult"           => [ 26, "integer" ],
                "Tropos-Input-Cap"            => [ 24, "integer" ],
                "Tropos-Latitude"             => [ 30, "string" ],
                "Tropos-Layer2-Input-Drops"   => [ 6,  "integer" ],
                "Tropos-Layer2-Input-Frames"  => [ 4,  "integer" ],
                "Tropos-Layer2-Input-Octets"  => [ 2,  "integer" ],
                "Tropos-Layer2-Output-Frames" => [ 5,  "integer" ],
                "Tropos-Layer2-Output-Octets" => [ 3,  "integer" ],
                "Tropos-Longitude"            => [ 31, "string" ],
                "Tropos-Noise-Floor"          => [ 7,  "ifid" ],
                "Tropos-Noise-Upper-Bound"    => [ 8,  "ifid" ],
                "Tropos-Output-Cap"           => [ 25, "integer" ],
                "Tropos-Rates-Received"       => [ 19, "octets" ],
                "Tropos-Rates-Sent"           => [ 18, "octets" ],
                "Tropos-Release"              => [ 9,  "string" ],
                "Tropos-Retries-Sent"         => [ 16, "integer" ],
                "Tropos-Retry-Bits"           => [ 17, "integer" ],
                "Tropos-Routed-Time"          => [ 21, "integer" ],
                "Tropos-Routless-Since"       => [ 22, "integer" ],
                "Tropos-Secondary-IP"         => [ 11, "octets" ],
                "Tropos-Serial-Number"        => [ 29, "string" ],
                "Tropos-Terminate-Cause"      => [ 12, "integer" ],
                "Tropos-Unicast-Cipher"       => [ 1,  "integer" ],
            },
            14559 => {
                "ChilliSpot-Bandwidth-Max-Down" => [ 5,   "integer" ],
                "ChilliSpot-Bandwidth-Max-Up"   => [ 4,   "integer" ],
                "ChilliSpot-Config"             => [ 6,   "string" ],
                "ChilliSpot-Interval"           => [ 102, "integer" ],
                "ChilliSpot-Lang"               => [ 7,   "string" ],
                "ChilliSpot-MAC-Allowed"        => [ 101, "string" ],
                "ChilliSpot-Max-Input-Octets"   => [ 1,   "integer" ],
                "ChilliSpot-Max-Output-Octets"  => [ 2,   "integer" ],
                "ChilliSpot-Max-Total-Octets"   => [ 3,   "integer" ],
                "ChilliSpot-OriginalURL"        => [ 9,   "string" ],
                "ChilliSpot-UAM-Allowed"        => [ 100, "string" ],
                "ChilliSpot-Version"            => [ 8,   "string" ],
            },
            14823 => {
                "Aruba-ACL-Server-Query-Info"        => [ 45, "string" ],
                "Aruba-Admin-Device-Group"           => [ 48, "string" ],
                "Aruba-Admin-Path"                   => [ 42, "string" ],
                "Aruba-Admin-Role"                   => [ 4,  "string" ],
                "Aruba-AirGroup-Device-Type"         => [ 27, "integer" ],
                "Aruba-AirGroup-Shared-Group"        => [ 35, "string" ],
                "Aruba-AirGroup-Shared-Role"         => [ 26, "string" ],
                "Aruba-AirGroup-Shared-User"         => [ 25, "string" ],
                "Aruba-AirGroup-User-Name"           => [ 24, "string" ],
                "Aruba-AirGroup-Version"             => [ 38, "integer" ],
                "Aruba-AP-Group"                     => [ 10, "string" ],
                "Aruba-AP-IP-Address"                => [ 34, "ipaddr" ],
                "Aruba-AP-MAC-Address"               => [ 60, "string" ],
                "Aruba-AS-Credential-Hash"           => [ 30, "string" ],
                "Aruba-AS-User-Name"                 => [ 29, "string" ],
                "Aruba-Auth-Survivability"           => [ 28, "string" ],
                "Aruba-Auth-SurvMethod"              => [ 39, "integer" ],
                "Aruba-AVPair"                       => [ 67, "string" ],
                "Aruba-Calea-Server-Ip"              => [ 41, "ipaddr" ],
                "Aruba-Captive-Portal-URL"           => [ 43, "string" ],
                "Aruba-Command-String"               => [ 46, "string" ],
                "Aruba-CPPM-Role"                    => [ 23, "string" ],
                "Aruba-Device-MAC-Address"           => [ 61, "string" ],
                "Aruba-Device-Traffic-Class"         => [ 63, "integer" ],
                "Aruba-Device-Type"                  => [ 12, "string" ],
                "Aruba-DPP-AKMs"                     => [ 71, "string" ],
                "Aruba-DPP-Bootstrapping-Key-B64"    => [ 57, "string" ],
                "Aruba-DPP-Bootstrapping-Key-SHA256" => [ 55, "string" ],
                "Aruba-DPP-Bootstrapping-Net-Access-Key-SHA256" =>
                  [ 56, "string" ],
                "Aruba-DPP-Passphrase"             => [ 72, "string" ],
                "Aruba-DPP-Service-Type"           => [ 68, "integer" ],
                "Aruba-Essid-Name"                 => [ 5,  "string" ],
                "Aruba-Framed-IPv6-Address"        => [ 11, "string" ],
                "Aruba-Gateway-Zone"               => [ 54, "string" ],
                "Aruba-Location-Id"                => [ 6,  "string" ],
                "Aruba-Mdps-Device-Iccid"          => [ 17, "string" ],
                "Aruba-Mdps-Device-Imei"           => [ 16, "string" ],
                "Aruba-Mdps-Device-Name"           => [ 19, "string" ],
                "Aruba-Mdps-Device-Product"        => [ 20, "string" ],
                "Aruba-Mdps-Device-Profile"        => [ 33, "string" ],
                "Aruba-Mdps-Device-Serial"         => [ 22, "string" ],
                "Aruba-Mdps-Device-Udid"           => [ 15, "string" ],
                "Aruba-Mdps-Device-Version"        => [ 21, "string" ],
                "Aruba-Mdps-Max-Devices"           => [ 18, "integer" ],
                "Aruba-Mdps-Provisioning-Settings" => [ 32, "string" ],
                "Aruba-MMS-User-Template"          => [ 8,  "string" ],
                "Aruba-MPSK-Key-Name"              => [ 62, "string" ],
                "Aruba-MPSK-Lookup-Info"           => [ 66, "string" ],
                "Aruba-MPSK-Passphrase"            => [ 44, "octets" ],
                "Aruba-Named-User-Vlan"            => [ 9,  "string" ],
                "Aruba-NAS-Filter-Rule"            => [ 51, "string" ],
                "Aruba-Network-Profile"            => [ 47, "string" ],
                "Aruba-Network-SSO-Token"          => [ 37, "string" ],
                "Aruba-Network-Test"               => [ 65, "integer" ],
                "Aruba-No-DHCP-Fingerprint"        => [ 14, "integer" ],
                "Aruba-Poe-Allocate-By-Method"     => [ 70, "integer" ],
                "Aruba-PoE-Priority"               => [ 49, "integer" ],
                "Aruba-Port-Auth-Mode"             => [ 50, "integer" ],
                "Aruba-Port-Bounce-Host"           => [ 40, "integer" ],
                "Aruba-Port-Identifier"            => [ 7,  "string" ],
                "Aruba-Priv-Admin-User"            => [ 3,  "integer" ],
                "Aruba-PVLAN-Port-Type"            => [ 64, "integer" ],
                "Aruba-QoS-Trust-Mode"             => [ 52, "integer" ],
                "Aruba-STP-Admin-Edge-Port"        => [ 58, "integer" ],
                "Aruba-UBT-Gateway-CPPM-Role"      => [ 59, "string" ],
                "Aruba-UBT-Gateway-Role"           => [ 53, "string" ],
                "Aruba-User-Group"                 => [ 36, "string" ],
                "Aruba-User-Mgmt-Interface"        => [ 69, "string" ],
                "Aruba-User-Role"                  => [ 1,  "string" ],
                "Aruba-User-Vlan"                  => [ 2,  "integer" ],
                "Aruba-WorkSpace-App-Name"         => [ 31, "string" ],
            },
            14895 => {
                "Propel-Accelerate"            => [ 1, "integer" ],
                "Propel-Client-IP-Address"     => [ 3, "ipaddr" ],
                "Propel-Client-NAS-IP-Address" => [ 4, "ipaddr" ],
                "Propel-Client-Source-ID"      => [ 5, "integer" ],
                "Propel-Content-Filter-ID"     => [ 6, "integer" ],
                "Propel-Dialed-Digits"         => [ 2, "string" ],
            },
            14988 => {
                "Mikrotik-Address-List"           => [ 19, "string" ],
                "Mikrotik-Advertise-Interval"     => [ 13, "integer" ],
                "Mikrotik-Advertise-URL"          => [ 12, "string" ],
                "Mikrotik-Delegated-IPv6-Pool"    => [ 22, "string" ],
                "Mikrotik-DHCP-Option-Param-STR1" => [ 24, "string" ],
                "Mikrotik-DHCP-Option-Param-STR2" => [ 25, "string" ],
                "Mikrotik-DHCP-Option-ParamSTR2"  => [ 25, "string" ],
                "Mikrotik-DHCP-Option-Set"        => [ 23, "string" ],
                "Mikrotik-Group"                  => [ 3,  "string" ],
                "Mikrotik-Host-IP"                => [ 10, "ipaddr" ],
                "Mikrotik-Mark-Id"                => [ 11, "string" ],
                "Mikrotik-Rate-Limit"             => [ 8,  "string" ],
                "Mikrotik-Realm"                  => [ 9,  "string" ],
                "Mikrotik-Recv-Limit"             => [ 1,  "integer" ],
                "Mikrotik-Recv-Limit-Gigawords"   => [ 14, "integer" ],
                "Mikrotik-Switching-Filter"       => [ 30, "string" ],
                "Mikrotik-Total-Limit"            => [ 17, "integer" ],
                "Mikrotik-Total-Limit-Gigawords"  => [ 18, "integer" ],
                "Mikrotik-Wireless-Comment"       => [ 21, "string" ],
                "Mikrotik-Wireless-Enc-Algo"      => [ 6,  "integer" ],
                "Mikrotik-Wireless-Enc-Key"       => [ 7,  "string" ],
                "Mikrotik-Wireless-Forward"       => [ 4,  "integer" ],
                "Mikrotik-Wireless-Maxsignal"     => [ 29, "string" ],
                "Mikrotik-Wireless-Minsignal"     => [ 28, "string" ],
                "Mikrotik-Wireless-MPKey"         => [ 20, "string" ],
                "Mikrotik-Wireless-PSK"           => [ 16, "string" ],
                "Mikrotik-Wireless-Skip-Dot1x"    => [ 5,  "integer" ],
                "Mikrotik-Wireless-VLANID"        => [ 26, "integer" ],
                "Mikrotik-Wireless-VLANID-Type"   => [ 27, "integer" ],
                "Mikrotik-Wireless-VLANIDtype"    => [ 27, "integer" ],
                "Mikrotik-Xmit-Limit"             => [ 2,  "integer" ],
                "Mikrotik-Xmit-Limit-Gigawords"   => [ 15, "integer" ],
            },
            15004 => { "RuggedCom-Privilege-level" => [ 2, "string" ] },
            15983 => {
                "Meru-Access-Point-Id"   => [ 1, "integer" ],
                "Meru-Access-Point-Name" => [ 2, "string" ],
            },
            16108 => {
                "Garderos-Location-Name" => [ 1, "string" ],
                "Garderos-MSISDN"        => [ 3, "string" ],
                "Garderos-Proxy"         => [ 4, "string" ],
                "Garderos-Service-Name"  => [ 2, "string" ],
            },
            16313 => {
                "VNC-PPPoE-CBQ-RX"          => [ 1,  "integer" ],
                "VNC-PPPoE-CBQ-RX-Fallback" => [ 3,  "integer" ],
                "VNC-PPPoE-CBQ-TX"          => [ 2,  "integer" ],
                "VNC-PPPoE-CBQ-TX-Fallback" => [ 4,  "integer" ],
                "VNC-Splash"                => [ 10, "integer" ],
            },
            16445 => {
                "Kineto-Billing-Rate-Indicator"     => [ 65286, "octets" ],
                "Kineto-Hand-In-Control-Flag"       => [ 65284, "octets" ],
                "Kineto-Hand-Out-Control-Flag"      => [ 65285, "octets" ],
                "Kineto-Location-Key"               => [ 65282, "octets" ],
                "Kineto-Service-Area-Code"          => [ 65289, "octets" ],
                "Kineto-UMA-3G-Cell-Identity"       => [ 73,    "octets" ],
                "Kineto-UMA-AP-Location"            => [ 42,    "octets" ],
                "Kineto-UMA-AP-Radio-Identity"      => [ 3,     "octets" ],
                "Kineto-UMA-AP-Service-Name"        => [ 61,    "octets" ],
                "Kineto-UMA-Cell-Identity"          => [ 4,     "octets" ],
                "Kineto-UMA-Classmark"              => [ 7,     "octets" ],
                "Kineto-UMA-Coverage-Indicator"     => [ 6,     "octets" ],
                "Kineto-UMA-Discovery-Reject-Cause" => [ 12,    "octets" ],
                "Kineto-UMA-Geographical-Location"  => [ 8,     "octets" ],
                "Kineto-UMA-Location-Area-Identification" => [ 5,  "octets" ],
                "Kineto-UMA-Location-Blacklist-Indicator" => [ 58, "octets" ],
                "Kineto-UMA-Location-Status"              => [ 44, "octets" ],
                "Kineto-UMA-MS-Radio-Identity"            => [ 96, "octets" ],
                "Kineto-UMA-Redirection-Counter"          => [ 11, "octets" ],
                "Kineto-UMA-Register-Reject-Cause"        => [ 21, "octets" ],
                "Kineto-UMA-Registration-Indicators"      => [ 68, "octets" ],
                "Kineto-UMA-Release-Indicator"            => [ 2,  "octets" ],
                "Kineto-UMA-Required-UMA-Services"        => [ 71, "octets" ],
                "Kineto-UMA-Routing-Area-Code"            => [ 41, "octets" ],
                "Kineto-UMA-RRC-State"                    => [ 17, "octets" ],
                "Kineto-UMA-Service-Zone-Information"     => [ 62, "octets" ],
                "Kineto-UMA-Serving-UNC-Table-Indicator"  => [ 67, "octets" ],
                "Kineto-UMA-SGW-FQDN"                     => [ 10, "octets" ],
                "Kineto-UMA-SGW-IP-Address"               => [ 9,  "octets" ],
                "Kineto-UMA-UMA-PLMN-List"                => [ 69, "octets" ],
                "Kineto-UMA-UNC-FQDN"                     => [ 98, "octets" ],
                "Kineto-UMA-UNC-IP-Address"               => [ 97, "octets" ],
                "Kineto-UMA-Utran-Cell-Identity"          => [ 49, "octets" ],
                "Kineto-UP-Client-Remote-Address"    => [ 65283, "octets" ],
                "Kineto-URR-Transaction-Type"        => [ 65281, "octets" ],
                "KW-HNB-CELL-ACCESS-MODE"            => [ 65428, "octets" ],
                "KW-HNB-CELL-ID"                     => [ 65418, "string" ],
                "KW-HNB-CSG-ID"                      => [ 65422, "string" ],
                "KW-HNB-IDENTITY"                    => [ 65410, "string" ],
                "KW-HNB-LAC"                         => [ 65419, "string" ],
                "KW-HNB-LOC-INFO-ALTITUDE-Direction" => [ 65415, "integer" ],
                "KW-HNB-LOC-INFO-GEO-COORDINATES"    => [ 65414, "integer" ],
                "KW-HNB-LOC-INFO-GERAN-CELL-ID"      => [ 65412, "string" ],
                "KW-HNB-LOC-INFO-IP-ADDRESS"         => [ 65416, "string" ],
                "KW-HNB-LOC-INFO-MACRO-COVERAGE-IND" => [ 65411, "integer" ],
                "KW-HNB-LOC-INFO-UTRAN-CELL-ID"      => [ 65413, "string" ],
                "KW-HNB-LOCATION-AREA-IND"           => [ 65424, "octets" ],
                "KW-HNB-LOCATION-BLACKLIST-IND"      => [ 65427, "octets" ],
                "KW-HNB-PLMN-ID"                     => [ 65417, "string" ],
                "KW-HNB-RAC"                         => [ 65420, "string" ],
                "KW-HNB-REMOTE-ADDRESS"              => [ 65409, "ipaddr" ],
                "KW-HNB-SAC"                         => [ 65421, "string" ],
                "KW-IUH-BILLING-RATE-INDICATOR"      => [ 65425, "octets" ],
                "KW-IUH-MESSAGE-TYPE"                => [ 65408, "string" ],
                "KW-REGISTRATION-REJECT-CAUSE"       => [ 65426, "octets" ],
                "KW-UE-Capabilities"                 => [ 65423, "integer" ],
                "KW-UE-MEMBERSHIP-STATUS"            => [ 65429, "octets" ],
            },
            16459 => {
                "Epygi-AccessType"               => [ 153, "string" ],
                "Epygi-AVPair"                   => [ 1,   "string" ],
                "Epygi-CallDisconnectReason"     => [ 196, "integer" ],
                "Epygi-CalledPartyNumber"        => [ 182, "string" ],
                "Epygi-CallInfo"                 => [ 154, "string" ],
                "Epygi-CallingPartyNumber"       => [ 181, "string" ],
                "Epygi-CallRedirectReason"       => [ 195, "integer" ],
                "Epygi-CallType"                 => [ 172, "integer" ],
                "Epygi-DateTimeConnect"          => [ 184, "integer" ],
                "Epygi-DateTimeDisconnect"       => [ 185, "integer" ],
                "Epygi-DateTimeOrigination"      => [ 183, "integer" ],
                "Epygi-DestIpAddr"               => [ 178, "integer" ],
                "Epygi-DestIpPort"               => [ 180, "integer" ],
                "Epygi-DeviceName"               => [ 173, "string" ],
                "Epygi-Duration"                 => [ 186, "integer" ],
                "Epygi-FiadID"                   => [ 151, "string" ],
                "Epygi-h323-billing-model"       => [ 109, "string" ],
                "Epygi-h323-call-origin"         => [ 26,  "string" ],
                "Epygi-h323-call-type"           => [ 27,  "string" ],
                "Epygi-h323-conf-id"             => [ 24,  "string" ],
                "Epygi-h323-connect-time"        => [ 28,  "string" ],
                "Epygi-h323-credit-amount"       => [ 101, "string" ],
                "Epygi-h323-credit-time"         => [ 102, "string" ],
                "Epygi-h323-currency"            => [ 110, "string" ],
                "Epygi-h323-disconnect-cause"    => [ 30,  "string" ],
                "Epygi-h323-disconnect-time"     => [ 29,  "string" ],
                "Epygi-h323-gw-id"               => [ 33,  "string" ],
                "Epygi-h323-incoming-conf-id"    => [ 35,  "string" ],
                "Epygi-h323-preferred-lang"      => [ 107, "string" ],
                "Epygi-h323-prompt-id"           => [ 104, "string" ],
                "Epygi-h323-redirect-ip-address" => [ 108, "string" ],
                "Epygi-h323-redirect-number"     => [ 106, "string" ],
                "Epygi-h323-remote-address"      => [ 23,  "string" ],
                "Epygi-h323-return-code"         => [ 103, "string" ],
                "Epygi-h323-setup-time"          => [ 25,  "string" ],
                "Epygi-h323-time-and-day"        => [ 105, "string" ],
                "Epygi-h323-voice-quality"       => [ 31,  "string" ],
                "Epygi-InDestRTP_IP"             => [ 190, "integer" ],
                "Epygi-InDestRTP_port"           => [ 194, "integer" ],
                "Epygi-InRTP_Jitter"             => [ 207, "integer" ],
                "Epygi-InRTP_Latency"            => [ 208, "integer" ],
                "Epygi-InRTP_Octets"             => [ 204, "integer" ],
                "Epygi-InRTP_Packets"            => [ 203, "integer" ],
                "Epygi-InRTP_PacketsDupl"        => [ 206, "integer" ],
                "Epygi-InRTP_PacketSize"         => [ 202, "integer" ],
                "Epygi-InRTP_PacketsLost"        => [ 205, "integer" ],
                "Epygi-InRTP_Payload"            => [ 201, "integer" ],
                "Epygi-InSourceRTP_IP"           => [ 189, "integer" ],
                "Epygi-InSourceRTP_port"         => [ 193, "integer" ],
                "Epygi-InterfaceName"            => [ 174, "integer" ],
                "Epygi-InterfaceNumber"          => [ 175, "integer" ],
                "Epygi-NAS-Port"                 => [ 2,   "string" ],
                "Epygi-OrigCallID"               => [ 170, "string" ],
                "Epygi-OrigIpAddr"               => [ 177, "integer" ],
                "Epygi-OrigIpPort"               => [ 179, "integer" ],
                "Epygi-OutDestRTP_IP"            => [ 188, "integer" ],
                "Epygi-OutDestRTP_port"          => [ 192, "integer" ],
                "Epygi-OutRTP_Octets"            => [ 200, "integer" ],
                "Epygi-OutRTP_Packets"           => [ 199, "integer" ],
                "Epygi-OutRTP_PacketSize"        => [ 198, "integer" ],
                "Epygi-OutRTP_Payload"           => [ 197, "integer" ],
                "Epygi-OutSourceRTP_IP"          => [ 187, "integer" ],
                "Epygi-OutSourceRTP_port"        => [ 191, "integer" ],
                "Epygi-ParentCallID"             => [ 171, "string" ],
                "Epygi-PortID"                   => [ 152, "string" ],
                "Epygi-RegExpDate"               => [ 150, "string" ],
                "Epygi-TimeslotNumber"           => [ 176, "integer" ],
            },
            16787 => {
                "T-Systems-Nova-Bandwidth-Max-Down"       => [ 8,  "integer" ],
                "T-Systems-Nova-Bandwidth-Max-Up"         => [ 7,  "integer" ],
                "T-Systems-Nova-Bandwidth-Min-Down"       => [ 6,  "integer" ],
                "T-Systems-Nova-Bandwidth-Min-Up"         => [ 5,  "integer" ],
                "T-Systems-Nova-Billing-Class-Of-Service" => [ 11, "string" ],
                "T-Systems-Nova-Location-ID"              => [ 1,  "string" ],
                "T-Systems-Nova-Location-Name"            => [ 2,  "string" ],
                "T-Systems-Nova-Logoff-URL"               => [ 3,  "string" ],
                "T-Systems-Nova-Price-Of-Service"         => [ 13, "integer" ],
                "T-Systems-Nova-Redirection-URL"          => [ 4,  "string" ],
                "T-Systems-Nova-Service-Name"             => [ 12, "string" ],
                "T-Systems-Nova-Session-Terminate-EoD"    => [ 10, "integer" ],
                "T-Systems-Nova-Session-Terminate-Time"   => [ 9,  "integer" ],
                "T-Systems-Nova-UnknownAVP"               => [ 15, "string" ],
                "T-Systems-Nova-Visiting-Provider-Code"   => [ 14, "string" ],
            },
            16924 => {
                "Sky-Wifi-AP-ID"                => [ 1, "integer" ],
                "Sky-Wifi-Billing-Class"        => [ 4, "octets" ],
                "Sky-Wifi-Credentials"          => [ 6, "string" ],
                "Sky-Wifi-Filter-Profile"       => [ 3, "string" ],
                "Sky-Wifi-Protocol-Restriction" => [ 8, "integer" ],
                "Sky-Wifi-Provider-ID"          => [ 5, "integer" ],
                "Sky-Wifi-Replicated-Packet"    => [ 7, "string" ],
                "Sky-Wifi-Service-ID"           => [ 2, "integer" ],
            },
            17163 => { "Riverbed-Local-User" => [ 1, "string" ] },
            17713 => {
                "Cambium-Acct-Class-Name"               => [ 159, "string" ],
                "Cambium-Acct-Input-Octets"             => [ 159, "integer" ],
                "Cambium-Acct-Input-Packets"            => [ 159, "integer" ],
                "Cambium-Acct-Output-Octets"            => [ 159, "integer" ],
                "Cambium-Acct-Output-Packets"           => [ 159, "integer" ],
                "Cambium-Auth-Role"                     => [ 1,   "integer" ],
                "Cambium-Authorize-Bytes-Left"          => [ 158, "integer64" ],
                "Cambium-Authorize-Class-Name"          => [ 158, "string" ],
                "Cambium-Authorize-Classes"             => [ 158, "tlv" ],
                "Cambium-ePMP-Data-VLAN-Id"             => [ 21,  "integer" ],
                "Cambium-ePMP-Data-VLAN-Priority"       => [ 54,  "integer" ],
                "Cambium-ePMP-Management-VLAN-Id"       => [ 22,  "integer" ],
                "Cambium-ePMP-Management-VLAN-Priority" => [ 53,  "integer" ],
                "Cambium-ePMP-Max-Burst-Downlink-Rate"  => [ 27,  "integer" ],
                "Cambium-ePMP-Max-Burst-Uplink-Rate"    => [ 26,  "integer" ],
                "Cambium-ePMP-Multicast-VLAN-Id"        => [ 57,  "integer" ],
                "Cambium-ePMP-Separate-Management-VLAN-Id" => [ 55, "integer" ],
                "Cambium-ePMP-Separate-Management-VLAN-Priority" =>
                  [ 56, "integer" ],
                "Cambium-ePMP-SM-Priority"         => [ 51,  "integer" ],
                "Cambium-ePMP-UserLevel"           => [ 50,  "integer" ],
                "Cambium-ePMP-VLAN-Mapping"        => [ 58,  "integer" ],
                "Cambium-ePMP-VLAN-Membersip-Set"  => [ 52,  "integer" ],
                "Cambium-Traffic-Classes-Acct"     => [ 159, "tlv" ],
                "Cambium-Traffic-Quota-Limit-Down" => [ 152, "integer" ],
                "Cambium-Traffic-Quota-Limit-Down-Gigwords" =>
                  [ 154, "integer" ],
                "Cambium-Traffic-Quota-Limit-Total" => [ 155, "integer" ],
                "Cambium-Traffic-Quota-Limit-Total-Gigwords" =>
                  [ 156, "integer" ],
                "Cambium-Traffic-Quota-Limit-Up"          => [ 151, "integer" ],
                "Cambium-Traffic-Quota-Limit-Up-Gigwords" => [ 153, "integer" ],
                "Cambium-VLAN-Pool-Id"                    => [ 157, "string" ],
                "Cambium-Walled-Garden-State"             => [ 160, "integer" ],
            },
            18022 => {
                "Covaro-Inhibit-Dbchg"   => [ 5, "integer" ],
                "Covaro-Inhibit-Message" => [ 4, "integer" ],
                "Covaro-Inhibit-Pmrept"  => [ 6, "integer" ],
                "Covaro-Max-Sessions"    => [ 2, "integer" ],
                "Covaro-Session-Timeout" => [ 3, "integer" ],
                "Covaro-User-Privilege"  => [ 1, "integer" ],
            },
            18681 => {
                "TP-Access-Class-Id"                => [ 9,  "string" ],
                "TP-Access-Group"                   => [ 26, "string" ],
                "TP-Access-Rule"                    => [ 25, "string" ],
                "TP-Auth-Reply"                     => [ 8,  "integer" ],
                "TP-CAPWAP-Boot-Version"            => [ 58, "string" ],
                "TP-CAPWAP-GPS-Altitude"            => [ 53, "string" ],
                "TP-CAPWAP-GPS-Hdop"                => [ 54, "string" ],
                "TP-CAPWAP-GPS-Latitude"            => [ 51, "string" ],
                "TP-CAPWAP-GPS-Longitude"           => [ 52, "string" ],
                "TP-CAPWAP-GPS-Timestamp"           => [ 55, "string" ],
                "TP-CAPWAP-Hardware-Version"        => [ 56, "string" ],
                "TP-CAPWAP-Max-WIFI-Clients"        => [ 49, "integer" ],
                "TP-CAPWAP-Other-Software-Version"  => [ 59, "string" ],
                "TP-CAPWAP-POWER-SAVE-BUSY-TIMEOUT" => [ 47, "integer" ],
                "TP-CAPWAP-POWER-SAVE-IDLE-TIMEOUT" => [ 46, "integer" ],
                "TP-CAPWAP-Radio-Id"                => [ 36, "integer" ],
                "TP-CAPWAP-Session-Id"              => [ 35, "octets" ],
                "TP-CAPWAP-Software-Version"        => [ 57, "string" ],
                "TP-CAPWAP-SSID"                    => [ 48, "string" ],
                "TP-CAPWAP-Timestamp"               => [ 33, "integer" ],
                "TP-CAPWAP-Walled-Garden"           => [ 50, "string" ],
                "TP-CAPWAP-WTP-Version"             => [ 34, "string" ],
                "TP-CAPWAP-WWAN-Cell-Id"            => [ 45, "integer" ],
                "TP-CAPWAP-WWAN-CREG"               => [ 40, "integer" ],
                "TP-CAPWAP-WWAN-Id"                 => [ 37, "integer" ],
                "TP-CAPWAP-WWAN-LAC"                => [ 41, "integer" ],
                "TP-CAPWAP-WWAN-Latency"            => [ 42, "integer" ],
                "TP-CAPWAP-WWAN-MCC"                => [ 43, "integer" ],
                "TP-CAPWAP-WWAN-MNC"                => [ 44, "integer" ],
                "TP-CAPWAP-WWAN-RAT"                => [ 38, "integer" ],
                "TP-CAPWAP-WWAN-RSSi"               => [ 39, "integer" ],
                "TP-DHCP-Client-Id"                 => [ 14, "string" ],
                "TP-DHCP-Parameter-Request-List"    => [ 12, "string" ],
                "TP-DHCP-Request-Option-List"       => [ 11, "string" ],
                "TP-DHCP-Vendor-Class-Id"           => [ 13, "string" ],
                "TP-ENC-IV"                         => [ 5,  "string" ],
                "TP-Exit-Access-Class-Id"           => [ 24, "string" ],
                "TP-Firmware-Variant"               => [ 2,  "string" ],
                "TP-Firmware-Version"               => [ 3,  "string" ],
                "TP-Gateway-Config"                 => [ 4,  "string" ],
                "TP-Gateway-Version"                => [ 1,  "string" ],
                "TP-Host-Name"                      => [ 10, "string" ],
                "TP-Keep-Alive-Timeout"             => [ 30, "integer" ],
                "TP-Location-Id"                    => [ 15, "string" ],
                "TP-Max-Input-Octets"               => [ 21, "integer64" ],
                "TP-Max-Output-Octets"              => [ 22, "integer64" ],
                "TP-Max-Total-Octets"               => [ 23, "integer64" ],
                "TP-Monitor-Id"                     => [ 18, "string" ],
                "TP-Monitor-Session-Id"             => [ 20, "integer" ],
                "TP-NAT-IP-Address"                 => [ 16, "ipaddr" ],
                "TP-NAT-Pool-Id"                    => [ 27, "string" ],
                "TP-NAT-Port-End"                   => [ 29, "integer" ],
                "TP-NAT-Port-Start"                 => [ 28, "integer" ],
                "TP-Password"                       => [ 6,  "string" ],
                "TP-Related-Session-Id"             => [ 19, "string" ],
                "TP-TLS-Auth-Type"                  => [ 31, "integer" ],
                "TP-TLS-Pre-Shared-Key"             => [ 32, "string" ],
                "TP-User-Agent"                     => [ 7,  "string" ],
                "TP-Zone-Id"                        => [ 17, "string" ],
            },
            19220 => {
                "Local-Web-Acct-Duration"             => [ 211, "integer" ],
                "Local-Web-Acct-Interim-Rx-Bytes"     => [ 213, "integer" ],
                "Local-Web-Acct-Interim-Rx-Gigawords" => [ 215, "integer" ],
                "Local-Web-Acct-Interim-Rx-Mgmt"      => [ 217, "integer" ],
                "Local-Web-Acct-Interim-Tx-Bytes"     => [ 212, "integer" ],
                "Local-Web-Acct-Interim-Tx-Gigawords" => [ 214, "integer" ],
                "Local-Web-Acct-Interim-Tx-Mgmt"      => [ 216, "integer" ],
                "Local-Web-Acct-Rx-Mgmt"              => [ 231, "integer" ],
                "Local-Web-Acct-Time"                 => [ 210, "integer" ],
                "Local-Web-Acct-Tx-Mgmt"              => [ 230, "integer" ],
                "Local-Web-Border-Router"             => [ 193, "string" ],
                "Local-Web-Client-Ip"                 => [ 192, "string" ],
                "Local-Web-Reauth-Counter"            => [ 240, "integer" ],
                "Local-Web-Rx-Limit"                  => [ 201, "integer" ],
                "Local-Web-Tx-Limit"                  => [ 200, "integer" ],
            },
            19382 => {
                "Manzara-ECP-Session-Key"   => [ 9,  "octets" ],
                "Manzara-Full-Login-String" => [ 6,  "string" ],
                "Manzara-Map-Error"         => [ 13, "string" ],
                "Manzara-Map-Key"           => [ 11, "string" ],
                "Manzara-Map-Name"          => [ 10, "string" ],
                "Manzara-Map-Value"         => [ 12, "string" ],
                "Manzara-PPP-Addr-String"   => [ 5,  "string" ],
                "Manzara-Service-Type"      => [ 14, "string" ],
                "Manzara-Tariff-Type"       => [ 8,  "integer" ],
                "Manzara-Tariff-Units"      => [ 7,  "integer" ],
                "Manzara-User-GID"          => [ 2,  "integer" ],
                "Manzara-User-Home"         => [ 3,  "string" ],
                "Manzara-User-Shell"        => [ 4,  "string" ],
                "Manzara-User-UID"          => [ 1,  "integer" ],
            },
            21074 => {
                "Purewave-Client-Profile"    => [ 1, "integer" ],
                "Purewave-CS-Type"           => [ 2, "integer" ],
                "Purewave-IP-Address"        => [ 5, "ipaddr" ],
                "Purewave-IP-Netmask"        => [ 6, "ipaddr" ],
                "Purewave-Max-Downlink-Rate" => [ 3, "integer" ],
                "Purewave-Max-Uplink-Rate"   => [ 4, "integer" ],
                "Purewave-Service-Enable"    => [ 7, "integer" ],
            },
            21274 => {
                "Camiant-MI-role"  => [ 1, "string" ],
                "Camiant-MI-scope" => [ 3, "string" ],
                "Camiant-SUI-role" => [ 2, "integer" ],
            },
            22197 => {
                "SoftBank-BB-Unit-HW-Revision"       => [ 4,   "string" ],
                "SoftBank-BB-Unit-MAC"               => [ 1,   "string" ],
                "SoftBank-BB-Unit-Manufacturer"      => [ 2,   "string" ],
                "SoftBank-BB-Unit-Model"             => [ 3,   "string" ],
                "SoftBank-DNS-IPv6-Primary"          => [ 198, "ipv6addr" ],
                "SoftBank-DNS-IPv6-Secondary"        => [ 199, "ipv6addr" ],
                "SoftBank-IPv4-Tunnel-Endpoint"      => [ 207, "ipv6addr" ],
                "SoftBank-IPv4-Tunnel-Local-Address" => [ 204, "ipaddr" ],
                "SoftBank-RouteInfo-Server"          => [ 215, "string" ],
                "SoftBank-SNTP-Server"               => [ 203, "ipv6addr" ],
                "SoftBank-Syslog-Server"             => [ 201, "ipv6addr" ],
                "SoftBank-TFTP-Config-File"          => [ 186, "string" ],
                "SoftBank-TFTP-Config-Server"        => [ 185, "ipaddr" ],
            },
            22472 => {
                "BW-Area-Code"         => [ 18, "integer" ],
                "BW-Category"          => [ 30, "string" ],
                "BW-City-Name"         => [ 17, "string" ],
                "BW-Class"             => [ 10, "string" ],
                "BW-e164-Country-Code" => [ 15, "string" ],
                "BW-ISO-Country-Code"  => [ 14, "string" ],
                "BW-Operator-Name"     => [ 37, "string" ],
                "BW-Service-Type"      => [ 9,  "string" ],
                "BW-State-Name"        => [ 16, "string" ],
                "BW-User-Group"        => [ 27, "string" ],
                "BW-User-Name"         => [ 33, "string" ],
                "BW-User-Password"     => [ 34, "string" ],
                "BW-User-Prefix"       => [ 35, "string" ],
                "BW-User-Realm"        => [ 36, "string" ],
                "BW-User-Role"         => [ 32, "string" ],
                "BW-Venue-Description" => [ 11, "string" ],
                "BW-Venue-Id"          => [ 7,  "string" ],
                "BW-Venue-Name"        => [ 29, "string" ],
                "BW-Venue-Port-Type"   => [ 13, "string" ],
                "BW-Venue-Price-Type"  => [ 12, "string" ],
                "BW-Venue-TZ"          => [ 8,  "string" ],
                "CL-APDB-Version"      => [ 24, "string" ],
                "CL-Brand"             => [ 19, "string" ],
                "CL-Method-Version"    => [ 22, "string" ],
                "CL-Reg-Number"        => [ 21, "string" ],
                "CL-Software-Version"  => [ 20, "string" ],
                "CL-SSC"               => [ 26, "string" ],
                "CL-Token-Version"     => [ 23, "string" ],
                "CL-User-Agent"        => [ 25, "string" ],
            },
            22736 => {
                "Asterisk-Acc-Code"    => [ 101, "string" ],
                "Asterisk-AMA-Flags"   => [ 116, "string" ],
                "Asterisk-Answer-Time" => [ 111, "string" ],
                "Asterisk-Bill-Sec"    => [ 114, "integer" ],
                "Asterisk-Chan"        => [ 106, "string" ],
                "Asterisk-Clid"        => [ 105, "string" ],
                "Asterisk-Disposition" => [ 115, "string" ],
                "Asterisk-Dst"         => [ 103, "string" ],
                "Asterisk-Dst-Chan"    => [ 107, "string" ],
                "Asterisk-Dst-Ctx"     => [ 104, "string" ],
                "Asterisk-Duration"    => [ 113, "integer" ],
                "Asterisk-End-Time"    => [ 112, "string" ],
                "Asterisk-Last-App"    => [ 108, "string" ],
                "Asterisk-Last-Data"   => [ 109, "string" ],
                "Asterisk-Src"         => [ 102, "string" ],
                "Asterisk-Start-Time"  => [ 110, "string" ],
                "Asterisk-Unique-ID"   => [ 117, "string" ],
                "Asterisk-User-Field"  => [ 118, "string" ],
            },
            23782 => {
                "ASN-Firewall-Available"    => [ 110, "integer" ],
                "ASN-Firewall-Block-Ping"   => [ 107, "integer" ],
                "ASN-Firewall-Open"         => [ 106, "string" ],
                "ASN-Firewall-State"        => [ 105, "integer" ],
                "ASN-IP-Pool-Name"          => [ 1,   "string" ],
                "ASN-IP-Redirect"           => [ 109, "string" ],
                "ASN-Kbps-Down"             => [ 100, "integer" ],
                "ASN-Kbps-Down-Localmedia"  => [ 112, "integer" ],
                "ASN-Kbps-Up"               => [ 101, "integer" ],
                "ASN-Pps-Down"              => [ 102, "integer" ],
                "ASN-Pps-Up"                => [ 103, "integer" ],
                "ASN-QoS-Available"         => [ 111, "integer" ],
                "ASN-QoS-State"             => [ 108, "integer" ],
                "ASN-TCP-Connlimit"         => [ 104, "integer" ],
                "ASN-Webfilter-Destination" => [ 115, "string" ],
                "ASN-Webfilter-Domain"      => [ 116, "string" ],
                "ASN-Webfilter-Mode"        => [ 113, "integer" ],
                "ASN-Webfilter-Redirect"    => [ 114, "string" ],
            },
            24023 => {
                "AM-ACK-HTMLFile"            => [ 6,  "string" ],
                "AM-Bandwidth-Pool"          => [ 8,  "string" ],
                "AM-Bandwidth-Pool-Max-Down" => [ 10, "integer" ],
                "AM-Bandwidth-Pool-Max-Up"   => [ 9,  "integer" ],
                "AM-Disconnect-Access"       => [ 12, "integer" ],
                "AM-HTTP-Proxy-Port"         => [ 5,  "integer" ],
                "AM-Interrupt-HTMLFile"      => [ 1,  "string" ],
                "AM-Interrupt-Interval"      => [ 2,  "integer" ],
                "AM-Interrupt-Timeout"       => [ 3,  "integer" ],
                "AM-Mirroring"               => [ 11, "integer" ],
                "AM-NAK-HTMLFile"            => [ 7,  "string" ],
                "AM-Status-HTMLFile"         => [ 4,  "string" ],
            },
            24757 => {
                "WiMAX-802.1p"                            => [ 28,  "octets" ],
                "WiMAX-AAA-Session-Id"                    => [ 4,   "octets" ],
                "WiMAX-Accounting-Capabilities"           => [ 1,   "byte" ],
                "WiMAX-Acct-Input-Packets-Gigaword"       => [ 48,  "integer" ],
                "WiMAX-Acct-Output-Packets-Gigaword"      => [ 49,  "integer" ],
                "WiMAX-Activation-Trigger"                => [ 28,  "byte" ],
                "WiMAX-Active-Time-Duration"              => [ 39,  "integer" ],
                "WiMAX-AE-Command-Code"                   => [ 143, "byte" ],
                "WiMAX-Age-Of-Location-Information"       => [ 156, "integer" ],
                "WiMAX-ASN-Ethernet-Service-Capabilities" => [ 1,   "byte" ],
                "WiMAX-ASN-IP-Service-Capabilities"       => [ 1,   "byte" ],
                "WiMAX-Authentication-Info"               => [ 145, "tlv" ],
                "WiMAX-Authorized-Anchor-Locations"       => [ 1,   "byte" ],
                "WiMAX-Authorized-Ethernet-Services"      => [ 1,   "byte" ],
                "WiMAX-Authorized-IP-Services"            => [ 1,   "byte" ],
                "WiMAX-Available-In-Client"               => [ 35,  "integer" ],
                "WiMAX-Beginning-Of-Session"              => [ 22,  "integer" ],
                "WiMAX-Blu-Coa-IPv6"                    => [ 51,  "ipv6addr" ],
                "WiMAX-BS-Id"                           => [ 46,  "octets" ],
                "WiMAX-BS-Location"                     => [ 88,  "octets" ],
                "WiMAX-Cancellation-Type"               => [ 155, "byte" ],
                "WiMAX-Capability"                      => [ 1,   "tlv" ],
                "WiMAX-Check-Balance-Result"            => [ 37,  "byte" ],
                "WiMAX-Classifer-Direction"             => [ 28,  "byte" ],
                "WiMAX-Classifer-Priority"              => [ 28,  "integer" ],
                "WiMAX-Classifer-Protocol"              => [ 28,  "integer" ],
                "WiMAX-Classifier"                      => [ 28,  "tlv" ],
                "WiMAX-ClassifierID"                    => [ 28,  "integer" ],
                "WiMAX-Control-Octets-In"               => [ 32,  "integer" ],
                "WiMAX-Control-Octets-Out"              => [ 34,  "integer" ],
                "WiMAX-Control-Packets-In"              => [ 31,  "integer" ],
                "WiMAX-Control-Packets-Out"             => [ 33,  "integer" ],
                "WiMAX-Cost-Information-AVP"            => [ 37,  "octets" ],
                "WiMAX-Count-Type"                      => [ 59,  "byte" ],
                "WiMAX-Current-Location-Retrieved"      => [ 156, "byte" ],
                "WiMAX-Destination-Assigned"            => [ 28,  "byte" ],
                "WiMAX-Destination-Inverted"            => [ 28,  "byte" ],
                "WiMAX-Destination-IPAddress"           => [ 28,  "ipaddr" ],
                "WiMAX-Destination-IPAddressRange"      => [ 28,  "octets" ],
                "WiMAX-Destination-Port"                => [ 28,  "short" ],
                "WiMAX-Destination-Port-Range"          => [ 28,  "integer" ],
                "WiMAX-Destination-Specification"       => [ 28,  "tlv" ],
                "WiMAX-Device-Authentication-Indicator" => [ 2,   "byte" ],
                "WiMAX-DGW-IPv4-addr"                   => [ 29,  "ipaddr" ],
                "WiMAX-DHCP-Msg-Server-IP"              => [ 43,  "ipaddr" ],
                "WiMAX-DHCP-Option"                     => [ 29,  "tlv" ],
                "WiMAX-DHCP-Option-Container"           => [ 29,  "string" ],
                "WiMAX-DHCP-RK"                         => [ 40,  "octets" ],
                "WiMAX-DHCP-RK-Key-Id"                  => [ 41,  "integer" ],
                "WiMAX-DHCP-RK-Lifetime"                => [ 42,  "integer" ],
                "WiMAX-Direction"                       => [ 28,  "byte" ],
                "WiMAX-DM-Action-Code"                  => [ 60,  "integer" ],
                "WiMAX-Downlink-Classifier"             => [ 28,  "string" ],
                "WiMAX-Downlink-Flow-Description"       => [ 62,  "string" ],
                "WiMAX-Downlink-Granted-QoS"            => [ 63,  "tlv" ],
                "WiMAX-Downlink-QOS-Id"                 => [ 28,  "byte" ],
                "WiMAX-Duration-Quota"                  => [ 37,  "integer" ],
                "WiMAX-Duration-Threshold"              => [ 37,  "integer" ],
                "WiMAX-E-UTRAN-Cell-Global-Identity"    => [ 156, "octets" ],
                "WiMAX-E-UTRAN-Vector"                  => [ 145, "tlv" ],
                "WiMAX-E-UTRAN-Vector-AUTN"             => [ 145, "octets" ],
                "WiMAX-E-UTRAN-Vector-Item-Number"      => [ 145, "integer" ],
                "WiMAX-E-UTRAN-Vector-KASME"            => [ 145, "octets" ],
                "WiMAX-E-UTRAN-Vector-RAND"             => [ 145, "octets" ],
                "WiMAX-E-UTRAN-Vector-XRES"             => [ 145, "octets" ],
                "WiMAX-EPS-Location-Information"        => [ 156, "tlv" ],
                "WiMAX-FA-RK-Key"                       => [ 14,  "octets" ],
                "WiMAX-FA-RK-SPI"                       => [ 61,  "integer" ],
                "WiMAX-Flow-Descriptor-v2"              => [ 83,  "tlv" ],
                "WiMAX-Geodetic-Information"            => [ 156, "octets" ],
                "WiMAX-Geographical-Information"        => [ 156, "octets" ],
                "WiMAX-Global-Service-Class-Name"       => [ 29,  "string" ],
                "WiMAX-GMT-Timezone-offset"             => [ 3,   "signed" ],
                "WiMAX-HA-RK-Key"                       => [ 15,  "octets" ],
                "WiMAX-HA-RK-Key-Requested"             => [ 58,  "integer" ],
                "WiMAX-HA-RK-Lifetime"                  => [ 17,  "integer" ],
                "WiMAX-HA-RK-SPI"                       => [ 16,  "integer" ],
                "WiMAX-hDHCP-DHCP-RK"                   => [ 86,  "string" ],
                "WiMAX-hDHCP-DHCP-RK-Key-Id"            => [ 86,  "integer" ],
                "WiMAX-hDHCP-DHCP-RK-Lifetime"          => [ 86,  "integer" ],
                "WiMAX-hDHCP-DHCPv4-Address"            => [ 86,  "ipaddr" ],
                "WiMAX-hDHCP-DHCPv6-Address"            => [ 86,  "ipv6addr" ],
                "WiMAX-hDHCP-Server-Parameters"         => [ 86,  "tlv" ],
                "WiMAX-hHA-IP-MIP4"                     => [ 6,   "ipaddr" ],
                "WiMAX-hHA-IP-MIP6"                     => [ 7,   "ipv6addr" ],
                "WiMAX-hLMA-IPv4-PMIP6"                 => [ 128, "ipaddr" ],
                "WiMAX-hLMA-IPv6-PMIP6"                 => [ 127, "ipv6addr" ],
                "WiMAX-Home-HNP-PMIP6"                 => [ 133, "ipv6prefix" ],
                "WiMAX-Home-Interface-Id-PMIP6"        => [ 134, "ifid" ],
                "WiMAX-Home-IPv4-HoA-PMIP6"            => [ 135, "ipaddr" ],
                "WiMAX-Hotline-Indicator"              => [ 24,  "string" ],
                "WiMAX-Hotline-Profile-Id"             => [ 53,  "string" ],
                "WiMAX-Hotline-Session-Timer"          => [ 56,  "integer" ],
                "WiMAX-Hotlining-Capabilities"         => [ 1,   "byte" ],
                "WiMAX-HTTP-Redirection-Rule"          => [ 54,  "string" ],
                "WiMAX-Idle-Mode-Notification-Cap"     => [ 1,   "byte" ],
                "WiMAX-Idle-Mode-Transition"           => [ 44,  "byte" ],
                "WiMAX-IMEI"                           => [ 151, "string" ],
                "WiMAX-Immediate-Response-Preferred"   => [ 144, "integer" ],
                "WiMAX-IP-Redirection-Rule"            => [ 55,  "string" ],
                "WiMAX-IP-Technology"                  => [ 23,  "integer" ],
                "WiMAX-IP-TOS/DSCP-Range-and-Mask"     => [ 28,  "octets" ],
                "WiMAX-IPv4-addr"                      => [ 29,  "ipaddr" ],
                "WiMAX-IPv4-Netmask"                   => [ 29,  "ipaddr" ],
                "WiMAX-Location"                       => [ 47,  "octets" ],
                "WiMAX-Maximum-Latency"                => [ 29,  "integer" ],
                "WiMAX-Maximum-Sustained-Traffic-Rate" => [ 29,  "integer" ],
                "WiMAX-Maximum-Traffic-Burst"          => [ 29,  "integer" ],
                "WiMAX-Media-Flow-Description-SDP"     => [ 29,  "string" ],
                "WiMAX-Media-Flow-Type"                => [ 29,  "byte" ],
                "WiMAX-Minimum-Reserved-Traffic-Rate"  => [ 29,  "integer" ],
                "WiMAX-MIP-Authorization-Status"       => [ 82,  "integer" ],
                "WiMAX-MN-hHA-MIP4-Key"                => [ 10,  "octets" ],
                "WiMAX-MN-hHA-MIP4-SPI"                => [ 11,  "integer" ],
                "WiMAX-MN-hHA-MIP6-Key"                => [ 12,  "octets" ],
                "WiMAX-MN-hHA-MIP6-SPI"                => [ 13,  "integer" ],
                "WiMAX-MN-vHA-MIP4-SPI"                => [ 71,  "integer" ],
                "WiMAX-MN-vHA-MIP6-Key"                => [ 70,  "octets" ],
                "WiMAX-MN-vHA-MIP6-SPI"                => [ 72,  "integer" ],
                "WiMAX-MS-Authenticated"               => [ 90,  "byte" ],
                "WiMAX-MSK"                            => [ 5,   "octets" ],
                "WiMAX-NAP-Id"                         => [ 45,  "octets" ],
                "WiMAX-NSP-Id"                         => [ 57,  "octets" ],
                "WiMAX-Number-Of-Requested-Vectors"    => [ 144, "integer" ],
                "WiMAX-Packet-Data-Flow-Id"            => [ 28,  "short" ],
                "WiMAX-Packet-Flow-Descriptor"         => [ 28,  "tlv" ],
                "WiMAX-Packet-Flow-Descriptor-v2"      => [ 84,  "tlv" ],
                "WiMAX-PDFID"                          => [ 26,  "short" ],
                "WiMAX-PFDv2-Activation-Trigger"       => [ 84,  "byte" ],
                "WiMAX-PFDv2-Classifier"               => [ 84,  "tlv" ],
                "WiMAX-PFDv2-Classifier-Action"        => [ 84,  "byte" ],
                "WiMAX-PFDv2-Classifier-Dest-Spec"     => [ 84,  "tlv" ],
                "WiMAX-PFDv2-Classifier-Direction"     => [ 84,  "byte" ],
                "WiMAX-PFDv2-Classifier-Eth-Option"    => [ 84,  "tlv" ],
                "WiMAX-PFDv2-Classifier-Id"            => [ 84,  "byte" ],
                "WiMAX-PFDv2-Classifier-IP-ToS-DSCP"   => [ 84,  "byte" ],
                "WiMAX-PFDv2-Classifier-Priority"      => [ 84,  "byte" ],
                "WiMAX-PFDv2-Classifier-Protocol"      => [ 84,  "byte" ],
                "WiMAX-PFDv2-Classifier-Source-Spec"   => [ 84,  "tlv" ],
                "WiMAX-PFDv2-Direction"                => [ 84,  "byte" ],
                "WiMAX-PFDv2-Downlink-QoS-Id"          => [ 84,  "byte" ],
                "WiMAX-PFDv2-Eth-Priority-Range"       => [ 84,  "tlv" ],
                "WiMAX-PFDv2-Eth-Priority-Range-High"  => [ 84,  "byte" ],
                "WiMAX-PFDv2-Eth-Priority-Range-Low"   => [ 84,  "byte" ],
                "WiMAX-PFDv2-Eth-Proto-Type"           => [ 84,  "tlv" ],
                "WiMAX-PFDv2-Eth-Proto-Type-DSAP"      => [ 84,  "byte" ],
                "WiMAX-PFDv2-Eth-Proto-Type-Ethertype" => [ 84,  "short" ],
                "WiMAX-PFDv2-Eth-VLAN-Id"              => [ 84,  "tlv" ],
                "WiMAX-PFDv2-Eth-VLAN-Id-C-VID"        => [ 84,  "integer" ],
                "WiMAX-PFDv2-Eth-VLAN-Id-S-VID"        => [ 84,  "integer" ],
                "WiMAX-PFDv2-Packet-Data-Flow-Id"      => [ 84,  "short" ],
                "WiMAX-PFDv2-Paging-Preference"        => [ 84,  "byte" ],
                "WiMAX-PFDv2-Service-Data-Flow-Id"     => [ 84,  "short" ],
                "WiMAX-PFDv2-Service-Profile-Id"       => [ 84,  "integer" ],
                "WiMAX-PFDv2-Src-Assigned"             => [ 84,  "byte" ],
                "WiMAX-PFDv2-Src-Inverted"             => [ 84,  "byte" ],
                "WiMAX-PFDv2-Src-IP-Address-Range"     => [ 84,  "octets" ],
                "WiMAX-PFDv2-Src-MAC-Address"          => [ 84,  "ether" ],
                "WiMAX-PFDv2-Src-MAC-Mask"             => [ 84,  "ether" ],
                "WiMAX-PFDv2-Src-Port"                 => [ 84,  "short" ],
                "WiMAX-PFDv2-Src-Port-Range"           => [ 84,  "integer" ],
                "WiMAX-PFDv2-Transport-Type"           => [ 84,  "byte" ],
                "WiMAX-PFDv2-Uplink-QoS-Id"            => [ 84,  "byte" ],
                "WiMAX-PFDv2-VLAN-Tag-Rule-Id"         => [ 84,  "short" ],
                "WiMAX-PMIP-Authenticated-Network-Identity" => [ 78, "string" ],
                "WiMAX-PMIP6-RK-Key"             => [ 131, "octets" ],
                "WiMAX-PMIP6-RK-SPI"             => [ 132, "integer" ],
                "WiMAX-PMIP6-Service-Info"       => [ 126, "short" ],
                "WiMAX-Pool-Id"                  => [ 37,  "integer" ],
                "WiMAX-Pool-Multiplier"          => [ 37,  "integer" ],
                "WiMAX-PPAC"                     => [ 35,  "tlv" ],
                "WiMAX-PPAQ"                     => [ 37,  "tlv" ],
                "WiMAX-PPAQ-Quota-Identifier"    => [ 37,  "octets" ],
                "WiMAX-Prepaid-Indicator"        => [ 25,  "byte" ],
                "WiMAX-Prepaid-Quota-Identifier" => [ 38,  "string" ],
                "WiMAX-Prepaid-Tariff-Switching" => [ 38,  "tlv" ],
                "WiMAX-QoS-Descriptor"           => [ 29,  "tlv" ],
                "WiMAX-QoS-Id"                   => [ 29,  "byte" ],
                "WiMAX-R3-IF-Descriptor"         => [ 29,  "tlv" ],
                "WiMAX-R3-IF-ID"                 => [ 29,  "octets" ],
                "WiMAX-R3-IF-Name"               => [ 29,  "string" ],
                "WiMAX-RAT-Type"                 => [ 150, "integer" ],
                "WiMAX-Rating-Group-Id"          => [ 37,  "integer" ],
                "WiMAX-Re-synchronization-Info"  => [ 144, "octets" ],
                "WiMAX-Reduced-Resources-Code"   => [ 29,  "byte" ],
                "WiMAX-Ref-R3-IF-Name"           => [ 29,  "string" ],
                "WiMAX-Release"                  => [ 1,   "string" ],
                "WiMAX-Requested-Action"         => [ 37,  "byte" ],
                "WiMAX-Requested-EUTRAN-Authentication-Info" => [ 144, "tlv" ],
                "WiMAX-Resource-Quota"                 => [ 37,  "integer" ],
                "WiMAX-Resource-Threshold"             => [ 37,  "integer" ],
                "WiMAX-RRQ-MN-HA-Key"                  => [ 19,  "octets" ],
                "WiMAX-RRQ-MN-HA-SPI"                  => [ 20,  "integer" ],
                "WiMAX-Schedule-Type"                  => [ 29,  "byte" ],
                "WiMAX-SDFID"                          => [ 27,  "short" ],
                "WiMAX-SDU-Size"                       => [ 29,  "short" ],
                "WiMAX-Service-Class-Name"             => [ 29,  "string" ],
                "WiMAX-Service-Data-Flow-Id"           => [ 28,  "short" ],
                "WiMAX-Service-Id"                     => [ 37,  "string" ],
                "WiMAX-Service-Profile-Id"             => [ 28,  "integer" ],
                "WiMAX-Service-Selection"              => [ 166, "string" ],
                "WiMAX-Session-Continue"               => [ 21,  "integer" ],
                "WiMAX-Session-Termination-Capability" => [ 36,  "integer" ],
                "WiMAX-Software-Version"               => [ 151, "string" ],
                "WiMAX-Source-Assigned"                => [ 28,  "byte" ],
                "WiMAX-Source-Inverted"                => [ 28,  "byte" ],
                "WiMAX-Source-IPAddress"               => [ 28,  "ipaddr" ],
                "WiMAX-Source-IPAddressRange"          => [ 28,  "octets" ],
                "WiMAX-Source-Port"                    => [ 28,  "short" ],
                "WiMAX-Source-Port-Range"              => [ 28,  "integer" ],
                "WiMAX-Source-Specification"           => [ 28,  "tlv" ],
                "WiMAX-Subscription-Data"              => [ 154, "tlv" ],
                "WiMAX-Tariff-Switch-Interval"         => [ 38,  "integer" ],
                "WiMAX-Terminal-Information"           => [ 151, "tlv" ],
                "WiMAX-Termination-Action"             => [ 37,  "byte" ],
                "WiMAX-Time-Interval-After"            => [ 38,  "integer" ],
                "WiMAX-Tolerated-Jitter"               => [ 29,  "integer" ],
                "WiMAX-Tracking-Area-Identity"         => [ 156, "octets" ],
                "WiMAX-Traffic-Priority"               => [ 29,  "byte" ],
                "WiMAX-Transport-Type"                 => [ 28,  "byte" ],
                "WiMAX-UE-AMBR-DL"                     => [ 154, "integer" ],
                "WiMAX-UE-AMBR-UL"                     => [ 154, "integer" ],
                "WiMAX-Unsolicited-Grant-Interval"     => [ 29,  "short" ],
                "WiMAX-Unsolicited-Polling-Interval"   => [ 29,  "short" ],
                "WiMAX-Update-Reason"                  => [ 37,  "integer" ],
                "WiMAX-Uplink-Classifier"              => [ 28,  "string" ],
                "WiMAX-Uplink-Flow-Description"        => [ 50,  "string" ],
                "WiMAX-Uplink-Granted-QoS"             => [ 30,  "string" ],
                "WiMAX-Uplink-QOS-Id"                  => [ 28,  "byte" ],
                "WiMAX-VCSN-Ethernet-Service-Capabilities" => [ 1,  "byte" ],
                "WiMAX-VCSN-IP-Service-Capabilities"       => [ 1,  "byte" ],
                "WiMAX-vDHCP-DHCP-RK"                      => [ 87, "string" ],
                "WiMAX-vDHCP-DHCP-RK-Key-Id"               => [ 87, "integer" ],
                "WiMAX-vDHCP-DHCP-RK-Lifetime"             => [ 87, "integer" ],
                "WiMAX-vDHCP-DHCPv4-Address"               => [ 87, "ipaddr" ],
                "WiMAX-vDHCP-DHCPv6-Address"           => [ 87,  "ipv6addr" ],
                "WiMAX-vDHCP-RK"                       => [ 75,  "octets" ],
                "WiMAX-vDHCP-RK-Key-ID"                => [ 76,  "integer" ],
                "WiMAX-vDHCP-RK-Lifetime"              => [ 77,  "integer" ],
                "WiMAX-vDHCP-Server-Parameters"        => [ 87,  "tlv" ],
                "WiMAX-vDHCPv4-Server"                 => [ 73,  "ipaddr" ],
                "WiMAX-vDHCPv6-Server"                 => [ 74,  "ipv6addr" ],
                "WiMAX-vHA-IP-MIP4"                    => [ 64,  "ipaddr" ],
                "WiMAX-vHA-IP-MIP6"                    => [ 65,  "ipv6addr" ],
                "WiMAX-vHA-MIP4-Key"                   => [ 66,  "octets" ],
                "WiMAX-vHA-RK-Key"                     => [ 67,  "octets" ],
                "WiMAX-vHA-RK-Lifetime"                => [ 69,  "integer" ],
                "WiMAX-vHA-RK-SPI"                     => [ 68,  "integer" ],
                "WiMAX-Visited-Framed-Interface-Id"    => [ 81,  "ifid" ],
                "WiMAX-Visited-Framed-IP-Address"      => [ 79,  "ipaddr" ],
                "WiMAX-Visited-Framed-IPv6-Prefix"     => [ 80,  "ipv6prefix" ],
                "WiMAX-Visited-HNP-PMIP6"              => [ 136, "ipv6prefix" ],
                "WiMAX-Visited-Interface-Id-PMIP6"     => [ 137, "ifid" ],
                "WiMAX-Visited-IPv4-HoA-PMIP6"         => [ 89,  "byte" ],
                "WiMAX-Visited-IPv4-HoA-PMIP6-2"       => [ 138, "ipaddr" ],
                "WiMAX-Visited-PLMN-ID"                => [ 146, "octets" ],
                "WiMAX-VLAN-ID"                        => [ 28,  "integer" ],
                "WiMAX-VLAN-Tag-C-S-VLAN-Id-Mapping"   => [ 85,  "integer" ],
                "WiMAX-VLAN-Tag-C-VLAN-Id"             => [ 85,  "short" ],
                "WiMAX-VLAN-Tag-C-VLAN-Priority"       => [ 85,  "byte" ],
                "WiMAX-VLAN-Tag-Local-Config-Info"     => [ 85,  "octets" ],
                "WiMAX-VLAN-Tag-Processing-Descriptor" => [ 85,  "tlv" ],
                "WiMAX-VLAN-Tag-Rule-Id"               => [ 85,  "short" ],
                "WiMAX-VLAN-Tag-S-VLAN-Id"             => [ 85,  "short" ],
                "WiMAX-VLAN-Tag-VLAN-Id-Assignment"    => [ 85,  "short" ],
                "WiMAX-vLMA-IPv4-PMIP6"                => [ 130, "ipaddr" ],
                "WiMAX-vLMA-IPv6-PMIP6"                => [ 129, "ipv6addr" ],
                "WiMAX-Volume-Quota"                   => [ 37,  "integer" ],
                "WiMAX-Volume-Threshold"               => [ 37,  "integer" ],
                "WiMAX-Volume-Used-After"              => [ 38,  "integer" ],
                "WiMAX-XXX"                            => [ 84,  "byte" ],
            },
            25053 => {
                "Ruckus-AAA-Id"                      => [ 152, "string" ],
                "Ruckus-AAA-IP"                      => [ 122, "ipaddr" ],
                "Ruckus-Accept-Enhancement-Reason"   => [ 12,  "integer" ],
                "Ruckus-Accounting-Status"           => [ 126, "integer" ],
                "Ruckus-Acct-Ctrs_Input-Octets"      => [ 149, "integer" ],
                "Ruckus-Acct-Ctrs_Input-Packets"     => [ 149, "integer" ],
                "Ruckus-Acct-Ctrs_Output-Octets"     => [ 149, "integer" ],
                "Ruckus-Acct-Ctrs_Output-Packets"    => [ 149, "integer" ],
                "Ruckus-Acct-Ctrs_TC-Name"           => [ 149, "string" ],
                "Ruckus-AP-Roamed"                   => [ 136, "integer" ],
                "Ruckus-APN-NI"                      => [ 104, "string" ],
                "Ruckus-APN-OI"                      => [ 111, "string" ],
                "Ruckus-APN-Resolution-Req"          => [ 107, "integer" ],
                "Ruckus-Area-Code"                   => [ 130, "octets" ],
                "Ruckus-Auth-Server-Id"              => [ 128, "string" ],
                "Ruckus-Auth-Type"                   => [ 112, "integer" ],
                "Ruckus-Brand-Code"                  => [ 114, "string" ],
                "Ruckus-BSSID"                       => [ 14,  "octets" ],
                "Ruckus-CDR-TYPE"                    => [ 123, "integer" ],
                "Ruckus-Cell-Identifier"             => [ 131, "octets" ],
                "Ruckus-Charging-Charac"             => [ 118, "octets" ],
                "Ruckus-ChCh-Selection-Mode"         => [ 121, "octets" ],
                "Ruckus-Client-Device-Type"          => [ 156, "string" ],
                "Ruckus-Client-Host-Name"            => [ 138, "string" ],
                "Ruckus-Client-Local-IP"             => [ 116, "ipaddr" ],
                "Ruckus-Client-Os-Class"             => [ 140, "string" ],
                "Ruckus-Client-Os-Type"              => [ 139, "string" ],
                "Ruckus-Cluster-Name"                => [ 154, "string" ],
                "Ruckus-CP-Token"                    => [ 143, "string" ],
                "Ruckus-Domain-Name"                 => [ 155, "string" ],
                "Ruckus-DPSK"                        => [ 142, "octets" ],
                "Ruckus-DPSK-AKM-Suite"              => [ 153, "octets" ],
                "Ruckus-DPSK-Anonce"                 => [ 153, "octets" ],
                "Ruckus-DPSK-Cipher"                 => [ 153, "byte" ],
                "Ruckus-DPSK-EAPOL-Key-Frame"        => [ 153, "octets" ],
                "Ruckus-DPSK-Params"                 => [ 153, "tlv" ],
                "Ruckus-Dynamic-Address-Flag"        => [ 120, "octets" ],
                "Ruckus-Eth-Profile-Id"              => [ 133, "integer" ],
                "Ruckus-FlexAuth-AVP"                => [ 20,  "string" ],
                "Ruckus-Gn-User-Name"                => [ 113, "string" ],
                "Ruckus-Grace-Period"                => [ 6,   "integer" ],
                "Ruckus-IMSI"                        => [ 102, "octets" ],
                "Ruckus-Location"                    => [ 5,   "string" ],
                "Ruckus-Max-DL-UL-Quota"             => [ 144, "integer" ],
                "Ruckus-MSISDN"                      => [ 103, "octets" ],
                "Ruckus-NAS-Type"                    => [ 109, "integer" ],
                "Ruckus-Nat-Pool-Name"               => [ 147, "string" ],
                "Ruckus-PDP-Type"                    => [ 119, "octets" ],
                "Ruckus-Policy-Name"                 => [ 115, "string" ],
                "Ruckus-QoS"                         => [ 105, "octets" ],
                "Ruckus-Read-Preference"             => [ 137, "octets" ],
                "Ruckus-SCG-CBlade-IP"               => [ 7,   "integer" ],
                "Ruckus-SCG-DBlade-IP"               => [ 8,   "integer" ],
                "Ruckus-SCI-Resource-Group"          => [ 201, "string" ],
                "Ruckus-SCI-Role"                    => [ 200, "string" ],
                "Ruckus-Selection-Mode"              => [ 106, "integer" ],
                "Ruckus-Session-Type"                => [ 125, "integer" ],
                "Ruckus-SGSN-IP"                     => [ 117, "ipaddr" ],
                "Ruckus-SGSN-Number"                 => [ 124, "octets" ],
                "Ruckus-SSID"                        => [ 3,   "string" ],
                "Ruckus-Sta-Expiration"              => [ 10,  "integer" ],
                "Ruckus-Sta-Inner-Id"                => [ 13,  "string" ],
                "Ruckus-Sta-RSSI"                    => [ 2,   "integer" ],
                "Ruckus-Sta-SVlan-Id"                => [ 148, "integer" ],
                "Ruckus-Sta-UUID"                    => [ 11,  "string" ],
                "Ruckus-Start-Time"                  => [ 108, "octets" ],
                "Ruckus-Status"                      => [ 110, "integer" ],
                "Ruckus-TC-Acct-Ctrs"                => [ 149, "tlv" ],
                "Ruckus-TC-Attr-Ids-With-Quota"      => [ 146, "tlv" ],
                "Ruckus-TC-Name-Quota"               => [ 146, "string" ],
                "Ruckus-TC-Quota"                    => [ 146, "octets" ],
                "Ruckus-Traffic-Class-Attribute-Ids" => [ 145, "string" ],
                "Ruckus-Triplets"                    => [ 101, "octets" ],
                "Ruckus-User-Groups"                 => [ 1,   "string" ],
                "Ruckus-Utp-Id"                      => [ 129, "string" ],
                "Ruckus-VLAN-ID"                     => [ 9,   "integer" ],
                "Ruckus-Vlan-Name"                   => [ 157, "string" ],
                "Ruckus-Vlan-Pool"                   => [ 141, "string" ],
                "Ruckus-Wispr-Redirect-Policy"       => [ 132, "string" ],
                "Ruckus-Wlan-Id"                     => [ 4,   "integer" ],
                "Ruckus-Wlan-Name"                   => [ 135, "string" ],
                "Ruckus-WSG-User"                    => [ 10,  "string" ],
                "Ruckus-Zone-Id"                     => [ 127, "string" ],
                "Ruckus-Zone-Name"                   => [ 134, "string" ],
            },
            25178 => {
                "Eduroam-Monitoring-Inflate" => [ 11, "string" ],
                "Eduroam-SP-Country"         => [ 10, "string" ],
            },
            25461 => {
                "PaloAlto-Admin-Access-Domain"          => [ 2,  "string" ],
                "PaloAlto-Admin-Role"                   => [ 1,  "string" ],
                "PaloAlto-Client-Hostname"              => [ 9,  "string" ],
                "PaloAlto-Client-OS"                    => [ 8,  "string" ],
                "PaloAlto-Client-Source-IP"             => [ 7,  "string" ],
                "PaloAlto-GlobalProtect-Client-Version" => [ 10, "string" ],
                "PaloAlto-Panorama-Admin-Access-Domain" => [ 4,  "string" ],
                "PaloAlto-Panorama-Admin-Role"          => [ 3,  "string" ],
                "PaloAlto-User-Domain"                  => [ 6,  "string" ],
                "PaloAlto-User-Group"                   => [ 5,  "string" ],
            },
            25506 => {
                "H3C-Accounting-Level"             => [ 215, "integer" ],
                "H3C-Acct-IPv6-Input-Gigawords"    => [ 148, "integer" ],
                "H3C-Acct-IPv6-Input-Octets"       => [ 144, "integer" ],
                "H3C-Acct-IPv6-Input-Packets"      => [ 146, "integer" ],
                "H3C-Acct-IPv6-Output-Gigawords"   => [ 149, "integer" ],
                "H3C-Acct-IPv6-Output-Octets"      => [ 145, "integer" ],
                "H3C-Acct-IPv6-Output-Packets"     => [ 147, "integer" ],
                "H3C-ANCP-Profile"                 => [ 105, "string" ],
                "H3C-Auth-Detail-Result"           => [ 246, "integer" ],
                "H3C-Authentication-Type"          => [ 249, "integer" ],
                "H3C-Av-Pair"                      => [ 210, "string" ],
                "H3C-Backup-NAS-IP"                => [ 207, "ipaddr" ],
                "H3C-Client-Primary-DNS"           => [ 135, "ipaddr" ],
                "H3C-Client-Secondary-DNS"         => [ 136, "ipaddr" ],
                "H3C-Command"                      => [ 20,  "integer" ],
                "H3C-Connect_Id"                   => [ 26,  "integer" ],
                "H3C-Control-Identifier"           => [ 24,  "integer" ],
                "H3C-Down-Priority"                => [ 107, "integer" ],
                "H3C-Exec-Privilege"               => [ 29,  "integer" ],
                "H3C-Ftp-Directory"                => [ 28,  "string" ],
                "H3C-IGMP-Access-Limit"            => [ 103, "integer" ],
                "H3C-Input-Average-Rate"           => [ 2,   "integer" ],
                "H3C-Input-Basic-Rate"             => [ 3,   "integer" ],
                "H3C-Input-Committed-Burst-Size"   => [ 247, "integer" ],
                "H3C-Input-Interval-Gigawords"     => [ 205, "integer" ],
                "H3C-Input-Interval-Octets"        => [ 201, "integer" ],
                "H3C-Input-Interval-Packets"       => [ 203, "integer" ],
                "H3C-Input-Peak-Rate"              => [ 1,   "integer" ],
                "H3C-Ip-Host-Addr"                 => [ 60,  "string" ],
                "H3C-IPv4-Multicast-Receive-Group" => [ 98,  "ipaddr" ],
                "H3C-IPv6-Multicast-Receive-Group" => [ 100, "ipv6addr" ],
                "H3C-ISP-ID"                       => [ 17,  "string" ],
                "H3C-Ita-Policy"                   => [ 216, "string" ],
                "H3C-L2TP-Local-Name"              => [ 102, "string" ],
                "H3C-Longitude-Latitude"           => [ 111, "string" ],
                "H3C-MLD-Access-Limit"             => [ 101, "integer" ],
                "H3C-NAS-Port-Name"                => [ 230, "string" ],
                "H3C-NAS-Startup-Timestamp"        => [ 59,  "integer" ],
                "H3C-NAT-End-Port"                 => [ 34,  "integer" ],
                "H3C-NAT-IP-Address"               => [ 32,  "ipaddr" ],
                "H3C-NAT-Start-Port"               => [ 33,  "integer" ],
                "H3C-Output-Average-Rate"          => [ 5,   "integer" ],
                "H3C-Output-Basic-Rate"            => [ 6,   "integer" ],
                "H3C-Output-Committed-Burst-Size"  => [ 248, "integer" ],
                "H3C-Output-Interval-Gigawords"    => [ 206, "integer" ],
                "H3C-Output-Interval-Octets"       => [ 202, "integer" ],
                "H3C-Output-Interval-Packets"      => [ 204, "integer" ],
                "H3C-Output-Peak-Rate"             => [ 4,   "integer" ],
                "H3C-Portal-URL"                   => [ 27,  "string" ],
                "H3C-Product-ID"                   => [ 255, "string" ],
                "H3C-Remanent-Volume"              => [ 15,  "integer" ],
                "H3C-Result-Code"                  => [ 25,  "integer" ],
                "H3C-Security-Level"               => [ 141, "integer" ],
                "H3C-Subscriber-ID"                => [ 251, "string" ],
                "H3C-Subscriber-Profile"           => [ 252, "string" ],
                "H3C-Up-Priority"                  => [ 106, "integer" ],
                "H3C-User-Group"                   => [ 140, "string" ],
                "H3C-User-HeartBeat"               => [ 62,  "string" ],
                "H3C-User-Notify"                  => [ 61,  "string" ],
                "H3C-User-Role"                    => [ 155, "string" ],
                "H3C-VPN-Instance"                 => [ 104, "string" ],
                "H3C-WEB-URL"                      => [ 250, "string" ],
            },
            25622 => {
                "EAP-Channel-Binding-Message"          => [ 135, "octets" ],
                "Moonshot-Host-TargetedId"             => [ 138, "string" ],
                "Moonshot-MSTID-GSS-Acceptor"          => [ 141, "string" ],
                "Moonshot-MSTID-Namespace"             => [ 142, "string" ],
                "Moonshot-MSTID-TargetedId"            => [ 143, "string" ],
                "Moonshot-OTP-Secret"                  => [ 144, "string" ],
                "Moonshot-Realm-TargetedId"            => [ 139, "string" ],
                "Moonshot-TR-COI-TargetedId"           => [ 140, "string" ],
                "SAML-AAA-Assertion"                   => [ 132, "string" ],
                "Trust-Router-APC"                     => [ 137, "string" ],
                "Trust-Router-COI"                     => [ 136, "string" ],
                "UKERNA-GSS-Acceptor-Host-Name"        => [ 129, "string" ],
                "UKERNA-GSS-Acceptor-Realm-Name"       => [ 131, "string" ],
                "UKERNA-GSS-Acceptor-Service-Name"     => [ 128, "string" ],
                "UKERNA-GSS-Acceptor-Service-Specific" => [ 130, "string" ],
            },
            26928 => {
                "AH-HM-Admin-Group-Id"              => [ 1,   "integer" ],
                "Extreme-Auth-Source"               => [ 213, "integer" ],
                "Extreme-AVPair"                    => [ 8,   "string" ],
                "Extreme-Client-Monitor-Problem"    => [ 210, "integer" ],
                "Extreme-Client-Monitor-Session"    => [ 209, "octets" ],
                "Extreme-Data-Usage-Limit"          => [ 7,   "octets" ],
                "Extreme-Daylight-Saving-Offset"    => [ 208, "integer" ],
                "Extreme-IDM-Message"               => [ 203, "integer" ],
                "Extreme-IDM-Redirect-URL"          => [ 211, "string" ],
                "Extreme-Libsip-Action"             => [ 4,   "integer" ],
                "Extreme-Libsip-Additional-Message" => [ 5,   "octets" ],
                "Extreme-Libsip-Patron-Info"        => [ 3,   "octets" ],
                "Extreme-MGT-MAC-Address"           => [ 212, "string" ],
                "Extreme-NT-Identity"               => [ 204, "integer" ],
                "Extreme-PPSK-PMK"                  => [ 202, "octets" ],
                "Extreme-PPSK-Request"              => [ 201, "octets" ],
                "Extreme-Radius-Code"               => [ 9,   "integer" ],
                "Extreme-Time-Zone-Offset"          => [ 207, "integer" ],
                "Extreme-User-Language"             => [ 205, "string" ],
                "Extreme-User-Profile-Attribute"    => [ 6,   "integer" ],
                "Extreme-User-Vlan"                 => [ 1,   "integer" ],
            },
            27030 => {
                "Wichorus-Policy-Name"    => [ 1, "string" ],
                "Wichorus-User-Privilege" => [ 2, "string" ],
            },
            27262 => { "Default-TTL" => [ 1, "integer" ] },
            27880 => {
                "Freeswitch-AMAFlags"         => [ 16, "integer" ],
                "Freeswitch-Ani"              => [ 8,  "string" ],
                "Freeswitch-Aniii"            => [ 9,  "string" ],
                "Freeswitch-AVPair"           => [ 1,  "string" ],
                "Freeswitch-Billusec"         => [ 15, "integer" ],
                "Freeswitch-Callanswerdate"   => [ 21, "string" ],
                "Freeswitch-Callenddate"      => [ 23, "string" ],
                "Freeswitch-Callstartdate"    => [ 20, "string" ],
                "Freeswitch-Calltransferdate" => [ 22, "string" ],
                "Freeswitch-CLID"             => [ 2,  "string" ],
                "Freeswitch-Context"          => [ 18, "string" ],
                "Freeswitch-Dialplan"         => [ 3,  "string" ],
                "Freeswitch-Disposition"      => [ 12, "string" ],
                "Freeswitch-Dst"              => [ 5,  "string" ],
                "Freeswitch-Dst-Channel"      => [ 7,  "string" ],
                "Freeswitch-Hangupcause"      => [ 13, "integer" ],
                "Freeswitch-Lastapp"          => [ 10, "string" ],
                "Freeswitch-Lastdata"         => [ 11, "string" ],
                "Freeswitch-RDNIS"            => [ 17, "string" ],
                "Freeswitch-Signalbond"       => [ 24, "string" ],
                "Freeswitch-Source"           => [ 19, "string" ],
                "Freeswitch-Src"              => [ 4,  "string" ],
                "Freeswitch-Src-Channel"      => [ 6,  "string" ],
            },
            27975 => { "Centec-Exec-Privilege" => [ 1, "integer" ] },
            28557 => {
                "Hillstone-User-Admin-Privilege"     => [ 3,   "integer" ],
                "Hillstone-User-Login-Type"          => [ 4,   "integer" ],
                "Hillstone-User-Mobile-Number"       => [ 5,   "string" ],
                "Hillstone-User-Mobile-Operator"     => [ 6,   "integer" ],
                "Hillstone-User-Policy-dst-ip-begin" => [ 7,   "ipaddr" ],
                "Hillstone-User-Policy-dst-ip-end"   => [ 8,   "ipaddr" ],
                "Hillstone-User-Role-Bame"           => [ 9,   "string" ],
                "Hillstone-User-Type"                => [ 2,   "integer" ],
                "Hillstone-User-vsys-id"             => [ 1,   "integer" ],
                "Hillstone-VPN-DHCP-Gateway"         => [ 100, "string" ],
                "Hillstone-VPN-DHCP-Mask"            => [ 101, "string" ],
                "Hillstone-VPN-DHCP-Pool"            => [ 102, "string" ],
                "Hillstone-VPN-DNS"                  => [ 104, "string" ],
                "Hillstone-VPN-SNAT"                 => [ 107, "integer" ],
                "Hillstone-VPN-Split-Route"          => [ 105, "string" ],
                "Hillstone-VPN-Tunnel-IP"            => [ 106, "string" ],
                "Hillstone-VPN-WINS"                 => [ 103, "string" ],
            },
            29464 => {
                "PacketFence-Authorization-Status" => [ 27, "string" ],
                "PacketFence-AutoReg"              => [ 16, "string" ],
                "PacketFence-Computer-Name"        => [ 22, "string" ],
                "PacketFence-Connection-Type"      => [ 12, "string" ],
                "PacketFence-ConnectorID"          => [ 40, "string" ],
                "PacketFence-Domain"               => [ 21, "string" ],
                "PacketFence-Eap-Type"             => [ 11, "string" ],
                "PacketFence-Handled"              => [ 23, "string" ],
                "PacketFence-IfIndex"              => [ 19, "string" ],
                "PacketFence-IsPhone"              => [ 15, "string" ],
                "PacketFence-KeyBalanced"          => [ 32, "string" ],
                "PacketFence-Mac"                  => [ 6,  "string" ],
                "PacketFence-NasName"              => [ 25, "string" ],
                "PacketFence-NTCacheHash"          => [ 34, "string" ],
                "PacketFence-NTLM-Auth-Host"       => [ 41, "string" ],
                "PacketFence-NTLM-Auth-Port"       => [ 42, "string" ],
                "PacketFence-NTLMv2-Only"          => [ 35, "string" ],
                "PacketFence-Outer-User"           => [ 36, "string" ],
                "PacketFence-Profile"              => [ 20, "string" ],
                "PacketFence-Proxied-From"         => [ 30, "string" ],
                "PacketFence-Proxied-To"           => [ 26, "string" ],
                "PacketFence-Radius-Ip"            => [ 33, "string" ],
                "PacketFence-reply-insert"         => [ 38, "string" ],
                "PacketFence-Request-Time"         => [ 24, "integer" ],
                "PacketFence-Role"                 => [ 17, "string" ],
                "PacketFence-RPC-Pass"             => [ 4,  "string" ],
                "PacketFence-RPC-Port"             => [ 2,  "string" ],
                "PacketFence-RPC-Proto"            => [ 5,  "string" ],
                "PacketFence-RPC-Server"           => [ 1,  "string" ],
                "PacketFence-RPC-User"             => [ 3,  "string" ],
                "PacketFence-ShortName"            => [ 29, "string" ],
                "PacketFence-Source"               => [ 13, "string" ],
                "PacketFence-SSID"                 => [ 14, "string" ],
                "PacketFence-Status"               => [ 18, "string" ],
                "PacketFence-Switch-Id"            => [ 8,  "string" ],
                "PacketFence-Switch-Ip-Address"    => [ 10, "string" ],
                "PacketFence-Switch-Mac"           => [ 9,  "string" ],
                "PacketFence-UserDN"               => [ 37, "string" ],
                "PacketFence-UserName"             => [ 7,  "string" ],
                "PacketFence-UserNameAttribute"    => [ 31, "string" ],
                "PacketFence-UserPassword"         => [ 39, "string" ],
            },
            29671 => {
                "Meraki-Ap-Name"      => [ 3, "string" ],
                "Meraki-Ap-Tags"      => [ 4, "string" ],
                "Meraki-Device-Name"  => [ 1, "string" ],
                "Meraki-Network-Name" => [ 2, "string" ],
            },
            30065 => {
                "Arista-AVPair"          => [ 1,  "string" ],
                "Arista-BlockMac"        => [ 7,  "string" ],
                "Arista-Captive-Portal"  => [ 10, "string" ],
                "Arista-Command"         => [ 5,  "string" ],
                "Arista-CVP-Role"        => [ 4,  "string" ],
                "Arista-PortFlap"        => [ 9,  "integer" ],
                "Arista-UnblockMac"      => [ 8,  "string" ],
                "Arista-User-Priv-Level" => [ 2,  "integer" ],
                "Arista-User-Role"       => [ 3,  "string" ],
                "Arista-WebAuth"         => [ 6,  "integer" ],
            },
            30585 => {
                "SSS-Proxy-Id"         => [ 2, "string" ],
                "SSS-Proxy-Identifier" => [ 3, "string" ],
                "SSS-Proxy-Location"   => [ 4, "string" ],
            },
            33049 => { "Mellanox-Local-User-Name" => [ 1, "string" ] },
            34536 => {
                "fdXtended-Bandwidth-Down" => [ 2,  "integer" ],
                "fdXtended-Bandwidth-Up"   => [ 1,  "integer" ],
                "fdXtended-BytesDown"      => [ 7,  "integer" ],
                "fdXtended-BytesUp"        => [ 8,  "integer" ],
                "fdXtended-ContentFilter"  => [ 5,  "integer" ],
                "fdXtended-Expiration"     => [ 9,  "string" ],
                "fdXtended-NetworkPolicy"  => [ 6,  "integer" ],
                "fdXtended-One2onenat-IP"  => [ 4,  "string" ],
                "fdXtended-PostAuthURL"    => [ 3,  "string" ],
                "fdXtended-SessionTimeout" => [ 10, "integer" ],
                "fdXtended-Wan-Interface"  => [ 11, "string" ],
            },
            35098 => {
                "Pica8-AVPair"                   => [ 1, "string" ],
                "Pica8-IP-Downloadable-ACL-Name" => [ 3, "string" ],
                "Pica8-IP-Downloadable-ACL-Rule" => [ 2, "string" ],
                "Pica8-Redirect-URL"             => [ 4, "string" ],
            },
            35265 => {
                "Eltex-AVPair"                => [ 1,  "string" ],
                "Eltex-Disconnect-Code-Local" => [ 11, "integer" ],
            },
            35987 => {
                "NetBorder-AMAFlags"         => [ 16, "integer" ],
                "NetBorder-Ani"              => [ 8,  "string" ],
                "NetBorder-Aniii"            => [ 9,  "string" ],
                "NetBorder-AVPair"           => [ 1,  "string" ],
                "NetBorder-Billusec"         => [ 15, "integer" ],
                "NetBorder-Callanswerdate"   => [ 21, "string" ],
                "NetBorder-Callenddate"      => [ 23, "string" ],
                "NetBorder-Callstartdate"    => [ 20, "string" ],
                "NetBorder-Calltransferdate" => [ 22, "string" ],
                "NetBorder-CLID"             => [ 2,  "string" ],
                "NetBorder-Context"          => [ 18, "string" ],
                "NetBorder-Dialplan"         => [ 3,  "string" ],
                "NetBorder-Disposition"      => [ 12, "string" ],
                "NetBorder-Dst"              => [ 5,  "string" ],
                "NetBorder-Dst-Channel"      => [ 7,  "string" ],
                "NetBorder-Hangupcause"      => [ 13, "integer" ],
                "NetBorder-Lastapp"          => [ 10, "string" ],
                "NetBorder-Lastdata"         => [ 11, "string" ],
                "NetBorder-RDNIS"            => [ 17, "string" ],
                "NetBorder-Signalbond"       => [ 24, "string" ],
                "NetBorder-Source"           => [ 19, "string" ],
                "NetBorder-Src"              => [ 4,  "string" ],
                "NetBorder-Src-Channel"      => [ 6,  "string" ],
            },
            37538 => {
                "BSN-AVPair"    => [ 2, "string" ],
                "BSN-User-Role" => [ 1, "string" ]
            },
            40676 => {
                "Microsemi-Fallback-User-Group"   => [ 6, "string" ],
                "Microsemi-Network-Element-Group" => [ 7, "string" ],
                "Microsemi-User-Email"            => [ 4, "string" ],
                "Microsemi-User-Full-Name"        => [ 1, "string" ],
                "Microsemi-User-Group"            => [ 5, "string" ],
                "Microsemi-User-Initials"         => [ 3, "string" ],
                "Microsemi-User-Name"             => [ 2, "string" ],
            },
            40808 => {
                "HS20-AP-Version"                      => [ 2, "byte" ],
                "HS20-Deauthentication-Request"        => [ 4, "octets" ],
                "HS20-Mobile-Device-Version"           => [ 3, "octets" ],
                "HS20-Roaming-Consortium"              => [ 6, "octets" ],
                "HS20-Session-Information-URL"         => [ 5, "octets" ],
                "HS20-Subscription-Remediation-Needed" => [ 1, "octets" ],
            },
            41482 => {
                "Yubikey-Counter"    => [ 4, "integer" ],
                "Yubikey-Key"        => [ 1, "octets" ],
                "Yubikey-OTP"        => [ 7, "string" ],
                "Yubikey-Private-ID" => [ 3, "octets" ],
                "Yubikey-Public-ID"  => [ 2, "string" ],
                "Yubikey-Random"     => [ 6, "integer" ],
                "Yubikey-Timestamp"  => [ 5, "integer" ],
            },
            43356 => {
                "Mimosa-CloudManagement-Parameter"         => [ 21, "byte" ],
                "Mimosa-Device-Configuration-Parameter"    => [ 1,  "string" ],
                "Mimosa-DeviceName-Parameter"              => [ 12, "string" ],
                "Mimosa-DNS1-Parameter"                    => [ 16, "ipaddr" ],
                "Mimosa-DNS2-Parameter"                    => [ 17, "ipaddr" ],
                "Mimosa-EnableHTTPS-Parameter"             => [ 19, "byte" ],
                "Mimosa-EnableSNMP-Parameter"              => [ 22, "byte" ],
                "Mimosa-EnableSyslog-Parameter"            => [ 26, "byte" ],
                "Mimosa-EthernetPortSpeed-Parameter"       => [ 15, "string" ],
                "Mimosa-FirmwareLocation-Parameter"        => [ 3,  "string" ],
                "Mimosa-FirmwareVersion-Parameter"         => [ 2,  "string" ],
                "Mimosa-HTTPPort-Parameter"                => [ 18, "integer" ],
                "Mimosa-HTTPSPort-Parameter"               => [ 20, "integer" ],
                "Mimosa-ManagementIPAddress-Parameter"     => [ 6,  "ipaddr" ],
                "Mimosa-ManagementIPAddressMode-Parameter" => [ 5,  "string" ],
                "Mimosa-ManagementIPGateway-Parameter"     => [ 8,  "ipaddr" ],
                "Mimosa-ManagementIPNetmask-Parameter"     => [ 7,  "ipaddr" ],
                "Mimosa-ManagementPassword-Parameter"      => [ 11, "string" ],
                "Mimosa-ManagementVlan-Parameter"          => [ 10, "string" ],
                "Mimosa-ManagementVlanStatus-Parameter"    => [ 9,  "byte" ],
                "Mimosa-NTPServerAddress-Parameter"        => [ 25, "string" ],
                "Mimosa-SNMPCommunityString-Parameter"     => [ 23, "string" ],
                "Mimosa-SNMPTrapServer-Parameter"          => [ 24, "ipaddr" ],
                "Mimosa-SyslogPort-Parameter"              => [ 28, "integer" ],
                "Mimosa-SyslogProtocol-Parameter"          => [ 29, "string" ],
                "Mimosa-SyslogServerAddress-Parameter"     => [ 27, "ipaddr" ],
                "Mimosa-TrafficShapingCommitted-Parameter" => [ 14, "string" ],
                "Mimosa-TrafficShapingPeak-Parameter"      => [ 13, "string" ],
                "Mimosa-WirelessProtocol-Parameter"        => [ 4,  "string" ],
            },
            43823 => {
                "VasExperts-Acct-Traffic-Class-Input-Octets" =>
                  [ 17, "integer64" ],
                "VasExperts-Acct-Traffic-Class-Input-Packets" =>
                  [ 19, "integer64" ],
                "VasExperts-Acct-Traffic-Class-Name" => [ 16, "string" ],
                "VasExperts-Acct-Traffic-Class-Output-Octets" =>
                  [ 18, "integer64" ],
                "VasExperts-Acct-Traffic-Class-Output-Packets" =>
                  [ 20, "integer64" ],
                "VasExperts-ARP-SourceIP"            => [ 60, "ipaddr" ],
                "VasExperts-ARP-TargetIP"            => [ 61, "ipaddr" ],
                "VasExperts-BOOTP-File"              => [ 44, "string" ],
                "VasExperts-BOOTP-SName"             => [ 43, "string" ],
                "VasExperts-Command-Code"            => [ 10, "integer" ],
                "VasExperts-DHCP-ClassId"            => [ 34, "octets" ],
                "VasExperts-DHCP-ClientId"           => [ 33, "octets" ],
                "VasExperts-DHCP-ClientIP"           => [ 36, "ipaddr" ],
                "VasExperts-DHCP-DNS"                => [ 41, "ipaddr" ],
                "VasExperts-DHCP-Gateway"            => [ 42, "ipaddr" ],
                "VasExperts-DHCP-Hostname"           => [ 32, "octets" ],
                "VasExperts-DHCP-Option"             => [ 40, "octets" ],
                "VasExperts-DHCP-Option-Bin"         => [ 48, "string" ],
                "VasExperts-DHCP-Option-IP"          => [ 45, "string" ],
                "VasExperts-DHCP-Option-IPv6"        => [ 80, "string" ],
                "VasExperts-DHCP-Option-IPv6-Prefix" => [ 81, "string" ],
                "VasExperts-DHCP-Option-Num"         => [ 46, "string" ],
                "VasExperts-DHCP-Option-String"      => [ 47, "string" ],
                "VasExperts-DHCP-RelayCircuitId"     => [ 39, "octets" ],
                "VasExperts-DHCP-RelayInfo"          => [ 35, "octets" ],
                "VasExperts-DHCP-RelayRemoteId"      => [ 38, "octets" ],
                "VasExperts-DHCP-Request"            => [ 37, "integer" ],
                "VasExperts-DHCP6-Option-Bin"        => [ 84, "string" ],
                "VasExperts-DHCP6-Option-Num"        => [ 82, "string" ],
                "VasExperts-DHCP6-Option-String"     => [ 83, "string" ],
                "VasExperts-DHCPv6-Delegated"        => [ 75, "integer" ],
                "VasExperts-DHCPv6-RemoteId"         => [ 73, "octets" ],
                "VasExperts-DHCPv6-Request"          => [ 70, "integer" ],
                "VasExperts-DHCPv6-SubsId"           => [ 74, "octets" ],
                "VasExperts-DHCPv6-UserClass"        => [ 71, "octets" ],
                "VasExperts-DHCPv6-VendorClass"      => [ 72, "octets" ],
                "VasExperts-Enable-Interconnect"     => [ 8,  "integer" ],
                "VasExperts-Enable-Service"          => [ 3,  "string" ],
                "VasExperts-Multi-IP-User"           => [ 4,  "integer" ],
                "VasExperts-NAT-IP"                  => [ 21, "ipaddr" ],
                "VasExperts-OutMAC"                  => [ 11, "string" ],
                "VasExperts-OutVLAN"                 => [ 9,  "integer" ],
                "VasExperts-Policing-Profile"        => [ 1,  "string" ],
                "VasExperts-Restrict-User"           => [ 7,  "integer" ],
                "VasExperts-Service-Profile"         => [ 2,  "string" ],
                "VasExperts-Service-Type"            => [ 6,  "integer" ],
                "VasExperts-UserName"                => [ 5,  "string" ],
            },
            46235 => {
                "RCNTEC-RPCM-Group"          => [ 1, "string" ],
                "RCNTEC-RPCM-Session-Expire" => [ 2, "integer" ],
            },
            49426 => {
                "BELRAS-Acct"                   => [ 27, "string" ],
                "BELRAS-AKAMAI-Speed"           => [ 12, "integer" ],
                "BELRAS-Auth"                   => [ 26, "string" ],
                "BELRAS-BELCACHE-Speed"         => [ 22, "integer" ],
                "BELRAS-BL"                     => [ 29, "string" ],
                "BELRAS-CACHE-Speed"            => [ 13, "integer" ],
                "BELRAS-CacheFly-Speed"         => [ 14, "integer" ],
                "BELRAS-CO"                     => [ 31, "string" ],
                "BELRAS-DHCP-Lease-Time"        => [ 23, "integer" ],
                "BELRAS-DHCP-Mask"              => [ 6,  "integer" ],
                "BELRAS-DHCP-Option82"          => [ 9,  "octets" ],
                "BELRAS-DHCP-Router-IP-Address" => [ 5,  "ipaddr" ],
                "BELRAS-Down-Speed-Limit"       => [ 2,  "integer" ],
                "BELRAS-Framed-IP-Address"      => [ 28, "string" ],
                "BELRAS-GGC-Speed"              => [ 15, "integer" ],
                "BELRAS-GOOGLE-Speed"           => [ 16, "integer" ],
                "BELRAS-Group"                  => [ 24, "integer" ],
                "BELRAS-IN"                     => [ 30, "string" ],
                "BELRAS-Incapsula-Speed"        => [ 17, "integer" ],
                "BELRAS-LIMELIGHT-Speed"        => [ 18, "integer" ],
                "BELRAS-LIMIT"                  => [ 25, "string" ],
                "BELRAS-Octets-Direction"       => [ 11, "integer" ],
                "BELRAS-OTHERS-Speed"           => [ 19, "integer" ],
                "BELRAS-Qos-Speed"              => [ 3,  "integer" ],
                "BELRAS-REDIFF-Speed"           => [ 20, "integer" ],
                "BELRAS-Redirect"               => [ 7,  "integer" ],
                "BELRAS-redirect-Pool"          => [ 8,  "integer" ],
                "BELRAS-Session-Octets-Limit"   => [ 10, "integer" ],
                "BELRAS-TORRENT-Speed"          => [ 21, "integer" ],
                "BELRAS-Up-Speed-Limit"         => [ 1,  "integer" ],
                "BELRAS-User"                   => [ 4,  "string" ],
            },
            52970 => {
                "Eleven-Authentication-Find-Key" => [ 3, "tlv" ],
                "Eleven-EAPOL-Anonce"            => [ 3, "octets" ],
                "Eleven-EAPOL-APMAC"             => [ 3, "octets" ],
                "Eleven-EAPOL-Frame-2"           => [ 3, "octets" ],
                "Eleven-EAPOL-SSID"              => [ 3, "string" ],
                "Eleven-EAPOL-STMAC"             => [ 3, "octets" ],
            },
            54268 => {
                "NetElastic-Acct-IPv6-Input-Gigawords"  => [ 148, "integer" ],
                "NetElastic-Acct-IPv6-Input-Octets"     => [ 144, "integer" ],
                "NetElastic-Acct-IPv6-Input-Packets"    => [ 146, "integer" ],
                "NetElastic-Acct-IPv6-Output-Gigawords" => [ 149, "integer" ],
                "NetElastic-Acct-IPv6-Output-Octets"    => [ 145, "integer" ],
                "NetElastic-Acct-IPv6-Output-Packets"   => [ 147, "integer" ],
                "NetElastic-Data-Filter"                => [ 82,  "string" ],
                "NetElastic-Domain-Name"                => [ 138, "string" ],
                "NetElastic-Framed-IPv6-Address"        => [ 158, "ipv6addr" ],
                "NetElastic-HTTP-Redirect-URL"          => [ 140, "string" ],
                "NetElastic-Input-Average-Rate"         => [ 2,   "integer" ],
                "NetElastic-Input-Burst-Size"           => [ 1,   "integer" ],
                "NetElastic-Input-Peak-Burst-Size"      => [ 77,  "integer" ],
                "NetElastic-Input-Peak-Rate"            => [ 3,   "integer" ],
                "NetElastic-ISP-ID"                     => [ 17,  "string" ],
                "NetElastic-Lease-Time"                 => [ 74,  "integer" ],
                "NetElastic-NAT-End-Port"               => [ 163, "integer" ],
                "NetElastic-NAT-Public-Address"         => [ 161, "ipaddr" ],
                "NetElastic-NAT-Start-Port"             => [ 162, "integer" ],
                "NetElastic-Output-Average-Rate"        => [ 5,   "integer" ],
                "NetElastic-Output-Burst-Size"          => [ 4,   "integer" ],
                "NetElastic-Output-Peak-Burst-Size"     => [ 78,  "integer" ],
                "NetElastic-Output-Peak-Rate"           => [ 6,   "integer" ],
                "NetElastic-Policy-Name"                => [ 95,  "string" ],
                "NetElastic-Portal-Mode"                => [ 85,  "integer" ],
                "NetElastic-PortalURL"                  => [ 27,  "string" ],
                "NetElastic-Primary-DNS"                => [ 135, "ipaddr" ],
                "NetElastic-Qos-Profile-Name"           => [ 31,  "string" ],
                "NetElastic-Remanent-Volume"            => [ 15,  "integer" ],
                "NetElastic-Remanent-Volume-Type"       => [ 251, "integer" ],
                "NetElastic-Secondary-DNS"              => [ 136, "ipaddr" ],
                "NetElastic-Tariff-Input-Gigawords"     => [ 249, "string" ],
                "NetElastic-Tariff-Input-Octets"        => [ 247, "string" ],
                "NetElastic-Tariff-Output-Gigawords"    => [ 250, "string" ],
                "NetElastic-Tariff-Output-Octets"       => [ 248, "string" ],
                "NetElastic-User-Mac"                   => [ 153, "string" ],
                "NetElastic-Web-COA"                    => [ 252, "integer" ],
            },
            58313 => {
                "Nile-AVPair"       => [ 3, "string" ],
                "Nile-Netseg"       => [ 2, "string" ],
                "Nile-Redirect-URL" => [ 1, "string" ],
            },
            58888 => { "OpenWiFi-AP-MAC-Address" => [ 1,  "string" ] },
            61349 => { "CKey-Auth-Info"          => [ 10, "integer" ] },
        },
        vsaval => {
            5 => {
                1 => {
                    "Access-Denied"                 => 8,
                    "Access-Partition-bind-failure" => 35,
                    "Administrative-reload"         => 49,
                    "Administrative-reset"          => 25,
                    "Administrative-reset-2"        => 48,
                    "Bad-route-specification"       => 34,
                    "Call-cleared-with-cause"       => 43,
                    "Callback"                      => 54,
                    "Configuration-disallowed"      => 38,
                    "Conflicting-attributes"        => 30,
                    "Facility-not-available"        => 32,
                    "Host-request"                  => 56,
                    "Idle-timeout"                  => 23,
                    "Incompatible-service-profile"  => 47,
                    "Inopportune-config-request"    => 44,
                    "Internal-config-error"         => 33,
                    "Invalid-attribute"             => 11,
                    "Invalid-attribute-value"       => 14,
                    "Invalid-config-parameter"      => 45,
                    "Invalid-framed-protocol"       => 13,
                    "Invalid-integer-syntax"        => 17,
                    "Invalid-IP-address"            => 16,
                    "Invalid-NAS-port"              => 18,
                    "Invalid-parameter"             => 42,
                    "Invalid-request"               => 40,
                    "Invalid-service-type"          => 12,
                    "Invalid-user-information"      => 15,
                    "Missing-attribute"             => 39,
                    "Missing-config-parameter"      => 46,
                    "Missing-parameter"             => 41,
                    "NAS-error"                     => 27,
                    "NAS-reload-or-reset"           => 26,
                    "NAS-request"                   => 28,
                    "Network-disconnect"            => 20,
                    "No-accounting-response"        => 7,
                    "No-accounting-server"          => 6,
                    "No-authentication-response"    => 5,
                    "No-authentication-server"      => 4,
                    "No-reason-No-Failure"          => 0,
                    "Physical-port-error"           => 22,
                    "Port-limit-exceeded"           => 31,
                    "Port-preempted"                => 51,
                    "Port-suspended"                => 52,
                    "Port-unneeded"                 => 50,
                    "Protocol-error"                => 10,
                    "Request-type-conflict"         => 37,
                    "Requested-by-user"             => 19,
                    "Resource-shortage"             => 1,
                    "Security-violation"            => 36,
                    "Service-interruption"          => 21,
                    "Service-unavailable"           => 53,
                    "Session-already-open"          => 2,
                    "Session-timeout"               => 24,
                    "Temporary-buffer-shortage"     => 9,
                    "Too-many-RADIUS-users"         => 3,
                    "Undefined-reason-given"        => 29,
                    "User-error"                    => 55,
                },
                2  => { Disabled => 1, Enabled => 2 },
                9  => { Direct   => 2, Funnel  => 1 },
                10 => { Disabled => 2, Enabled => 1 },
                15 => {
                    "Access-information-discarded"    => 43,
                    "Bearer-capability-not-available" => 58,
                    "Bearer-capability-unauthorized"  => 57,
                    "Bearer-capablity-not-implmented" => 65,
                    "Call-awarded-being-delivered"    => 7,
                    "Call-identify-in-use"            => 84,
                    "Call-rejected"                   => 21,
                    "Cause-unspecified"               => 0,
                    "Channel-type-not-implemented"    => 66,
                    "Channel-unacceptable"            => 6,
                    "Circuit-or-channed-preempted"    => 45,
                    "Circuit-or-channel-unavailable"  => 44,
                    "Destination-out-of-order"        => 27,
                    "Facility-not-implemented"        => 69,
                    "Facility-not-subscribed"         => 50,
                    "Facility-rejected"               => 29,
                    "Identified-channel-doesnt-exist" => 82,
                    "Incoming-calls-barred"           => 54,
                    "Incompatible-destination"        => 88,
                    "Infrmtion-elemnt-not-implmented" => 99,
                    "Inopportune-message"             => 98,
                    "Interworking"                    => 127,
                    "Invalid-call-reference"          => 81,
                    "Invalid-message"                 => 95,
                    "Invalid-or-incomplete-number"    => 28,
                    "Invalid-transit-network-selctin" => 91,
                    "Invlid-infrmtion-element-contnt" => 100,
                    "Mandtory-infrmtion-elment-miss"  => 96,
                    "Message-incompatible-with-state" => 101,
                    "Message-not-implemented"         => 97,
                    "Mndtry-infrmtion-elmnt-lngt-err" => 103,
                    "Network-out-of-order"            => 38,
                    "No-call-suspended"               => 85,
                    "No-circuit-or-channel-available" => 34,
                    "No-route-to-destination"         => 3,
                    "No-route-to-transit-network"     => 2,
                    "No-user-responding"              => 18,
                    "Non-selected-user-clearing"      => 26,
                    "Normal-clearing"                 => 16,
                    "Normal-unspecified-cause"        => 31,
                    "Number-changed"                  => 22,
                    "Outgoing-calls-barred"           => 52,
                    "Protocol-error"                  => 111,
                    "Quality-of-service-unavailable"  => 49,
                    "Recovery-on-timer-expiration"    => 102,
                    "Resources-unavailable"           => 47,
                    "Response-to-status-inquiry"      => 30,
                    "Restrcted-digtal-infrmtion-only" => 70,
                    "Service-not-available"           => 63,
                    "Service-not-implemented"         => 79,
                    "Suspended-call-cleared"          => 86,
                    "Switching-equipment-congestion"  => 42,
                    "Temporary-failure"               => 41,
                    "Unassigned-number"               => 1,
                    "User-alerted-no-answer"          => 19,
                    "User-busy"                       => 17,
                },
                16 => {
                    "Beyond-interworking-point"       => 10,
                    "International-network"           => 6,
                    "Local-or-remote-user"            => 0,
                    "Pblic-ntwork-serv-remote-user"   => 5,
                    "Pblic-ntwork-serving-local-user" => 2,
                    "Prvte-ntwork-serv-remote-user"   => 4,
                    "Prvte-ntwork-serving-local-user" => 1,
                    "Transit-network"                 => 3,
                },
                18 => {
                    "Dial-Request"          => 2,
                    "Ring-Indication"       => 1,
                    "Tunnel-Authentication" => 4,
                    "User-Authentication"   => 3,
                },
                19 => { Disabled => 1, Enabled => 2 },
                20 => { False    => 1, True    => 2 },
                21 => {
                    "Configuration-Reload" => 3,
                    "Configuration-Reset"  => 2,
                    "Disabled"             => 5,
                    "Enabled"              => 4,
                    "NAS-Reload"           => 1,
                    "NAS-Reset"            => 0,
                },
                28 => { Disabled => 1, Enabled => 2 },
                29 => { Disabled => 1, Enabled => 2 },
                36 => {
                    "CBCP-Callback"        => 6,
                    "CLI-Callback"         => 7,
                    "User-Auth"            => 0,
                    "User-Specified-E-164" => 3,
                },
                37 => {
                    "CBCP-None"           => 1,
                    "CBCP-Pre-Specified"  => 3,
                    "CBCP-User-Specified" => 2
                },
                38 => { "CHAP" => 2, "CHAP-PAP" => 3, "NONE" => 4, "PAP" => 1 },
                42 => { NETMAN => 2, PUBLIC     => 1 },
                43 => {
                    "Access-Partition-Disabled"     => 2,
                    "Home-Server-Down"              => 5,
                    "License-Portlimit-Exceeded"    => 4,
                    "NAS-Administratively-Disabled" => 7,
                    "No-Access-Partition"           => 1,
                    "Partition-Portlimit-Exceeded"  => 3,
                    "Rejected-By-Home-Server"       => 6,
                },
                47 => { Disabled => 2, Enabled => 1 },
                48 => { V1       => 1, V2      => 2 },
            },
            9 => {
                195 => {
                    "Bad-Hostname"                  => 53,
                    "Bad-Port"                      => 54,
                    "Call-Disconnect"               => 3,
                    "Call-Duration"                 => 195,
                    "CLID-Authentication-Failure"   => 4,
                    "Close-Virtual-Connection"      => 29,
                    "Control-C-Detected"            => 27,
                    "End-Virtual-Connection"        => 30,
                    "EXEC-Program-Destroyed"        => 28,
                    "Exit-Raw-TCP"                  => 24,
                    "Exit-Rlogin"                   => 31,
                    "Exit-Telnet-Session"           => 22,
                    "Failed-PPP-CHAP-Auth"          => 43,
                    "Failed-PPP-LCP-Negotiation"    => 41,
                    "Failed-PPP-PAP-Auth-Fail"      => 42,
                    "Failed-PPP-Remote-Auth"        => 44,
                    "Foreign-Host-Close-TCP"        => 63,
                    "Idle-Timeout"                  => 21,
                    "Insufficient-Resources"        => 33,
                    "Invalid-IP-Address"            => 52,
                    "Invalid-Protocol"              => 120,
                    "Invalid-Rlogin-Option"         => 32,
                    "Local-Admin-Disconnect"        => 151,
                    "Local-Hangup"                  => 180,
                    "Lost-Carrier"                  => 11,
                    "MP-Error-PPP"                  => 48,
                    "NCP-Closed-PPP"                => 47,
                    "No-Carrier"                    => 10,
                    "No-Detected-Result-Codes"      => 12,
                    "No-Disconnect"                 => 1,
                    "No-Modem-Available"            => 9,
                    "No-Reason"                     => 0,
                    "No-Remote-IP-Addr"             => 23,
                    "Password-Fail"                 => 25,
                    "PPP-Authentication-Timeout"    => 170,
                    "PPP-Closed-Event"              => 46,
                    "PPP-Maximum-Channels"          => 49,
                    "PPP-Remote-Terminate"          => 45,
                    "RADIUS-Disconnect"             => 150,
                    "Raw-TCP-Disabled"              => 26,
                    "Remote-Hangup"                 => 185,
                    "Reset-TCP"                     => 60,
                    "Resources-Full"                => 51,
                    "Session-End-Callback"          => 102,
                    "Session-Failed-Security"       => 101,
                    "Session-Timeout"               => 100,
                    "SNMP-Disconnect"               => 152,
                    "T1-Quiesced"                   => 190,
                    "Tables-Full"                   => 50,
                    "TCP-Connection-Refused"        => 61,
                    "TCP-Host-Unreachable"          => 65,
                    "TCP-Network-Admin-Unreachable" => 66,
                    "TCP-Network-Unreachable"       => 64,
                    "TCP-Port-Unreachable"          => 67,
                    "Timeout-PPP-LCP"               => 40,
                    "Timeout-TCP"                   => 62,
                    "Unknown"                       => 2,
                    "User-Ends-Session"             => 20,
                    "V110-Retries"                  => 160,
                    "VPN-Admin-Disconnect"          => 604,
                    "VPN-Bad-Control-Packet"        => 603,
                    "VPN-Call-Redirect"             => 608,
                    "VPN-Carrier-Loss"              => 601,
                    "VPN-Local-Disconnect"          => 606,
                    "VPN-No-Resources"              => 602,
                    "VPN-Session-Limit"             => 607,
                    "VPN-Tunnel-Shut"               => 605,
                    "VPN-User-Disconnect"           => 600,
                },
            },
            11 => {
                3  => { "Deny-List"  => 1, "Permit-List" => 0 },
                13 => { "Port-Based" => 1, "User-Based"  => 2 },
                26 => { HTTP         => 5, HTTPS         => 6 },
            },
            43 => {
                1 => {
                    "3Com-Administrator" => 3,
                    "3Com-Manager"       => 2,
                    "3Com-Monitor"       => 1,
                    "3Com-Visitor"       => 0,
                },
            },
            52 => {
                201 => {
                    "BR-IPX-Enable"    => 6,
                    "Bridge-Enable"    => 2,
                    "IP-BR-Enable"     => 3,
                    "IP-BR-IPX-Enable" => 7,
                    "IP-Enable"        => 1,
                },
                202 => {
                    "BR-IPX-Callable"    => 6,
                    "Bridge-Callable"    => 2,
                    "IP-BR-Callable"     => 3,
                    "IP-BR-IPX-Callable" => 7,
                    "IP-Callable"        => 1,
                },
            },
            64 => {
                1 => {
                    "Called-Only"    => 2,
                    "Calling-Called" => 3,
                    "Calling-Only"   => 4,
                    "Disabled"       => 1,
                },
                2 => { Disabled => 1, Enabled => 2 },
                3 => {
                    "3100Hz-Audio"     => 3,
                    "Digital-56K"      => 2,
                    "Unrestricted-64K" => 1
                },
                6 => {
                    "CHAP"                          => 1,
                    "PAP"                           => 2,
                    "PAP-Sending-on-Incoming-Calls" => 3
                },
                7  => { BCP      => 2, IPCP    => 3 },
                8  => { Disabled => 1, Enabled => 2 },
                9  => { Disabled => 1, Enabled => 2 },
                10 => { Disabled => 1, Enabled => 2 },
                11 => { Disabled => 1, Enabled => 2 },
                12 => { Disabled => 1, Enabled => 2 },
                13 => { Disabled => 1, Enabled => 2 },
                23 => {
                    "Filter-all-outgoing-RIP-SAP" => 3,
                    "Forward"                     => 1,
                    "Spoof"                       => 2
                },
                24 => { Disabled => 1, Enabled => 2 },
                31 => { Disabled => 1, Enabled => 2 },
                32 => { Disabled => 1, Enabled => 2 },
                33 => { Disabled => 1, Enabled => 2 },
            },
            161 => {
                5  => { Disable => 0, Enable  => 1 },
                14 => { Disable => 0, Enable  => 1 },
                15 => { All     => 0, Tagged  => 1, Untagged => 2 },
                23 => { Disable => 0, Enable  => 1 },
                50 => { ADMIN   => 3, INSTALL => 2, TECH => 1 },
            },
            166 => {
                30 => {
                    Negotiate => 1,
                    None      => 0,
                    Predictor => 3,
                    Spider    => 2,
                    STAC      => 4
                },
                61 => {
                    "Listener"          => 5,
                    "Primary"           => 1,
                    "RADIUS"            => 6,
                    "Secondary-Augment" => 3,
                    "Secondary-Backup"  => 2,
                    "Secondary-Switch"  => 4,
                },
                93 => {
                    "Analog"              => 1,
                    "Digital"             => 3,
                    "Digital-Leased-Line" => 6,
                    "Digital-V110"        => 4,
                    "Digital-V120"        => 5,
                    "Digitized-Analog"    => 2,
                },
                97 => {
                    AALAP => 5,
                    ARAV1 => 2,
                    ARAV2 => 3,
                    HDLC  => 1,
                    SHELL => 4,
                    SLIP  => 6
                },
                100 => {
                    "Admin-Disconnect"      => 5,
                    "Backup"                => 13,
                    "Bandwidth-On-Demand"   => 8,
                    "Blocked"               => 11,
                    "Dialback"              => 6,
                    "Error"                 => 2,
                    "Failed-Authentication" => 9,
                    "Idle-Timeout"          => 3,
                    "Preempted"             => 10,
                    "Remote"                => 1,
                    "Session-Timeout"       => 4,
                    "Tariff-Management"     => 12,
                    "Virtual-Connection"    => 7,
                },
                103 => {
                    "Dialin"     => 1,
                    "Dialout"    => 2,
                    "Lan-To-Lan" => 3,
                    "Unknown"    => 0
                },
                104 => {
                    "Bandwidth-On-Demand" => 4,
                    "Dialback"            => 2,
                    "Remote"              => 1,
                    "Virtual-Connection"  => 3,
                },
            },
            171 => {
                1 => {
                    "Admin"        => 5,
                    "Admin-Legacy" => 15,
                    "Operator"     => 4,
                    "Power-User"   => 6,
                    "User"         => 3,
                    "User-Legacy"  => 1,
                },
            },
            307 => {
                9 => {
                    "Console-Off"    => 7,
                    "Console-On"     => 3,
                    "SA-Failure-Off" => 6,
                    "SA-Failure-On"  => 2,
                    "SA-Success-Off" => 5,
                    "SA-Success-On"  => 1,
                    "Syslog-Off"     => 8,
                    "Syslog-On"      => 4,
                },
                10 => { "Drop" => 1, "ICMP-Reject" => 2, "Pass-Through" => 3 },
                16 => {
                    "Console-Off"        => 7,
                    "Console-On"         => 3,
                    "Failure-Off"        => 6,
                    "Session-Failure-On" => 2,
                    "Session-Success-On" => 1,
                    "Success-Off"        => 5,
                    "Syslog-Off"         => 8,
                    "Syslog-On"          => 4,
                },
                17 => { "Drop" => 1, "ICMP-Reject" => 2, "Pass-Through" => 3 },
                23 => { On     => 1 },
            },
            311 => {
                7 => { "Encryption-Allowed" => 1, "Encryption-Required" => 2 },
                8 => {
                    "RC4-128bit-Allowed"      => 2,
                    "RC4-40bit-Allowed"       => 1,
                    "RC4-40or128-bit-Allowed" => 6,
                },
                13 => { "Allowed" => 1, "Not-Allowed" => 0, "Required" => 2 },
                21 => {
                    "Admin-Requires-Password-Change" => 3,
                    "Expired-Password"               => 2,
                    "Just-Change-Password"           => 1,
                    "Password-Too-Short"             => 4,
                },
                23 => {
                    "CHAP"      => 2,
                    "EAP"       => 5,
                    "MS-CHAP-1" => 3,
                    "MS-CHAP-2" => 4,
                    "PAP"       => 1
                },
                24 => {
                    "Generic-Token-Card" => 6,
                    "MD5"                => 4,
                    "OTP"                => 5,
                    "TLS"                => 13
                },
                41 => {
                    "Ignore-User-Lookup-Failure" => 2,
                    "Machine-Health-Check"       => 1
                },
                45 =>
                  { "Full-Access" => 0, "Probation" => 2, "Quarantine" => 1 },
                47 => {
                    "DHCP-Server"             => 3,
                    "HCAP-Server"             => 6,
                    "HRA"                     => 5,
                    "Remote-Access-Server"    => 2,
                    "Terminal-Server-Gateway" => 1,
                    "Unspecified"             => 0,
                    "Wireless-Access-Point"   => 4,
                },
                48 => {
                    "MS-AFW-Zone-Boundary-Policy"    => 1,
                    "MS-AFW-Zone-Protected-Policy"   => 3,
                    "MS-AFW-Zone-Unprotected-Policy" => 2,
                },
                49 => {
                    "HECP-Response-Sign-And-Encrypt" => 2,
                    "HECP-Response-Sign-Only"        => 1,
                },
                54 => { "SoH-Not-Sent" => 1, "SoH-Sent" => 0 },
                57 => {
                    "Infected"   => 2,
                    "No-Data"    => 4,
                    "Transition" => 1,
                    "Unknown"    => 3
                },
            },
            318 => {
                1 => {
                    Admin       => 1,
                    Card        => 5,
                    Device      => 2,
                    NetworkOnly => 6,
                    Outlet      => 4,
                    ReadOnly    => 3
                },
            },
            388 => {
                1 => {
                    Helpdesk     => 2,
                    Monitor      => 1,
                    NetworkAdmin => 4,
                    Security     => 32,
                    SuperUser    => 32768,
                    SysAdmin     => 8,
                    WebAdmin     => 16,
                },
                5 =>
                  { Background => 2, BestEffort => 1, Video => 3, Voice => 4 },
                100 => {
                    All     => 240,
                    Console => 128,
                    HTTP    => 16,
                    SSH     => 32,
                    Telnet  => 64
                },
            },
            429 => {
                94 => {
                    "110-BPS"     => 1,
                    "115K-BPS"    => 22,
                    "1200-BPS"    => 4,
                    "12K-BPS"     => 9,
                    "14.4K-BPS"   => 10,
                    "16.8-BPS"    => 11,
                    "19.2K-BPS"   => 12,
                    "21.6K-BPS"   => 18,
                    "2400-BPS"    => 5,
                    "24K-BPS"     => 19,
                    "26K-BPS"     => 20,
                    "28K-BPS"     => 21,
                    "300-BPS"     => 2,
                    "38.4K-BPS"   => 13,
                    "450-BPS"     => 15,
                    "4800-BPS"    => 6,
                    "57.6K-BPS"   => 17,
                    "600-BPS"     => 3,
                    "7200-BPS"    => 7,
                    "75-BPS"      => 14,
                    "9600-BPS"    => 8,
                    "UNKNOWN-BPS" => 16,
                },
                103 => { Asynchronous => 1, Synchronous => 2 },
                104 => {
                    Answer_in_Answer_Mode       => 4,
                    Answer_in_Originate_Mode    => 3,
                    Originate_in_Answer_Mode    => 2,
                    Originate_in_Originate_Mode => 1,
                },
                105 => {
                    abnormalDisconnect         => 77,
                    abortAnlgDstOvrIsdn        => 72,
                    athCommand                 => 3,
                    autopassFailed             => 45,
                    bearerIncompatibility      => 75,
                    carrierLoss                => 4,
                    class2FaxHangupCmd         => 66,
                    dialBackLink               => 43,
                    dialSecurity               => 34,
                    ds0Teardown                => 37,
                    dspHeadPtrInvalid          => 98,
                    dspInterruptTimeout        => 64,
                    dspReboot                  => 94,
                    dspTailPtrInvalid          => 97,
                    dtrDrop                    => 1,
                    escapeSequence             => 2,
                    hstSpeedSwitchTimeout      => 67,
                    inactivityTimout           => 5,
                    incomingCallBlock          => 88,
                    incomingInvalidBearerCap   => 83,
                    incomingInvalidCalledPty   => 87,
                    incomingInvalidCallingPty  => 86,
                    incomingInvalidChannelID   => 84,
                    incomingInvalidProgInd     => 85,
                    incomingLoopStNoRingOff    => 89,
                    incomingModemNotAvailable  => 82,
                    invalidCauseValue          => 78,
                    invalidSpeed               => 13,
                    keyAbort                   => 17,
                    lineBusy                   => 18,
                    linkAbort                  => 44,
                    linkDisconnectMsgRec       => 11,
                    linkPassword               => 9,
                    loopLoss                   => 36,
                    managementCommand          => 15,
                    mnpIncompatible            => 6,
                    mnpProtocolViolation       => 65,
                    modeIncompatible           => 41,
                    noAnswer                   => 19,
                    noAnswerTone               => 21,
                    noCarrier                  => 22,
                    noDialTone                 => 16,
                    noDSPRespToDisc            => 96,
                    noDSPRespToKA              => 95,
                    noLoopCurrent              => 12,
                    nonArqMode                 => 40,
                    none                       => 32,
                    noPromptingInSync          => 39,
                    noPromptInNonARQ           => 42,
                    normalUnspecified          => 74,
                    normalUserCallClear        => 73,
                    outgoingEMWinkTimeout      => 91,
                    outgoingEMWinkTooShort     => 92,
                    outgoingNoChannelAvail     => 93,
                    outgoingTelcoDisconnect    => 90,
                    pbAckWaitTimeout           => 58,
                    pbBadFrame                 => 57,
                    pbClockMissing             => 54,
                    pbGenericError             => 46,
                    pbLinkErrRxTAL             => 52,
                    pbLinkErrTxPreAck          => 47,
                    pbLinkErrTxTAL             => 51,
                    pbLinkErrTxTardyACK        => 48,
                    pbOutOfSequenceFrame       => 56,
                    pbReceiveBusTimeout        => 50,
                    pbReceivedAckSeqErr        => 59,
                    pbReceivedLsWhileLinkUp    => 55,
                    pbReceiveMsgBufOvrflw      => 61,
                    pbReceiveOvrflwRNRFail     => 60,
                    pbTransmitBusTimeout       => 49,
                    pbTransmitMasterTimeout    => 53,
                    priDialoutRqTimeout        => 71,
                    promptNotEnabled           => 38,
                    protocolErrorEvent         => 76,
                    rcvdGatewayDiscCmd         => 62,
                    remoteAccessDenied         => 35,
                    remoteHungUpDuringTraining => 80,
                    remotePassword             => 8,
                    resourceUnavailable        => 79,
                    retransmitLimit            => 10,
                    t1Glare                    => 70,
                    timerExpired               => 69,
                    tokenPassingTimeout        => 63,
                    tooManyUnacked             => 68,
                    trainingTimeout            => 81,
                    unableToRetrain            => 14,
                    undefined                  => 7,
                    undetermined               => 23,
                    v32Cleardown               => 33,
                    v42BadSetup                => 28,
                    v42BreakTimeout            => 25,
                    v42DisconnectCmd           => 26,
                    v42IdExchangeFail          => 27,
                    v42InvalidCodeWord         => 29,
                    v42InvalidCommand          => 31,
                    v42SabmeTimeout            => 24,
                    v42StringToLong            => 30,
                    voice                      => 20,
                },
                106 => {
                    "110-BPS"     => 1,
                    "115200-BPS"  => 22,
                    "1200-BPS"    => 4,
                    "12000-BPS"   => 9,
                    "14400-BPS"   => 10,
                    "16800-BPS"   => 11,
                    "19200-BPS"   => 12,
                    "21600-BPS"   => 18,
                    "2400-BPS"    => 5,
                    "24000-BPS"   => 19,
                    "25333-BPS"   => 25,
                    "26400-BPS"   => 20,
                    "26666-BPS"   => 26,
                    "28000-BPS"   => 27,
                    "28800-BPS"   => 21,
                    "29333-BPS"   => 28,
                    "300-BPS"     => 2,
                    "30666-BPS"   => 29,
                    "31200-BPS"   => 23,
                    "32000-BPS"   => 30,
                    "33333-BPS"   => 31,
                    "33600-BPS"   => 24,
                    "34666-BPS"   => 32,
                    "36000-BPS"   => 33,
                    "37333-BPS"   => 34,
                    "38400-BPS"   => 13,
                    "38666-BPS"   => 35,
                    "40000-BPS"   => 36,
                    "41333-BPS"   => 37,
                    "42666-BPS"   => 38,
                    "44000-BPS"   => 39,
                    "450-BPS"     => 15,
                    "45333-BPS"   => 40,
                    "46666-BPS"   => 41,
                    "4800-BPS"    => 6,
                    "48000-BPS"   => 42,
                    "49333-BPS"   => 43,
                    "50666-BPS"   => 44,
                    "52000-BPS"   => 45,
                    "53333-BPS"   => 46,
                    "54666-BPS"   => 47,
                    "56000-BPS"   => 48,
                    "57333-BPS"   => 49,
                    "57600-BPS"   => 17,
                    "58666-BPS"   => 50,
                    "600-BPS"     => 3,
                    "60000-BPS"   => 51,
                    "61333-BPS"   => 52,
                    "62666-BPS"   => 53,
                    "64000-BPS"   => 54,
                    "7200-BPS"    => 7,
                    "75-BPS"      => 14,
                    "9600-BPS"    => 8,
                    "UNKNOWN-BPS" => 16,
                },
                107 => {
                    "110-BPS"     => 1,
                    "115200-BPS"  => 22,
                    "1200-BPS"    => 4,
                    "12000-BPS"   => 9,
                    "14400-BPS"   => 10,
                    "16800-BPS"   => 11,
                    "19200-BPS"   => 12,
                    "21600-BPS"   => 18,
                    "2400-BPS"    => 5,
                    "24000-BPS"   => 19,
                    "25333-BPS"   => 25,
                    "26400-BPS"   => 20,
                    "26666-BPS"   => 26,
                    "28000-BPS"   => 27,
                    "28800-BPS"   => 21,
                    "29333-BPS"   => 28,
                    "300-BPS"     => 2,
                    "30666-BPS"   => 29,
                    "31200-BPS"   => 23,
                    "32000-BPS"   => 30,
                    "33333-BPS"   => 31,
                    "33600-BPS"   => 24,
                    "34666-BPS"   => 32,
                    "36000-BPS"   => 33,
                    "37333-BPS"   => 34,
                    "38400-BPS"   => 13,
                    "38666-BPS"   => 35,
                    "40000-BPS"   => 36,
                    "41333-BPS"   => 37,
                    "42666-BPS"   => 38,
                    "44000-BPS"   => 39,
                    "450-BPS"     => 15,
                    "45333-BPS"   => 40,
                    "46666-BPS"   => 41,
                    "4800-BPS"    => 6,
                    "48000-BPS"   => 42,
                    "49333-BPS"   => 43,
                    "50666-BPS"   => 44,
                    "52000-BPS"   => 45,
                    "53333-BPS"   => 46,
                    "54666-BPS"   => 47,
                    "56000-BPS"   => 48,
                    "57333-BPS"   => 49,
                    "57600-BPS"   => 17,
                    "58666-BPS"   => 50,
                    "600-BPS"     => 3,
                    "60000-BPS"   => 51,
                    "61333-BPS"   => 52,
                    "62666-BPS"   => 53,
                    "64000-BPS"   => 54,
                    "7200-BPS"    => 7,
                    "75-BPS"      => 14,
                    "9600-BPS"    => 8,
                    "UNKNOWN-BPS" => 16,
                },
                108 => {
                    asyncSyncPPP      => 27,
                    bell103           => 4,
                    bell208b          => 10,
                    bell212           => 6,
                    ccittV21          => 5,
                    ccittV22bis       => 3,
                    ccittV23          => 8,
                    ccittV32          => 2,
                    ccittV32bis       => 7,
                    clearChannel      => 28,
                    negotiationFailed => 9,
                    piafs             => 31,
                    usRoboticsHST     => 1,
                    v110              => 24,
                    v120              => 25,
                    v17FaxClass1      => 14,
                    v17FaxClass2      => 18,
                    v21FaxClass1      => 11,
                    v21FaxClass2      => 15,
                    v27FaxClass1      => 12,
                    v27FaxClass2      => 16,
                    v29FaxClass1      => 13,
                    v29FaxClass2      => 17,
                    v32Terbo          => 19,
                    v34               => 20,
                    v34plus           => 22,
                    v90AllDigital     => 35,
                    v90Analog         => 33,
                    v90Digital        => 34,
                    vFC               => 21,
                    x2                => 23,
                    x2client          => 29,
                    x2symmetric       => 30,
                    x2version2        => 32,
                    x75               => 26,
                },
                111 => { Long     => 1, Short    => 2 },
                112 => { Disabled => 1, Enabled  => 2 },
                124 => { "300BPS" => 2, "450BPS" => 1, "None" => 3 },
                153 => {
                    ccittV42        => 4,
                    lapmEtc         => 11,
                    mnp10           => 8,
                    mnp10Etc        => 10,
                    mnpLevel2       => 7,
                    mnpLevel3       => 2,
                    mnpLevel4       => 3,
                    none            => 1,
                    piafs           => 14,
                    synchronousNone => 6,
                    usRoboticsHST   => 5,
                    v42Etc          => 9,
                    v42Etc2         => 12,
                    v42SRej         => 13,
                },
                155 => {
                    abnormalDisconnect         => 77,
                    abortAnlgDstOvrIsdn        => 72,
                    athCommand                 => 3,
                    autopassFailed             => 45,
                    bearerIncompatibility      => 75,
                    carrierLoss                => 4,
                    class2FaxHangupCmd         => 66,
                    dialBackLink               => 43,
                    dialSecurity               => 34,
                    ds0Teardown                => 37,
                    dspHeadPtrInvalid          => 98,
                    dspInterruptTimeout        => 64,
                    dspReboot                  => 94,
                    dspTailPtrInvalid          => 97,
                    dtrDrop                    => 1,
                    escapeSequence             => 2,
                    hstSpeedSwitchTimeout      => 67,
                    inactivityTimout           => 5,
                    incomingCallBlock          => 88,
                    incomingInvalidBearerCap   => 83,
                    incomingInvalidCalledPty   => 87,
                    incomingInvalidCallingPty  => 86,
                    incomingInvalidChannelID   => 84,
                    incomingInvalidProgInd     => 85,
                    incomingLoopStNoRingOff    => 89,
                    incomingModemNotAvailable  => 82,
                    invalidCauseValue          => 78,
                    invalidSpeed               => 13,
                    keyAbort                   => 17,
                    lineBusy                   => 18,
                    linkAbort                  => 44,
                    linkDisconnectMsgReceived  => 11,
                    linkPassword               => 9,
                    loopLoss                   => 36,
                    managementCommand          => 15,
                    mnpIncompatible            => 6,
                    mnpProtocolViolation       => 65,
                    modeIncompatible           => 41,
                    noAnswer                   => 19,
                    noAnswerTone               => 21,
                    noCarrier                  => 22,
                    noDialTone                 => 16,
                    noDSPRespToDisc            => 96,
                    noDSPRespToKA              => 95,
                    noLoopCurrent              => 12,
                    nonArqMode                 => 40,
                    none                       => 32,
                    noPromptingInSync          => 39,
                    noPromptInNonARQ           => 42,
                    normalUnspecified          => 74,
                    normalUserCallClear        => 73,
                    outgoingEMWinkTimeout      => 91,
                    outgoingEMWinkTooShort     => 92,
                    outgoingNoChannelAvail     => 93,
                    outgoingTelcoDisconnect    => 90,
                    pbAckWaitTimeout           => 58,
                    pbBadFrame                 => 57,
                    pbClockMissing             => 54,
                    pbGenericError             => 46,
                    pbLinkErrRxTAL             => 52,
                    pbLinkErrTxPreAck          => 47,
                    pbLinkErrTxTAL             => 51,
                    pbLinkErrTxTardyACK        => 48,
                    pbOutOfSequenceFrame       => 56,
                    pbReceiveBusTimeout        => 50,
                    pbReceivedAckSeqErr        => 59,
                    pbReceivedLsWhileLinkUp    => 55,
                    pbReceiveMsgBufOvrflw      => 61,
                    pbReceiveOvrflwRNRFail     => 60,
                    pbTransmitBusTimeout       => 49,
                    pbTransmitMasterTimeout    => 53,
                    priDialoutRqTimeout        => 71,
                    promptNotEnabled           => 38,
                    protocolErrorEvent         => 76,
                    rcvdGatewayDiscCmd         => 62,
                    remoteAccessDenied         => 35,
                    remoteHungUpDuringTraining => 80,
                    remotePassword             => 8,
                    resourceUnavailable        => 79,
                    retransmitLimit            => 10,
                    t1Glare                    => 70,
                    timerExpired               => 69,
                    tokenPassingTimeout        => 63,
                    tooManyUnacked             => 68,
                    trainingTimeout            => 81,
                    unableToRetrain            => 14,
                    undefined                  => 7,
                    undetermined               => 23,
                    v32Cleardown               => 33,
                    v42BadSetup                => 28,
                    v42BreakTimeout            => 25,
                    v42DisconnectCmd           => 26,
                    v42IdExchangeFail          => 27,
                    v42InvalidCodeWord         => 29,
                    v42InvalidCommand          => 31,
                    v42SabmeTimeout            => 24,
                    v42StringToLong            => 30,
                    voice                      => 20,
                },
                199 => { ccittV42bis => 2, mnpLevel5 => 3, none => 1 },
                461 => {
                    notDetectedInRemoteModem => 2,
                    notEnabledInLocalModem   => 1,
                    ok                       => 3
                },
                2305 => {
                    initialConnection => 2,
                    none              => 1,
                    plannedDisconnect => 5,
                    retrain           => 3,
                    speedShift        => 4,
                },
                2313 => {
                    connectNotSupport3200    => 13,
                    excessHighFrequencyAtten => 12,
                    incompatibleModes        => 10,
                    incompatibleVersion      => 9,
                    invalidSpeedSetting      => 6,
                    local3200Disabled        => 11,
                    notOperational           => 1,
                    operational              => 2,
                    remote3200Disabled       => 5,
                    retrainBeforeConnection  => 14,
                    v8Disabled               => 4,
                    v8NotDetected            => 7,
                    x2Disabled               => 3,
                    x2NotDetected            => 8,
                },
                2314 => {
                    arqProtocolError          => 8,
                    arqProtocolRetransmitLim  => 9,
                    athCommand                => 6,
                    dteInterfaceError         => 3,
                    dteNotReady               => 2,
                    dteRequest                => 4,
                    escapeToOnlineCommandMode => 5,
                    inactivityTimeout         => 7,
                    invalidComprDataCodeword  => 10,
                    invalidComprDataCommand   => 12,
                    invalidComprDataStringLen => 11,
                    none                      => 1,
                },
                2339 => {
                    asyncSyncPPP      => 27,
                    bell103           => 4,
                    bell208b          => 10,
                    bell212           => 6,
                    ccittV21          => 5,
                    ccittV22bis       => 3,
                    ccittV23          => 8,
                    ccittV32          => 2,
                    ccittV32bis       => 7,
                    clearChannel      => 28,
                    negotiationFailed => 9,
                    piafs             => 31,
                    usRoboticsHST     => 1,
                    v110              => 24,
                    v120              => 25,
                    v17FaxClass1      => 14,
                    v17FaxClass2      => 18,
                    v21FaxClass1      => 11,
                    v21FaxClass2      => 15,
                    v27FaxClass1      => 12,
                    v27FaxClass2      => 16,
                    v29FaxClass1      => 13,
                    v29FaxClass2      => 17,
                    v32Terbo          => 19,
                    v34               => 20,
                    v34plus           => 22,
                    v90AllDigital     => 35,
                    v90Analogue       => 33,
                    v90Digital        => 34,
                    vFC               => 21,
                    x2                => 23,
                    x2client          => 29,
                    x2symmetric       => 30,
                    x2version2        => 32,
                    x75               => 26,
                },
                32770 => {
                    "COMS-ADMINISTRATIVE-ACCT" => 4,
                    "COMS-NEW-ACCT"            => 2,
                    "COMS-PREPAID-ACCT"        => 1,
                    "COMS-SUSPENDED-ACCT"      => 3,
                    "COMS-UNKNOWN-ACCT-TYPE"   => 0,
                },
                32774 => {
                    "COMS-EGRESS-CLOSE"         => 514,
                    "COMS-EGRESS-OPEN"          => 258,
                    "COMS-GTKPR-GEN-EGR-CLOSE"  => 516,
                    "COMS-GTKPR-GEN-EGR-OPEN"   => 260,
                    "COMS-GTKPR-GEN-INGR-CLOSE" => 515,
                    "COMS-GTKPR-GEN-INGR-OPEN"  => 259,
                    "COMS-INGRESS-CLOSE"        => 513,
                    "COMS-INGRESS-OPEN"         => 257,
                    "COMS-UNKNOWN-SOURCE"       => 0,
                },
                32778 => { "LAST-CALL" => 1, "NOT-THE-LAST-CALL" => 0 },
                32780 => {
                    comsAbbreviatedNumber     => 6,
                    comsInternationalNumber   => 2,
                    comsNationalNumber        => 3,
                    comsNetworkSpecificNumber => 4,
                    comsReserved              => 7,
                    comsSubscriberNumber      => 5,
                    comsUnknown               => 1,
                },
                32782 => { SCTP => 3, TCP => 1, UDP => 2 },
                32786 => {
                    comsAbbreviatedNumber     => 6,
                    comsInternationalNumber   => 2,
                    comsNationalNumber        => 3,
                    comsNetworkSpecificNumber => 4,
                    comsReserved              => 7,
                    comsSubscriberNumber      => 5,
                    comsUnknown               => 1,
                },
                32788 => { SCTP => 3, TCP => 1, UDP => 2 },
                32794 => {
                    comsAbbreviatedNumber     => 6,
                    comsInternationalNumber   => 2,
                    comsNationalNumber        => 3,
                    comsNetworkSpecificNumber => 4,
                    comsReserved              => 7,
                    comsSubscriberNumber      => 5,
                    comsUnknown               => 1,
                },
                32796 => { SCTP => 3, TCP => 1, UDP => 2 },
                32800 => { SCTP => 3, TCP => 1, UDP => 2 },
                32804 => { SCTP => 3, TCP => 1, UDP => 2 },
                32808 => { SCTP => 3, TCP => 1, UDP => 2 },
                32813 => {
                    "COMS-PC-TO-PC"         => 4,
                    "COMS-PC-TO-PHONE"      => 3,
                    "COMS-PHONE-TO-PC"      => 2,
                    "COMS-PHONE-TO-PHONE"   => 1,
                    "COMS-UNKNOWN-CALLTYPE" => 0,
                },
                32821 => {
                    "COMS-FAX-MODULATION"  => 255,
                    "COMS-G710-ALaw"       => 3,
                    "COMS-G711-MuLaw"      => 4,
                    "COMS-G723-1"          => 1,
                    "COMS-G729-A"          => 2,
                    "COMS-UNDEFINED-CODEC" => 0,
                },
                32822 => {
                    "CAUSE-ABANDON"                   => 15,
                    "CAUSE-ACCT-BAL-DEPLETED"         => 3,
                    "CAUSE-ACCT-INUSE"                => 22,
                    "CAUSE-AUTHENT-SERVER-DOWN"       => 19,
                    "CAUSE-BUSY"                      => 14,
                    "CAUSE-CLD-PARTY-TERMINATE"       => 1,
                    "CAUSE-CLG-PARTY-TERMINATE"       => 2,
                    "CAUSE-DEBIT-ACCT-BAL-ZERO"       => 23,
                    "CAUSE-DEBIT-ACCTBAL-INSUFF"      => 24,
                    "CAUSE-DIR-SERVER-DOWN"           => 9,
                    "CAUSE-EGR-FACILITY-DISC"         => 8,
                    "CAUSE-GATEKEEPER-TIMEOUT"        => 20,
                    "CAUSE-GATEWAY-NO-RESOURCES"      => 21,
                    "CAUSE-GATEWAY-SHUTDOWN"          => 11,
                    "CAUSE-GTKPR-SHUTDOWN-GTWAY"      => 13,
                    "CAUSE-GTKPR-TERMINATE"           => 12,
                    "CAUSE-H225-UNABLE-TO-CON"        => 5,
                    "CAUSE-H245-UNABLE-TO-CON"        => 6,
                    "CAUSE-INGR-FACILITY-DISC"        => 7,
                    "CAUSE-INVALID-DESTNUMBER-THRESH" => 25,
                    "CAUSE-INVALID-LOGIN-LIMIT"       => 16,
                    "CAUSE-NO-DESTNUMBER-ENTRY"       => 26,
                    "CAUSE-NO-EGR-PORTS-AVAIL"        => 4,
                    "CAUSE-NOACCTNUMBER-ENTRY"        => 17,
                    "CAUSE-RATING-SERVER-DOWN"        => 10,
                    "CAUSE-SEQUENCE-DIALING-THRESH"   => 27,
                    "CAUSE-SUSPENDED-ACCT-LOGIN"      => 18,
                    "CAUSE-UNKNOWN"                   => 0,
                },
                32845 =>
                  { "SIG-H323" => 2, "SIG-SIP" => 1, "SIG-UNKNOWN" => 0 },
                32846 => { SCTP => 3, TCP => 1, UDP => 2 },
                32847 => { SCTP => 3, TCP => 1, UDP => 2 },
                32851 => { SCTP => 3, TCP => 1, UDP => 2 },
                32855 => { SCTP => 3, TCP => 1, UDP => 2 },
                32859 => { SCTP => 3, TCP => 1, UDP => 2 },
                32865 => {
                    "Abbreviated-Number"      => 6,
                    "International-Number"    => 2,
                    "National-Number"         => 3,
                    "Network-Specific-Number" => 4,
                    "Reserved"                => 7,
                    "Subscriber-Number"       => 5,
                    "Unknown"                 => 1,
                },
                36883 => {
                    "Off"       => 0,
                    "On-Framed" => 2,
                    "On-Raw"    => 1,
                    "Unknown"   => 4294967295
                },
                36897 => { Any => 4, MS => 3, NONE => 1, Stac => 2 },
                36899 => {
                    "115200-BPS"  => 16,
                    "1200-75-BPS" => 19,
                    "1200-BPS"    => 3,
                    "12000-BPS"   => 8,
                    "14400-BPS"   => 9,
                    "16800-BPS"   => 10,
                    "19200-BPS"   => 11,
                    "21600-BPS"   => 12,
                    "2400-BPS"    => 4,
                    "24000-BPS"   => 20,
                    "25333-BPS"   => 40,
                    "26400-BPS"   => 21,
                    "26666-BPS"   => 41,
                    "28000-BPS"   => 42,
                    "28800-BPS"   => 13,
                    "288000-BPS"  => 17,
                    "29333-BPS"   => 43,
                    "300-BPS"     => 2,
                    "30666-BPS"   => 44,
                    "31200-BPS"   => 22,
                    "32000-BPS"   => 45,
                    "33333-BPS"   => 24,
                    "33600-BPS"   => 23,
                    "34666-BPS"   => 46,
                    "36000-BPS"   => 47,
                    "37333-BPS"   => 25,
                    "38400-BPS"   => 14,
                    "38666-BPS"   => 48,
                    "40000-BPS"   => 49,
                    "41333-BPS"   => 26,
                    "42666-BPS"   => 27,
                    "44000-BPS"   => 28,
                    "45333-BPS"   => 29,
                    "46666-BPS"   => 30,
                    "4800-BPS"    => 5,
                    "48000-BPS"   => 31,
                    "49333-BPS"   => 32,
                    "50666-BPS"   => 33,
                    "52000-BPS"   => 34,
                    "53333-BPS"   => 35,
                    "54666-BPS"   => 36,
                    "56000-BPS"   => 37,
                    "57333-BPS"   => 38,
                    "57600-BPS"   => 15,
                    "58666-BPS"   => 50,
                    "60000-BPS"   => 51,
                    "61333-BPS"   => 52,
                    "62666-BPS"   => 53,
                    "64000-BPS"   => 39,
                    "7200-BPS"    => 6,
                    "75-1200-BPS" => 18,
                    "9600-BPS"    => 7,
                    "NONE"        => 1,
                },
                38913 => { 56 => 1, 64 => 2, Auto => 0, Voice => 3 },
                38917 => { Constant => 1, Linear => 2 },
                38918 => {
                    Ascend    => 2,
                    Auto      => 4,
                    Microsoft => 3,
                    None      => 0,
                    Stac      => 1
                },
                38922 => {
                    "Auto"               => 0,
                    "Reset-Every-Packet" => 1,
                    "Reset-On-Error"     => 2
                },
                38926 => { disabled => 2, enabled => 1 },
                38927 => { disabled => 2, enabled => 1 },
                38928 => { disabled => 2, enabled => 1 },
                38929 => { disabled => 2, enabled => 1 },
                38950 => { Rip1     => 1, Rip2    => 2 },
                38952 =>
                  { all => 4, listen => 2, none => 0, respond => 3, send => 1 },
                38953 => { disabled => 2, enabled => 1 },
                38954 => {
                    AcceptDefault => 8,
                    FlashUpdate   => 64,
                    PoisonReserve => 32,
                    SendDefault   => 0,
                    SendRoutes    => 2,
                    SendSubnets   => 4,
                    Silent        => 2147483648,
                    SimpleAuth    => 128,
                    SplitHorizon  => 16,
                    V1Receive     => 512,
                    V1Send        => 256,
                    V2Receive     => 1024,
                },
                38976 => { disabled => 2, enabled => 1 },
                38980 => {
                    "Both-Data-and-Control" => 3,
                    "Control-Only"          => 1,
                    "Data-Only"             => 2,
                    "None"                  => 0,
                },
                39018 => { ANI => 2, Dynamic => 4, Normal => 1, Static => 3 },
                39030 => { FA  => 1, HA => 2 },
                39051 => {
                    "Call-Drop-Req"           => 5,
                    "CHAP-Auth-Failure"       => 28,
                    "DNIS-Auth-Failed"        => 26,
                    "Host-Req-Drop"           => 9,
                    "Idle-Timeout"            => 6,
                    "Line-Busy"               => 16,
                    "NAS-Drop-For-Callback"   => 13,
                    "NAS-Drop-Misc-Non-Error" => 14,
                    "NAS-Internal-Error"      => 15,
                    "No-Carrier"              => 1,
                    "No-DSR"                  => 2,
                    "No-Error"                => 0,
                    "PAP-Auth-Failure"        => 27,
                    "PPP-LCP-Failed"          => 29,
                    "PPP-NCP-Failed"          => 30,
                    "Radius-Res-Reclaim"      => 25,
                    "Radius-Timeout"          => 31,
                    "Reset"                   => 4,
                    "Service-Interruption"    => 10,
                    "Service-Unavailable"     => 11,
                    "Session-Timeout"         => 7,
                    "Timeout"                 => 3,
                    "Tunnel-Auth-Failed"      => 21,
                    "Tunnel-Refused"          => 20,
                    "Tunnel-Session-Timeout"  => 22,
                    "Tunnel-Term-Unreach"     => 19,
                    "Tunnel-Timeout"          => 23,
                    "User-Input-Error"        => 12,
                    "User-Req-Drop"           => 8,
                },
                48735 => { isdnGateway => 2, None => 1, quadModem => 3 },
                48738 => {
                    analogBlocked      => 21,
                    bcReject           => 14,
                    blocked            => 20,
                    busy               => 24,
                    calledPartyReject  => 19,
                    callingPartyReject => 18,
                    chidReject         => 16,
                    congestion         => 25,
                    digitalBlocked     => 22,
                    ieReject           => 15,
                    igwRejectCall      => 11,
                    igwSetupTimeout    => 12,
                    inCallArrival      => 29,
                    inCallConnect      => 31,
                    inOutCallCollision => 28,
                    modemSetupTimeout  => 9,
                    modemsNotAllowed   => 7,
                    modemsRejectCall   => 8,
                    noFreeBchannel     => 27,
                    noFreeIGW          => 10,
                    noFreeModem        => 6,
                    noFreeTdmts        => 13,
                    notSupported       => 1,
                    outCallArrival     => 30,
                    outCallConnect     => 32,
                    outOfService       => 23,
                    progReject         => 17,
                    protocolError      => 26,
                    setup              => 2,
                    telcoDisconnect    => 4,
                    usrDisconnect      => 5,
                    usrSetup           => 3,
                },
                48773 => {
                    "486EthernetGatewayNAC"     => 20,
                    "486TrGatewayNAC"           => 19,
                    "486X25GatewayNAC"          => 23,
                    "AccessServer"              => 18,
                    "ApplicationServerNAC"      => 25,
                    "BellcoreLongHaulDualT1NIC" => 1025,
                    "BellcoreShrtHaulDualT1NIC" => 1026,
                    "ClkedNetMgtCard"           => 28,
                    "DualAlogMdmNIC"            => 1002,
                    "DualAlogMgdIntlMdmNIC"     => 1009,
                    "DualE1NIC"                 => 1022,
                    "DualHighSpeedV35NIC"       => 1020,
                    "DualModemNAC"              => 5,
                    "DualRS232NAC"              => 22,
                    "DualT1NAC"                 => 4,
                    "DualT1NIC"                 => 1001,
                    "DualV34ModemNAC"           => 9,
                    "EnhancedAccessServer"      => 44,
                    "EnhancedISDNGatewayNAC"    => 45,
                    "EthernetGatewayNAC"        => 17,
                    "EthernetNIC"               => 1007,
                    "HSEthernetWithoutV35NIC"   => 1019,
                    "HSEthernetWithV35NIC"      => 1018,
                    "ISDNGatewayNAC"            => 26,
                    "ISDNpriT1NAC"              => 27,
                    "ModemPoolISDNNAC"          => 32,
                    "ModemPoolManagementNAC"    => 29,
                    "ModemPoolNetserverNAC"     => 30,
                    "ModemPoolV34ModemNAC"      => 31,
                    "NETServerFrameRelayNAC"    => 37,
                    "NETServerTokenRingNAC"     => 38,
                    "NetwMgtCard"               => 3,
                    "NTServerNAC"               => 33,
                    "QuadAlogDgtlMdmNIC"        => 1004,
                    "QuadAlogMgdIntlMdmNIC"     => 1012,
                    "QuadAlogNonMgdIntlMdmNIC"  => 1013,
                    "QuadAlogNonMgdMdmNIC"      => 1011,
                    "QuadDgtlMdmNIC"            => 1003,
                    "QuadLsdLiMgdIntlMdmNIC"    => 1016,
                    "QuadLsdLiMgdMdmNIC"        => 1014,
                    "QuadLsdLiNonMgdIntlMdmNIC" => 1017,
                    "QuadLsdLiNonMgdMdmNIC"     => 1015,
                    "QuadModemNAC"              => 6,
                    "QuadV32AnalogModemNAC"     => 11,
                    "QuadV32DigAnlModemNAC"     => 12,
                    "QuadV32DigitalModemNAC"    => 10,
                    "QuadV34AnalogG2NAC"        => 35,
                    "QuadV34AnlModemNAC"        => 14,
                    "QuadV34DigAnlgG2NAC"       => 36,
                    "QuadV34DigAnlModemNAC"     => 15,
                    "QuadV34DigitalG2NAC"       => 34,
                    "QuadV34DigModemNAC"        => 13,
                    "QuadV35RS232LowSpeedNIC"   => 1021,
                    "SCSIEdgeServerNIC"         => 1027,
                    "ShortHaulDualE1NIC"        => 1023,
                    "ShortHaulDualT1NIC"        => 1008,
                    "SingleT1NAC"               => 16,
                    "SingleT1NIC"               => 1006,
                    "SlotEmpty"                 => 1,
                    "SlotUnknown"               => 2,
                    "TokenRingNIC"              => 1005,
                    "TrGatewayNAC"              => 7,
                    "WirelessGatewayNac"        => 42,
                    "X2524ChannelNAC"           => 39,
                    "X25GatewayNAC"             => 8,
                    "X25NIC"                    => 1010,
                },
                48940 => {
                    "110-BPS"     => 1,
                    "115200-BPS"  => 22,
                    "1200-BPS"    => 4,
                    "12000-BPS"   => 9,
                    "14400-BPS"   => 10,
                    "16800-BPS"   => 11,
                    "19200-BPS"   => 12,
                    "21600-BPS"   => 18,
                    "2400-BPS"    => 5,
                    "24000-BPS"   => 19,
                    "25333-BPS"   => 25,
                    "26400-BPS"   => 20,
                    "26666-BPS"   => 26,
                    "28000-BPS"   => 27,
                    "28800-BPS"   => 21,
                    "29333-BPS"   => 28,
                    "300-BPS"     => 2,
                    "30666-BPS"   => 29,
                    "31200-BPS"   => 23,
                    "32000-BPS"   => 30,
                    "33333-BPS"   => 31,
                    "33600-BPS"   => 24,
                    "34666-BPS"   => 32,
                    "36000-BPS"   => 33,
                    "37333-BPS"   => 34,
                    "38400-BPS"   => 13,
                    "38666-BPS"   => 35,
                    "40000-BPS"   => 36,
                    "41333-BPS"   => 37,
                    "42666-BPS"   => 38,
                    "44000-BPS"   => 39,
                    "450-BPS"     => 15,
                    "45333-BPS"   => 40,
                    "46666-BPS"   => 41,
                    "4800-BPS"    => 6,
                    "48000-BPS"   => 42,
                    "49333-BPS"   => 43,
                    "50666-BPS"   => 44,
                    "52000-BPS"   => 45,
                    "53333-BPS"   => 46,
                    "54666-BPS"   => 47,
                    "56000-BPS"   => 48,
                    "57333-BPS"   => 49,
                    "57600-BPS"   => 17,
                    "58666-BPS"   => 50,
                    "600-BPS"     => 3,
                    "60000-BPS"   => 51,
                    "61333-BPS"   => 52,
                    "62666-BPS"   => 53,
                    "64000-BPS"   => 54,
                    "7200-BPS"    => 7,
                    "75-BPS"      => 14,
                    "9600-BPS"    => 8,
                    "UNKNOWN-BPS" => 16,
                },
                48941 => {
                    "110-BPS"     => 1,
                    "115200-BPS"  => 22,
                    "1200-BPS"    => 4,
                    "12000-BPS"   => 9,
                    "14400-BPS"   => 10,
                    "16800-BPS"   => 11,
                    "19200-BPS"   => 12,
                    "21600-BPS"   => 18,
                    "2400-BPS"    => 5,
                    "24000-BPS"   => 19,
                    "25333-BPS"   => 25,
                    "26400-BPS"   => 20,
                    "26666-BPS"   => 26,
                    "28000-BPS"   => 27,
                    "28800-BPS"   => 21,
                    "29333-BPS"   => 28,
                    "300-BPS"     => 2,
                    "30666-BPS"   => 29,
                    "31200-BPS"   => 23,
                    "32000-BPS"   => 30,
                    "33333-BPS"   => 31,
                    "33600-BPS"   => 24,
                    "34666-BPS"   => 32,
                    "36000-BPS"   => 33,
                    "37333-BPS"   => 34,
                    "38400-BPS"   => 13,
                    "38666-BPS"   => 35,
                    "40000-BPS"   => 36,
                    "41333-BPS"   => 37,
                    "42666-BPS"   => 38,
                    "44000-BPS"   => 39,
                    "450-BPS"     => 15,
                    "45333-BPS"   => 40,
                    "46666-BPS"   => 41,
                    "4800-BPS"    => 6,
                    "48000-BPS"   => 42,
                    "49333-BPS"   => 43,
                    "50666-BPS"   => 44,
                    "52000-BPS"   => 45,
                    "53333-BPS"   => 46,
                    "54666-BPS"   => 47,
                    "56000-BPS"   => 48,
                    "57333-BPS"   => 49,
                    "57600-BPS"   => 17,
                    "58666-BPS"   => 50,
                    "600-BPS"     => 3,
                    "60000-BPS"   => 51,
                    "61333-BPS"   => 52,
                    "62666-BPS"   => 53,
                    "64000-BPS"   => 54,
                    "7200-BPS"    => 7,
                    "75-BPS"      => 14,
                    "9600-BPS"    => 8,
                    "UNKNOWN-BPS" => 16,
                },
                49086 => {
                    "Acct-Server-Contact-Loss"        => 54,
                    "Application-ProcessorReset"      => 93,
                    "Attempted-Login-Blacklisted"     => 47,
                    "Block-Error-at-Threshold"        => 23,
                    "CDMA-Call-End"                   => 192,
                    "CDMA-Call-Start"                 => 191,
                    "Changed-to-Maint-Srvs-State"     => 95,
                    "Connection-Attempt-Failure"      => 63,
                    "Connection-Failed"               => 18,
                    "Connection-Timeout"              => 19,
                    "Continuous-CRC-Alarm"            => 64,
                    "Continuous-CRC-Alarm-Clear"      => 65,
                    "D-Channel-In-Service"            => 75,
                    "D-Channel-Out-of-Service"        => 76,
                    "Dial-Back-Restricted-Number"     => 45,
                    "Dial-In-Call-Duration"           => 51,
                    "Dial-In-Login-Failure"           => 43,
                    "Dial-Out-Call-Duration"          => 50,
                    "Dial-Out-Login-Failure"          => 42,
                    "Dial-Out-Restricted-Number"      => 44,
                    "DNS-Contact-Degraded"            => 100,
                    "DNS-Contact-Lost"                => 85,
                    "DNS-Contact-Restored"            => 99,
                    "DS0s-In-Service"                 => 77,
                    "DS0s-Out-of-Service"             => 78,
                    "DSP-Reset"                       => 94,
                    "DTE-Ring-No-Answer"              => 34,
                    "DTE-Transmit-Idle"               => 20,
                    "DTR-False"                       => 22,
                    "DTR-True"                        => 21,
                    "Fallbacks-at-Threshold"          => 24,
                    "Fan-Failed"                      => 11,
                    "Gateway-Network-Failed"          => 71,
                    "Gateway-Network-Restored"        => 72,
                    "Gateway-Port-Link-Active"        => 41,
                    "Gateway-Port-Out-of-Service"     => 40,
                    "HUB-Temp-Out-of-Range"           => 10,
                    "In-Connection-Est"               => 14,
                    "In-Connection-Failed"            => 91,
                    "In-Connection-Term"              => 16,
                    "Incoming-Connection-Established" => 59,
                    "Incoming-Connection-Terminated"  => 61,
                    "IPGW-Link-Down"                  => 89,
                    "IPGW-Link-Up"                    => 88,
                    "Login-Attempt-Limit-Exceeded"    => 49,
                    "Loop-Back-cleared-on-channel"    => 96,
                    "Loop-Back-on-channel"            => 97,
                    "Loss-Of-Signal"                  => 29,
                    "Loss-Of-Signal-Clear"            => 57,
                    "Mgmt-Bus-Failure"                => 13,
                    "Modem-Reset-by-DTE"              => 32,
                    "Modem-Ring-No-Answer"            => 33,
                    "Module-Inserted"                 => 6,
                    "Module-Removed"                  => 7,
                    "NMC-AutoRespnse-Trap"            => 53,
                    "No-Dial-Tone-Detected"           => 25,
                    "No-Loop-Current-Detected"        => 26,
                    "NTP-Contact-Degraded"            => 90,
                    "NTP-Contact-Lost"                => 86,
                    "NTP-Contact-Restored"            => 87,
                    "Out-Connection-Est"              => 15,
                    "Out-Connection-Failed"           => 92,
                    "Out-Connection-Term"             => 17,
                    "Outgoing-Connection-Established" => 60,
                    "Outgoing-Connection-Terminated"  => 62,
                    "Packet-Bus-Clock-Lost"           => 73,
                    "Packet-Bus-Clock-Restored"       => 74,
                    "Physical-State-Change"           => 66,
                    "Pkt-Bus-Session-Active"          => 35,
                    "Pkt-Bus-Session-Congestion"      => 36,
                    "Pkt-Bus-Session-Err-Status"      => 52,
                    "Pkt-Bus-Session-Inactive"        => 38,
                    "Pkt-Bus-Session-Lost"            => 37,
                    "PSU-Failed"                      => 9,
                    "Psu-Incompatible"                => 80,
                    "PSU-Voltage-Alarm"               => 8,
                    "RADIUS-Accounting-Group-Degrade" => 103,
                    "RADIUS-Accounting-Group-NonOper" => 104,
                    "RADIUS-Accounting-Group-Restore" => 102,
                    "RADIUS-Accounting-Restored"      => 101,
                    "Rcv-Alrm-Ind-Signal"             => 30,
                    "Rcv-Alrm-Ind-Signal-Clear"       => 58,
                    "Red-Alarm"                       => 28,
                    "Red-Alarm-Clear"                 => 56,
                    "Response-Attempt-Limit-Exceeded" => 48,
                    "RMMIE-Retrain-Event"             => 121,
                    "RMMIE-Speed-Shift-Event"         => 122,
                    "T1,T1-E1/PRI-Call-Arrive-Event"  => 81,
                    "T1,T1-E1/PRI-Call-Connect-Event" => 82,
                    "T1,T1-E1/PRI-Call-Failed-Event"  => 84,
                    "T1,T1-E1/PRI-Call-Termina-Event" => 83,
                    "T1/T1-E1/PRI-InCall-Fail-Event"  => 119,
                    "T1/T1-E1/PRI-OutCall-Fail-Event" => 120,
                    "T1/T1PRI/E1PRI-Call-Event"       => 79,
                    "Telco-Abnormal-Response"         => 98,
                    "Timing-Source-Switch"            => 31,
                    "User-Blacklisted"                => 46,
                    "User-Interface-Reset"            => 39,
                    "Watchdog-Timeout"                => 12,
                    "Yellow-Alarm"                    => 27,
                    "Yellow-Alarm-Clear"              => 55,
                },
                61441 => {
                    "Access-Accept"           => 2,
                    "Access-Challenge"        => 11,
                    "Access-Password-Ack"     => 8,
                    "Access-Password-Change"  => 7,
                    "Access-Password-Reject"  => 9,
                    "Access-Reject"           => 3,
                    "Access-Request"          => 1,
                    "Accounting-Request"      => 4,
                    "Accounting-Response"     => 5,
                    "Disconnect-User"         => 25,
                    "NAS-Reboot-Request"      => 26,
                    "NAS-Reboot-Response"     => 27,
                    "Reserved"                => 255,
                    "Resource-Free-Request"   => 21,
                    "Resource-Free-Response"  => 22,
                    "Resource-Query-Request"  => 23,
                    "Resource-Query-Response" => 24,
                    "Status-Client"           => 13,
                    "Status-Server"           => 12,
                    "Tacacs-Message"          => 253,
                },
                61442 => {
                    "3Com-HiPerArc"      => 2,
                    "3Com-NETBuilder-II" => 7,
                    "3Com-NETServer"     => 1,
                    "3Com-NMC"           => 0,
                    "3Com-SA-Server"     => 4,
                    "Ascend"             => 5,
                    "Generic-RADIUS"     => 6,
                    "TACACS+-Server"     => 3,
                },
                61443 => {
                    "Auth-3Com"       => 0,
                    "Auth-Ace"        => 1,
                    "Auth-Defender"   => 4,
                    "Auth-EAP-Proxy"  => 8,
                    "Auth-Netware"    => 6,
                    "Auth-Safeword"   => 2,
                    "Auth-Skey"       => 7,
                    "Auth-TACACSP"    => 5,
                    "Auth-UNIX-Crypt" => 9,
                    "Auth-UNIX-PW"    => 3,
                },
            },
            529 => {
                13 => {
                    "1_2_2"   => 3,
                    "2_4_5_5" => 2,
                    "2_4_6_4" => 1,
                    "Unknown" => 0
                },
                14 => {
                    "VC-End-To-End-Loopback" => 2,
                    "VC-No-Loopback"         => 0,
                    "VC-Segment-Loopback"    => 1,
                },
                16 => { "Ascend-PVC" => 0, "Ascend-SVC" => 1 },
                17 => {
                    "Ascend-SVC-Enabled-No"  => 0,
                    "Ascend-SVC-Enabled-Yes" => 1
                },
                18 => {
                    "Ascend-Session-G711-Alaw"  => 3,
                    "Ascend-Session-G711-Ulaw"  => 2,
                    "Ascend-Session-G723"       => 4,
                    "Ascend-Session-G723-64KPS" => 6,
                    "Ascend-Session-G728"       => 7,
                    "Ascend-Session-G729"       => 5,
                    "Ascend-Session-RT24"       => 8,
                    "Ascend-Session-Unknown"    => 1,
                    "Ascend-Session-Unused"     => 0,
                },
                29 => {
                    CC_SSP   => 4,
                    CC_TSP   => 5,
                    CRT      => 0,
                    CUSTOM   => 11,
                    DEFAULT  => 2,
                    HARDCOPY => 6,
                    HDX      => 7,
                    INFONET  => 1,
                    NULL     => 10,
                    POS      => 9,
                    SCEN     => 3,
                    SHARK    => 8,
                },
                32 =>
                  { "Reverse-Charging-No" => 0, "Reverse-Charging-Yes" => 1 },
                46 => {
                    "Bi-Directional-Auth-Allowed"  => 1,
                    "Bi-Directional-Auth-None"     => 0,
                    "Bi-Directional-Auth-Required" => 2,
                },
                48 => {
                    "Ascend-Call-Direction-Incoming" => 0,
                    "Ascend-Call-Direction-Outgoing" => 1,
                },
                49 => {
                    "Ascend-Service-Type-ATM"         => 20,
                    "Ascend-Service-Type-Combinet"    => 7,
                    "Ascend-Service-Type-EuRaw"       => 9,
                    "Ascend-Service-Type-EuUi"        => 10,
                    "Ascend-Service-Type-FR"          => 8,
                    "Ascend-Service-Type-HdlcNrm"     => 21,
                    "Ascend-Service-Type-IpFax"       => 19,
                    "Ascend-Service-Type-MP"          => 15,
                    "Ascend-Service-Type-MPP"         => 5,
                    "Ascend-Service-Type-NetToNet"    => 25,
                    "Ascend-Service-Type-None"        => 1,
                    "Ascend-Service-Type-NotUsed"     => 0,
                    "Ascend-Service-Type-Other"       => 2,
                    "Ascend-Service-Type-PPP"         => 3,
                    "Ascend-Service-Type-PseuTunPPP"  => 18,
                    "Ascend-Service-Type-RawTcp"      => 13,
                    "Ascend-Service-Type-Slip"        => 4,
                    "Ascend-Service-Type-Telnet"      => 11,
                    "Ascend-Service-Type-TelnetBin"   => 12,
                    "Ascend-Service-Type-TermServer"  => 14,
                    "Ascend-Service-Type-VirtualConn" => 16,
                    "Ascend-Service-Type-Visa2"       => 23,
                    "Ascend-Service-Type-VoIp"        => 22,
                    "Ascend-Service-Type-X25"         => 6,
                    "Ascend-Service-Type-X25DChan"    => 17,
                },
                50 => { "Required-No" => 0, "Required-Yes" => 1 },
                55 => { "Required-No" => 0, "Required-Yes" => 1 },
                56 => { "Refresh-No"  => 0, "Refresh-Yes"  => 1 },
                65 => {
                    "IPX-Header-Compression-No"  => 0,
                    "IPX-Header-Compression-Yes" => 1
                },
                66 => {
                    "Abbreviated-Number"   => 6,
                    "International-Number" => 1,
                    "National-Number"      => 2,
                    "Network-Specific"     => 3,
                    "Subscriber-Number"    => 4,
                    "Unknown"              => 0,
                },
                67 => {
                    "Data"           => 3,
                    "ISDN-Telephony" => 1,
                    "National"       => 8,
                    "Private"        => 9,
                    "Telex"          => 4,
                    "Unknown"        => 0,
                },
                68 => {
                    "Allowed"              => 0,
                    "Number-Not-Available" => 2,
                    "Restricted"           => 1
                },
                69 => {
                    "Network-Provided"     => 3,
                    "User-Not-Screened"    => 0,
                    "User-Provided-Failed" => 2,
                    "User-Provided-Passed" => 1,
                },
                70 => { "BIR-Enable-No" => 0, "BIR-Enable-Yes" => 1 },
                71 => { "BIR-Proxy-No"  => 0, "BIR-Proxy-Yes"  => 1 },
                74 => { "PPPoE-No"      => 0, "PPPoE-Yes"      => 1 },
                75 =>
                  { "Bridge-Non-PPPoE-No" => 0, "Bridge-Non-PPPoE-Yes" => 1 },
                76 => { "ATM-Direct-No"  => 0, "ATM-Direct-Yes"  => 1 },
                80 => { "WINS-Assign-No" => 0, "WINS-Assign-Yes" => 1 },
                81 => {
                    "Auth-Any"     => 2,
                    "Auth-CHAP"    => 4,
                    "Auth-Default" => 1,
                    "Auth-MS-CHAP" => 5,
                    "Auth-None"    => 0,
                    "Auth-PAP"     => 3,
                },
                82 => { "Ascend-Proto-TCP" => 6, "Ascend-Proto-UDP" => 17 },
                85 =>
                  { "IP-Pool-Chaining-No" => 0, "IP-Pool-Chaining-Yes" => 1 },
                87 => {
                    "IP-TOS-Cost"        => 2,
                    "IP-TOS-Disabled"    => 1,
                    "IP-TOS-Latency"     => 16,
                    "IP-TOS-Normal"      => 0,
                    "IP-TOS-Reliability" => 4,
                    "IP-TOS-Throughput"  => 8,
                },
                88 => {
                    "IP-TOS-Precedence-Pri-Five"   => 160,
                    "IP-TOS-Precedence-Pri-Four"   => 128,
                    "IP-TOS-Precedence-Pri-Normal" => 0,
                    "IP-TOS-Precedence-Pri-One"    => 32,
                    "IP-TOS-Precedence-Pri-Seven"  => 224,
                    "IP-TOS-Precedence-Pri-Six"    => 192,
                    "IP-TOS-Precedence-Pri-Three"  => 96,
                    "IP-TOS-Precedence-Pri-Two"    => 64,
                },
                89 => {
                    "IP-TOS-Apply-To-Both"     => 3072,
                    "IP-TOS-Apply-To-Incoming" => 1024,
                    "IP-TOS-Apply-To-Outgoing" => 2048,
                },
                92 => {
                    "Rate-Type-AdslCap"     => 2,
                    "Rate-Type-AdslDmt"     => 4,
                    "Rate-Type-AdslDmtCell" => 3,
                    "Rate-Type-Disabled"    => 0,
                    "Rate-Type-Sdsl"        => 1,
                },
                96 => { "Source-IP-Check-No" => 0, "Source-IP-Check-Yes" => 1 },
                97 => { "Rate-Mode-AutoBaud" => 1, "Rate-Mode-Single"    => 2 },
                98 => {
                    "adslcap-up-1088000" => 50,
                    "adslcap-up-272000"  => 56,
                    "adslcap-up-408000"  => 55,
                    "adslcap-up-544000"  => 54,
                    "adslcap-up-680000"  => 53,
                    "adslcap-up-816000"  => 52,
                    "adslcap-up-952000"  => 51,
                    "adsldmt-up-1088000" => 151,
                    "adsldmt-up-128000"  => 160,
                    "adsldmt-up-256000"  => 159,
                    "adsldmt-up-384000"  => 158,
                    "adsldmt-up-512000"  => 157,
                    "adsldmt-up-640000"  => 156,
                    "adsldmt-up-768000"  => 155,
                    "adsldmt-up-800000"  => 154,
                    "adsldmt-up-896000"  => 153,
                    "adsldmt-up-928000"  => 152,
                    "adsldmt-up-auto"    => 150,
                    "sdsl-1168000"       => 5,
                    "sdsl-144000"        => 0,
                    "sdsl-1552000"       => 6,
                    "sdsl-2320000"       => 7,
                    "sdsl-272000"        => 1,
                    "sdsl-400000"        => 2,
                    "sdsl-528000"        => 3,
                    "sdsl-784000"        => 4,
                },
                99 => {
                    "adslcap-dn-1280000" => 10,
                    "adslcap-dn-1600000" => 9,
                    "adslcap-dn-1920000" => 8,
                    "adslcap-dn-2240000" => 7,
                    "adslcap-dn-2560000" => 6,
                    "adslcap-dn-2688000" => 5,
                    "adslcap-dn-3200000" => 4,
                    "adslcap-dn-4480000" => 3,
                    "adslcap-dn-5120000" => 2,
                    "adslcap-dn-6272000" => 1,
                    "adslcap-dn-640000"  => 12,
                    "adslcap-dn-7168000" => 0,
                    "adslcap-dn-960000"  => 11,
                    "adsldmt-dn-128000"  => 121,
                    "adsldmt-dn-1280000" => 114,
                    "adsldmt-dn-1600000" => 113,
                    "adsldmt-dn-1920000" => 112,
                    "adsldmt-dn-2240000" => 111,
                    "adsldmt-dn-256000"  => 120,
                    "adsldmt-dn-2560000" => 110,
                    "adsldmt-dn-2688000" => 109,
                    "adsldmt-dn-3200000" => 108,
                    "adsldmt-dn-384000"  => 119,
                    "adsldmt-dn-4480000" => 107,
                    "adsldmt-dn-512000"  => 118,
                    "adsldmt-dn-5120000" => 106,
                    "adsldmt-dn-6272000" => 105,
                    "adsldmt-dn-640000"  => 117,
                    "adsldmt-dn-7168000" => 104,
                    "adsldmt-dn-768000"  => 116,
                    "adsldmt-dn-8000000" => 103,
                    "adsldmt-dn-8960000" => 102,
                    "adsldmt-dn-9504000" => 101,
                    "adsldmt-dn-960000"  => 115,
                    "adsldmt-dn-auto"    => 100,
                },
                105 => {
                    "ISDN-Numbering-Plan"    => 1,
                    "Private-Numbering-Plan" => 9,
                    "Unknown-Numbering-Plan" => 0,
                },
                106 => {
                    "Ascend-FR-LMI-Dlci-0"    => 0,
                    "Ascend-FR-LMI-Dlci-1023" => 1023
                },
                112 => { "CBCP-Enabled" => 1, "CBCP-Not-Enabled" => 0 },
                113 => {
                    "CBCP-Any-Or-No"        => 7,
                    "CBCP-No-Callback"      => 1,
                    "CBCP-Off"              => 8,
                    "CBCP-Profile-Callback" => 3,
                    "CBCP-User-Callback"    => 2,
                },
                117 => {
                    "Appletalk-Peer-Dialin" => 1,
                    "Appletalk-Peer-Router" => 0
                },
                118 =>
                  { "Route-Appletalk-No" => 0, "Route-Appletalk-Yes" => 1 },
                126 => { "Temp-Rtes-No"      => 0, "Temp-Rtes-Yes"       => 1 },
                127 => { "ATMP-Tunnel"       => 0, "VTP-Tunnel"          => 1 },
                128 => { "Shared-Profile-No" => 0, "Shared-Profile-Yes"  => 1 },
                131 => { "Dialout-Allowed"   => 1, "Dialout-Not-Allowed" => 0 },
                133 => { "BACP-No"           => 0, "BACP-Yes"            => 1 },
                137 => { "DNS-Assign-No"     => 0, "DNS-Assign-Yes"      => 1 },
                138 => {
                    "Ascend-User-Acct-None"         => 0,
                    "Ascend-User-Acct-User"         => 1,
                    "Ascend-User-Acct-User-Default" => 2,
                },
                142 => { "Base-10"       => 0, "Base-16"        => 1 },
                147 => { "DHCP-Reply-No" => 0, "DHCP-Reply-Yes" => 1 },
                149 =>
                  { "Expect-Callback-No" => 0, "Expect-Callback-Yes" => 1 },
                150 => { "Ascend-ColdStart" => 1, "Ascend-Session-Event" => 2 },
                155 => { "Multicast-No"     => 0, "Multicast-Yes"        => 1 },
                157 => {
                    "Ascend-LinkUp-AlwaysUp" => 1,
                    "Ascend-LinkUp-Default"  => 0
                },
                159 => {
                    "Ascend-FR-DCE" => 1,
                    "Ascend-FR-DTE" => 0,
                    "Ascend-FR-NNI" => 2
                },
                160 => {
                    "Ascend-FR-No-Link-Mgt" => 0,
                    "Ascend-FR-Q-933A"      => 2,
                    "Ascend-FR-T1-617D"     => 1,
                },
                170 => {
                    "TS-Idle-Input"        => 1,
                    "TS-Idle-Input-Output" => 2,
                    "TS-Idle-None"         => 0
                },
                171 => {
                    "DBA-None"          => 2,
                    "DBA-Transmit"      => 0,
                    "DBA-Transmit-Recv" => 1
                },
                175 => { "FT1-No" => 0, "FT1-Yes" => 1 },
                177 => {
                    "AO/DI"         => 6,
                    "MegaMax"       => 7,
                    "Nailed"        => 1,
                    "Nailed/Mpp"    => 2,
                    "Perm/Switched" => 3,
                    "Switched"      => 0,
                },
                195 => {
                    "Bad-Or-Missing-Port-Number"     => 54,
                    "Call-Disconnected"              => 3,
                    "CLID-Authentication-Failed"     => 4,
                    "CLID-RADIUS-Timeout"            => 5,
                    "Connection-Closed"              => 63,
                    "Connection-Refused"             => 61,
                    "Connection-Timeout"             => 62,
                    "DCD-Detected-Then-Inactive"     => 11,
                    "Disconnect-Due-To-Callback"     => 102,
                    "Disconnect-Req-By-Local-Admin"  => 151,
                    "Disconnect-Req-By-RADIUS"       => 150,
                    "Host-Reset"                     => 60,
                    "Host-Unreachable"               => 65,
                    "Host-Unreachable-Admin"         => 67,
                    "Hostname-Resolution-Failed"     => 53,
                    "Invalid-Incoming-User"          => 101,
                    "Invalid-IP-Address"             => 52,
                    "Max-Call-Duration-Reached"      => 195,
                    "Modem-Invalid-Result-Codes"     => 12,
                    "Modem-No-DCD"                   => 10,
                    "MPP-No-NULL-Msg-Timeout"        => 35,
                    "Network-Unreachable"            => 64,
                    "Network-Unreachable-Admin"      => 66,
                    "No-Reason"                      => 0,
                    "Not-Applicable"                 => 1,
                    "Out-Of-Resources"               => 51,
                    "Port-Unreachable"               => 68,
                    "PPP-Auth-Timeout-Exceeded"      => 170,
                    "PPP-CHAP-Auth-Failed"           => 43,
                    "PPP-LCP-Close-MP-Add-Fail"      => 49,
                    "PPP-LCP-Negotion-Failed"        => 41,
                    "PPP-LCP-Timeout"                => 40,
                    "PPP-MP-Bundle-Unknown"          => 48,
                    "PPP-No-NCPs-Open"               => 47,
                    "PPP-PAP-Auth-Failed"            => 42,
                    "PPP-Rcv-Close-Event"            => 46,
                    "PPP-Rcv-Terminate-Req"          => 45,
                    "PPP-Rmt-Auth-Failed"            => 44,
                    "Proto-Disabled-Or-Unsupported"  => 120,
                    "Remote-End-Hung-Up"             => 185,
                    "Resource-Has-Been-Quiesced"     => 190,
                    "Session-Table-Full"             => 50,
                    "Session-Timeout"                => 100,
                    "TermSrv-Bad-Rlogin-Option"      => 32,
                    "TermSrv-CTRL-C-In-Login"        => 27,
                    "TermSrv-Destroyed"              => 28,
                    "TermSrv-Exit-Login-Failed"      => 25,
                    "TermSrv-Exit-Raw-TCP"           => 24,
                    "TermSrv-Exit-Raw-TCP-Disabled"  => 26,
                    "TermSrv-Exit-Rlogin"            => 31,
                    "TermSrv-Exit-Telnet"            => 22,
                    "TermSrv-Idle-Timeout"           => 21,
                    "TermSrv-No-IPaddr"              => 23,
                    "TermSrv-Not-Enough-Resources"   => 33,
                    "TermSrv-User-Closed-VCon"       => 29,
                    "TermSrv-User-Quit"              => 20,
                    "TermSrv-VCon-Destroyed"         => 30,
                    "Unknown"                        => 2,
                    "User-Executed-Do-Hangup"        => 180,
                    "V110-Timeout-Sync-Retry-Exceed" => 160,
                },
                196 => {
                    "ATNCP-Opened"              => 81,
                    "BACP-Opened"               => 83,
                    "BACP-Opening"              => 82,
                    "BNCP-Opened"               => 68,
                    "BNCP-Opening"              => 64,
                    "Call-Up"                   => 10,
                    "CCP-Opened"                => 66,
                    "CCP-Opening"               => 62,
                    "IPNCP-Opened"              => 67,
                    "IPNCP-Opening"             => 63,
                    "IPXNCP-Opened"             => 80,
                    "LAN-Session-Up"            => 60,
                    "LCP-Opened"                => 65,
                    "LCP-Opening"               => 61,
                    "LCP-State-Ack-Received"    => 76,
                    "LCP-State-Ack-Sent"        => 77,
                    "LCP-State-Closed"          => 71,
                    "LCP-State-Closing"         => 73,
                    "LCP-State-Initial"         => 69,
                    "LCP-State-Request-Sent"    => 75,
                    "LCP-State-Starting"        => 70,
                    "LCP-State-Stopped"         => 72,
                    "LCP-State-Stopping"        => 74,
                    "Modem-Awaiting-Codes"      => 32,
                    "Modem-Awaiting-DCD"        => 31,
                    "Modem-Outdial-Call-Up"     => 50,
                    "Modem-Up"                  => 30,
                    "No-Progress"               => 0,
                    "TermSrv-Raw-TCP-Connected" => 43,
                    "TermSrv-Raw-TCP-Started"   => 41,
                    "TermSrv-Rlogin-Connected"  => 46,
                    "TermSrv-Rlogin-Started"    => 45,
                    "TermSrv-Started"           => 40,
                    "TermSrv-Telnet-Connected"  => 44,
                    "TermSrv-Telnet-Started"    => 42,
                    "V110-State-Carrier"        => 92,
                    "V110-State-Closed"         => 94,
                    "V110-State-Opened"         => 91,
                    "V110-State-Reset"          => 93,
                    "V110-Up"                   => 90,
                },
                200 => { "Tok-Imm-No"       => 0, "Tok-Imm-Yes"  => 1 },
                201 => { "Not-Require-Auth" => 0, "Require-Auth" => 1 },
                207 => { "Days-Of-Warning"  => 0 },
                208 => { "Lifetime-In-Days" => 0 },
                210 => { "VJ-Slot-Comp-No"  => 1 },
                211 => { "PPP-VJ-1172"      => 1 },
                216 => { "IPX-Peer-Dialin"  => 1, "IPX-Peer-Router" => 0 },
                219 => { "FR-Direct-No"     => 0, "FR-Direct-Yes"   => 1 },
                222 => {
                    "Handle-IPX-Client" => 1,
                    "Handle-IPX-None"   => 0,
                    "Handle-IPX-Server" => 2,
                },
                226 => {
                    "Abbrev-Number"       => 5,
                    "Intl-Number"         => 1,
                    "Local-Number"        => 4,
                    "National-Number"     => 2,
                    "Net-Specific-Number" => 3,
                    "Unknown-Number"      => 0,
                },
                228 => { "Route-IP-No"  => 0, "Route-IP-Yes"  => 1 },
                229 => { "Route-IPX-No" => 0, "Route-IPX-Yes" => 1 },
                230 => { "Bridge-No"    => 0, "Bridge-Yes"    => 1 },
                231 => {
                    "Send-Auth-CHAP"    => 2,
                    "Send-Auth-MS-CHAP" => 3,
                    "Send-Auth-None"    => 0,
                    "Send-Auth-PAP"     => 1,
                },
                233 => {
                    "Link-Comp-MS-Stac"      => 3,
                    "Link-Comp-None"         => 0,
                    "Link-Comp-Stac"         => 1,
                    "Link-Comp-Stac-Draft-9" => 2,
                },
                239 => {
                    "History-Constant"  => 0,
                    "History-Linear"    => 1,
                    "History-Quadratic" => 2,
                },
                246 => { "Callback-No" => 0, "Callback-Yes" => 1 },
                247 => {
                    "Nailed-56KR"                    => 1,
                    "Nailed-64K"                     => 2,
                    "Switched-1024K"                 => 23,
                    "Switched-1088K"                 => 24,
                    "Switched-1152K"                 => 25,
                    "Switched-1216K"                 => 26,
                    "Switched-1280K"                 => 27,
                    "Switched-128K"                  => 9,
                    "Switched-1344K"                 => 28,
                    "Switched-1408K"                 => 29,
                    "Switched-1472K"                 => 30,
                    "Switched-1536K"                 => 7,
                    "Switched-1536KR"                => 8,
                    "Switched-1600K"                 => 31,
                    "Switched-1664K"                 => 32,
                    "Switched-1728K"                 => 33,
                    "Switched-1792K"                 => 34,
                    "Switched-1856K"                 => 35,
                    "Switched-1920K"                 => 36,
                    "Switched-192K"                  => 10,
                    "Switched-256K"                  => 11,
                    "Switched-320K"                  => 12,
                    "Switched-384K"                  => 6,
                    "Switched-384K-MR"               => 13,
                    "Switched-384KR"                 => 5,
                    "Switched-448K"                  => 14,
                    "Switched-512K"                  => 15,
                    "Switched-56K"                   => 4,
                    "Switched-576K"                  => 16,
                    "Switched-640K"                  => 17,
                    "Switched-64KR"                  => 3,
                    "Switched-704K"                  => 18,
                    "Switched-768K"                  => 19,
                    "Switched-832K"                  => 20,
                    "Switched-896K"                  => 21,
                    "Switched-960K"                  => 22,
                    "Switched-ATM"                   => 69,
                    "Switched-atmodem"               => 43,
                    "Switched-clear-56-v110"         => 41,
                    "Switched-clear-bearer-v110"     => 39,
                    "Switched-FR"                    => 70,
                    "Switched-inherited"             => 37,
                    "Switched-modem"                 => 42,
                    "Switched-Pots"                  => 68,
                    "Switched-restricted-64-x30"     => 40,
                    "Switched-restricted-bearer-x30" => 38,
                    "Switched-V110-192-56"           => 48,
                    "Switched-V110-192-56R"          => 53,
                    "Switched-V110-192-64"           => 58,
                    "Switched-V110-192-64R"          => 63,
                    "Switched-V110-24-56"            => 45,
                    "Switched-V110-24-56R"           => 50,
                    "Switched-V110-24-64"            => 55,
                    "Switched-V110-24-64R"           => 60,
                    "Switched-V110-384-56"           => 49,
                    "Switched-V110-384-56R"          => 54,
                    "Switched-V110-384-64"           => 59,
                    "Switched-V110-384-64R"          => 64,
                    "Switched-V110-48-56"            => 46,
                    "Switched-V110-48-56R"           => 51,
                    "Switched-V110-48-64"            => 56,
                    "Switched-V110-48-64R"           => 61,
                    "Switched-V110-96-56"            => 47,
                    "Switched-V110-96-56R"           => 52,
                    "Switched-V110-96-64"            => 57,
                    "Switched-V110-96-64R"           => 62,
                    "Switched-Voice-Bearer"          => 0,
                },
                248 => { "Force-56-No" => 0, "Force-56-Yes" => 1 },
            },
            562 => {
                166 => {
                    "Admin"                  => 15,
                    "AdminDownload"          => 13,
                    "AlarmViewer"            => 24,
                    "Application-BCMMonitor" => 9,
                    "ApplicationIVR"         => 28,
                    "BackupOperator"         => 20,
                    "CDRApp"                 => 10,
                    "ContactCenter"          => 1,
                    "CTEApp"                 => 7,
                    "DataAdmin"              => 16,
                    "DiagnosticLogs"         => 27,
                    "ExclusiveAccess"        => 14,
                    "Guest"                  => 18,
                    "GuestLogin"             => 12,
                    "ISDN-Dial-in"           => 30,
                    "ModemLogin"             => 11,
                    "OperationalLogs"        => 26,
                    "RemoteAccess"           => 17,
                    "RemoteMonitoring"       => 21,
                    "SBA-IPSetRegistration"  => 8,
                    "SBABasic"               => 5,
                    "SBAInstaller"           => 2,
                    "SBASystemCoord"         => 3,
                    "SBASystemCoordBasic"    => 4,
                    "Security"               => 6,
                    "SoftwareUpgrade"        => 22,
                    "System-SerialPort"      => 36,
                    "VoiceAdmin"             => 19,
                    "VoiceMailAdmin"         => 0,
                    "WAN-Dial-in"            => 32,
                },
                170 => { No => 0, Yes => 1 },
            },
            637 => {
                1536 => {
                    "Alcatel-Maint-Priv-Level-1"  => 1,
                    "Alcatel-Maint-Priv-Level-2"  => 2,
                    "Alcatel-Maint-Priv-Level-3"  => 3,
                    "Alcatel-Maint-Priv-Level-4"  => 4,
                    "Alcatel-Maint-Priv-Level-5"  => 5,
                    "Alcatel-Maint-Priv-Level-6"  => 6,
                    "Alcatel-Maint-Priv-Level-7"  => 7,
                    "Alcatel-No-Maint-Priv-Level" => 0,
                },
                1537 => {
                    "Alcatel-Maint-Priv-Level-1"  => 1,
                    "Alcatel-Maint-Priv-Level-2"  => 2,
                    "Alcatel-Maint-Priv-Level-3"  => 3,
                    "Alcatel-Maint-Priv-Level-4"  => 4,
                    "Alcatel-Maint-Priv-Level-5"  => 5,
                    "Alcatel-Maint-Priv-Level-6"  => 6,
                    "Alcatel-Maint-Priv-Level-7"  => 7,
                    "Alcatel-No-Maint-Priv-Level" => 0,
                },
                1539 => {
                    "Alcatel-Maint-Priv-Level-1"  => 1,
                    "Alcatel-Maint-Priv-Level-2"  => 2,
                    "Alcatel-Maint-Priv-Level-3"  => 3,
                    "Alcatel-Maint-Priv-Level-4"  => 4,
                    "Alcatel-Maint-Priv-Level-5"  => 5,
                    "Alcatel-Maint-Priv-Level-6"  => 6,
                    "Alcatel-Maint-Priv-Level-7"  => 7,
                    "Alcatel-No-Maint-Priv-Level" => 0,
                },
                1796 => {
                    "IP-Addr-In-Use"        => 11,
                    "Missing-Attributes"    => 14,
                    "No-IP-Addr-Available"  => 12,
                    "No-Pool-Id"            => 7,
                    "No-User-IP-Addr"       => 13,
                    "No-Vlan"               => 4,
                    "No-VRF"                => 2,
                    "Pool-Admin-Locked"     => 6,
                    "Pool-VRF-Inconsistent" => 8,
                    "QOS-Params-Syntax-Err" => 10,
                    "Unknown-Pool-Id"       => 5,
                    "Unknown-QOS-Profile"   => 9,
                    "Unknown-Vlan"          => 3,
                    "Unknown-VRF"           => 1,
                },
                1801 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1802 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1803 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1804 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1805 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1806 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1807 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1808 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1809 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1810 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1811 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1812 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1813 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1814 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1815 => {
                    "Alcatel-Maint-Priv-Level-1"  => 1,
                    "Alcatel-Maint-Priv-Level-2"  => 2,
                    "Alcatel-Maint-Priv-Level-3"  => 3,
                    "Alcatel-Maint-Priv-Level-4"  => 4,
                    "Alcatel-Maint-Priv-Level-5"  => 5,
                    "Alcatel-Maint-Priv-Level-6"  => 6,
                    "Alcatel-Maint-Priv-Level-7"  => 7,
                    "Alcatel-No-Maint-Priv-Level" => 0,
                    "Alcatel-No-Priv"             => 0,
                    "Alcatel-Read-Priv"           => 1,
                    "Alcatel-RW-Priv"             => 3,
                    "Alcatel-Write-Priv"          => 2,
                },
                1816 => {
                    "Alcatel-No-Priv"    => 0,
                    "Alcatel-Read-Priv"  => 1,
                    "Alcatel-RW-Priv"    => 3,
                    "Alcatel-Write-Priv" => 2,
                },
                1820 => {
                    "SLOT-NUMBERING-LEGACY"   => 3,
                    "SLOT-NUMBERING-POSITION" => 2,
                    "SLOT-NUMBERING-TYPE"     => 1,
                },
            },
            762 => {
                152 => {
                    "TxRate-100096k"  => 1798,
                    "TxRate-1000k"    => 1000,
                    "TxRate-1001k"    => 1001,
                    "TxRate-100224k"  => 1799,
                    "TxRate-1002k"    => 1002,
                    "TxRate-100352k"  => 1800,
                    "TxRate-1003k"    => 1003,
                    "TxRate-100480k"  => 1801,
                    "TxRate-1004k"    => 1004,
                    "TxRate-1005k"    => 1005,
                    "TxRate-100608k"  => 1802,
                    "TxRate-1006k"    => 1006,
                    "TxRate-100736k"  => 1803,
                    "TxRate-1007k"    => 1007,
                    "TxRate-100864k"  => 1804,
                    "TxRate-1008k"    => 1008,
                    "TxRate-100992k"  => 1805,
                    "TxRate-1009k"    => 1009,
                    "TxRate-100k"     => 100,
                    "TxRate-1010k"    => 1010,
                    "TxRate-101120k"  => 1806,
                    "TxRate-10112k"   => 1095,
                    "TxRate-1011k"    => 1011,
                    "TxRate-101248k"  => 1807,
                    "TxRate-1012k"    => 1012,
                    "TxRate-101376k"  => 1808,
                    "TxRate-1013k"    => 1013,
                    "TxRate-1014k"    => 1014,
                    "TxRate-101504k"  => 1809,
                    "TxRate-1015k"    => 1015,
                    "TxRate-101632k"  => 1810,
                    "TxRate-1016k"    => 1016,
                    "TxRate-101760k"  => 1811,
                    "TxRate-1017k"    => 1017,
                    "TxRate-101888k"  => 1812,
                    "TxRate-1018k"    => 1018,
                    "TxRate-1019k"    => 1019,
                    "TxRate-101k"     => 101,
                    "TxRate-102016k"  => 1813,
                    "TxRate-1020k"    => 1020,
                    "TxRate-102144k"  => 1814,
                    "TxRate-1021k"    => 1021,
                    "TxRate-102272k"  => 1815,
                    "TxRate-1022k"    => 1022,
                    "TxRate-1023k"    => 1023,
                    "TxRate-102400k"  => 1816,
                    "TxRate-10240k"   => 1096,
                    "TxRate-1024k"    => 1024,
                    "TxRate-102528k"  => 1817,
                    "TxRate-102656k"  => 1818,
                    "TxRate-102784k"  => 1819,
                    "TxRate-102912k"  => 1820,
                    "TxRate-102k"     => 102,
                    "TxRate-103040k"  => 1821,
                    "TxRate-103168k"  => 1822,
                    "TxRate-103296k"  => 1823,
                    "TxRate-103424k"  => 1824,
                    "TxRate-103552k"  => 1825,
                    "TxRate-103680k"  => 1826,
                    "TxRate-10368k"   => 1097,
                    "TxRate-103808k"  => 1827,
                    "TxRate-103936k"  => 1828,
                    "TxRate-103k"     => 103,
                    "TxRate-104064k"  => 1829,
                    "TxRate-104192k"  => 1830,
                    "TxRate-104320k"  => 1831,
                    "TxRate-104448k"  => 1832,
                    "TxRate-104576k"  => 1833,
                    "TxRate-104704k"  => 1834,
                    "TxRate-104832k"  => 1835,
                    "TxRate-104960k"  => 1836,
                    "TxRate-10496k"   => 1098,
                    "TxRate-104k"     => 104,
                    "TxRate-105088k"  => 1837,
                    "TxRate-105216k"  => 1838,
                    "TxRate-105344k"  => 1839,
                    "TxRate-105472k"  => 1840,
                    "TxRate-105600k"  => 1841,
                    "TxRate-105728k"  => 1842,
                    "TxRate-105856k"  => 1843,
                    "TxRate-105984k"  => 1844,
                    "TxRate-105k"     => 105,
                    "TxRate-106112k"  => 1845,
                    "TxRate-106240k"  => 1846,
                    "TxRate-10624k"   => 1099,
                    "TxRate-106368k"  => 1847,
                    "TxRate-106496k"  => 1848,
                    "TxRate-106624k"  => 1849,
                    "TxRate-106752k"  => 1850,
                    "TxRate-106880k"  => 1851,
                    "TxRate-106k"     => 106,
                    "TxRate-107008k"  => 1852,
                    "TxRate-107136k"  => 1853,
                    "TxRate-107264k"  => 1854,
                    "TxRate-107392k"  => 1855,
                    "TxRate-107520k"  => 1856,
                    "TxRate-10752k"   => 1100,
                    "TxRate-107648k"  => 1857,
                    "TxRate-107776k"  => 1858,
                    "TxRate-107904k"  => 1859,
                    "TxRate-107k"     => 107,
                    "TxRate-108032k"  => 1860,
                    "TxRate-108160k"  => 1861,
                    "TxRate-108288k"  => 1862,
                    "TxRate-108416k"  => 1863,
                    "TxRate-108544k"  => 1864,
                    "TxRate-108672k"  => 1865,
                    "TxRate-108800k"  => 1866,
                    "TxRate-10880k"   => 1101,
                    "TxRate-108928k"  => 1867,
                    "TxRate-108k"     => 108,
                    "TxRate-109056k"  => 1868,
                    "TxRate-109184k"  => 1869,
                    "TxRate-109312k"  => 1870,
                    "TxRate-109440k"  => 1871,
                    "TxRate-109568k"  => 1872,
                    "TxRate-109696k"  => 1873,
                    "TxRate-109824k"  => 1874,
                    "TxRate-109952k"  => 1875,
                    "TxRate-109k"     => 109,
                    "TxRate-110080k"  => 1876,
                    "TxRate-11008k"   => 1102,
                    "TxRate-110208k"  => 1877,
                    "TxRate-110336k"  => 1878,
                    "TxRate-110464k"  => 1879,
                    "TxRate-110592k"  => 1880,
                    "TxRate-110720k"  => 1881,
                    "TxRate-110848k"  => 1882,
                    "TxRate-110976k"  => 1883,
                    "TxRate-110k"     => 110,
                    "TxRate-111104k"  => 1884,
                    "TxRate-111232k"  => 1885,
                    "TxRate-111360k"  => 1886,
                    "TxRate-11136k"   => 1103,
                    "TxRate-111488k"  => 1887,
                    "TxRate-111616k"  => 1888,
                    "TxRate-111744k"  => 1889,
                    "TxRate-111872k"  => 1890,
                    "TxRate-111k"     => 111,
                    "TxRate-112000k"  => 1891,
                    "TxRate-112128k"  => 1892,
                    "TxRate-112256k"  => 1893,
                    "TxRate-112384k"  => 1894,
                    "TxRate-112512k"  => 1895,
                    "TxRate-112640k"  => 1896,
                    "TxRate-11264k"   => 1104,
                    "TxRate-112768k"  => 1897,
                    "TxRate-112896k"  => 1898,
                    "TxRate-112k"     => 112,
                    "TxRate-113024k"  => 1899,
                    "TxRate-113152k"  => 1900,
                    "TxRate-113280k"  => 1901,
                    "TxRate-113408k"  => 1902,
                    "TxRate-113536k"  => 1903,
                    "TxRate-113664k"  => 1904,
                    "TxRate-113792k"  => 1905,
                    "TxRate-113920k"  => 1906,
                    "TxRate-11392k"   => 1105,
                    "TxRate-113k"     => 113,
                    "TxRate-114048k"  => 1907,
                    "TxRate-114176k"  => 1908,
                    "TxRate-114304k"  => 1909,
                    "TxRate-114432k"  => 1910,
                    "TxRate-114560k"  => 1911,
                    "TxRate-114688k"  => 1912,
                    "TxRate-114816k"  => 1913,
                    "TxRate-114944k"  => 1914,
                    "TxRate-114k"     => 114,
                    "TxRate-115072k"  => 1915,
                    "TxRate-115200k"  => 1916,
                    "TxRate-11520k"   => 1106,
                    "TxRate-1152k"    => 1025,
                    "TxRate-115328k"  => 1917,
                    "TxRate-115456k"  => 1918,
                    "TxRate-115584k"  => 1919,
                    "TxRate-115712k"  => 1920,
                    "TxRate-115840k"  => 1921,
                    "TxRate-115968k"  => 1922,
                    "TxRate-115k"     => 115,
                    "TxRate-116096k"  => 1923,
                    "TxRate-116224k"  => 1924,
                    "TxRate-116352k"  => 1925,
                    "TxRate-116480k"  => 1926,
                    "TxRate-11648k"   => 1107,
                    "TxRate-116608k"  => 1927,
                    "TxRate-116736k"  => 1928,
                    "TxRate-116864k"  => 1929,
                    "TxRate-116992k"  => 1930,
                    "TxRate-116k"     => 116,
                    "TxRate-117120k"  => 1931,
                    "TxRate-117248k"  => 1932,
                    "TxRate-117376k"  => 1933,
                    "TxRate-117504k"  => 1934,
                    "TxRate-117632k"  => 1935,
                    "TxRate-117760k"  => 1936,
                    "TxRate-11776k"   => 1108,
                    "TxRate-117888k"  => 1937,
                    "TxRate-117k"     => 117,
                    "TxRate-118016k"  => 1938,
                    "TxRate-118144k"  => 1939,
                    "TxRate-118272k"  => 1940,
                    "TxRate-118400k"  => 1941,
                    "TxRate-118528k"  => 1942,
                    "TxRate-118656k"  => 1943,
                    "TxRate-118784k"  => 1944,
                    "TxRate-118912k"  => 1945,
                    "TxRate-118k"     => 118,
                    "TxRate-119040k"  => 1946,
                    "TxRate-11904k"   => 1109,
                    "TxRate-119168k"  => 1947,
                    "TxRate-119296k"  => 1948,
                    "TxRate-119424k"  => 1949,
                    "TxRate-119552k"  => 1950,
                    "TxRate-119680k"  => 1951,
                    "TxRate-119808k"  => 1952,
                    "TxRate-119936k"  => 1953,
                    "TxRate-119k"     => 119,
                    "TxRate-11k"      => 11,
                    "TxRate-120064k"  => 1954,
                    "TxRate-120192k"  => 1955,
                    "TxRate-120320k"  => 1956,
                    "TxRate-12032k"   => 1110,
                    "TxRate-120448k"  => 1957,
                    "TxRate-120576k"  => 1958,
                    "TxRate-120704k"  => 1959,
                    "TxRate-120832k"  => 1960,
                    "TxRate-120960k"  => 1961,
                    "TxRate-120k"     => 120,
                    "TxRate-121088k"  => 1962,
                    "TxRate-121216k"  => 1963,
                    "TxRate-121344k"  => 1964,
                    "TxRate-121472k"  => 1965,
                    "TxRate-121600k"  => 1966,
                    "TxRate-12160k"   => 1111,
                    "TxRate-121728k"  => 1967,
                    "TxRate-121856k"  => 1968,
                    "TxRate-121984k"  => 1969,
                    "TxRate-121k"     => 121,
                    "TxRate-122112k"  => 1970,
                    "TxRate-122240k"  => 1971,
                    "TxRate-122368k"  => 1972,
                    "TxRate-122496k"  => 1973,
                    "TxRate-122624k"  => 1974,
                    "TxRate-122752k"  => 1975,
                    "TxRate-122880k"  => 1976,
                    "TxRate-12288k"   => 1112,
                    "TxRate-122k"     => 122,
                    "TxRate-123008k"  => 1977,
                    "TxRate-123136k"  => 1978,
                    "TxRate-123264k"  => 1979,
                    "TxRate-123392k"  => 1980,
                    "TxRate-123520k"  => 1981,
                    "TxRate-123648k"  => 1982,
                    "TxRate-123776k"  => 1983,
                    "TxRate-123904k"  => 1984,
                    "TxRate-123k"     => 123,
                    "TxRate-124032k"  => 1985,
                    "TxRate-124160k"  => 1986,
                    "TxRate-12416k"   => 1113,
                    "TxRate-124288k"  => 1987,
                    "TxRate-124416k"  => 1988,
                    "TxRate-124544k"  => 1989,
                    "TxRate-124672k"  => 1990,
                    "TxRate-124800k"  => 1991,
                    "TxRate-124928k"  => 1992,
                    "TxRate-124k"     => 124,
                    "TxRate-125056k"  => 1993,
                    "TxRate-125184k"  => 1994,
                    "TxRate-125312k"  => 1995,
                    "TxRate-125440k"  => 1996,
                    "TxRate-12544k"   => 1114,
                    "TxRate-125568k"  => 1997,
                    "TxRate-125696k"  => 1998,
                    "TxRate-125824k"  => 1999,
                    "TxRate-125952k"  => 2000,
                    "TxRate-125k"     => 125,
                    "TxRate-126080k"  => 2001,
                    "TxRate-126208k"  => 2002,
                    "TxRate-126336k"  => 2003,
                    "TxRate-126464k"  => 2004,
                    "TxRate-126592k"  => 2005,
                    "TxRate-126720k"  => 2006,
                    "TxRate-12672k"   => 1115,
                    "TxRate-126848k"  => 2007,
                    "TxRate-126976k"  => 2008,
                    "TxRate-126k"     => 126,
                    "TxRate-127104k"  => 2009,
                    "TxRate-127232k"  => 2010,
                    "TxRate-127360k"  => 2011,
                    "TxRate-127488k"  => 2012,
                    "TxRate-127616k"  => 2013,
                    "TxRate-127744k"  => 2014,
                    "TxRate-127872k"  => 2015,
                    "TxRate-127k"     => 127,
                    "TxRate-128000k"  => 2016,
                    "TxRate-12800k"   => 1116,
                    "TxRate-1280k"    => 1026,
                    "TxRate-128128k"  => 2017,
                    "TxRate-128256k"  => 2018,
                    "TxRate-128384k"  => 2019,
                    "TxRate-128512k"  => 2020,
                    "TxRate-128640k"  => 2021,
                    "TxRate-128768k"  => 2022,
                    "TxRate-128896k"  => 2023,
                    "TxRate-128k"     => 128,
                    "TxRate-129024k"  => 2024,
                    "TxRate-129152k"  => 2025,
                    "TxRate-129280k"  => 2026,
                    "TxRate-12928k"   => 1117,
                    "TxRate-129408k"  => 2027,
                    "TxRate-129536k"  => 2028,
                    "TxRate-129664k"  => 2029,
                    "TxRate-129792k"  => 2030,
                    "TxRate-129920k"  => 2031,
                    "TxRate-129k"     => 129,
                    "TxRate-12k"      => 12,
                    "TxRate-130048k"  => 2032,
                    "TxRate-130176k"  => 2033,
                    "TxRate-130304k"  => 2034,
                    "TxRate-130432k"  => 2035,
                    "TxRate-130560k"  => 2036,
                    "TxRate-13056k"   => 1118,
                    "TxRate-130688k"  => 2037,
                    "TxRate-130816k"  => 2038,
                    "TxRate-130944k"  => 2039,
                    "TxRate-130k"     => 130,
                    "TxRate-131072k"  => 2040,
                    "TxRate-131200k"  => 2041,
                    "TxRate-131328k"  => 2042,
                    "TxRate-131456k"  => 2043,
                    "TxRate-131584k"  => 2044,
                    "TxRate-131712k"  => 2045,
                    "TxRate-131840k"  => 2046,
                    "TxRate-13184k"   => 1119,
                    "TxRate-131968k"  => 2047,
                    "TxRate-131k"     => 131,
                    "TxRate-132k"     => 132,
                    "TxRate-13312k"   => 1120,
                    "TxRate-133k"     => 133,
                    "TxRate-13440k"   => 1121,
                    "TxRate-134k"     => 134,
                    "TxRate-13568k"   => 1122,
                    "TxRate-135k"     => 135,
                    "TxRate-13696k"   => 1123,
                    "TxRate-136k"     => 136,
                    "TxRate-137k"     => 137,
                    "TxRate-13824k"   => 1124,
                    "TxRate-138k"     => 138,
                    "TxRate-13952k"   => 1125,
                    "TxRate-139k"     => 139,
                    "TxRate-13k"      => 13,
                    "TxRate-14080k"   => 1126,
                    "TxRate-1408k"    => 1027,
                    "TxRate-140k"     => 140,
                    "TxRate-141k"     => 141,
                    "TxRate-14208k"   => 1127,
                    "TxRate-142k"     => 142,
                    "TxRate-14336k"   => 1128,
                    "TxRate-143k"     => 143,
                    "TxRate-14464k"   => 1129,
                    "TxRate-144k"     => 144,
                    "TxRate-14592k"   => 1130,
                    "TxRate-145k"     => 145,
                    "TxRate-146k"     => 146,
                    "TxRate-14720k"   => 1131,
                    "TxRate-147k"     => 147,
                    "TxRate-14848k"   => 1132,
                    "TxRate-148k"     => 148,
                    "TxRate-14976k"   => 1133,
                    "TxRate-149k"     => 149,
                    "TxRate-14k"      => 14,
                    "TxRate-150k"     => 150,
                    "TxRate-15104k"   => 1134,
                    "TxRate-151k"     => 151,
                    "TxRate-15232k"   => 1135,
                    "TxRate-152k"     => 152,
                    "TxRate-15360k"   => 1136,
                    "TxRate-1536k"    => 1028,
                    "TxRate-153k"     => 153,
                    "TxRate-15488k"   => 1137,
                    "TxRate-154k"     => 154,
                    "TxRate-155k"     => 155,
                    "TxRate-15616k"   => 1138,
                    "TxRate-156k"     => 156,
                    "TxRate-15744k"   => 1139,
                    "TxRate-157k"     => 157,
                    "TxRate-15872k"   => 1140,
                    "TxRate-158k"     => 158,
                    "TxRate-159k"     => 159,
                    "TxRate-15k"      => 15,
                    "TxRate-16000k"   => 1141,
                    "TxRate-160k"     => 160,
                    "TxRate-16128k"   => 1142,
                    "TxRate-161k"     => 161,
                    "TxRate-16256k"   => 1143,
                    "TxRate-162k"     => 162,
                    "TxRate-16384k"   => 1144,
                    "TxRate-163k"     => 163,
                    "TxRate-164k"     => 164,
                    "TxRate-16512k"   => 1145,
                    "TxRate-165k"     => 165,
                    "TxRate-16640k"   => 1146,
                    "TxRate-1664k"    => 1029,
                    "TxRate-166k"     => 166,
                    "TxRate-16768k"   => 1147,
                    "TxRate-167k"     => 167,
                    "TxRate-16896k"   => 1148,
                    "TxRate-168k"     => 168,
                    "TxRate-169k"     => 169,
                    "TxRate-16k"      => 16,
                    "TxRate-17024k"   => 1149,
                    "TxRate-170k"     => 170,
                    "TxRate-17152k"   => 1150,
                    "TxRate-171k"     => 171,
                    "TxRate-17280k"   => 1151,
                    "TxRate-172k"     => 172,
                    "TxRate-173k"     => 173,
                    "TxRate-17408k"   => 1152,
                    "TxRate-174k"     => 174,
                    "TxRate-17536k"   => 1153,
                    "TxRate-175k"     => 175,
                    "TxRate-17664k"   => 1154,
                    "TxRate-176k"     => 176,
                    "TxRate-17792k"   => 1155,
                    "TxRate-177k"     => 177,
                    "TxRate-178k"     => 178,
                    "TxRate-17920k"   => 1156,
                    "TxRate-1792k"    => 1030,
                    "TxRate-179k"     => 179,
                    "TxRate-17k"      => 17,
                    "TxRate-18048k"   => 1157,
                    "TxRate-180k"     => 180,
                    "TxRate-18176k"   => 1158,
                    "TxRate-181k"     => 181,
                    "TxRate-182k"     => 182,
                    "TxRate-18304k"   => 1159,
                    "TxRate-183k"     => 183,
                    "TxRate-18432k"   => 1160,
                    "TxRate-184k"     => 184,
                    "TxRate-18560k"   => 1161,
                    "TxRate-185k"     => 185,
                    "TxRate-18688k"   => 1162,
                    "TxRate-186k"     => 186,
                    "TxRate-187k"     => 187,
                    "TxRate-18816k"   => 1163,
                    "TxRate-188k"     => 188,
                    "TxRate-18944k"   => 1164,
                    "TxRate-189k"     => 189,
                    "TxRate-18k"      => 18,
                    "TxRate-19072k"   => 1165,
                    "TxRate-190k"     => 190,
                    "TxRate-191k"     => 191,
                    "TxRate-19200k"   => 1166,
                    "TxRate-1920k"    => 1031,
                    "TxRate-192k"     => 192,
                    "TxRate-19328k"   => 1167,
                    "TxRate-193k"     => 193,
                    "TxRate-19456k"   => 1168,
                    "TxRate-194k"     => 194,
                    "TxRate-19584k"   => 1169,
                    "TxRate-195k"     => 195,
                    "TxRate-196k"     => 196,
                    "TxRate-19712k"   => 1170,
                    "TxRate-197k"     => 197,
                    "TxRate-19840k"   => 1171,
                    "TxRate-198k"     => 198,
                    "TxRate-19968k"   => 1172,
                    "TxRate-199k"     => 199,
                    "TxRate-19k"      => 19,
                    "TxRate-20096k"   => 1173,
                    "TxRate-200k"     => 200,
                    "TxRate-201k"     => 201,
                    "TxRate-20224k"   => 1174,
                    "TxRate-202k"     => 202,
                    "TxRate-20352k"   => 1175,
                    "TxRate-203k"     => 203,
                    "TxRate-20480k"   => 1176,
                    "TxRate-2048k"    => 1032,
                    "TxRate-204k"     => 204,
                    "TxRate-205k"     => 205,
                    "TxRate-20608k"   => 1177,
                    "TxRate-206k"     => 206,
                    "TxRate-20736k"   => 1178,
                    "TxRate-207k"     => 207,
                    "TxRate-20864k"   => 1179,
                    "TxRate-208k"     => 208,
                    "TxRate-20992k"   => 1180,
                    "TxRate-209k"     => 209,
                    "TxRate-20k"      => 20,
                    "TxRate-210k"     => 210,
                    "TxRate-21120k"   => 1181,
                    "TxRate-211k"     => 211,
                    "TxRate-21248k"   => 1182,
                    "TxRate-212k"     => 212,
                    "TxRate-21376k"   => 1183,
                    "TxRate-213k"     => 213,
                    "TxRate-214k"     => 214,
                    "TxRate-21504k"   => 1184,
                    "TxRate-215k"     => 215,
                    "TxRate-21632k"   => 1185,
                    "TxRate-216k"     => 216,
                    "TxRate-21760k"   => 1186,
                    "TxRate-2176k"    => 1033,
                    "TxRate-217k"     => 217,
                    "TxRate-21888k"   => 1187,
                    "TxRate-218k"     => 218,
                    "TxRate-219k"     => 219,
                    "TxRate-21k"      => 21,
                    "TxRate-22016k"   => 1188,
                    "TxRate-220k"     => 220,
                    "TxRate-22144k"   => 1189,
                    "TxRate-221k"     => 221,
                    "TxRate-22272k"   => 1190,
                    "TxRate-222k"     => 222,
                    "TxRate-223k"     => 223,
                    "TxRate-22400k"   => 1191,
                    "TxRate-224k"     => 224,
                    "TxRate-22528k"   => 1192,
                    "TxRate-225k"     => 225,
                    "TxRate-22656k"   => 1193,
                    "TxRate-226k"     => 226,
                    "TxRate-22784k"   => 1194,
                    "TxRate-227k"     => 227,
                    "TxRate-228k"     => 228,
                    "TxRate-22912k"   => 1195,
                    "TxRate-229k"     => 229,
                    "TxRate-22k"      => 22,
                    "TxRate-23040k"   => 1196,
                    "TxRate-2304k"    => 1034,
                    "TxRate-230k"     => 230,
                    "TxRate-23168k"   => 1197,
                    "TxRate-231k"     => 231,
                    "TxRate-23296k"   => 1198,
                    "TxRate-232k"     => 232,
                    "TxRate-233k"     => 233,
                    "TxRate-23424k"   => 1199,
                    "TxRate-234k"     => 234,
                    "TxRate-23552k"   => 1200,
                    "TxRate-235k"     => 235,
                    "TxRate-23680k"   => 1201,
                    "TxRate-236k"     => 236,
                    "TxRate-237k"     => 237,
                    "TxRate-23808k"   => 1202,
                    "TxRate-238k"     => 238,
                    "TxRate-23936k"   => 1203,
                    "TxRate-239k"     => 239,
                    "TxRate-23k"      => 23,
                    "TxRate-24064k"   => 1204,
                    "TxRate-240k"     => 240,
                    "TxRate-24192k"   => 1205,
                    "TxRate-241k"     => 241,
                    "TxRate-242k"     => 242,
                    "TxRate-24320k"   => 1206,
                    "TxRate-2432k"    => 1035,
                    "TxRate-243k"     => 243,
                    "TxRate-24448k"   => 1207,
                    "TxRate-244k"     => 244,
                    "TxRate-24576k"   => 1208,
                    "TxRate-245k"     => 245,
                    "TxRate-246k"     => 246,
                    "TxRate-24704k"   => 1209,
                    "TxRate-247k"     => 247,
                    "TxRate-24832k"   => 1210,
                    "TxRate-248k"     => 248,
                    "TxRate-24960k"   => 1211,
                    "TxRate-249k"     => 249,
                    "TxRate-24k"      => 24,
                    "TxRate-25088k"   => 1212,
                    "TxRate-250k"     => 250,
                    "TxRate-251k"     => 251,
                    "TxRate-25216k"   => 1213,
                    "TxRate-252k"     => 252,
                    "TxRate-25344k"   => 1214,
                    "TxRate-253k"     => 253,
                    "TxRate-25472k"   => 1215,
                    "TxRate-254k"     => 254,
                    "TxRate-255k"     => 255,
                    "TxRate-25600k"   => 1216,
                    "TxRate-2560k"    => 1036,
                    "TxRate-256k"     => 256,
                    "TxRate-25728k"   => 1217,
                    "TxRate-257k"     => 257,
                    "TxRate-25856k"   => 1218,
                    "TxRate-258k"     => 258,
                    "TxRate-25984k"   => 1219,
                    "TxRate-259k"     => 259,
                    "TxRate-25k"      => 25,
                    "TxRate-260k"     => 260,
                    "TxRate-26112k"   => 1220,
                    "TxRate-261k"     => 261,
                    "TxRate-26240k"   => 1221,
                    "TxRate-262k"     => 262,
                    "TxRate-26368k"   => 1222,
                    "TxRate-263k"     => 263,
                    "TxRate-26496k"   => 1223,
                    "TxRate-264k"     => 264,
                    "TxRate-265k"     => 265,
                    "TxRate-26624k"   => 1224,
                    "TxRate-266k"     => 266,
                    "TxRate-26752k"   => 1225,
                    "TxRate-267k"     => 267,
                    "TxRate-26880k"   => 1226,
                    "TxRate-2688k"    => 1037,
                    "TxRate-268k"     => 268,
                    "TxRate-269k"     => 269,
                    "TxRate-26k"      => 26,
                    "TxRate-27008k"   => 1227,
                    "TxRate-270k"     => 270,
                    "TxRate-27136k"   => 1228,
                    "TxRate-271k"     => 271,
                    "TxRate-27264k"   => 1229,
                    "TxRate-272k"     => 272,
                    "TxRate-27392k"   => 1230,
                    "TxRate-273k"     => 273,
                    "TxRate-274k"     => 274,
                    "TxRate-27520k"   => 1231,
                    "TxRate-275k"     => 275,
                    "TxRate-27648k"   => 1232,
                    "TxRate-276k"     => 276,
                    "TxRate-27776k"   => 1233,
                    "TxRate-277k"     => 277,
                    "TxRate-278k"     => 278,
                    "TxRate-27904k"   => 1234,
                    "TxRate-279k"     => 279,
                    "TxRate-27k"      => 27,
                    "TxRate-28032k"   => 1235,
                    "TxRate-280k"     => 280,
                    "TxRate-28160k"   => 1236,
                    "TxRate-2816k"    => 1038,
                    "TxRate-281k"     => 281,
                    "TxRate-28288k"   => 1237,
                    "TxRate-282k"     => 282,
                    "TxRate-283k"     => 283,
                    "TxRate-28416k"   => 1238,
                    "TxRate-284k"     => 284,
                    "TxRate-28544k"   => 1239,
                    "TxRate-285k"     => 285,
                    "TxRate-28672k"   => 1240,
                    "TxRate-286k"     => 286,
                    "TxRate-287k"     => 287,
                    "TxRate-28800k"   => 1241,
                    "TxRate-288k"     => 288,
                    "TxRate-28928k"   => 1242,
                    "TxRate-289k"     => 289,
                    "TxRate-28k"      => 28,
                    "TxRate-29056k"   => 1243,
                    "TxRate-290k"     => 290,
                    "TxRate-29184k"   => 1244,
                    "TxRate-291k"     => 291,
                    "TxRate-292k"     => 292,
                    "TxRate-29312k"   => 1245,
                    "TxRate-293k"     => 293,
                    "TxRate-29440k"   => 1246,
                    "TxRate-2944k"    => 1039,
                    "TxRate-294k"     => 294,
                    "TxRate-29568k"   => 1247,
                    "TxRate-295k"     => 295,
                    "TxRate-29696k"   => 1248,
                    "TxRate-296k"     => 296,
                    "TxRate-297k"     => 297,
                    "TxRate-29824k"   => 1249,
                    "TxRate-298k"     => 298,
                    "TxRate-29952k"   => 1250,
                    "TxRate-299k"     => 299,
                    "TxRate-29k"      => 29,
                    "TxRate-30080k"   => 1251,
                    "TxRate-300k"     => 300,
                    "TxRate-301k"     => 301,
                    "TxRate-30208k"   => 1252,
                    "TxRate-302k"     => 302,
                    "TxRate-30336k"   => 1253,
                    "TxRate-303k"     => 303,
                    "TxRate-30464k"   => 1254,
                    "TxRate-304k"     => 304,
                    "TxRate-30592k"   => 1255,
                    "TxRate-305k"     => 305,
                    "TxRate-306k"     => 306,
                    "TxRate-30720k"   => 1256,
                    "TxRate-3072k"    => 1040,
                    "TxRate-307k"     => 307,
                    "TxRate-30848k"   => 1257,
                    "TxRate-308k"     => 308,
                    "TxRate-30976k"   => 1258,
                    "TxRate-309k"     => 309,
                    "TxRate-30k"      => 30,
                    "TxRate-310k"     => 310,
                    "TxRate-31104k"   => 1259,
                    "TxRate-311k"     => 311,
                    "TxRate-31232k"   => 1260,
                    "TxRate-312k"     => 312,
                    "TxRate-31360k"   => 1261,
                    "TxRate-313k"     => 313,
                    "TxRate-31488k"   => 1262,
                    "TxRate-314k"     => 314,
                    "TxRate-315k"     => 315,
                    "TxRate-31616k"   => 1263,
                    "TxRate-316k"     => 316,
                    "TxRate-31744k"   => 1264,
                    "TxRate-317k"     => 317,
                    "TxRate-31872k"   => 1265,
                    "TxRate-318k"     => 318,
                    "TxRate-319k"     => 319,
                    "TxRate-31k"      => 31,
                    "TxRate-32000k"   => 1266,
                    "TxRate-3200k"    => 1041,
                    "TxRate-320k"     => 320,
                    "TxRate-32128k"   => 1267,
                    "TxRate-321k"     => 321,
                    "TxRate-32256k"   => 1268,
                    "TxRate-322k"     => 322,
                    "TxRate-32384k"   => 1269,
                    "TxRate-323k"     => 323,
                    "TxRate-324k"     => 324,
                    "TxRate-32512k"   => 1270,
                    "TxRate-325k"     => 325,
                    "TxRate-32640k"   => 1271,
                    "TxRate-326k"     => 326,
                    "TxRate-32768k"   => 1272,
                    "TxRate-327k"     => 327,
                    "TxRate-32896k"   => 1273,
                    "TxRate-328k"     => 328,
                    "TxRate-329k"     => 329,
                    "TxRate-32k"      => 32,
                    "TxRate-33024k"   => 1274,
                    "TxRate-330k"     => 330,
                    "TxRate-33152k"   => 1275,
                    "TxRate-331k"     => 331,
                    "TxRate-33280k"   => 1276,
                    "TxRate-3328k"    => 1042,
                    "TxRate-332k"     => 332,
                    "TxRate-333k"     => 333,
                    "TxRate-33408k"   => 1277,
                    "TxRate-334k"     => 334,
                    "TxRate-33536k"   => 1278,
                    "TxRate-335k"     => 335,
                    "TxRate-33664k"   => 1279,
                    "TxRate-336k"     => 336,
                    "TxRate-33792k"   => 1280,
                    "TxRate-337k"     => 337,
                    "TxRate-338k"     => 338,
                    "TxRate-33920k"   => 1281,
                    "TxRate-339k"     => 339,
                    "TxRate-33k"      => 33,
                    "TxRate-34048k"   => 1282,
                    "TxRate-340k"     => 340,
                    "TxRate-34176k"   => 1283,
                    "TxRate-341k"     => 341,
                    "TxRate-342k"     => 342,
                    "TxRate-34304k"   => 1284,
                    "TxRate-343k"     => 343,
                    "TxRate-34432k"   => 1285,
                    "TxRate-344k"     => 344,
                    "TxRate-34560k"   => 1286,
                    "TxRate-3456k"    => 1043,
                    "TxRate-345k"     => 345,
                    "TxRate-34688k"   => 1287,
                    "TxRate-346k"     => 346,
                    "TxRate-347k"     => 347,
                    "TxRate-34816k"   => 1288,
                    "TxRate-348k"     => 348,
                    "TxRate-34944k"   => 1289,
                    "TxRate-349k"     => 349,
                    "TxRate-34k"      => 34,
                    "TxRate-35072k"   => 1290,
                    "TxRate-350k"     => 350,
                    "TxRate-351k"     => 351,
                    "TxRate-35200k"   => 1291,
                    "TxRate-352k"     => 352,
                    "TxRate-35328k"   => 1292,
                    "TxRate-353k"     => 353,
                    "TxRate-35456k"   => 1293,
                    "TxRate-354k"     => 354,
                    "TxRate-35584k"   => 1294,
                    "TxRate-355k"     => 355,
                    "TxRate-356k"     => 356,
                    "TxRate-35712k"   => 1295,
                    "TxRate-357k"     => 357,
                    "TxRate-35840k"   => 1296,
                    "TxRate-3584k"    => 1044,
                    "TxRate-358k"     => 358,
                    "TxRate-35968k"   => 1297,
                    "TxRate-359k"     => 359,
                    "TxRate-35k"      => 35,
                    "TxRate-36096k"   => 1298,
                    "TxRate-360k"     => 360,
                    "TxRate-361k"     => 361,
                    "TxRate-36224k"   => 1299,
                    "TxRate-362k"     => 362,
                    "TxRate-36352k"   => 1300,
                    "TxRate-363k"     => 363,
                    "TxRate-36480k"   => 1301,
                    "TxRate-364k"     => 364,
                    "TxRate-365k"     => 365,
                    "TxRate-36608k"   => 1302,
                    "TxRate-366k"     => 366,
                    "TxRate-36736k"   => 1303,
                    "TxRate-367k"     => 367,
                    "TxRate-36864k"   => 1304,
                    "TxRate-368k"     => 368,
                    "TxRate-36992k"   => 1305,
                    "TxRate-369k"     => 369,
                    "TxRate-36k"      => 36,
                    "TxRate-370k"     => 370,
                    "TxRate-37120k"   => 1306,
                    "TxRate-3712k"    => 1045,
                    "TxRate-371k"     => 371,
                    "TxRate-37248k"   => 1307,
                    "TxRate-372k"     => 372,
                    "TxRate-37376k"   => 1308,
                    "TxRate-373k"     => 373,
                    "TxRate-374k"     => 374,
                    "TxRate-37504k"   => 1309,
                    "TxRate-375k"     => 375,
                    "TxRate-37632k"   => 1310,
                    "TxRate-376k"     => 376,
                    "TxRate-37760k"   => 1311,
                    "TxRate-377k"     => 377,
                    "TxRate-37888k"   => 1312,
                    "TxRate-378k"     => 378,
                    "TxRate-379k"     => 379,
                    "TxRate-37k"      => 37,
                    "TxRate-38016k"   => 1313,
                    "TxRate-380k"     => 380,
                    "TxRate-38144k"   => 1314,
                    "TxRate-381k"     => 381,
                    "TxRate-38272k"   => 1315,
                    "TxRate-382k"     => 382,
                    "TxRate-383k"     => 383,
                    "TxRate-38400k"   => 1316,
                    "TxRate-3840k"    => 1046,
                    "TxRate-384k"     => 384,
                    "TxRate-38528k"   => 1317,
                    "TxRate-385k"     => 385,
                    "TxRate-38656k"   => 1318,
                    "TxRate-386k"     => 386,
                    "TxRate-38784k"   => 1319,
                    "TxRate-387k"     => 387,
                    "TxRate-388k"     => 388,
                    "TxRate-38912k"   => 1320,
                    "TxRate-389k"     => 389,
                    "TxRate-38k"      => 38,
                    "TxRate-39040k"   => 1321,
                    "TxRate-390k"     => 390,
                    "TxRate-39168k"   => 1322,
                    "TxRate-391k"     => 391,
                    "TxRate-39296k"   => 1323,
                    "TxRate-392k"     => 392,
                    "TxRate-393k"     => 393,
                    "TxRate-39424k"   => 1324,
                    "TxRate-394k"     => 394,
                    "TxRate-39552k"   => 1325,
                    "TxRate-395k"     => 395,
                    "TxRate-39680k"   => 1326,
                    "TxRate-3968k"    => 1047,
                    "TxRate-396k"     => 396,
                    "TxRate-397k"     => 397,
                    "TxRate-39808k"   => 1327,
                    "TxRate-398k"     => 398,
                    "TxRate-39936k"   => 1328,
                    "TxRate-399k"     => 399,
                    "TxRate-39k"      => 39,
                    "TxRate-40064k"   => 1329,
                    "TxRate-400k"     => 400,
                    "TxRate-40192k"   => 1330,
                    "TxRate-401k"     => 401,
                    "TxRate-402k"     => 402,
                    "TxRate-40320k"   => 1331,
                    "TxRate-403k"     => 403,
                    "TxRate-40448k"   => 1332,
                    "TxRate-404k"     => 404,
                    "TxRate-40576k"   => 1333,
                    "TxRate-405k"     => 405,
                    "TxRate-406k"     => 406,
                    "TxRate-40704k"   => 1334,
                    "TxRate-407k"     => 407,
                    "TxRate-40832k"   => 1335,
                    "TxRate-408k"     => 408,
                    "TxRate-40960k"   => 1336,
                    "TxRate-4096k"    => 1048,
                    "TxRate-409k"     => 409,
                    "TxRate-40k"      => 40,
                    "TxRate-41088k"   => 1337,
                    "TxRate-410k"     => 410,
                    "TxRate-411k"     => 411,
                    "TxRate-41216k"   => 1338,
                    "TxRate-412k"     => 412,
                    "TxRate-41344k"   => 1339,
                    "TxRate-413k"     => 413,
                    "TxRate-41472k"   => 1340,
                    "TxRate-414k"     => 414,
                    "TxRate-415k"     => 415,
                    "TxRate-41600k"   => 1341,
                    "TxRate-416k"     => 416,
                    "TxRate-41728k"   => 1342,
                    "TxRate-417k"     => 417,
                    "TxRate-41856k"   => 1343,
                    "TxRate-418k"     => 418,
                    "TxRate-41984k"   => 1344,
                    "TxRate-419k"     => 419,
                    "TxRate-41k"      => 41,
                    "TxRate-420k"     => 420,
                    "TxRate-42112k"   => 1345,
                    "TxRate-421k"     => 421,
                    "TxRate-42240k"   => 1346,
                    "TxRate-4224k"    => 1049,
                    "TxRate-422k"     => 422,
                    "TxRate-42368k"   => 1347,
                    "TxRate-423k"     => 423,
                    "TxRate-42496k"   => 1348,
                    "TxRate-424k"     => 424,
                    "TxRate-425k"     => 425,
                    "TxRate-42624k"   => 1349,
                    "TxRate-426k"     => 426,
                    "TxRate-42752k"   => 1350,
                    "TxRate-427k"     => 427,
                    "TxRate-42880k"   => 1351,
                    "TxRate-428k"     => 428,
                    "TxRate-429k"     => 429,
                    "TxRate-42k"      => 42,
                    "TxRate-43008k"   => 1352,
                    "TxRate-430k"     => 430,
                    "TxRate-43136k"   => 1353,
                    "TxRate-431k"     => 431,
                    "TxRate-43264k"   => 1354,
                    "TxRate-432k"     => 432,
                    "TxRate-43392k"   => 1355,
                    "TxRate-433k"     => 433,
                    "TxRate-434k"     => 434,
                    "TxRate-43520k"   => 1356,
                    "TxRate-4352k"    => 1050,
                    "TxRate-435k"     => 435,
                    "TxRate-43648k"   => 1357,
                    "TxRate-436k"     => 436,
                    "TxRate-43776k"   => 1358,
                    "TxRate-437k"     => 437,
                    "TxRate-438k"     => 438,
                    "TxRate-43904k"   => 1359,
                    "TxRate-439k"     => 439,
                    "TxRate-43k"      => 43,
                    "TxRate-44032k"   => 1360,
                    "TxRate-440k"     => 440,
                    "TxRate-44160k"   => 1361,
                    "TxRate-441k"     => 441,
                    "TxRate-44288k"   => 1362,
                    "TxRate-442k"     => 442,
                    "TxRate-443k"     => 443,
                    "TxRate-44416k"   => 1363,
                    "TxRate-444k"     => 444,
                    "TxRate-44544k"   => 1364,
                    "TxRate-445k"     => 445,
                    "TxRate-44672k"   => 1365,
                    "TxRate-446k"     => 446,
                    "TxRate-447k"     => 447,
                    "TxRate-44800k"   => 1366,
                    "TxRate-4480k"    => 1051,
                    "TxRate-448k"     => 448,
                    "TxRate-44928k"   => 1367,
                    "TxRate-449k"     => 449,
                    "TxRate-44k"      => 44,
                    "TxRate-45056k"   => 1368,
                    "TxRate-450k"     => 450,
                    "TxRate-45184k"   => 1369,
                    "TxRate-451k"     => 451,
                    "TxRate-452k"     => 452,
                    "TxRate-45312k"   => 1370,
                    "TxRate-453k"     => 453,
                    "TxRate-45440k"   => 1371,
                    "TxRate-454k"     => 454,
                    "TxRate-45568k"   => 1372,
                    "TxRate-455k"     => 455,
                    "TxRate-45696k"   => 1373,
                    "TxRate-456k"     => 456,
                    "TxRate-457k"     => 457,
                    "TxRate-45824k"   => 1374,
                    "TxRate-458k"     => 458,
                    "TxRate-45952k"   => 1375,
                    "TxRate-459k"     => 459,
                    "TxRate-45k"      => 45,
                    "TxRate-46080k"   => 1376,
                    "TxRate-4608k"    => 1052,
                    "TxRate-460k"     => 460,
                    "TxRate-461k"     => 461,
                    "TxRate-46208k"   => 1377,
                    "TxRate-462k"     => 462,
                    "TxRate-46336k"   => 1378,
                    "TxRate-463k"     => 463,
                    "TxRate-46464k"   => 1379,
                    "TxRate-464k"     => 464,
                    "TxRate-46592k"   => 1380,
                    "TxRate-465k"     => 465,
                    "TxRate-466k"     => 466,
                    "TxRate-46720k"   => 1381,
                    "TxRate-467k"     => 467,
                    "TxRate-46848k"   => 1382,
                    "TxRate-468k"     => 468,
                    "TxRate-46976k"   => 1383,
                    "TxRate-469k"     => 469,
                    "TxRate-46k"      => 46,
                    "TxRate-470k"     => 470,
                    "TxRate-47104k"   => 1384,
                    "TxRate-471k"     => 471,
                    "TxRate-47232k"   => 1385,
                    "TxRate-472k"     => 472,
                    "TxRate-47360k"   => 1386,
                    "TxRate-4736k"    => 1053,
                    "TxRate-473k"     => 473,
                    "TxRate-47488k"   => 1387,
                    "TxRate-474k"     => 474,
                    "TxRate-475k"     => 475,
                    "TxRate-47616k"   => 1388,
                    "TxRate-476k"     => 476,
                    "TxRate-47744k"   => 1389,
                    "TxRate-477k"     => 477,
                    "TxRate-47872k"   => 1390,
                    "TxRate-478k"     => 478,
                    "TxRate-479k"     => 479,
                    "TxRate-47k"      => 47,
                    "TxRate-48000k"   => 1391,
                    "TxRate-480k"     => 480,
                    "TxRate-48128k"   => 1392,
                    "TxRate-481k"     => 481,
                    "TxRate-48256k"   => 1393,
                    "TxRate-482k"     => 482,
                    "TxRate-48384k"   => 1394,
                    "TxRate-483k"     => 483,
                    "TxRate-484k"     => 484,
                    "TxRate-48512k"   => 1395,
                    "TxRate-485k"     => 485,
                    "TxRate-48640k"   => 1396,
                    "TxRate-4864k"    => 1054,
                    "TxRate-486k"     => 486,
                    "TxRate-48768k"   => 1397,
                    "TxRate-487k"     => 487,
                    "TxRate-48896k"   => 1398,
                    "TxRate-488k"     => 488,
                    "TxRate-489k"     => 489,
                    "TxRate-48k"      => 48,
                    "TxRate-49024k"   => 1399,
                    "TxRate-490k"     => 490,
                    "TxRate-49152k"   => 1400,
                    "TxRate-491k"     => 491,
                    "TxRate-49280k"   => 1401,
                    "TxRate-492k"     => 492,
                    "TxRate-493k"     => 493,
                    "TxRate-49408k"   => 1402,
                    "TxRate-494k"     => 494,
                    "TxRate-49536k"   => 1403,
                    "TxRate-495k"     => 495,
                    "TxRate-49664k"   => 1404,
                    "TxRate-496k"     => 496,
                    "TxRate-49792k"   => 1405,
                    "TxRate-497k"     => 497,
                    "TxRate-498k"     => 498,
                    "TxRate-49920k"   => 1406,
                    "TxRate-4992k"    => 1055,
                    "TxRate-499k"     => 499,
                    "TxRate-49k"      => 49,
                    "TxRate-50048k"   => 1407,
                    "TxRate-500k"     => 500,
                    "TxRate-50176k"   => 1408,
                    "TxRate-501k"     => 501,
                    "TxRate-502k"     => 502,
                    "TxRate-50304k"   => 1409,
                    "TxRate-503k"     => 503,
                    "TxRate-50432k"   => 1410,
                    "TxRate-504k"     => 504,
                    "TxRate-50560k"   => 1411,
                    "TxRate-505k"     => 505,
                    "TxRate-50688k"   => 1412,
                    "TxRate-506k"     => 506,
                    "TxRate-507k"     => 507,
                    "TxRate-50816k"   => 1413,
                    "TxRate-508k"     => 508,
                    "TxRate-50944k"   => 1414,
                    "TxRate-509k"     => 509,
                    "TxRate-50k"      => 50,
                    "TxRate-51072k"   => 1415,
                    "TxRate-510k"     => 510,
                    "TxRate-511k"     => 511,
                    "TxRate-51200k"   => 1416,
                    "TxRate-5120k"    => 1056,
                    "TxRate-512k"     => 512,
                    "TxRate-51328k"   => 1417,
                    "TxRate-513k"     => 513,
                    "TxRate-51456k"   => 1418,
                    "TxRate-514k"     => 514,
                    "TxRate-51584k"   => 1419,
                    "TxRate-515k"     => 515,
                    "TxRate-516k"     => 516,
                    "TxRate-51712k"   => 1420,
                    "TxRate-517k"     => 517,
                    "TxRate-51840k"   => 1421,
                    "TxRate-518k"     => 518,
                    "TxRate-51968k"   => 1422,
                    "TxRate-519k"     => 519,
                    "TxRate-51k"      => 51,
                    "TxRate-52096k"   => 1423,
                    "TxRate-520k"     => 520,
                    "TxRate-521k"     => 521,
                    "TxRate-52224k"   => 1424,
                    "TxRate-522k"     => 522,
                    "TxRate-52352k"   => 1425,
                    "TxRate-523k"     => 523,
                    "TxRate-52480k"   => 1426,
                    "TxRate-5248k"    => 1057,
                    "TxRate-524k"     => 524,
                    "TxRate-525k"     => 525,
                    "TxRate-52608k"   => 1427,
                    "TxRate-526k"     => 526,
                    "TxRate-52736k"   => 1428,
                    "TxRate-527k"     => 527,
                    "TxRate-52864k"   => 1429,
                    "TxRate-528k"     => 528,
                    "TxRate-52992k"   => 1430,
                    "TxRate-529k"     => 529,
                    "TxRate-52k"      => 52,
                    "TxRate-530k"     => 530,
                    "TxRate-53120k"   => 1431,
                    "TxRate-531k"     => 531,
                    "TxRate-53248k"   => 1432,
                    "TxRate-532k"     => 532,
                    "TxRate-53376k"   => 1433,
                    "TxRate-533k"     => 533,
                    "TxRate-534k"     => 534,
                    "TxRate-53504k"   => 1434,
                    "TxRate-535k"     => 535,
                    "TxRate-53632k"   => 1435,
                    "TxRate-536k"     => 536,
                    "TxRate-53760k"   => 1436,
                    "TxRate-5376k"    => 1058,
                    "TxRate-537k"     => 537,
                    "TxRate-53888k"   => 1437,
                    "TxRate-538k"     => 538,
                    "TxRate-539k"     => 539,
                    "TxRate-53k"      => 53,
                    "TxRate-54016k"   => 1438,
                    "TxRate-540k"     => 540,
                    "TxRate-54144k"   => 1439,
                    "TxRate-541k"     => 541,
                    "TxRate-54272k"   => 1440,
                    "TxRate-542k"     => 542,
                    "TxRate-543k"     => 543,
                    "TxRate-54400k"   => 1441,
                    "TxRate-544k"     => 544,
                    "TxRate-54528k"   => 1442,
                    "TxRate-545k"     => 545,
                    "TxRate-54656k"   => 1443,
                    "TxRate-546k"     => 546,
                    "TxRate-54784k"   => 1444,
                    "TxRate-547k"     => 547,
                    "TxRate-548k"     => 548,
                    "TxRate-54912k"   => 1445,
                    "TxRate-549k"     => 549,
                    "TxRate-54k"      => 54,
                    "TxRate-55040k"   => 1446,
                    "TxRate-5504k"    => 1059,
                    "TxRate-550k"     => 550,
                    "TxRate-55168k"   => 1447,
                    "TxRate-551k"     => 551,
                    "TxRate-55296k"   => 1448,
                    "TxRate-552k"     => 552,
                    "TxRate-553k"     => 553,
                    "TxRate-55424k"   => 1449,
                    "TxRate-554k"     => 554,
                    "TxRate-55552k"   => 1450,
                    "TxRate-555k"     => 555,
                    "TxRate-55680k"   => 1451,
                    "TxRate-556k"     => 556,
                    "TxRate-557k"     => 557,
                    "TxRate-55808k"   => 1452,
                    "TxRate-558k"     => 558,
                    "TxRate-55936k"   => 1453,
                    "TxRate-559k"     => 559,
                    "TxRate-55k"      => 55,
                    "TxRate-56064k"   => 1454,
                    "TxRate-560k"     => 560,
                    "TxRate-56192k"   => 1455,
                    "TxRate-561k"     => 561,
                    "TxRate-562k"     => 562,
                    "TxRate-56320k"   => 1456,
                    "TxRate-5632k"    => 1060,
                    "TxRate-563k"     => 563,
                    "TxRate-56448k"   => 1457,
                    "TxRate-564k"     => 564,
                    "TxRate-56576k"   => 1458,
                    "TxRate-565k"     => 565,
                    "TxRate-566k"     => 566,
                    "TxRate-56704k"   => 1459,
                    "TxRate-567k"     => 567,
                    "TxRate-56832k"   => 1460,
                    "TxRate-568k"     => 568,
                    "TxRate-56960k"   => 1461,
                    "TxRate-569k"     => 569,
                    "TxRate-56k"      => 56,
                    "TxRate-57088k"   => 1462,
                    "TxRate-570k"     => 570,
                    "TxRate-571k"     => 571,
                    "TxRate-57216k"   => 1463,
                    "TxRate-572k"     => 572,
                    "TxRate-57344k"   => 1464,
                    "TxRate-573k"     => 573,
                    "TxRate-57472k"   => 1465,
                    "TxRate-574k"     => 574,
                    "TxRate-575k"     => 575,
                    "TxRate-57600k"   => 1466,
                    "TxRate-5760k"    => 1061,
                    "TxRate-576k"     => 576,
                    "TxRate-57728k"   => 1467,
                    "TxRate-577k"     => 577,
                    "TxRate-57856k"   => 1468,
                    "TxRate-578k"     => 578,
                    "TxRate-57984k"   => 1469,
                    "TxRate-579k"     => 579,
                    "TxRate-57k"      => 57,
                    "TxRate-580k"     => 580,
                    "TxRate-58112k"   => 1470,
                    "TxRate-581k"     => 581,
                    "TxRate-58240k"   => 1471,
                    "TxRate-582k"     => 582,
                    "TxRate-58368k"   => 1472,
                    "TxRate-583k"     => 583,
                    "TxRate-58496k"   => 1473,
                    "TxRate-584k"     => 584,
                    "TxRate-585k"     => 585,
                    "TxRate-58624k"   => 1474,
                    "TxRate-586k"     => 586,
                    "TxRate-58752k"   => 1475,
                    "TxRate-587k"     => 587,
                    "TxRate-58880k"   => 1476,
                    "TxRate-5888k"    => 1062,
                    "TxRate-588k"     => 588,
                    "TxRate-589k"     => 589,
                    "TxRate-58k"      => 58,
                    "TxRate-59008k"   => 1477,
                    "TxRate-590k"     => 590,
                    "TxRate-59136k"   => 1478,
                    "TxRate-591k"     => 591,
                    "TxRate-59264k"   => 1479,
                    "TxRate-592k"     => 592,
                    "TxRate-59392k"   => 1480,
                    "TxRate-593k"     => 593,
                    "TxRate-594k"     => 594,
                    "TxRate-59520k"   => 1481,
                    "TxRate-595k"     => 595,
                    "TxRate-59648k"   => 1482,
                    "TxRate-596k"     => 596,
                    "TxRate-59776k"   => 1483,
                    "TxRate-597k"     => 597,
                    "TxRate-598k"     => 598,
                    "TxRate-59904k"   => 1484,
                    "TxRate-599k"     => 599,
                    "TxRate-59k"      => 59,
                    "TxRate-60032k"   => 1485,
                    "TxRate-600k"     => 600,
                    "TxRate-60160k"   => 1486,
                    "TxRate-6016k"    => 1063,
                    "TxRate-601k"     => 601,
                    "TxRate-60288k"   => 1487,
                    "TxRate-602k"     => 602,
                    "TxRate-603k"     => 603,
                    "TxRate-60416k"   => 1488,
                    "TxRate-604k"     => 604,
                    "TxRate-60544k"   => 1489,
                    "TxRate-605k"     => 605,
                    "TxRate-60672k"   => 1490,
                    "TxRate-606k"     => 606,
                    "TxRate-607k"     => 607,
                    "TxRate-60800k"   => 1491,
                    "TxRate-608k"     => 608,
                    "TxRate-60928k"   => 1492,
                    "TxRate-609k"     => 609,
                    "TxRate-60k"      => 60,
                    "TxRate-61056k"   => 1493,
                    "TxRate-610k"     => 610,
                    "TxRate-61184k"   => 1494,
                    "TxRate-611k"     => 611,
                    "TxRate-612k"     => 612,
                    "TxRate-61312k"   => 1495,
                    "TxRate-613k"     => 613,
                    "TxRate-61440k"   => 1496,
                    "TxRate-6144k"    => 1064,
                    "TxRate-614k"     => 614,
                    "TxRate-61568k"   => 1497,
                    "TxRate-615k"     => 615,
                    "TxRate-61696k"   => 1498,
                    "TxRate-616k"     => 616,
                    "TxRate-617k"     => 617,
                    "TxRate-61824k"   => 1499,
                    "TxRate-618k"     => 618,
                    "TxRate-61952k"   => 1500,
                    "TxRate-619k"     => 619,
                    "TxRate-61k"      => 61,
                    "TxRate-62080k"   => 1501,
                    "TxRate-620k"     => 620,
                    "TxRate-621k"     => 621,
                    "TxRate-62208k"   => 1502,
                    "TxRate-622k"     => 622,
                    "TxRate-62336k"   => 1503,
                    "TxRate-623k"     => 623,
                    "TxRate-62464k"   => 1504,
                    "TxRate-624k"     => 624,
                    "TxRate-62592k"   => 1505,
                    "TxRate-625k"     => 625,
                    "TxRate-626k"     => 626,
                    "TxRate-62720k"   => 1506,
                    "TxRate-6272k"    => 1065,
                    "TxRate-627k"     => 627,
                    "TxRate-62848k"   => 1507,
                    "TxRate-628k"     => 628,
                    "TxRate-62976k"   => 1508,
                    "TxRate-629k"     => 629,
                    "TxRate-62k"      => 62,
                    "TxRate-630k"     => 630,
                    "TxRate-63104k"   => 1509,
                    "TxRate-631k"     => 631,
                    "TxRate-63232k"   => 1510,
                    "TxRate-632k"     => 632,
                    "TxRate-63360k"   => 1511,
                    "TxRate-633k"     => 633,
                    "TxRate-63488k"   => 1512,
                    "TxRate-634k"     => 634,
                    "TxRate-635k"     => 635,
                    "TxRate-63616k"   => 1513,
                    "TxRate-636k"     => 636,
                    "TxRate-63744k"   => 1514,
                    "TxRate-637k"     => 637,
                    "TxRate-63872k"   => 1515,
                    "TxRate-638k"     => 638,
                    "TxRate-639k"     => 639,
                    "TxRate-63k"      => 63,
                    "TxRate-64000k"   => 1516,
                    "TxRate-6400k"    => 1066,
                    "TxRate-640k"     => 640,
                    "TxRate-64128k"   => 1517,
                    "TxRate-641k"     => 641,
                    "TxRate-64256k"   => 1518,
                    "TxRate-642k"     => 642,
                    "TxRate-64384k"   => 1519,
                    "TxRate-643k"     => 643,
                    "TxRate-644k"     => 644,
                    "TxRate-64512k"   => 1520,
                    "TxRate-645k"     => 645,
                    "TxRate-64640k"   => 1521,
                    "TxRate-646k"     => 646,
                    "TxRate-64768k"   => 1522,
                    "TxRate-647k"     => 647,
                    "TxRate-64896k"   => 1523,
                    "TxRate-648k"     => 648,
                    "TxRate-649k"     => 649,
                    "TxRate-64k"      => 64,
                    "TxRate-65024k"   => 1524,
                    "TxRate-650k"     => 650,
                    "TxRate-65152k"   => 1525,
                    "TxRate-651k"     => 651,
                    "TxRate-65280k"   => 1526,
                    "TxRate-6528k"    => 1067,
                    "TxRate-652k"     => 652,
                    "TxRate-653k"     => 653,
                    "TxRate-65408k"   => 1527,
                    "TxRate-654k"     => 654,
                    "TxRate-65536k"   => 1528,
                    "TxRate-655k"     => 655,
                    "TxRate-65664k"   => 1529,
                    "TxRate-656k"     => 656,
                    "TxRate-65792k"   => 1530,
                    "TxRate-657k"     => 657,
                    "TxRate-658k"     => 658,
                    "TxRate-65920k"   => 1531,
                    "TxRate-659k"     => 659,
                    "TxRate-65k"      => 65,
                    "TxRate-66048k"   => 1532,
                    "TxRate-660k"     => 660,
                    "TxRate-66176k"   => 1533,
                    "TxRate-661k"     => 661,
                    "TxRate-662k"     => 662,
                    "TxRate-66304k"   => 1534,
                    "TxRate-663k"     => 663,
                    "TxRate-66432k"   => 1535,
                    "TxRate-664k"     => 664,
                    "TxRate-66560k"   => 1536,
                    "TxRate-6656k"    => 1068,
                    "TxRate-665k"     => 665,
                    "TxRate-66688k"   => 1537,
                    "TxRate-666k"     => 666,
                    "TxRate-667k"     => 667,
                    "TxRate-66816k"   => 1538,
                    "TxRate-668k"     => 668,
                    "TxRate-66944k"   => 1539,
                    "TxRate-669k"     => 669,
                    "TxRate-66k"      => 66,
                    "TxRate-67072k"   => 1540,
                    "TxRate-670k"     => 670,
                    "TxRate-671k"     => 671,
                    "TxRate-67200k"   => 1541,
                    "TxRate-672k"     => 672,
                    "TxRate-67328k"   => 1542,
                    "TxRate-673k"     => 673,
                    "TxRate-67456k"   => 1543,
                    "TxRate-674k"     => 674,
                    "TxRate-67584k"   => 1544,
                    "TxRate-675k"     => 675,
                    "TxRate-676k"     => 676,
                    "TxRate-67712k"   => 1545,
                    "TxRate-677k"     => 677,
                    "TxRate-67840k"   => 1546,
                    "TxRate-6784k"    => 1069,
                    "TxRate-678k"     => 678,
                    "TxRate-67968k"   => 1547,
                    "TxRate-679k"     => 679,
                    "TxRate-67k"      => 67,
                    "TxRate-68096k"   => 1548,
                    "TxRate-680k"     => 680,
                    "TxRate-681k"     => 681,
                    "TxRate-68224k"   => 1549,
                    "TxRate-682k"     => 682,
                    "TxRate-68352k"   => 1550,
                    "TxRate-683k"     => 683,
                    "TxRate-68480k"   => 1551,
                    "TxRate-684k"     => 684,
                    "TxRate-685k"     => 685,
                    "TxRate-68608k"   => 1552,
                    "TxRate-686k"     => 686,
                    "TxRate-68736k"   => 1553,
                    "TxRate-687k"     => 687,
                    "TxRate-68864k"   => 1554,
                    "TxRate-688k"     => 688,
                    "TxRate-68992k"   => 1555,
                    "TxRate-689k"     => 689,
                    "TxRate-68k"      => 68,
                    "TxRate-690k"     => 690,
                    "TxRate-69120k"   => 1556,
                    "TxRate-6912k"    => 1070,
                    "TxRate-691k"     => 691,
                    "TxRate-69248k"   => 1557,
                    "TxRate-692k"     => 692,
                    "TxRate-69376k"   => 1558,
                    "TxRate-693k"     => 693,
                    "TxRate-694k"     => 694,
                    "TxRate-69504k"   => 1559,
                    "TxRate-695k"     => 695,
                    "TxRate-69632k"   => 1560,
                    "TxRate-696k"     => 696,
                    "TxRate-69760k"   => 1561,
                    "TxRate-697k"     => 697,
                    "TxRate-69888k"   => 1562,
                    "TxRate-698k"     => 698,
                    "TxRate-699k"     => 699,
                    "TxRate-69k"      => 69,
                    "TxRate-70016k"   => 1563,
                    "TxRate-700k"     => 700,
                    "TxRate-70144k"   => 1564,
                    "TxRate-701k"     => 701,
                    "TxRate-70272k"   => 1565,
                    "TxRate-702k"     => 702,
                    "TxRate-703k"     => 703,
                    "TxRate-70400k"   => 1566,
                    "TxRate-7040k"    => 1071,
                    "TxRate-704k"     => 704,
                    "TxRate-70528k"   => 1567,
                    "TxRate-705k"     => 705,
                    "TxRate-70656k"   => 1568,
                    "TxRate-706k"     => 706,
                    "TxRate-70784k"   => 1569,
                    "TxRate-707k"     => 707,
                    "TxRate-708k"     => 708,
                    "TxRate-70912k"   => 1570,
                    "TxRate-709k"     => 709,
                    "TxRate-70k"      => 70,
                    "TxRate-71040k"   => 1571,
                    "TxRate-710k"     => 710,
                    "TxRate-71168k"   => 1572,
                    "TxRate-711k"     => 711,
                    "TxRate-71296k"   => 1573,
                    "TxRate-712k"     => 712,
                    "TxRate-713k"     => 713,
                    "TxRate-71424k"   => 1574,
                    "TxRate-714k"     => 714,
                    "TxRate-71552k"   => 1575,
                    "TxRate-715k"     => 715,
                    "TxRate-71680k"   => 1576,
                    "TxRate-7168k"    => 1072,
                    "TxRate-716k"     => 716,
                    "TxRate-717k"     => 717,
                    "TxRate-71808k"   => 1577,
                    "TxRate-718k"     => 718,
                    "TxRate-71936k"   => 1578,
                    "TxRate-719k"     => 719,
                    "TxRate-71k"      => 71,
                    "TxRate-72064k"   => 1579,
                    "TxRate-720k"     => 720,
                    "TxRate-72192k"   => 1580,
                    "TxRate-721k"     => 721,
                    "TxRate-722k"     => 722,
                    "TxRate-72320k"   => 1581,
                    "TxRate-723k"     => 723,
                    "TxRate-72448k"   => 1582,
                    "TxRate-724k"     => 724,
                    "TxRate-72576k"   => 1583,
                    "TxRate-725k"     => 725,
                    "TxRate-726k"     => 726,
                    "TxRate-72704k"   => 1584,
                    "TxRate-727k"     => 727,
                    "TxRate-72832k"   => 1585,
                    "TxRate-728k"     => 728,
                    "TxRate-72960k"   => 1586,
                    "TxRate-7296k"    => 1073,
                    "TxRate-729k"     => 729,
                    "TxRate-72k"      => 72,
                    "TxRate-73088k"   => 1587,
                    "TxRate-730k"     => 730,
                    "TxRate-731k"     => 731,
                    "TxRate-73216k"   => 1588,
                    "TxRate-732k"     => 732,
                    "TxRate-73344k"   => 1589,
                    "TxRate-733k"     => 733,
                    "TxRate-73472k"   => 1590,
                    "TxRate-734k"     => 734,
                    "TxRate-735k"     => 735,
                    "TxRate-73600k"   => 1591,
                    "TxRate-736k"     => 736,
                    "TxRate-73728k"   => 1592,
                    "TxRate-737k"     => 737,
                    "TxRate-73856k"   => 1593,
                    "TxRate-738k"     => 738,
                    "TxRate-73984k"   => 1594,
                    "TxRate-739k"     => 739,
                    "TxRate-73k"      => 73,
                    "TxRate-740k"     => 740,
                    "TxRate-74112k"   => 1595,
                    "TxRate-741k"     => 741,
                    "TxRate-74240k"   => 1596,
                    "TxRate-7424k"    => 1074,
                    "TxRate-742k"     => 742,
                    "TxRate-74368k"   => 1597,
                    "TxRate-743k"     => 743,
                    "TxRate-74496k"   => 1598,
                    "TxRate-744k"     => 744,
                    "TxRate-745k"     => 745,
                    "TxRate-74624k"   => 1599,
                    "TxRate-746k"     => 746,
                    "TxRate-74752k"   => 1600,
                    "TxRate-747k"     => 747,
                    "TxRate-74880k"   => 1601,
                    "TxRate-748k"     => 748,
                    "TxRate-749k"     => 749,
                    "TxRate-74k"      => 74,
                    "TxRate-75008k"   => 1602,
                    "TxRate-750k"     => 750,
                    "TxRate-75136k"   => 1603,
                    "TxRate-751k"     => 751,
                    "TxRate-75264k"   => 1604,
                    "TxRate-752k"     => 752,
                    "TxRate-75392k"   => 1605,
                    "TxRate-753k"     => 753,
                    "TxRate-754k"     => 754,
                    "TxRate-75520k"   => 1606,
                    "TxRate-7552k"    => 1075,
                    "TxRate-755k"     => 755,
                    "TxRate-75648k"   => 1607,
                    "TxRate-756k"     => 756,
                    "TxRate-75776k"   => 1608,
                    "TxRate-757k"     => 757,
                    "TxRate-758k"     => 758,
                    "TxRate-75904k"   => 1609,
                    "TxRate-759k"     => 759,
                    "TxRate-75k"      => 75,
                    "TxRate-76032k"   => 1610,
                    "TxRate-760k"     => 760,
                    "TxRate-76160k"   => 1611,
                    "TxRate-761k"     => 761,
                    "TxRate-76288k"   => 1612,
                    "TxRate-762k"     => 762,
                    "TxRate-763k"     => 763,
                    "TxRate-76416k"   => 1613,
                    "TxRate-764k"     => 764,
                    "TxRate-76544k"   => 1614,
                    "TxRate-765k"     => 765,
                    "TxRate-76672k"   => 1615,
                    "TxRate-766k"     => 766,
                    "TxRate-767k"     => 767,
                    "TxRate-76800k"   => 1616,
                    "TxRate-7680k"    => 1076,
                    "TxRate-768k"     => 768,
                    "TxRate-76928k"   => 1617,
                    "TxRate-769k"     => 769,
                    "TxRate-76k"      => 76,
                    "TxRate-77056k"   => 1618,
                    "TxRate-770k"     => 770,
                    "TxRate-77184k"   => 1619,
                    "TxRate-771k"     => 771,
                    "TxRate-772k"     => 772,
                    "TxRate-77312k"   => 1620,
                    "TxRate-773k"     => 773,
                    "TxRate-77440k"   => 1621,
                    "TxRate-774k"     => 774,
                    "TxRate-77568k"   => 1622,
                    "TxRate-775k"     => 775,
                    "TxRate-77696k"   => 1623,
                    "TxRate-776k"     => 776,
                    "TxRate-777k"     => 777,
                    "TxRate-77824k"   => 1624,
                    "TxRate-778k"     => 778,
                    "TxRate-77952k"   => 1625,
                    "TxRate-779k"     => 779,
                    "TxRate-77k"      => 77,
                    "TxRate-78080k"   => 1626,
                    "TxRate-7808k"    => 1077,
                    "TxRate-780k"     => 780,
                    "TxRate-781k"     => 781,
                    "TxRate-78208k"   => 1627,
                    "TxRate-782k"     => 782,
                    "TxRate-78336k"   => 1628,
                    "TxRate-783k"     => 783,
                    "TxRate-78464k"   => 1629,
                    "TxRate-784k"     => 784,
                    "TxRate-78592k"   => 1630,
                    "TxRate-785k"     => 785,
                    "TxRate-786k"     => 786,
                    "TxRate-78720k"   => 1631,
                    "TxRate-787k"     => 787,
                    "TxRate-78848k"   => 1632,
                    "TxRate-788k"     => 788,
                    "TxRate-78976k"   => 1633,
                    "TxRate-789k"     => 789,
                    "TxRate-78k"      => 78,
                    "TxRate-790k"     => 790,
                    "TxRate-79104k"   => 1634,
                    "TxRate-791k"     => 791,
                    "TxRate-79232k"   => 1635,
                    "TxRate-792k"     => 792,
                    "TxRate-79360k"   => 1636,
                    "TxRate-7936k"    => 1078,
                    "TxRate-793k"     => 793,
                    "TxRate-79488k"   => 1637,
                    "TxRate-794k"     => 794,
                    "TxRate-795k"     => 795,
                    "TxRate-79616k"   => 1638,
                    "TxRate-796k"     => 796,
                    "TxRate-79744k"   => 1639,
                    "TxRate-797k"     => 797,
                    "TxRate-79872k"   => 1640,
                    "TxRate-798k"     => 798,
                    "TxRate-799k"     => 799,
                    "TxRate-79k"      => 79,
                    "TxRate-80000k"   => 1641,
                    "TxRate-800k"     => 800,
                    "TxRate-80128k"   => 1642,
                    "TxRate-801k"     => 801,
                    "TxRate-80256k"   => 1643,
                    "TxRate-802k"     => 802,
                    "TxRate-80384k"   => 1644,
                    "TxRate-803k"     => 803,
                    "TxRate-804k"     => 804,
                    "TxRate-80512k"   => 1645,
                    "TxRate-805k"     => 805,
                    "TxRate-80640k"   => 1646,
                    "TxRate-8064k"    => 1079,
                    "TxRate-806k"     => 806,
                    "TxRate-80768k"   => 1647,
                    "TxRate-807k"     => 807,
                    "TxRate-80896k"   => 1648,
                    "TxRate-808k"     => 808,
                    "TxRate-809k"     => 809,
                    "TxRate-80k"      => 80,
                    "TxRate-81024k"   => 1649,
                    "TxRate-810k"     => 810,
                    "TxRate-81152k"   => 1650,
                    "TxRate-811k"     => 811,
                    "TxRate-81280k"   => 1651,
                    "TxRate-812k"     => 812,
                    "TxRate-813k"     => 813,
                    "TxRate-81408k"   => 1652,
                    "TxRate-814k"     => 814,
                    "TxRate-81536k"   => 1653,
                    "TxRate-815k"     => 815,
                    "TxRate-81664k"   => 1654,
                    "TxRate-816k"     => 816,
                    "TxRate-81792k"   => 1655,
                    "TxRate-817k"     => 817,
                    "TxRate-818k"     => 818,
                    "TxRate-81920k"   => 1656,
                    "TxRate-8192k"    => 1080,
                    "TxRate-819k"     => 819,
                    "TxRate-81k"      => 81,
                    "TxRate-82048k"   => 1657,
                    "TxRate-820k"     => 820,
                    "TxRate-82176k"   => 1658,
                    "TxRate-821k"     => 821,
                    "TxRate-822k"     => 822,
                    "TxRate-82304k"   => 1659,
                    "TxRate-823k"     => 823,
                    "TxRate-82432k"   => 1660,
                    "TxRate-824k"     => 824,
                    "TxRate-82560k"   => 1661,
                    "TxRate-825k"     => 825,
                    "TxRate-82688k"   => 1662,
                    "TxRate-826k"     => 826,
                    "TxRate-827k"     => 827,
                    "TxRate-82816k"   => 1663,
                    "TxRate-828k"     => 828,
                    "TxRate-82944k"   => 1664,
                    "TxRate-829k"     => 829,
                    "TxRate-82k"      => 82,
                    "TxRate-83072k"   => 1665,
                    "TxRate-830k"     => 830,
                    "TxRate-831k"     => 831,
                    "TxRate-83200k"   => 1666,
                    "TxRate-8320k"    => 1081,
                    "TxRate-832k"     => 832,
                    "TxRate-83328k"   => 1667,
                    "TxRate-833k"     => 833,
                    "TxRate-83456k"   => 1668,
                    "TxRate-834k"     => 834,
                    "TxRate-83584k"   => 1669,
                    "TxRate-835k"     => 835,
                    "TxRate-836k"     => 836,
                    "TxRate-83712k"   => 1670,
                    "TxRate-837k"     => 837,
                    "TxRate-83840k"   => 1671,
                    "TxRate-838k"     => 838,
                    "TxRate-83968k"   => 1672,
                    "TxRate-839k"     => 839,
                    "TxRate-83k"      => 83,
                    "TxRate-84096k"   => 1673,
                    "TxRate-840k"     => 840,
                    "TxRate-841k"     => 841,
                    "TxRate-84224k"   => 1674,
                    "TxRate-842k"     => 842,
                    "TxRate-84352k"   => 1675,
                    "TxRate-843k"     => 843,
                    "TxRate-84480k"   => 1676,
                    "TxRate-8448k"    => 1082,
                    "TxRate-844k"     => 844,
                    "TxRate-845k"     => 845,
                    "TxRate-84608k"   => 1677,
                    "TxRate-846k"     => 846,
                    "TxRate-84736k"   => 1678,
                    "TxRate-847k"     => 847,
                    "TxRate-84864k"   => 1679,
                    "TxRate-848k"     => 848,
                    "TxRate-84992k"   => 1680,
                    "TxRate-849k"     => 849,
                    "TxRate-84k"      => 84,
                    "TxRate-850k"     => 850,
                    "TxRate-85120k"   => 1681,
                    "TxRate-851k"     => 851,
                    "TxRate-85248k"   => 1682,
                    "TxRate-852k"     => 852,
                    "TxRate-85376k"   => 1683,
                    "TxRate-853k"     => 853,
                    "TxRate-854k"     => 854,
                    "TxRate-85504k"   => 1684,
                    "TxRate-855k"     => 855,
                    "TxRate-85632k"   => 1685,
                    "TxRate-856k"     => 856,
                    "TxRate-85760k"   => 1686,
                    "TxRate-8576k"    => 1083,
                    "TxRate-857k"     => 857,
                    "TxRate-85888k"   => 1687,
                    "TxRate-858k"     => 858,
                    "TxRate-859k"     => 859,
                    "TxRate-85k"      => 85,
                    "TxRate-86016k"   => 1688,
                    "TxRate-860k"     => 860,
                    "TxRate-86144k"   => 1689,
                    "TxRate-861k"     => 861,
                    "TxRate-86272k"   => 1690,
                    "TxRate-862k"     => 862,
                    "TxRate-863k"     => 863,
                    "TxRate-86400k"   => 1691,
                    "TxRate-864k"     => 864,
                    "TxRate-86528k"   => 1692,
                    "TxRate-865k"     => 865,
                    "TxRate-86656k"   => 1693,
                    "TxRate-866k"     => 866,
                    "TxRate-86784k"   => 1694,
                    "TxRate-867k"     => 867,
                    "TxRate-868k"     => 868,
                    "TxRate-86912k"   => 1695,
                    "TxRate-869k"     => 869,
                    "TxRate-86k"      => 86,
                    "TxRate-87040k"   => 1696,
                    "TxRate-8704k"    => 1084,
                    "TxRate-870k"     => 870,
                    "TxRate-87168k"   => 1697,
                    "TxRate-871k"     => 871,
                    "TxRate-87296k"   => 1698,
                    "TxRate-872k"     => 872,
                    "TxRate-873k"     => 873,
                    "TxRate-87424k"   => 1699,
                    "TxRate-874k"     => 874,
                    "TxRate-87552k"   => 1700,
                    "TxRate-875k"     => 875,
                    "TxRate-87680k"   => 1701,
                    "TxRate-876k"     => 876,
                    "TxRate-877k"     => 877,
                    "TxRate-87808k"   => 1702,
                    "TxRate-878k"     => 878,
                    "TxRate-87936k"   => 1703,
                    "TxRate-879k"     => 879,
                    "TxRate-87k"      => 87,
                    "TxRate-88064k"   => 1704,
                    "TxRate-880k"     => 880,
                    "TxRate-88192k"   => 1705,
                    "TxRate-881k"     => 881,
                    "TxRate-882k"     => 882,
                    "TxRate-88320k"   => 1706,
                    "TxRate-8832k"    => 1085,
                    "TxRate-883k"     => 883,
                    "TxRate-88448k"   => 1707,
                    "TxRate-884k"     => 884,
                    "TxRate-88576k"   => 1708,
                    "TxRate-885k"     => 885,
                    "TxRate-886k"     => 886,
                    "TxRate-88704k"   => 1709,
                    "TxRate-887k"     => 887,
                    "TxRate-88832k"   => 1710,
                    "TxRate-888k"     => 888,
                    "TxRate-88960k"   => 1711,
                    "TxRate-889k"     => 889,
                    "TxRate-88k"      => 88,
                    "TxRate-89088k"   => 1712,
                    "TxRate-890k"     => 890,
                    "TxRate-891k"     => 891,
                    "TxRate-89216k"   => 1713,
                    "TxRate-892k"     => 892,
                    "TxRate-89344k"   => 1714,
                    "TxRate-893k"     => 893,
                    "TxRate-89472k"   => 1715,
                    "TxRate-894k"     => 894,
                    "TxRate-895k"     => 895,
                    "TxRate-89600k"   => 1716,
                    "TxRate-8960k"    => 1086,
                    "TxRate-896k"     => 896,
                    "TxRate-89728k"   => 1717,
                    "TxRate-897k"     => 897,
                    "TxRate-89856k"   => 1718,
                    "TxRate-898k"     => 898,
                    "TxRate-89984k"   => 1719,
                    "TxRate-899k"     => 899,
                    "TxRate-89k"      => 89,
                    "TxRate-900k"     => 900,
                    "TxRate-90112k"   => 1720,
                    "TxRate-901k"     => 901,
                    "TxRate-90240k"   => 1721,
                    "TxRate-902k"     => 902,
                    "TxRate-90368k"   => 1722,
                    "TxRate-903k"     => 903,
                    "TxRate-90496k"   => 1723,
                    "TxRate-904k"     => 904,
                    "TxRate-905k"     => 905,
                    "TxRate-90624k"   => 1724,
                    "TxRate-906k"     => 906,
                    "TxRate-90752k"   => 1725,
                    "TxRate-907k"     => 907,
                    "TxRate-90880k"   => 1726,
                    "TxRate-9088k"    => 1087,
                    "TxRate-908k"     => 908,
                    "TxRate-909k"     => 909,
                    "TxRate-90k"      => 90,
                    "TxRate-91008k"   => 1727,
                    "TxRate-910k"     => 910,
                    "TxRate-91136k"   => 1728,
                    "TxRate-911k"     => 911,
                    "TxRate-91264k"   => 1729,
                    "TxRate-912k"     => 912,
                    "TxRate-91392k"   => 1730,
                    "TxRate-913k"     => 913,
                    "TxRate-914k"     => 914,
                    "TxRate-91520k"   => 1731,
                    "TxRate-915k"     => 915,
                    "TxRate-91648k"   => 1732,
                    "TxRate-916k"     => 916,
                    "TxRate-91776k"   => 1733,
                    "TxRate-917k"     => 917,
                    "TxRate-918k"     => 918,
                    "TxRate-91904k"   => 1734,
                    "TxRate-919k"     => 919,
                    "TxRate-91k"      => 91,
                    "TxRate-92032k"   => 1735,
                    "TxRate-920k"     => 920,
                    "TxRate-92160k"   => 1736,
                    "TxRate-9216k"    => 1088,
                    "TxRate-921k"     => 921,
                    "TxRate-92288k"   => 1737,
                    "TxRate-922k"     => 922,
                    "TxRate-923k"     => 923,
                    "TxRate-92416k"   => 1738,
                    "TxRate-924k"     => 924,
                    "TxRate-92544k"   => 1739,
                    "TxRate-925k"     => 925,
                    "TxRate-92672k"   => 1740,
                    "TxRate-926k"     => 926,
                    "TxRate-927k"     => 927,
                    "TxRate-92800k"   => 1741,
                    "TxRate-928k"     => 928,
                    "TxRate-92928k"   => 1742,
                    "TxRate-929k"     => 929,
                    "TxRate-92k"      => 92,
                    "TxRate-93056k"   => 1743,
                    "TxRate-930k"     => 930,
                    "TxRate-93184k"   => 1744,
                    "TxRate-931k"     => 931,
                    "TxRate-932k"     => 932,
                    "TxRate-93312k"   => 1745,
                    "TxRate-933k"     => 933,
                    "TxRate-93440k"   => 1746,
                    "TxRate-9344k"    => 1089,
                    "TxRate-934k"     => 934,
                    "TxRate-93568k"   => 1747,
                    "TxRate-935k"     => 935,
                    "TxRate-93696k"   => 1748,
                    "TxRate-936k"     => 936,
                    "TxRate-937k"     => 937,
                    "TxRate-93824k"   => 1749,
                    "TxRate-938k"     => 938,
                    "TxRate-93952k"   => 1750,
                    "TxRate-939k"     => 939,
                    "TxRate-93k"      => 93,
                    "TxRate-94080k"   => 1751,
                    "TxRate-940k"     => 940,
                    "TxRate-941k"     => 941,
                    "TxRate-94208k"   => 1752,
                    "TxRate-942k"     => 942,
                    "TxRate-94336k"   => 1753,
                    "TxRate-943k"     => 943,
                    "TxRate-94464k"   => 1754,
                    "TxRate-944k"     => 944,
                    "TxRate-94592k"   => 1755,
                    "TxRate-945k"     => 945,
                    "TxRate-946k"     => 946,
                    "TxRate-94720k"   => 1756,
                    "TxRate-9472k"    => 1090,
                    "TxRate-947k"     => 947,
                    "TxRate-94848k"   => 1757,
                    "TxRate-948k"     => 948,
                    "TxRate-94976k"   => 1758,
                    "TxRate-949k"     => 949,
                    "TxRate-94k"      => 94,
                    "TxRate-950k"     => 950,
                    "TxRate-95104k"   => 1759,
                    "TxRate-951k"     => 951,
                    "TxRate-95232k"   => 1760,
                    "TxRate-952k"     => 952,
                    "TxRate-95360k"   => 1761,
                    "TxRate-953k"     => 953,
                    "TxRate-95488k"   => 1762,
                    "TxRate-954k"     => 954,
                    "TxRate-955k"     => 955,
                    "TxRate-95616k"   => 1763,
                    "TxRate-956k"     => 956,
                    "TxRate-95744k"   => 1764,
                    "TxRate-957k"     => 957,
                    "TxRate-95872k"   => 1765,
                    "TxRate-958k"     => 958,
                    "TxRate-959k"     => 959,
                    "TxRate-95k"      => 95,
                    "TxRate-96000k"   => 1766,
                    "TxRate-9600k"    => 1091,
                    "TxRate-960k"     => 960,
                    "TxRate-96128k"   => 1767,
                    "TxRate-961k"     => 961,
                    "TxRate-96256k"   => 1768,
                    "TxRate-962k"     => 962,
                    "TxRate-96384k"   => 1769,
                    "TxRate-963k"     => 963,
                    "TxRate-964k"     => 964,
                    "TxRate-96512k"   => 1770,
                    "TxRate-965k"     => 965,
                    "TxRate-96640k"   => 1771,
                    "TxRate-966k"     => 966,
                    "TxRate-96768k"   => 1772,
                    "TxRate-967k"     => 967,
                    "TxRate-96896k"   => 1773,
                    "TxRate-968k"     => 968,
                    "TxRate-969k"     => 969,
                    "TxRate-96k"      => 96,
                    "TxRate-97024k"   => 1774,
                    "TxRate-970k"     => 970,
                    "TxRate-97152k"   => 1775,
                    "TxRate-971k"     => 971,
                    "TxRate-97280k"   => 1776,
                    "TxRate-9728k"    => 1092,
                    "TxRate-972k"     => 972,
                    "TxRate-973k"     => 973,
                    "TxRate-97408k"   => 1777,
                    "TxRate-974k"     => 974,
                    "TxRate-97536k"   => 1778,
                    "TxRate-975k"     => 975,
                    "TxRate-97664k"   => 1779,
                    "TxRate-976k"     => 976,
                    "TxRate-97792k"   => 1780,
                    "TxRate-977k"     => 977,
                    "TxRate-978k"     => 978,
                    "TxRate-97920k"   => 1781,
                    "TxRate-979k"     => 979,
                    "TxRate-97k"      => 97,
                    "TxRate-98048k"   => 1782,
                    "TxRate-980k"     => 980,
                    "TxRate-98176k"   => 1783,
                    "TxRate-981k"     => 981,
                    "TxRate-982k"     => 982,
                    "TxRate-98304k"   => 1784,
                    "TxRate-983k"     => 983,
                    "TxRate-98432k"   => 1785,
                    "TxRate-984k"     => 984,
                    "TxRate-98560k"   => 1786,
                    "TxRate-9856k"    => 1093,
                    "TxRate-985k"     => 985,
                    "TxRate-98688k"   => 1787,
                    "TxRate-986k"     => 986,
                    "TxRate-987k"     => 987,
                    "TxRate-98816k"   => 1788,
                    "TxRate-988k"     => 988,
                    "TxRate-98944k"   => 1789,
                    "TxRate-989k"     => 989,
                    "TxRate-98k"      => 98,
                    "TxRate-99072k"   => 1790,
                    "TxRate-990k"     => 990,
                    "TxRate-991k"     => 991,
                    "TxRate-99200k"   => 1791,
                    "TxRate-992k"     => 992,
                    "TxRate-99328k"   => 1792,
                    "TxRate-993k"     => 993,
                    "TxRate-99456k"   => 1793,
                    "TxRate-994k"     => 994,
                    "TxRate-99584k"   => 1794,
                    "TxRate-995k"     => 995,
                    "TxRate-996k"     => 996,
                    "TxRate-99712k"   => 1795,
                    "TxRate-997k"     => 997,
                    "TxRate-99840k"   => 1796,
                    "TxRate-9984k"    => 1094,
                    "TxRate-998k"     => 998,
                    "TxRate-99968k"   => 1797,
                    "TxRate-999k"     => 999,
                    "TxRate-99k"      => 99,
                    "TxRate-Local"    => 0,
                    "TxRate-MaxSpeed" => 8,
                },
                153 => { Down => 1, Up => 0 },
                154 => {
                    "Base"         => 1,
                    "Base-Polling" => 2,
                    "Peer-to-Peer" => 0,
                    "Satellite-NT" => 3
                },
            },
            800 => {
                16 => {
                    "Xylan-Admin-Priv" => 3,
                    "Xylan-Read-Priv"  => 1,
                    "Xylan-Write-Priv" => 2,
                },
            },
            831 => {
                14  => { Disconnect => 2, Ignore => 1 },
                210 => { False      => 0, True   => 1 },
            },
            890 => {
                192 => { Mandatory     => 2, None => 0, Optional => 1 },
                193 => { Preconfigured => 0, User => 1 },
            },
            969 => {
                13 => {
                    "FTP"           => 1,
                    "IMAP"          => 4,
                    "Other"         => 200,
                    "POP"           => 3,
                    "SMTP-Auth"     => 7,
                    "Unix-Logon"    => 6,
                    "WEB"           => 2,
                    "Windows-Logon" => 5,
                },
                17 => { "Admin-User" => 2, "Anonymous-User" => 1 },
            },
            1271 => {
                1 => {
                    "admin"      => 2,
                    "diag"       => 4,
                    "limited"    => 1,
                    "super-user" => 3
                },
                10 => {
                    "admin"      => 2,
                    "diag"       => 4,
                    "limited"    => 1,
                    "super-user" => 3
                },
            },
            1584 => {
                38 => { "kmd5-128" => 1, "none"          => 0 },
                39 => { "none"     => 0, "prefix-suffix" => 1 },
                42 => { local      => 1, remote          => 2 },
                44 => {
                    "Abnormal-termination"     => 13,
                    "Admin-port-reset"         => 16,
                    "CHAP-auth-failed"         => 20,
                    "CLI-auth-failed"          => 17,
                    "CLI-Hangup-command"       => 9,
                    "CLI-inactivity"           => 15,
                    "CLI-last-job"             => 10,
                    "DCD-wait-failed"          => 14,
                    "Dial-failed"              => 2,
                    "Disconnect-reset"         => 4,
                    "DVS-Home-agent-dereg"     => 52,
                    "DVS-Registration-failure" => 51,
                    "DVS-Tunnel-expired"       => 54,
                    "DVS-Tunnel-no-renew"      => 53,
                    "Error-from-adm_notify"    => 5,
                    "Inactivity-timer"         => 8,
                    "Line-disconnected"        => 1,
                    "Local-modem-reset"        => 21,
                    "Modem-dead"               => 22,
                    "Modem-down-adm_notify"    => 6,
                    "PAP-auth-failed"          => 19,
                    "PPP-Address-In-Use"       => 37,
                    "PPP-ATCP-failure"         => 26,
                    "PPP-ATCP-timeout"         => 31,
                    "PPP-CCP-failure"          => 27,
                    "PPP-CCP-timeout"          => 32,
                    "PPP-Connection-Abort"     => 45,
                    "PPP-Dialback-failed"      => 36,
                    "PPP-Hangup-rcvd"          => 40,
                    "PPP-init-failure"         => 34,
                    "PPP-Invalid-device"       => 49,
                    "PPP-IPCP-failure"         => 24,
                    "PPP-IPCP-timeout"         => 29,
                    "PPP-IPXCP-failure"        => 25,
                    "PPP-IPXCP-timeout"        => 30,
                    "PPP-Kill-rcvd"            => 42,
                    "PPP-LCP-failure"          => 23,
                    "PPP-MMP-bundle-failure"   => 50,
                    "PPP-Modem-hangup-rcvd"    => 39,
                    "PPP-MP-failure"           => 28,
                    "PPP-MP-invalid-port"      => 48,
                    "PPP-MP-timeout"           => 33,
                    "PPP-No-device"            => 38,
                    "PPP-No-memory"            => 44,
                    "PPP-protocol-disconnect"  => 7,
                    "PPP-Termination-rcvd"     => 41,
                    "PPP-Time-rcvd"            => 43,
                    "PPP-Unknown"              => 35,
                    "PPP-VPN-Auth-failure"     => 47,
                    "PPP-VPN-LCP-failure"      => 46,
                    "Session-timeout"          => 11,
                    "Slave-auth-failed"        => 18,
                    "Slave-termination"        => 12,
                    "Unknown"                  => 0,
                    "WAN-manager-error"        => 3,
                },
                45 => {
                    "Carrier-Lost"          => 7,
                    "CD-Timer-Expired"      => 2,
                    "Clear-down"            => 5,
                    "Local-disconnect"      => 1,
                    "Long-Space-disconnect" => 6,
                    "Modem-Retrain-Timeout" => 8,
                    "Remote-protocol-disc"  => 4,
                    "Unknown"               => 0,
                },
                47  => { DHCP    => 1, none     => 0 },
                100 => { Manager => 2, Operator => 8, User => 4 },
                101 => { Manager => 2, Operator => 8, User => 4 },
                192 => {
                    "L1-Read-Write-Access"  => 2,
                    "L2-Read-Write-Access"  => 3,
                    "L3-Read-Write-Access"  => 4,
                    "None-Access"           => 0,
                    "Read-Only-Access"      => 1,
                    "Read-Write-Access"     => 5,
                    "Read-Write-All-Access" => 6,
                },
                194 => { False => 0, True => 1 },
            },
            1768 => {
                35 => {
                    "A-suspended-call-exists-but-this-call-identity-does-not"
                      => 83,
                    "Access-information-discarded"              => 43,
                    "Bearer-capability-not-authorized"          => 57,
                    "Bearer-capability-not-presently-available" => 58,
                    "Bearer-service-not-implemented"            => 65,
                    "Call-awarded-and-being-delivered-in-an-established-channel"
                      => 7,
                    "Call-having-the-requested-call-identity-has-been-cleared"
                      => 86,
                    "Call-identity-in-use"          => 84,
                    "Call-rejected"                 => 21,
                    "Call-resumed"                  => 25,
                    "Call-suspended"                => 24,
                    "Call-waiting-not-subscribed"   => 56,
                    "Called-user-not-member-of-CUG" => 87,
                    "Channel-type-not-implemented"  => 66,
                    "Channel-unacceptable"          => 6,
                    "Circuit-out-of-order"          => 33,
                    "Degraded-service"              => 37,
                    "Destination-address-missing-and-direct-call-not-subscribed"
                      => 90,
                    "Destination-out-of-order"                           => 27,
                    "Destination-unattainable"                           => 35,
                    "Facility-rejected"                                  => 29,
                    "Identified-channel-does-not-exist"                  => 82,
                    "Incoming-calls-barred"                              => 54,
                    "Incoming-calls-barred-within-CUG"                   => 55,
                    "Incompatible-destination"                           => 88,
                    "information-element-nonexistant-or-not-implemented" => 99,
                    "Internetworking-unspecified"                        => 127,
                    "Invalid-call-reference-value"                       => 81,
                    "Invalid-facility-parameter"                         => 92,
                    "Invalid-information-element-contents"               => 100,
                    "Invalid-message-unspecified"                        => 95,
                    "Invalid-number-format-incomplete-number"            => 28,
                    "Invalid-transit-network-selection-national-use"     => 91,
                    "Mandatory-information-element-is-missing"           => 93,
                    "Mandatory-information-element-is-missing-2"         => 96,
                    "Message-not-compatible-with-call-state"             => 98,
                    "Message-not-compatible-with-call-state-2"           => 101,
                    "Message-not-implemented"                            => 68,
                    "Message-type-non-existent-or-not-implemented"       => 97,
                    "misdialled-trunk-prefix"                            => 5,
                    "More-digits-received-than-allowed-call-is-proceeding" =>
                      11,
                    "Network-WAN-out-of-order"                  => 38,
                    "no-answer-from-user"                       => 19,
                    "No-call-suspended"                         => 85,
                    "No-circuit/channel-available"              => 34,
                    "No-route-to-destination"                   => 3,
                    "No-route-to-specified-transit-network-WAN" => 2,
                    "No-user-responding"                        => 18,
                    "Non-existent-abbreviated-address-entry"    => 89,
                    "Non-selected-user-clearing"                => 26,
                    "Normal-call-clearing"                      => 16,
                    "Normal-unspecified"                        => 31,
                    "Number-changed"                            => 22,
"Only-restricted-digital-information-bearer-capability-is-avail"
                      => 70,
                    "Outgoing-calls-barred"                               => 52,
                    "Outgoing-calls-barred-within-CUG"                    => 53,
                    "parameter-non-existent-or-not-implemented-passed-on" =>
                      103,
                    "Pre-empted"                                    => 45,
                    "Precedence-call-blocked"                       => 46,
                    "Prefix-0-dialed-but-not-allowed"               => 8,
                    "Prefix-1-dialed-but-not-allowed"               => 9,
                    "Prefix-1-dialed-but-not-required"              => 10,
                    "Protocol-error-unspecified"                    => 111,
                    "Quality-of-service-unavailable"                => 49,
                    "Recovery-on-timer-expiry"                      => 102,
                    "Requested-circuit-channel-not-available"       => 44,
                    "Requested-facility-not-implemented"            => 69,
                    "Requested-facility-not-subscribed"             => 50,
                    "Resource-unavailable-unspecified"              => 47,
                    "Response-to-STATUS-ENQUIRY"                    => 30,
                    "Reverse-charging-not-allowed"                  => 51,
                    "Reverse-charging-rejected"                     => 23,
                    "send-special-information-tone"                 => 4,
                    "Service-or-option-not-available-unspecified"   => 63,
                    "Service-or-option-not-implemented-unspecified" => 79,
                    "Switching-equipment-congestion"                => 42,
                    "Temporary-failure"                             => 41,
                    "Throughput-range-cannot-be-achieved"           => 40,
                    "Transit-delay-range-cannot-be-achieved"        => 39,
                    "Transit-network-selection-not-implemented"     => 67,
                    "Unallocated-runassigned-number"                => 1,
                    "User-busy"                                     => 17,
                    "Valid-cause-code-not-yet-received"             => 0,
                },
            },
            1872 => {
                26 => {
                    "Alteon-L4admin"  => 250,
                    "Alteon-L4oper"   => 253,
                    "Alteon-Oper"     => 252,
                    "Alteon-Slbadmin" => 251,
                    "Alteon-Slboper"  => 254,
                    "Alteon-User"     => 255,
                },
            },
            1916 => {
                201 => { Disabled => 0, Enabled => 1 },
                206 => { Disabled => 0, Enabled => 1 },
            },
            1966 => {
                99  => { Disabled => 0, Enabled => 1 },
                100 => { Admin => 1, Menu => 4, Normal => 2, Restricted => 3 },
                101 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                102 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                103 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                104 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                105 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                106 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                107 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                108 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                109 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                110 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                111 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                112 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                113 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                114 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                115 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                116 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                117 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                118 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                119 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                120 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                121 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                122 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                123 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                124 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                125 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                126 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                127 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                128 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                129 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                130 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                131 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                132 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                133 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                134 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                135 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                136 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                137 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                138 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                139 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                140 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                141 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                142 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                143 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                144 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                145 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                146 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                147 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                148 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
                149 => {
                    "Disabled"                => 0,
                    "Read-Input"              => 2,
                    "Read-Input-Write"        => 3,
                    "Read-Output"             => 4,
                    "Read-Output-Input"       => 6,
                    "Read-Output-Input-Write" => 7,
                    "Read-Output-Write"       => 5,
                    "Read-Write"              => 1,
                },
            },
            1991 => {
                4 => {
                    AAA_pri_0  => 0,
                    AAA_pri_1  => 1,
                    AAA_pri_10 => 10,
                    AAA_pri_11 => 11,
                    AAA_pri_12 => 12,
                    AAA_pri_13 => 13,
                    AAA_pri_14 => 14,
                    AAA_pri_15 => 15,
                    AAA_pri_2  => 2,
                    AAA_pri_3  => 3,
                    AAA_pri_4  => 4,
                    AAA_pri_5  => 5,
                    AAA_pri_6  => 6,
                    AAA_pri_7  => 7,
                    AAA_pri_8  => 8,
                    AAA_pri_9  => 9,
                },
                8 => {
                    QoS_priority_0 => 0,
                    QoS_priority_1 => 1,
                    QoS_priority_2 => 2,
                    QoS_priority_3 => 3,
                    QoS_priority_4 => 4,
                    QoS_priority_5 => 5,
                    QoS_priority_6 => 6,
                    QoS_priority_7 => 7,
                },
            },
            2011 => {
                25 => { Succeeded     => 0 },
                85 => { "Non-captive" => 2, "PADM" => 0, "Redirectional" => 1 },
                142 => {
                    "L2TP"          => 3,
                    "L2TP-Inbound"  => 1,
                    "L2TP-Outbound" => 2,
                    "Original"      => 0
                },
                168 => { Danger => 2, Safe => 0, Warning => 1 },
                180 => {
                    Administrative => 7,
                    Bind           => 5,
                    Dot1x          => 3,
                    Fast           => 4,
                    MIP            => 9,
                    None           => 10,
                    PPP            => 1,
                    Tunnel         => 8,
                    Web            => 2,
                    WLAN           => 6,
                },
                183 => {
                    "Disable"         => 0,
                    "Downlink-Enable" => 2,
                    "Enable"          => 3,
                    "Uplink-Enable"   => 1
                },
                196 => { Supported => 1, Unsupported => 0 },
                215 => {
                    "Fixed"         => 1,
                    "Full-Mobile"   => 5,
                    "Nomadic"       => 2,
                    "Portable"      => 3,
                    "Simple-Mobile" => 4,
                },
                218 => { Common => 0, Copper => 1, Gold => 3, Silver => 2 },
            },
            2167 => {
                1 => {
                    "Cajun-Admin-User"      => 3,
                    "Cajun-Read-Only-User"  => 1,
                    "Cajun-Read-Write-User" => 2,
                },
                13 => {
                    "Type-0" => 0,
                    "Type-1" => 1,
                    "Type-2" => 2,
                    "Type-3" => 3,
                    "Type-4" => 4,
                    "Type-5" => 5,
                    "Type-6" => 6,
                    "Type-7" => 7,
                },
            },
            2180 => {
                1 => {
                    "1st-modem-async-only-2nd-sync"   => 7,
                    "Bad-resp-to-feature-negotiation" => 10,
                    "Call-Waiting-Caused-Disconnect"  => 3,
                    "Clears-previous-disc-reason"     => 21,
                    "Disconnect-after-three-retrains" => 23,
                    "Inactivity-timeout"              => 17,
                    "Key-abort-disconnect"            => 20,
                    "Long-space-disconnect"           => 19,
                    "Lost-DTR"                        => 15,
                    "No-connection-established"       => 22,
                    "No-err-correction-at-other-end"  => 5,
                    "No-framing-technique-in-common"  => 8,
                    "No-protocol-in-common"           => 9,
                    "No-resp-to-feature-negotiation"  => 6,
                    "No-sync-info-from-remote-modem"  => 11,
                    "Normal-Hangup-by-Remote-modem"   => 12,
                    "Normal-Hangup-No-Error-Occurred" => 0,
                    "Physical-Carrier-Loss"           => 4,
                    "Protocol-violation-occurred"     => 14,
                    "Received-GSTN-cleardown"         => 16,
                    "Retransmission-limit-reached"    => 13,
                    "Speed-not-supported"             => 18,
                },
            },
            2352 => {
                14 => { Disabled  => 2, Enabled        => 1 },
                15 => { Disabled  => 2, Enabled        => 1 },
                18 => { "LAC-LNS" => 3, "LAC-Only"     => 1, "LNS-Only" => 2 },
                23 => { "CHAP"    => 1, "CHAP-PAP"     => 3, "PAP"      => 2 },
                29 => { Disabled  => 2, Enabled        => 1 },
                31 => { "First"   => 1, "Load-Balance" => 2, "WRR"      => 3 },
                33 => { "NO-SEND" => 1, "SEND" => 2, "UNSOLICITED-SEND" => 3 },
                34 => { "NO-RECEIVE" => 1, "RECEIVE" => 2 },
                37 => { "DNIS" => 1, "DNIS-Generate" => 4, "DNIS-Only" => 2 },
                38 =>
                  { Cable => 12, DSL => 11, Satellite => 14, Wireless => 13 },
                39 => {
                    "AAA-ENCAPS-ATM-AUTO1483"             => 3,
                    "AAA-ENCAPS-ATM-BRIDGE1483"           => 5,
                    "AAA-ENCAPS-ATM-L2TP"                 => 11,
                    "AAA-ENCAPS-ATM-MULTI"                => 4,
                    "AAA-ENCAPS-ATM-MULTI-IPV6OE"         => 28,
                    "AAA-ENCAPS-ATM-MULTI-PPPOE"          => 27,
                    "AAA-ENCAPS-ATM-MULTI-PPPOE-N-IPV6OE" => 29,
                    "AAA-ENCAPS-ATM-PPP"                  => 6,
                    "AAA-ENCAPS-ATM-PPP-AUTO"             => 9,
                    "AAA-ENCAPS-ATM-PPP-LLC"              => 12,
                    "AAA-ENCAPS-ATM-PPP-NLPID"            => 8,
                    "AAA-ENCAPS-ATM-PPP-SERIAL"           => 7,
                    "AAA-ENCAPS-ATM-PPPOE"                => 10,
                    "AAA-ENCAPS-ATM-RAW"                  => 1,
                    "AAA-ENCAPS-ATM-ROUTE1483"            => 2,
                    "AAA-ENCAPS-ETH"                      => 22,
                    "AAA-ENCAPS-ETH-DOT1Q"                => 25,
                    "AAA-ENCAPS-ETH-DOT1Q-PPPOE"          => 26,
                    "AAA-ENCAPS-ETH-DOT1Q-TUNNEL"         => 30,
                    "AAA-ENCAPS-ETH-DOT1Q-TUNNEL-PPPOE"   => 31,
                    "AAA-ENCAPS-ETH-MULTI"                => 24,
                    "AAA-ENCAPS-ETH-PPPOE"                => 23,
                    "AAA-ENCAPS-FRAME-AUTO1490"           => 13,
                    "AAA-ENCAPS-FRAME-BRIDGE1490"         => 15,
                    "AAA-ENCAPS-FRAME-L2TP"               => 20,
                    "AAA-ENCAPS-FRAME-MULTI"              => 14,
                    "AAA-ENCAPS-FRAME-PPP"                => 16,
                    "AAA-ENCAPS-FRAME-PPP-AUTO"           => 17,
                    "AAA-ENCAPS-FRAME-PPPOE"              => 18,
                    "AAA-ENCAPS-FRAME-ROUTE1490"          => 19,
                    "AAA-ENCAPS-L2TP-VC-MUXED"            => 21,
                },
                41 =>
                  { "AAA-CIRCUIT-NO-PADDING" => 2, "AAA-CIRCUIT-PADDING" => 1 },
                42 => {
                    "AAA-AUTH-BIND"            => 1,
                    "AAA-AUTO-SUBSCRIBER-BIND" => 14,
                    "AAA-BRIDGE-GROUP-BIND"    => 11,
                    "AAA-BYPASS-BIND"          => 2,
                    "AAA-DHCP-BIND"            => 9,
                    "AAA-INTERFACE-BIND"       => 3,
                    "AAA-MULTI-BIND"           => 8,
                    "AAA-MULTI-BIND-SUB"       => 10,
                    "AAA-Q8021-BIND"           => 7,
                    "AAA-SESSION-BIND"         => 6,
                    "AAA-SUBSCRIBE-BIND"       => 4,
                    "AAA-TUNNEL-BIND"          => 5,
                    "AAA-VLAN-BIND"            => 12,
                    "AAA-VLAN-GROUP-BIND"      => 13,
                },
                43 => {
                    "AAA-PPP-CHAP"          => 2,
                    "AAA-PPP-CHAP-PAP"      => 4,
                    "AAA-PPP-CHAP-WAIT"     => 3,
                    "AAA-PPP-CHAP-WAIT-PAP" => 5,
                    "AAA-PPP-EAP"           => 6,
                    "AAA-PPP-PAP"           => 1,
                    "AAA-PPP-PAP-CHAP"      => 7,
                    "AAA-PPP-PAP-CHAP-WAIT" => 8,
                },
                61 => {
                    "max-reliability-only"                               => 2,
                    "max-reliability-plus-min-cost"                      => 3,
                    "max-throughput-only"                                => 4,
                    "max-throughput-plus-max-reliability"                => 6,
                    "max-throughput-plus-max-reliability-plus-min-cost"  => 7,
                    "max-throughput-plus-min-cost"                       => 5,
                    "min-cost-only"                                      => 1,
                    "min-delay-only"                                     => 8,
                    "min-delay-plus-max-reliability"                     => 10,
                    "min-delay-plus-max-reliability-plus-min-cost"       => 11,
                    "min-delay-plus-max-throughput"                      => 12,
                    "min-delay-plus-max-throughput-plus-max-reliability" => 14,
"min-delay-plus-max-throughput-plus-max-reliability-plus-min-cost"
                      => 15,
                    "min-delay-plus-max-throughput-plus-min-cost" => 13,
                    "min-delay-plus-min-cost"                     => 9,
                    "normal"                                      => 0,
                },
                98 => {
                    "SE-100"        => 4,
                    "SE-400"        => 3,
                    "SmartEdge-800" => 2,
                    "SMS"           => 1
                },
                111 => { "ENCAPS-PPPOE" => 27 },
                139 => {
                    "NAS-PORT-TYPE-1000BSX"   => 54,
                    "NAS-PORT-TYPE-100BT"     => 41,
                    "NAS-PORT-TYPE-10BT"      => 40,
                    "NAS-PORT-TYPE-CHAN-T3"   => 48,
                    "NAS-PORT-TYPE-DS1-FR"    => 49,
                    "NAS-PORT-TYPE-DS3-ATM"   => 43,
                    "NAS-PORT-TYPE-DS3-ATM-2" => 52,
                    "NAS-PORT-TYPE-DS3-FR"    => 42,
                    "NAS-PORT-TYPE-E1-ATM"    => 56,
                    "NAS-PORT-TYPE-E1-FR"     => 55,
                    "NAS-PORT-TYPE-E3-ATM"    => 50,
                    "NAS-PORT-TYPE-E3-FR"     => 57,
                    "NAS-PORT-TYPE-EIA530"    => 46,
                    "NAS-PORT-TYPE-HSSI"      => 45,
                    "NAS-PORT-TYPE-IMA-ATM"   => 51,
                    "NAS-PORT-TYPE-OC12-POS"  => 59,
                    "NAS-PORT-TYPE-OC3"       => 44,
                    "NAS-PORT-TYPE-OC3-ATM-2" => 53,
                    "NAS-PORT-TYPE-OC3-POS"   => 58,
                    "NAS-PORT-TYPE-PPPOE"     => 60,
                    "NAS-PORT-TYPE-T1"        => 47,
                },
                140 => {
                    "NAS-PORT-TYPE-1000BSX"   => 54,
                    "NAS-PORT-TYPE-100BT"     => 41,
                    "NAS-PORT-TYPE-10BT"      => 40,
                    "NAS-PORT-TYPE-CHAN-T3"   => 48,
                    "NAS-PORT-TYPE-DS1-FR"    => 49,
                    "NAS-PORT-TYPE-DS3-ATM"   => 43,
                    "NAS-PORT-TYPE-DS3-ATM-2" => 52,
                    "NAS-PORT-TYPE-DS3-FR"    => 42,
                    "NAS-PORT-TYPE-E1-ATM"    => 56,
                    "NAS-PORT-TYPE-E1-FR"     => 55,
                    "NAS-PORT-TYPE-E3-ATM"    => 50,
                    "NAS-PORT-TYPE-E3-FR"     => 57,
                    "NAS-PORT-TYPE-EIA530"    => 46,
                    "NAS-PORT-TYPE-HSSI"      => 45,
                    "NAS-PORT-TYPE-IMA-ATM"   => 51,
                    "NAS-PORT-TYPE-OC12-POS"  => 59,
                    "NAS-PORT-TYPE-OC3"       => 44,
                    "NAS-PORT-TYPE-OC3-ATM-2" => 53,
                    "NAS-PORT-TYPE-OC3-POS"   => 58,
                    "NAS-PORT-TYPE-PPPOE"     => 60,
                    "NAS-PORT-TYPE-T1"        => 47,
                },
                144 => {
                    "AAA-LOAD-ACCT-ACL-ACTION"            => 13,
                    "AAA-LOAD-ACCT-ACL-TIMERED-ACTION"    => 12,
                    "AAA-LOAD-ACCT-CMD"                   => 14,
                    "AAA-LOAD-ACCT-DHCP-IP-ADDR-GRANTED"  => 10,
                    "AAA-LOAD-ACCT-DHCP-IP-ADDR-RELEASED" => 11,
                    "AAA-LOAD-ACCT-DYN-AC-ENT-START"      => 4,
                    "AAA-LOAD-ACCT-DYN-AC-ENT-STOP"       => 5,
                    "AAA-LOAD-ACCT-DYN-AC-ENT-TIMEOUT"    => 6,
                    "AAA-LOAD-ACCT-PERIODIC"              => 3,
                    "AAA-LOAD-ACCT-PPP-IPCP-UP"           => 8,
                    "AAA-LOAD-ACCT-PPP-MP-LINK-UP"        => 9,
                    "AAA-LOAD-ACCT-SESSION-DOWN"          => 2,
                    "AAA-LOAD-ACCT-SESSION-UP"            => 1,
                    "AAA-LOAD-ACCT-SUBSCRIBER-REAUTHOR"   => 7,
                    "AAA-LOAD-ACCT-TEST"                  => 15,
                },
                180 => { Idle => 2, Showtime => 1, Silent => 3 },
                182 => {
                    "ADSL1"   => 1,
                    "ADSL2"   => 2,
                    "ADSL2+"  => 3,
                    "SDSL"    => 6,
                    "UNKNOWN" => 7,
                    "VDSL1"   => 4,
                    "VDSL2"   => 5,
                },
                191 => {
                    "ACTIVATE-WITH-ACCT"    => 1,
                    "ACTIVATE-WITHOUT-ACCT" => 2,
                    "DE-ACTIVATE"           => 0,
                },
                193 => {
                    "Generic-service-error"       => 550,
                    "Invalid-request"             => 404,
                    "Missing-attribute"           => 402,
                    "Resource-unavailable"        => 506,
                    "Service-accounting-disabled" => 553,
                    "Service-already-active"      => 552,
                    "Service-duplicate-parameter" => 554,
                    "Service-not-found"           => 551,
                    "Service-success"             => 0,
                    "Unsupported-attribute"       => 401,
                },
            },
            2454 => {
                10 => {
                    "Disable"               => 1,
                    "Enable"                => 2,
                    "Enable-On-IP-Update"   => 4,
                    "Lastpacket"            => 3,
                    "Reset-Acct-Session-ID" => 5,
                },
                13 => {
                    "Pre-Auth"          => 1,
                    "Service-Selection" => 2,
                    "Web-Auth"          => 3
                },
                14 => {
                    "Echo"                                 => 2,
                    "L2Echo"                               => 6,
                    "Macantispoof"                         => 3,
                    "Reject"                               => 1,
                    "User-Space-Overwrite"                 => 4,
                    "User-Space-Overwrite-On-Next-Service" => 5,
                },
                32  => { "Normal"   => 1, "Pass-Through" => 3, "Update" => 2 },
                33  => { Disconnect => 1, Update         => 2 },
                40  => { MLP        => 1, ROAM           => 2 },
                53  => { CLI        => 3, Service        => 1, User => 2 },
                56  => { Off        => 1 },
                61  => { Disable    => 1 },
                73  => { OSPF       => 2, RIPv2 => 1 },
                85  => { PPP        => 1 },
                110 => { Disable    => 2, Enable => 1 },
                120 => {
                    "Idle"                      => 5,
                    "Idle-On-Session-Idle"      => 262149,
                    "Reconnect-Disable"         => 4320,
                    "Reconnect-Disable-On-Idle" => 266464,
                },
                123 => {
                    Idle       => 4,
                    Mobility   => 1,
                    NoIdle     => 4294967291,
                    NoMobility => 4294967294,
                    NoSleep    => 4294967293,
                    Sleep      => 2,
                },
                124 => { Disable => 1, Enable => 0 },
                125 => { Off     => 1, On     => 2 },
            },
            2544 => {
                100 => {
                    Admin           => 4,
                    Operate_Control => 2,
                    Provision       => 3,
                    Reserved        => 1,
                    Retrieve        => 0,
                    Super           => 5,
                },
                102 => {
                    Admin     => 4,
                    Monitor   => 0,
                    Operator  => 2,
                    Provision => 3,
                    Reserved  => 1,
                    Root      => 5
                },
            },
            2636 => {
                21 => {
                    Admin            => 2,
                    Auditor          => 4,
                    Privileged_Admin => 3,
                    Read_Only        => 1
                },
                22 => { Global_Admin => 3, Net_Admin => 2, Net_View    => 1 },
                23 => { Auditor => 3, System_Admin   => 2, Web_Manager => 1 },
            },
            2979 => {
                1 => { be => 1, bronze => 2, gold => 4, silver => 3 },
                2 => { disabled => 0, enabled => 1 },
                7 => {
                    auto    => 1,
                    f_9050  => 3,
                    f_9084  => 7,
                    f_9116  => 4,
                    f_9150  => 8,
                    f_9184  => 5,
                    f_9216  => 9,
                    f_9250  => 6,
                    nomadic => 2,
                },
                15 => {
                    p_15 => 1,
                    p_16 => 2,
                    p_17 => 3,
                    p_18 => 4,
                    p_19 => 5,
                    p_20 => 6,
                    p_21 => 7,
                    p_22 => 8,
                    p_23 => 9,
                    p_24 => 10,
                    p_25 => 11,
                    p_26 => 12,
                },
            },
            3041 => {
                18 => { No => 0, Yes => 1 },
                22 => {
                    "IP-TOS-Cost"        => 2,
                    "IP-TOS-Disabled"    => 1,
                    "IP-TOS-Latency"     => 16,
                    "IP-TOS-Normal"      => 0,
                    "IP-TOS-Reliability" => 4,
                    "IP-TOS-Throughput"  => 8,
                },
                23 => {
                    "IP-TOS-Precedence-Pri-Five"   => 160,
                    "IP-TOS-Precedence-Pri-Four"   => 128,
                    "IP-TOS-Precedence-Pri-Normal" => 0,
                    "IP-TOS-Precedence-Pri-One"    => 32,
                    "IP-TOS-Precedence-Pri-Seven"  => 224,
                    "IP-TOS-Precedence-Pri-Six"    => 192,
                    "IP-TOS-Precedence-Pri-Three"  => 96,
                    "IP-TOS-Precedence-Pri-Two"    => 64,
                },
                24 => {
                    "IP-TOS-Apply-To-Both"     => 3072,
                    "IP-TOS-Apply-To-Incoming" => 1024,
                    "IP-TOS-Apply-To-Outgoing" => 2048,
                },
                27 => { "Multicast-No"       => 0, "Multicast-Yes"       => 1 },
                62 => { "Not-Require-Auth"   => 0, "Require-Auth"        => 1 },
                66 => { "Source-IP-Check-No" => 0, "Source-IP-Check-Yes" => 1 },
                68 => {
                    "AAT-Auth-Any"     => 2,
                    "AAT-Auth-CHAP"    => 4,
                    "AAT-Auth-Default" => 1,
                    "AAT-Auth-MS-CHAP" => 5,
                    "AAT-Auth-None"    => 0,
                    "AAT-Auth-PAP"     => 3,
                },
                72 => { "DNS-Assign-No" => 0, "DNS-Assign-Yes" => 1 },
            },
            3076 => {
                13 => {
                    "Internal"                  => 5,
                    "Kerberos/Active-Directory" => 7,
                    "LDAP-Authorization-only"   => 2,
                    "None"                      => 0,
                    "NT-Domain"                 => 3,
                    "RADIUS"                    => 1,
                    "RADIUS-with-Expiry"        => 6,
                    "SDI"                       => 4,
                },
                16 => { Disabled     => 0, Enabled         => 1 },
                17 => { Disabled     => 0, Enabled         => 1 },
                30 => { "LAN-to-LAN" => 1, "Remote-Access" => 2 },
                31 => { Disabled     => 0, Enabled         => 1 },
                34 => { Disabled     => 0, Enabled         => 1 },
                37 => { Disabled     => 0, Enabled         => 1 },
                38 => { Disabled     => 0, Enabled         => 1 },
                39 => { Disabled     => 0, Enabled         => 1 },
                40 => {
                    "Do-Not-Check"                     => 3,
                    "If-Supported-By-Peer-Certificate" => 2,
                    "Required"                         => 1,
                },
                41 => { Disabled => 0, Enabled => 1 },
                42 => { Disabled => 0, Enabled => 1 },
                45 => {
                    "Cisco-CIC"  => 1,
                    "Cisco-IPSA" => 5,
                    "NetworkICE" => 3,
                    "Sygate"     => 4,
                    "Zone-Labs"  => 2,
                },
                48 => { Disabled => 0, Enabled => 1 },
                49 => { Disabled => 0, Enabled => 1 },
                51 => { Disabled => 0, Enabled => 1 },
                55 => {
                    "Local-LAN-Permitted" => 2,
                    "No-Split-Tunneling"  => 0,
                    "Split-Tunneling"     => 1,
                },
                56 => {
                    "None"                    => 0,
                    "Policy-from-Server"      => 4,
                    "Policy-Pushed"           => 2,
                    "Policy-Remotely-Defined" => 1,
                },
                58 => { Optional => 1, Required => 0 },
                59 => {
                    "Disable-and-clear-client-list" => 2,
                    "Use-Backup-Server-List"        => 3,
                    "Use-Client-Configured-List"    => 1,
                },
                62 => { Disabled => 0, Enabled => 1 },
                64 => { Disabled => 0, Enabled => 1 },
                65 => { LDAP     => 2, None    => 0, Radius => 1 },
                66 => { No       => 0, Yes     => 1 },
                75 => { Disabled => 0, Enabled => 1 },
                81 => {
                    "Auto-detect"              => 3,
                    "No-Modify"                => 1,
                    "No-Proxy"                 => 2,
                    "Use-Concentrator-Setting" => 4,
                },
                83  => { Local                 => 1, None    => 0 },
                88  => { No                    => 0, Yes     => 1 },
                89  => { No                    => 0, Yes     => 1 },
                93  => { Disabled              => 0, Enabled => 1 },
                94  => { Disabled              => 0, Enabled => 1 },
                95  => { Disabled              => 0, Enabled => 1 },
                96  => { Disabled              => 0, Enabled => 1 },
                97  => { Disabled              => 0, Enabled => 1 },
                98  => { Disabled              => 0, Enabled => 1 },
                99  => { Disabled              => 0, Enabled => 1 },
                101 => { Disabled              => 0, Enabled => 1 },
                102 => { Disabled              => 0, Enabled => 1 },
                103 => { Disabled              => 0, Enabled => 1 },
                104 => { Disabled              => 0, Enabled => 1 },
                105 => { Disabled              => 0, Enabled => 1 },
                111 => { "New-Tunnel"          => 2, "Off"   => 0, "SSL" => 1 },
                112 => { "Deflate-Compression" => 1, "Off"   => 0 },
                120 => { "Deflate-Compression" => 1, "Off"   => 0 },
                122 => { Disabled              => 0, Enabled => 1 },
                123 => { Disabled => 0, Enabled => 1, FALSE => 0, TRUE => 1 },
                126 => { None     => 0, Visible => 1 },
                131 => {
                    "Disabled"                  => 0,
                    "Enable-Default-Clientless" => 5,
                    "Enable-Default-Service"    => 3,
                    "Enabled"                   => 1,
                },
                135 => { Disabled  => 0, Enabled  => 1 },
                138 => { AutoStart => 2, Disabled => 0, Enabled => 1 },
                150 => {
                    "AnyConnect-Client-IPSec-VPN-IKEv2" => 6,
                    "AnyConnect-Client-SSL-VPN"         => 2,
                    "Cisco-VPN-Client-IKEv1"            => 1,
                    "Clientless-SSL-VPN"                => 3,
                    "Cut-Through-Proxy"                 => 4,
                    "L2TP/IPsec-SSL-VPN"                => 5,
                },
                151 => {
                    "AnyConnect-Client-IPSec-VPN/IKEv2" => 2,
                    "AnyConnect-Client-SSL-VPN"         => 1,
                    "Cisco-VPN-Client/IKEv1"            => 5,
                    "Clientless-Email-Proxy"            => 4,
                    "Clientless-SSL-VPN"                => 3,
                    "IKEv1-LAN-to-LAN"                  => 6,
                    "IKEv2-LAN-to-LAN"                  => 7,
                    "None"                              => 0,
                    "VPN-Load-Balancing"                => 8,
                },
                152 => {
                    "Client"      => 2,
                    "Client-Only" => 3,
                    "Clientless"  => 1,
                    "None"        => 0
                },
                225 => { Disabled => 0, Enabled => 1 },
            },
            3199 =>
              { 1 => { "SSuper-User" => 3, "Super-User" => 2, "User" => 1 } },
            3224 => {
                1 => {
                    "All-VSYS-Root-Admin"  => 2,
                    "Read-Only-Admin"      => 4,
                    "Read-Only-VSYS-Admin" => 5,
                    "Root-Admin"           => 1,
                    "VSYS-Admin"           => 3,
                },
            },
            3309 => { 4 => { PrivatePool => 0, PublicPool => 1 } },
            3375 => {
                1 => {
                    "Acceleration-Policy-Editor"             => 850,
                    "Administrator"                          => 0,
                    "Advanced-Operator"                      => 350,
                    "App-Editor"                             => 300,
                    "Auditor"                                => 80,
                    "Certificate-Manager"                    => 500,
                    "Firewall-Manager"                       => 450,
                    "Fraud-Protection-Manager"               => 480,
                    "Guest"                                  => 700,
                    "IRule-Manager"                          => 510,
                    "Manager"                                => 100,
                    "No-Access"                              => 900,
                    "Operator"                               => 400,
                    "Resource-Admin"                         => 20,
                    "User-Manager"                           => 40,
                    "Web-Application-Security-Administrator" => 800,
                    "Web-Application-Security-Editor"        => 810,
                },
                2 => { Disabled => 0, Enabled => 1 },
                4 => { Disabled => 0, Enabled => 1 },
            },
            4491 => {
                1 => {
                    "Call-Answer"                        => 15,
                    "Call-Disconnect"                    => 16,
                    "Database-Query"                     => 3,
                    "Intelligent-Peripheral-Usage-Start" => 4,
                    "Intelligent-Peripheral-Usage-Stop"  => 5,
                    "Interconnect-Signaling-Start"       => 13,
                    "Interconnect-Signaling-Stop"        => 14,
                    "Media-Alive"                        => 20,
                    "Media-Report"                       => 11,
                    "Policy-Delete"                      => 32,
                    "Policy-Request"                     => 31,
                    "Policy-Update"                      => 33,
                    "QoS-Commit"                         => 19,
                    "QoS-Release"                        => 8,
                    "QoS-Reserve"                        => 7,
                    "Reserved"                           => 0,
                    "Service-Activation"                 => 9,
                    "Service-Deactivation"               => 10,
                    "Service-Instance"                   => 6,
                    "Signal-Instance"                    => 12,
                    "Signaling-Start"                    => 1,
                    "Signaling-Stop"                     => 2,
                    "Time-Change"                        => 17,
                },
                7 => {
                    "Calling-Name-Delivery-Lookup" => 3,
                    "LNP-Number-Lookup"            => 2,
                    "Reserved"                     => 0,
                    "Toll-Free-Number-Looukp"      => 1,
                },
                29 => { Change => 2, Close => 3, Open => 1, Reserved => 0 },
                37 => { Originating => 1, Terminating => 2, Undefined => 0 },
                50 => { Downstream  => 2, Reserved    => 0, Upstream  => 1 },
                51 => {
                    "Network-Signal" => 1,
                    "Reserved"       => 0,
                    "Subject-Signal" => 2
                },
                52 => {
                    "Call-Waiting-Tone-1"   => 6,
                    "Call-Waiting-Tone-2"   => 7,
                    "Call-Waiting-Tone-3"   => 8,
                    "Call-Waiting-Tone-4"   => 9,
                    "Distinctive-Ringing-0" => 11,
                    "Distinctive-Ringing-1" => 12,
                    "Distinctive-Ringing-2" => 2,
                    "Distinctive-Ringing-3" => 3,
                    "Distinctive-Ringing-4" => 4,
                    "Distinctive-Ringing-5" => 13,
                    "Distinctive-Ringing-6" => 14,
                    "Distinctive-Ringing-7" => 15,
                    "Reserved-0"            => 0,
                    "Reserved-10"           => 10,
                    "Ringing"               => 1,
                    "Ringsplash"            => 5,
                },
                61 => {
                    "Busy-Tone"                 => 5,
                    "Confirmation-Tone"         => 6,
                    "Dial-Tone"                 => 1,
                    "Message-Waiting-Indicator" => 8,
                    "Off-hook-Warning-Tone"     => 9,
                    "Reorder-Tone"              => 4,
                    "Reserved-0"                => 0,
                    "Reserved-7"                => 7,
                    "Ring-Back-Tone"            => 3,
                    "Stutter-Dial-Tone"         => 2,
                },
                65 => {
                    "Client"          => 0,
                    "Embedded-Client" => 2,
                    "Policy-Server"   => 1
                },
                66 => {
                    "Admitted-Timer-Expiration"                     => 7,
                    "CM-Failure"                                    => 3,
                    "CM-Request"                                    => 6,
                    "Gate-Closed-By-PS"                             => 1,
                    "Inactivity-Resource-Recovery-Timer-Expiration" => 2,
                    "Other"                                         => 127,
                    "Pre-Empted"                                    => 4,
                    "RSVP-PathTear-request"                         => 5,
                },
                67 => {
                    "Incompatible-Envelope"                   => 6,
                    "Insufficient-Resources"                  => 2,
                    "Other"                                   => 127,
                    "Policy-Server-Admission-Control-Failure" => 1,
                    "Unauthorized-AMID"                       => 4,
                    "Undefined-Service-Class-Name"            => 5,
                    "Unknown-Subscriber"                      => 3,
                },
                68 => {
                    "Application-Manager-Request" => 1,
                    "CMTS-Decistion"              => 2,
                    "Other"                       => 127,
                },
                69 => {
                    "Classifier"       => 2,
                    "Multiple-Updates" => 6,
                    "Opaque-Data"      => 5,
                    "Other"            => 127,
                    "Time-Limit"       => 4,
                    "Traffic-Profile"  => 1,
                    "Volume-Limit"     => 3,
                },
                70 => { "Policy-Approved" => 1, "Policy-Denied" => 2 },
            },
            4735 => {
                16 => {
                    "Admin"       => 3,
                    "Read-Config" => 1,
                    "Read-Status" => 0,
                    "Read-Write"  => 2,
                    "Super-user"  => 4,
                },
            },
            4874 => {
                12 => { disable => 0, enable => 1 },
                13 => { disable => 0, enable => 1 },
                14 => { CBR     => 4, nrtVBR => 3, UBR => 1, UBRPCR => 2 },
                19 => { disable => 0, enable => 1 },
                22 => { disable => 0, enable => 1 },
                23 => { disable => 0, enable => 1 },
                29 => {
                    "ATM"         => 2,
                    "ATM-1483"    => 6,
                    "CBF"         => 9,
                    "ETHERNET"    => 4,
                    "FRAME-RELAY" => 7,
                    "HDLC"        => 3,
                    "IP"          => 1,
                    "IP-TUNNEL"   => 10,
                    "MPLS-MINOR"  => 8,
                    "PPPOE-SUB"   => 12,
                    "SERVER-PORT" => 5,
                    "VLAN-SUB"    => 11,
                },
                30 => { "CISCO-CLID" => 1, "None" => 0 },
                38 => {
                    "CHAP"     => 2,
                    "CHAP-PAP" => 4,
                    "None"     => 0,
                    "PAP"      => 1,
                    "PAP-CHAP" => 3
                },
                41 => { Analog     => 1, Digital => 2, None          => 0 },
                58 => { noop       => 2, off     => 0, on            => 1 },
                69 => { "disabled" => 0, "time"  => 1, "time-volume" => 2 },
                70 => { "dont-ignore-df-bit" => 0, "ignore-df-bit" => 1 },
                77 => { v1                   => 1, v2              => 2 },
                78 => { v1                   => 1, v2 => 2, v3 => 3 },
                90 => {
                    "disable"                     => 0,
                    "failover"                    => 1,
                    "failover-with-silent-backup" => 3,
                    "silent-failover"             => 2,
                },
                94 => {
                    "actual"         => 4,
                    "dynamic-layer2" => 2,
                    "qos"            => 3,
                    "static-layer2"  => 1
                },
                97  => { disabled => 0, enabled  => 1 },
                100 => { disabled => 0, enabled  => 1 },
                101 => { disabled => 0, enabled  => 1 },
                102 => { disabled => 0, enabled  => 1 },
                103 => { disabled => 0, enabled  => 1 },
                104 => { disabled => 0, enabled  => 1 },
                105 => { disabled => 0, enabled  => 1 },
                127 => { IDLE     => 2, SHOWTIME => 1, SILENT => 3 },
                128 => {
                    ADSL1     => 1,
                    ADSL2     => 2,
                    ADSL2PLUS => 3,
                    SDSL      => 6,
                    UNKNOWN   => 7,
                    VDSL1     => 4,
                    VDSL2     => 5
                },
                144 => { disabled       => 0, enabled    => 1 },
                173 => { dynamic        => 1, opscript   => 1 },
                193 => { disabled       => 0, enabled    => 1 },
                206 => { "client-renew" => 1, "disabled" => 0 },
                210 => {
                    "Acct-Start-Ack"            => 1,
                    "Address-Assignment-Change" => 512,
                    "CoA-Complete"              => 1024,
                    "IP-Active"                 => 4,
                    "IP-Inactive"               => 8,
                    "IPv6-Active"               => 16,
                    "IPv6-Inactive"             => 32,
                    "Line-Speed-Change"         => 256,
                    "Periodic"                  => 2,
                    "Session-Active"            => 64,
                    "Session-Inactive"          => 128,
                },
                212 => { disabled => 0, enabled => 1 },
                219 => {
                    "GPON"     => 1,
                    "Other"    => 0,
                    "TWDM-PON" => 3,
                    "UNKNOWN"  => 7,
                    "WDM-PON"  => 5,
                    "XG-PON1"  => 2,
                    "XGS-PON"  => 4,
                },
            },
            5003 => {
                35 => {
                    "ACL-Auth-AdminLevel"         => 100,
                    "ACL-Auth-SecurityAdminLevel" => 200,
                    "ACL-Auth-UserLevel"          => 50,
                },
            },
            5535 => {
                5 => {
                    "AF11"        => 10,
                    "AF12"        => 12,
                    "AF13"        => 14,
                    "AF21"        => 18,
                    "AF22"        => 20,
                    "AF23"        => 22,
                    "AF31"        => 26,
                    "AF32"        => 28,
                    "AF33"        => 30,
                    "AF41"        => 34,
                    "AF42"        => 36,
                    "AF43"        => 38,
                    "Best-Effort" => 0,
                    "EF"          => 46,
                },
                117 => { HAAA => 1, VAAA => 2 },
            },
            5948 => {
                14 => { "ESP" => 2, "IP-IP" => 1, "L2TP" => 3 },
                15 => { NAPT  => 2, NAT     => 1 },
            },
            6321 => {
                221 => { Disabled => 0, Enabled => 1 },
                222 => { Disabled => 0, Enabled => 1 },
                223 => { Disabled => 0, Enabled => 1 },
            },
            6527 => {
                1  => { both             => 3, console => 2, ftp => 1 },
                3  => { false            => 2, true    => 1 },
                5  => { "deny-all"       => 2, "none" => 3, "permit-all" => 1 },
                7  => { deny             => 2, permit            => 1 },
                47 => { "existing-first" => 2, "weighted-access" => 1 },
                54 => { "all"  => 3, "nothing" => 1, "sensitive-only" => 2 },
                65 => { group1 => 1, group2    => 2, group5           => 5 },
                66 => {
                    aes128 => 4,
                    aes192 => 5,
                    aes256 => 6,
                    des    => 2,
                    des3   => 3,
                    null   => 1
                },
                67  => { md5       => 2, null     => 1, sha1 => 3 },
                97  => { always    => 2, never    => 1 },
                122 => { "disable" => 3, "enable" => 2, "no-action" => 1 },
                124 => {
                    af => 2,
                    be => 0,
                    ef => 5,
                    h1 => 6,
                    h2 => 4,
                    l1 => 3,
                    l2 => 1,
                    nc => 7
                },
                125 => { egress      => 2, ingress       => 1 },
                130 => { "audit-end" => 3, "audit-start" => 2, "host" => 1 },
                145 => { gn          => 1, s2a           => 2, s2b    => 3 },
                163 => {
                    "Alc-Ipv6-Address-down"      => 7,
                    "Alc-Ipv6-Address-up"        => 6,
                    "Delegated-IPv6-Prefix-down" => 9,
                    "Delegated-IPv6-Prefix-up"   => 8,
                    "Framed-IP-Address-down"     => 5,
                    "Framed-IP-Address-up"       => 4,
                    "Framed-IPv6-Prefix-down"    => 11,
                    "Framed-IPv6-Prefix-up"      => 10,
                    "regular"                    => 1,
                    "sla-start"                  => 2,
                    "sla-stop"                   => 3,
                },
            },
            7262 => {
                1 => {
                    "DragonWave-Admin-User" => 1,
                    "DragonWave-NOC-User"   => 2,
                    "DragonWave-Super-User" => 3,
                },
            },
            7751 => {
                6 => {
                    "Chosen-By-SGSN" => 2,
                    "Sent-By-MS"     => 1,
                    "Subscribed"     => 0
                },
                7  => { "Not-Required" => 0, "Required" => 1 },
                10 => { Failure        => 1, Success    => 0 },
                12 => {
                    "Dummy-IMSI"   => 2,
                    "Local-Radius" => 7,
                    "Post-paid"    => 5,
                    "PPP-SIM"      => 1,
                    "Pre-paid"     => 6,
                    "Proxy-Radius" => 8,
                    "Radius-SIM"   => 4,
                    "Soft-SIM"     => 3,
                },
            },
            8164 => {
                3 => {
                    "a11-badly-formed"                                => 118,
                    "a11-badly-formed-on-handoff"                     => 172,
                    "a11-disconnect-handoff-no-active-stop"           => 154,
                    "a11-disconnect-no-active-stop"                   => 133,
                    "A11-Lifetime-Expired"                            => 31,
                    "A11-Max-Retry"                                   => 30,
                    "A11-Message-Integrity-Failure"                   => 32,
                    "a11-mismatched-id"                               => 121,
                    "a11-mismatched-id-on-handoff"                    => 171,
                    "a11-mn-ha-auth-failure"                          => 117,
                    "A11-RRQ-Deny-Max-Count"                          => 176,
                    "a11-t-bit-not-set"                               => 119,
                    "a11-t-bit-not-set-on-handoff"                    => 174,
                    "a11-unsupported-vendor-id"                       => 120,
                    "a11-unsupported-vendor-id-on-handoff"            => 173,
                    "aaa-auth-req-failed"                             => 417,
                    "AAA-context-removed"                             => 50,
                    "aaa-session-id-not-found"                        => 309,
                    "aaa-unreachable"                                 => 425,
                    "active-start-param-change"                       => 131,
                    "active-to-dormant"                               => 129,
                    "actv-rejected-by-sgsn"                           => 402,
                    "Admin-AAA-disconnect"                            => 148,
                    "Admin-AAA-disconnect-handoff"                    => 149,
                    "Admin-Disconnect"                                => 1,
                    "All-dynamic-pool-addr-occupied"                  => 288,
                    "apn-denied-no-subscription"                      => 418,
                    "apn-removed"                                     => 95,
                    "apn-restrict-violation"                          => 421,
                    "asngw-im-entry-prohibited"                       => 281,
                    "asngw-invalid-qos-configuration"                 => 251,
                    "asngw-non-anchor-prohibited"                     => 280,
                    "asngw-service-flow-deletion"                     => 426,
                    "asngw-tid-entry-not-found"                       => 334,
                    "asnpc-del-ms-entry-recd"                         => 327,
                    "asnpc-idle-mode-auth-failed"                     => 250,
                    "asnpc-idle-mode-exit"                            => 249,
                    "asnpc-idle-mode-timeout"                         => 248,
                    "asnpc-ms-power-down-nwexit"                      => 284,
                    "asnpc-pc-relocation"                             => 324,
                    "asnpc-pc-relocation-failed"                      => 323,
                    "asnpc-r4-nwexit-recd"                            => 285,
                    "Auth-Failed"                                     => 194,
                    "auth_policy_mismatch"                            => 325,
                    "bs-monitor-keep-alive-failed"                    => 290,
                    "call-internal-reject"                            => 115,
                    "call-restarted"                                  => 116,
                    "call-restarted-inter-pdsn-handoff"               => 155,
                    "call-restarted-ppp-termination"                  => 156,
                    "Call-type-detection-failed"                      => 37,
                    "closed_rp-duplicate-session"                     => 111,
                    "closed_rp-handoff-complete"                      => 110,
                    "closed_rp-handoff-failed"                        => 113,
                    "closed_rp-handoff-session-not-found"             => 112,
                    "conflict-in-ip-addr-assignment"                  => 94,
                    "constructed-nai-auth-fail"                       => 142,
                    "container-max-exceeded"                          => 136,
                    "counter-rollover"                                => 141,
                    "credits-used-bytes-in"                           => 96,
                    "credits-used-bytes-out"                          => 97,
                    "credits-used-bytes-total"                        => 98,
                    "CSCF-Call-Admin-disconnect"                      => 387,
                    "CSCF-CALL-Inactivity-timeout"                    => 392,
                    "CSCF-CALL-Local-disconnect"                      => 389,
                    "CSCF-CALL-Media-Auth-Failure"                    => 393,
                    "CSCF-CALL-No-Resource"                           => 390,
                    "CSCF-CALL-No-Respone"                            => 391,
                    "CSCF-CAll-User-disconnect"                       => 388,
                    "CSCF-REG-Admin-disconnect"                       => 383,
                    "CSCF-REG-Inactivity-timeout"                     => 385,
                    "CSCF-REG-Network-disconnect"                     => 386,
                    "CSCF-REG-No-Resource"                            => 394,
                    "CSCF-REG-User-disconnect"                        => 384,
                    "css-service-not-found"                           => 193,
                    "css-synch-cause"                                 => 201,
                    "CT-PMIP-RRQ-NVSE-Value-Change"                   => 427,
                    "delayed-abort-timer-expired"                     => 147,
                    "Demux-mgr-failed"                                => 48,
                    "Destination-context-removed"                     => 46,
                    "dhcp-client-sent-nak"                            => 196,
                    "dhcp-client-sent-release"                        => 195,
                    "dhcp-ip-addr-allocation-tmr-exp"                 => 79,
                    "dhcp-ip-addr-not-available-at-present"           => 82,
                    "dhcp-ip-validation-failed"                       => 80,
                    "dhcp-lease-expired"                              => 83,
                    "dhcp-lease-mismatch-detected"                    => 376,
                    "dhcp-no-ip-addr-allocated"                       => 78,
                    "dhcp-relay-ip-validation-failed"                 => 73,
                    "dhcp-relay-static-ip-addr-not-allowed"           => 77,
                    "dhcp-static-addr-not-allowed"                    => 81,
                    "diameter-protocol-error"                         => 449,
                    "diameter-request-timeout"                        => 450,
                    "Disc-Excd-Service-Limit"                         => 5,
                    "Disc-No-Resource"                                => 4,
                    "disconn-on-violation-focs-odb"                   => 382,
                    "disconnect-from-policy-server"                   => 412,
                    "disconnect-on-violation-odb"                     => 381,
                    "Dormant-Transition-During-Session-Setup"         => 177,
                    "driver-initiated"                                => 186,
                    "dt-ggsn-tun-reestablish-failed"                  => 293,
                    "dup-static-ip-addr-req"                          => 420,
                    "duplicate-session-detected"                      => 344,
                    "duration-quota-reached"                          => 162,
                    "eap-max-retry-reached"                           => 207,
                    "eap-msk-lifetime-expiry"                         => 211,
                    "eap-msk-lifetime-too-low"                        => 212,
                    "eapol-max-retry-reached"                         => 378,
                    "ecsv2-license-exceeded"                          => 184,
                    "excessive-phs-pd-flows-cfgd"                     => 336,
                    "excessive-wimax-pd-flows-cfgd"                   => 229,
                    "failed-auth-with-charging-svc"                   => 158,
                    "Failed-Provide-Service"                          => 17,
                    "failed-update-handoff"                           => 109,
                    "Failed-User-Filter"                              => 16,
                    "failed_tunnel_connect"                           => 58,
                    "Flow-add-failed"                                 => 36,
                    "flow-is-deactivated"                             => 183,
                    "flow-released"                                   => 189,
                    "FNG-Auth-failed"                                 => 408,
                    "fw-and-nat-policy-removed"                       => 407,
                    "ggsn-aaa-auth-req-failed"                        => 93,
                    "ggsn-init-deact"                                 => 260,
                    "ggsn-no-rsp-from-sgsn"                           => 448,
                    "gre-flow-control-timeout"                        => 168,
                    "gre-key-collision"                               => 144,
                    "gre-key-mismatch"                                => 55,
                    "gtp-all-dynamic-pdp-addr-occupied"               => 75,
                    "Gtp-context-replacement"                         => 202,
                    "gtp-no-memory-is-available"                      => 76,
                    "gtp-unknown-pdp-addr-or-pdp-type"                => 74,
                    "gtp-user-authentication-failed"                  => 163,
                    "gtpc-err-ind"                                    => 414,
                    "gtpc-path-failure"                               => 400,
                    "gtpu-err-ind"                                    => 415,
                    "gtpu-path-failure"                               => 401,
                    "ha-stale-key-disconnect"                         => 409,
                    "ha-unreachable"                                  => 124,
                    "hlr-init-deact"                                  => 261,
                    "Hotlining-Status-Change"                         => 447,
                    "hss-profile-update-failed"                       => 246,
                    "ike-keepalive-failed"                            => 341,
                    "ikev2-subscriber-ipsecmgr-death"                 => 287,
                    "ims-auth-decision-invalid"                       => 227,
                    "ims-authorization-failed"                        => 187,
                    "ims-authorization-released"                      => 226,
                    "ims-authorization-revoked"                       => 225,
                    "in-acl-disconnect-on-violation"                  => 210,
                    "Inactivity-Timeout"                              => 24,
                    "inter-pdsn-handoff"                              => 128,
                    "inter-pdsn-service-optimize-handoff-disabled"    => 143,
                    "inter-pdsn-service-optimize-handoff-triggered"   => 145,
                    "Interim-Update"                                  => 338,
                    "Internal-error"                                  => 49,
                    "intra-pdsn-handoff"                              => 191,
                    "intra-pdsn-handoff-triggered"                    => 146,
                    "Invalid-AAA-Attr"                                => 15,
                    "Invalid-dest-context"                            => 44,
                    "invalid-ip-addr-from-sgsn"                       => 91,
                    "Invalid-IP-Address-AAA"                          => 18,
                    "Invalid-IP-Pool-AAA"                             => 19,
                    "Invalid-IP-Source-Address"                       => 27,
                    "invalid-nat-config"                              => 333,
                    "invalid-pdn-type"                                => 416,
                    "Invalid-Prepaid-AAA-attr-in-auth-response"       => 166,
                    "invalid-service-type"                            => 51,
                    "invalid-version-attr"                            => 454,
                    "invalid-wapn"                                    => 422,
                    "invalid_tunnel_context"                          => 56,
                    "IPSG-Auth-Failed"                                => 185,
                    "IPSP-addr-in-use"                                => 125,
                    "l2tp-admin-disconnect_remote"                    => 69,
                    "l2tp-auth-failed-local"                          => 64,
                    "l2tp-auth-failed-remote"                         => 63,
                    "l2tp-ipsec-tunnel-disconnected"                  => 101,
                    "l2tp-ipsec-tunnel-failure"                       => 100,
                    "l2tp-no-resource-local"                          => 66,
                    "l2tp-no-resource-remote"                         => 67,
                    "l2tp-protocol-error-local"                       => 62,
                    "l2tp-protocol-error-remote"                      => 61,
                    "l2tp-try-another-lns-from-remote"                => 65,
                    "l2tp-tunnel-disconnect-local"                    => 68,
                    "l2tp-tunnel-disconnect-remote"                   => 59,
                    "l2tp-tunnel-timeout"                             => 60,
                    "l2tp-unknown-apn"                                => 204,
                    "l2tpmgr-reached-max-capacity"                    => 70,
                    "link-broken"                                     => 198,
                    "Local-Disconnect"                                => 3,
                    "Local-purge"                                     => 108,
                    "Long-Duration-Timeout"                           => 103,
                    "lpool-ip-validation-failed"                      => 84,
                    "lpool-static-ip-addr-not-allowed"                => 85,
                    "mac-addr-validation-failed"                      => 228,
                    "mandatory-gtp-ie-missing"                        => 424,
                    "Max-Data-Excd"                                   => 26,
                    "mbms-bearer-service-disconnect"                  => 380,
                    "MIP-auth-failure"                                => 42,
                    "mip-ipsec-sa-inactive"                           => 102,
                    "MIP-lifetime-expiry"                             => 40,
                    "mip-paaa-bc-query-not-found"                     => 169,
                    "MIP-private-ip-no-rev-tunnel"                    => 165,
                    "MIP-proto-error"                                 => 41,
                    "mip-rcvd-relay-failure"                          => 53,
                    "MIP-reg-revocation"                              => 71,
                    "MIP-reg-revocation-i-bit-on"                     => 175,
                    "MIP-reg-revocation-no-lcp-term"                  => 164,
                    "MIP-reg-timeout"                                 => 43,
                    "mip-registration-dropped"                        => 140,
                    "mip-relay-req-failed"                            => 52,
                    "MIP-remote-dereg"                                => 39,
                    "mip6ha-ip-addr-not-available"                    => 289,
                    "mipfa-dup-home-addr-req"                         => 126,
                    "mipfa-inter-tech-handoff"                        => 213,
                    "mipfa-resource-conflict"                         => 157,
                    "mipha-dup-home-addr-req"                         => 122,
                    "mipha-dup-imsi-session"                          => 123,
                    "mipha-dup-imsi-session-purge"                    => 159,
                    "mipha-dup-wimax-session"                         => 453,
                    "mipha-dynamic-ip-addr-not-available"             => 170,
                    "mipha-ip-pool-busyout"                           => 127,
                    "mipha-prepaid-reset-dynamic-newcall"             => 167,
                    "mipha-rev-pending-newcall"                       => 160,
                    "mipha-subscriber-ipsec-tunnel-down"              => 180,
                    "mipha-subscriber-ipsec-tunnel-failed"            => 181,
                    "mipha-subscriber-ipsecmgr-death"                 => 182,
                    "mipv6-id-mismatch"                               => 308,
                    "mme-authentication-failure"                      => 368,
                    "mme-egtpc-connection-failed"                     => 366,
                    "mme-egtpc-create-session-failed"                 => 367,
                    "mme-hss-connection-failure"                      => 374,
                    "mme-hss-detach"                                  => 371,
                    "mme-hss-user-unknown"                            => 375,
                    "mme-mme-detach"                                  => 370,
                    "mme-pgw-detach"                                  => 372,
                    "mme-s1AP-send-failed"                            => 365,
                    "mme-sub-validation-failure"                      => 373,
                    "mme-ue-detach"                                   => 369,
                    "ms-init-deact"                                   => 262,
                    "ms-unexpected-idle-mode-entry"                   => 395,
                    "ms-unexpected-network-reentry"                   => 205,
                    "MSID-Auth-Failed"                                => 28,
                    "MSID-Auth-Fauiled-No-AAA-Resp"                   => 29,
                    "msid-dhcp-chaddr-mismatch"                       => 197,
                    "nemo-link-layer-down"                            => 377,
                    "No-IPV6-address-for-subscriber"                  => 410,
                    "no-more-sessions-in-aaa"                         => 92,
                    "No-NAT-IP-Address"                               => 335,
                    "no-response"                                     => 363,
                    "no_peer_lns_address"                             => 57,
                    "Not-Defined"                                     => 0,
                    "npu-gre-flows-not-available"                     => 220,
                    "nw-reachability-failed-redirect"                 => 135,
                    "nw-reachability-failed-reject"                   => 134,
                    "operator-policy"                                 => 451,
                    "overload-disconnect"                             => 192,
                    "path-failure"                                    => 72,
                    "pcf-monitor-keep-alive-failed"                   => 114,
                    "PDG-Auth-failed"                                 => 364,
                    "PDIF-Auth-failed"                                => 203,
                    "phs-invalid-nai"                                 => 358,
                    "phs-thirdparty-auth-fail"                        => 361,
                    "phsgw-invalid-qos-configuration"                 => 337,
                    "phsgw-non-anchor-prohibited"                     => 322,
                    "phsgw-tid-entry-not-found"                       => 355,
                    "phspc-del-ms-entry-recd"                         => 356,
                    "phspc-ms-power-down-nwexit"                      => 331,
                    "phspc-sleep-mode-auth-failed"                    => 330,
                    "phspc-sleep-mode-exit"                           => 329,
                    "phspc-sleep-mode-timeout"                        => 328,
                    "phspc-x2-nwexit-recd"                            => 332,
                    "PPP-Auth-Failed"                                 => 11,
                    "PPP-Auth-Failed-No-AAA-Resp"                     => 12,
                    "PPP-Auth-Max-Retry"                              => 14,
                    "PPP-Auth-No-Response"                            => 13,
                    "PPP-Echo-Failed"                                 => 10,
                    "PPP-IPCP-Max-Retry"                              => 22,
                    "PPP-IPCP-Neg-Failed"                             => 20,
                    "PPP-IPCP-No-Response"                            => 21,
                    "PPP-IPV6CP-Max-Retry"                            => 152,
                    "PPP-IPV6CP-Neg-Failed"                           => 150,
                    "PPP-IPV6CP-No-Response"                          => 151,
                    "PPP-keepalive-failure"                           => 35,
                    "PPP-LCP-Loopback"                                => 8,
                    "PPP-LCP-Max-Retry"                               => 9,
                    "PPP-LCP-Neg-Failed"                              => 6,
                    "PPP-LCP-No-Response"                             => 7,
                    "PPP-lcp-remote-disc"                             => 33,
                    "PPP-No-Rem-IP-Address"                           => 23,
                    "PPP-Rem-Reneg-Disc-Always-Cfg"                   => 178,
                    "PPP-Rem-Reneg-Disc-NAI-MSID-Mismatch"            => 179,
                    "ppp-renego-no-ha-addr"                           => 190,
                    "ppp-renegotiation"                               => 130,
                    "ppp-restart-inter-pdsn-handoff"                  => 54,
                    "PPP-Restart-Invalid-source-IPV4-address"         => 153,
                    "prefix-registration-failure"                     => 411,
                    "prepaid-failed"                                  => 99,
                    "prog-end-timeout"                                => 199,
                    "proxy-mip-binding-update"                        => 105,
                    "proxy-mip-inter-pdsn-handoff-mismatched-address" => 107,
                    "proxy-mip-inter-pdsn-handoff-require-ip-address" => 106,
                    "proxy-mip-registration-failure"                  => 104,
                    "qos-update-wait-timeout"                         => 200,
                    "r4-dereg-req-recd"                               => 223,
                    "r4-max-retry-reached"                            => 221,
                    "r4-nwexit-recd"                                  => 222,
                    "r4-remote-failure"                               => 224,
                    "r6-dereg-req-recd"                               => 216,
                    "r6-invalid-nai"                                  => 206,
                    "r6-max-retry-reached"                            => 214,
                    "r6-nwexit-recd"                                  => 215,
                    "r6-pmk-key-change-failure"                       => 253,
                    "r6-remote-failure"                               => 217,
                    "r6r4-protocol-errors"                            => 218,
                    "radius-ip-addr-not-provided"                     => 90,
                    "radius-ip-validation-failed"                     => 89,
                    "re-auth-failed"                                  => 396,
                    "Remote-Disconnect"                               => 2,
                    "remote-error-notify"                             => 362,
                    "Req-service-addr-unavailable"                    => 47,
                    "s6b-auth-failed"                                 => 413,
                    "sa-lifetime-expiry"                              => 326,
                    "sa-rekeying-failure"                             => 320,
                    "service-instance-released"                       => 188,
                    "sess-sleep-mode-entry-timeout"                   => 321,
                    "sess-termination-timeout"                        => 255,
                    "session-idle-mode-entry-timeout"                 => 282,
                    "session-idle-mode-exit-timeout"                  => 283,
                    "Session-setup-timeout"                           => 34,
                    "session-sleep-mode-exit-timeout"                 => 359,
                    "Session-Timeout"                                 => 25,
                    "sgsn-abnormal-deact"                             => 277,
                    "sgsn-actv-rejected-by-peer"                      => 278,
                    "sgsn-apn-restrict-vio"                           => 275,
                    "sgsn-apn-unknown"                                => 299,
                    "sgsn-ard-failure"                                => 436,
                    "sgsn-att-in-reg-state"                           => 291,
                    "sgsn-attach-abrt-ms-suspend"                     => 342,
                    "sgsn-attach-abrt-rad-lost"                       => 339,
                    "sgsn-attach-on-attch-init-abort"                 => 301,
                    "sgsn-attach-on-inbound-irau"                     => 350,
                    "sgsn-attach-on-outbound-irau"                    => 351,
                    "sgsn-auth-fail"                                  => 235,
                    "sgsn-bvc-blocked"                                => 349,
                    "sgsn-camel-release"                              => 437,
                    "sgsn-canc-loc-sub"                               => 230,
                    "sgsn-canc-loc-upd"                               => 231,
                    "sgsn-check-imei-failure"                         => 404,
                    "sgsn-cont-rsp-fail"                              => 241,
                    "sgsn-detach-init-deact"                          => 263,
                    "sgsn-dns-fail-inter-rau"                         => 240,
                    "sgsn-dsd-allgprswithdrawn"                       => 252,
                    "sgsn-duplicate-context"                          => 245,
                    "sgsn-duplicate-pdp-context"                      => 296,
                    "sgsn-err-ind"                                    => 279,
                    "sgsn-failure-rsp-from-ggsn"                      => 298,
                    "sgsn-ggsn-ctxt-non-existent"                     => 274,
                    "sgsn-glu-fail"                                   => 236,
                    "sgsn-gtp-no-resource"                            => 270,
                    "sgsn-gtp-req-failure"                            => 347,
                    "sgsn-gtpc-path-failure"                          => 267,
                    "sgsn-gtpu-path-failure"                          => 266,
                    "sgsn-guard-timeout-abort"                        => 306,
                    "sgsn-hlr-not-found-for-imsi"                     => 242,
                    "sgsn-ident-fail"                                 => 233,
                    "sgsn-illegal-me"                                 => 254,
                    "sgsn-imp-det"                                    => 237,
                    "sgsn-imsi-mismatch"                              => 348,
                    "sgsn-inbnd-irau-abrt-ms-suspend"                 => 343,
                    "sgsn-inbnd-irau-abrt-rad-lost"                   => 340,
                    "sgsn-inbound-srns-in-reg-state"                  => 292,
                    "sgsn-incorrect-state"                            => 352,
                    "sgsn-init-deact"                                 => 259,
                    "sgsn-invalid-ti"                                 => 273,
                    "sgsn-iu-rel-before-call-est"                     => 286,
                    "sgsn-iu-rel-in-israu-init-abort"                 => 302,
                    "sgsn-iu-rel-init-deact"                          => 265,
                    "sgsn-local-handoff-init-deact"                   => 268,
                    "sgsn-mm-ctx-cleanup-init-abort"                  => 304,
                    "sgsn-mm-ctxt-gtp-no-resource"                    => 398,
                    "sgsn-mnr-exp"                                    => 232,
                    "sgsn-ms-init-det"                                => 243,
                    "sgsn-no-pdp-activated"                           => 247,
                    "sgsn-no-rsp-from-ggsn"                           => 297,
                    "sgsn-nse-cleanup"                                => 346,
                    "sgsn-odb-init-deact"                             => 272,
                    "sgsn-offload-phase2"                             => 360,
                    "sgsn-offload-phase3"                             => 379,
                    "sgsn-opr-policy-fail"                            => 244,
                    "sgsn-page-timer-expiry"                          => 354,
                    "sgsn-pdp-auth-failure"                           => 295,
                    "sgsn-pdp-gprs-camel-release"                     => 403,
                    "sgsn-pdp-inactivity-timeout"                     => 406,
                    "sgsn-pdp-local-purge"                            => 357,
                    "sgsn-pdp-nse-cleanup"                            => 397,
                    "sgsn-rab-rel-init-deact"                         => 264,
                    "sgsn-rai-removal"                                => 258,
                    "sgsn-regular-deact"                              => 276,
                    "sgsn-remote-handoff-init-deact"                  => 269,
                    "sgsn-rnc-no-resource"                            => 271,
                    "sgsn-rnc-removal"                                => 257,
                    "sgsn-sai-fail"                                   => 256,
                    "sgsn-sec-fail"                                   => 234,
                    "sgsn-serv-req-init-deact"                        => 300,
                    "sgsn-smgr-init-abort"                            => 303,
                    "sgsn-smgr-purge"                                 => 238,
                    "sgsn-sndcp-init-deact"                           => 405,
                    "sgsn-subs-handed-to-peer"                        => 239,
                    "sgsn-t3350-expiry"                               => 353,
                    "sgsn-unknown-abort"                              => 305,
                    "sgsn-unknown-pdp"                                => 294,
                    "sgsn-xid-response-failure"                       => 345,
                    "sgsn-zone-code-failure"                          => 455,
                    "Sgw-context-replacement"                         => 419,
                    "Source-context-removed"                          => 45,
                    "spr-connection-timeout"                          => 452,
                    "ssl-alert-received"                              => 433,
                    "ssl-bad-message"                                 => 432,
                    "ssl-disconnect"                                  => 434,
                    "ssl-handshake-failed"                            => 430,
                    "ssl-migration"                                   => 435,
                    "ssl-renegotiate-failed"                          => 431,
                    "static-addr-not-allowed-by-radius"               => 139,
                    "static-addr-not-allowed-in-apn"                  => 137,
                    "static-addr-required-by-radius"                  => 138,
                    "static-ip-addr-not-allowed"                      => 88,
                    "static-ip-addr-not-present"                      => 87,
                    "static-ip-validation-failed"                     => 86,
                    "tarrif-boundary"                                 => 132,
                    "tcp-read-failed"                                 => 428,
                    "tcp-write-failed"                                => 429,
                    "ttg-nsapi-allocation-failed"                     => 423,
                    "unknown-apn"                                     => 399,
                    "vbm-hoa-session-disconnected"                    => 208,
                    "vbm-voa-session-disconnected"                    => 209,
                    "volume-quota-reached"                            => 161,
                    "vpn-bounce-dhcpip-validate-req"                  => 307,
                    "wimax-qos-invalid-aaa-attr"                      => 219,
                    "Wrong-ipcp-params"                               => 38,
                    "x1-dereg-req-recd"                               => 312,
                    "x1-max-retry-reached"                            => 310,
                    "x1-nwexit-recd"                                  => 311,
                    "x1-pmk-key-change-failure"                       => 319,
                    "x1-remote-failure"                               => 313,
                    "x1x2-protocol-errors"                            => 314,
                    "x2-dereg-req-recd"                               => 317,
                    "x2-max-retry-reached"                            => 315,
                    "x2-nwexit-recd"                                  => 316,
                    "x2-remote-failure"                               => 318,
                },
                4 => {
                    "Call-Arrived"                    => 11,
                    "Call-ASN-Non-Anchor-Connected"   => 200,
                    "Call-ASNPC-Connected"            => 210,
                    "Call-Auth-Only-Connected"        => 247,
                    "Call-Authenticated"              => 14,
                    "Call-Authenticating"             => 13,
                    "Call-Bcmcs-Authenticating"       => 70,
                    "Call-Bcmcs-Connected"            => 150,
                    "Call-Disconnecting"              => 2,
                    "Call-Got-Addr-From-DHCP"         => 170,
                    "Call-GTP-IPv4-Connected"         => 235,
                    "Call-GTP-IPv4-IPv6-Connected"    => 237,
                    "Call-GTP-IPv6-Connected"         => 236,
                    "Call-HA-IPSEC-Connected"         => 190,
                    "Call-HA-IPSEC-Tunnel-Connecting" => 180,
                    "Call-Imsa-Authorized"            => 97,
                    "Call-Imsa-Authorizing"           => 95,
                    "Call-Ipcp-Up"                    => 15,
                    "Call-Ipsg-Connected"             => 145,
                    "Call-Lcp-Down"                   => 1,
                    "Call-Lcp-Down_1"                 => 10,
                    "Call-Lcp-Up"                     => 12,
                    "Call-MBMS-Bearer-Authorizing"    => 99,
                    "Call-MBMS-Bearer-Connected"      => 156,
                    "Call-MBMS-UE-Authorizing"        => 98,
                    "Call-MBMS-UE-Connected"          => 155,
                    "Call-MME-Attached"               => 246,
                    "Call-Mobile-IP-Connected"        => 17,
                    "Call-Mobile-IPv6-Connected"      => 220,
                    "Call-Pdg-Connected"              => 142,
                    "Call-Pdg-Ssl-Connected"          => 141,
                    "Call-Pdg-Ssl-Connecting"         => 46,
                    "Call-Pdg-Tcp-Connecting"         => 45,
                    "Call-Pdp-Type-IP-Connected"      => 120,
                    "Call-Pdp-Type-IPv6-Connected"    => 125,
                    "Call-Pdp-Type-PPP-Connected"     => 130,
                    "Call-Pending-Addr-From-DHCP"     => 160,
                    "Call-PHSPC-Connected"            => 230,
                    "Call-PMIPv6-Connected"           => 221,
                    "Call-PPP-Renegotiating"          => 3,
                    "Call-Proxy-Mobile-IP-Connected"  => 140,
                    "Call-SGW-Connected"              => 245,
                    "Call-Simple-IP-Connected"        => 16,
                    "Call-Tunnel-Connected"           => 115,
                    "Call-Tunnel-Connecting"          => 85,
                    "Not-Defined"                     => 0,
                },
                9 => {
                    "Deflate"               => 4,
                    "Deflate-MPCC"          => 6,
                    "Deflate-MPCC-Stac-LZS" => 7,
                    "Deflate-Stac-LZS"      => 5,
                    "MPCC-Stac-LZS"         => 3,
                    "MPPC"                  => 2,
                    "None"                  => 0,
                    "Stac-LZS"              => 1,
                },
                14 => { No     => 0, Yes       => 1 },
                19 => { Normal => 0, Stateless => 1 },
                20 => {
                    "All"                    => 7,
                    "All_New"                => 63,
                    "FA-HA-NEMO"             => 38,
                    "GGSN-PDP-TYPE-IP"       => 8,
                    "GGSN-PDP-TYPE-PPP"      => 16,
                    "HA-Mobile-IP"           => 4,
                    "Mobile-IP"              => 2,
                    "Mobile-IP-HA-Mobile-IP" => 6,
                    "Network-Mobility"       => 32,
                    "None"                   => 0,
                    "Simple-IP"              => 1,
                    "Simple-IP-HA-Mobile-IP" => 5,
                    "Simple-IP-Mobile-IP"    => 3,
                },
                21 => {
                    "CLI"                   => 1,
                    "CLI-ECS"               => 9,
                    "CLI-FTP"               => 3,
                    "CLI-FTP-ECS"           => 11,
                    "CLI-Intercept"         => 5,
                    "CLI-Intercept-ECS"     => 13,
                    "CLI-Intercept-FTP"     => 7,
                    "CLI-Intercept-FTP-ECS" => 15,
                    "ECS"                   => 8,
                    "FTP"                   => 2,
                    "Intercept"             => 4,
                    "None"                  => 0,
                },
                22 => { Disabled => 0, Enabled => 1 },
                24 => {
                    ASNGW         => 8,
                    BNG           => 20,
                    CSCF          => 7,
                    FNG           => 17,
                    GGSN          => 4,
                    HA            => 3,
                    HNBGW         => 19,
                    IPSG          => 6,
                    LNS           => 5,
                    Management    => 2,
                    MIPV6HA       => 14,
                    None          => 0,
                    OGW           => 18,
                    PDG           => 13,
                    PDIF          => 9,
                    PDSN          => 1,
                    PGW           => 15,
                    PHSGW         => 12,
                    SGSN          => 11,
                    SGW           => 16,
                    STANDALONE_FA => 10,
                },
                25 => { Disable    => 0, Enable       => 1 },
                27 => { balanced   => 2, prioritized  => 3, random => 1 },
                31 => { Compressed => 1, Uncompressed => 0 },
                43 => {
                    "local-alloc"             => 1,
                    "local-alloc-validate"    => 2,
                    "no-local-alloc-validate" => 0,
                },
                45 => {
                    "Detection"                  => 1,
                    "Disconnection"              => 2,
                    "Dormant-Only-Detection"     => 4,
                    "Dormant-Only-Disconnection" => 3,
                },
                46 => { Disabled => 0, Enabled => 1 },
                47 => { Disabled => 0, Enabled => 1 },
                48 => {
                    Disabled              => 0,
                    EnabledOrNVSE_Custom1 => 1,
                    NVSE_Custom2          => 2,
                    NVSE_Starent          => 3,
                },
                49 => { Disabled => 0, Enabled => 1 },
                50 => { Disabled => 0, Enabled => 1 },
                51 => { Disabled => 0, Enabled => 1 },
                52 => { Disabled => 0, Enabled => 1 },
                53 => {
                    Alloc_Dhcp_Client  => 1,
                    Alloc_Dhcp_Relay   => 5,
                    Alloc_Local_Pool   => 0,
                    Alloc_No_Alloc     => 3,
                    Alloc_Radius       => 2,
                    Alloc_Static_Alloc => 4,
                },
                54 => { Disabled => 0, Enabled => 1 },
                60 => { Disabled => 0, Enabled => 1 },
                62 => {
                    GTP_VERSION_0 => 0,
                    GTP_VERSION_1 => 1,
                    GTP_VERSION_2 => 2
                },
                63 => {
                    "DF-Fragment-ICMP-Notify" => 2,
                    "DF-Ignore"               => 1,
                    "Normal"                  => 0
                },
                64 => { GTPP     => 2, None     => 0, Radius => 1 },
                67 => { Detect   => 1, Force    => 0 },
                68 => { Disabled => 0, Enabled  => 1 },
                69 => { Normal   => 0, Suppress => 1 },
                70 => { Normal   => 0, Suppress => 1 },
                71 => { Normal   => 0, Suppress => 1 },
                73 => { Disabled => 0, Policing => 1, Shaping => 2 },
                77 => {
                    "Buffer"                  => 3,
                    "Drop"                    => 1,
                    "Lower-IP-Precedence"     => 2,
                    "Transmit"                => 0,
                    "Transmit-On-Buffer-Full" => 4,
                },
                78 => {
                    "Buffer"                  => 3,
                    "Drop"                    => 1,
                    "Lower-IP-Precedence"     => 2,
                    "Transmit"                => 0,
                    "Transmit-On-Buffer-Full" => 4,
                },
                79 => { Disabled => 0, Policing => 1, Shaping => 2 },
                83 => {
                    "Buffer"                  => 3,
                    "Drop"                    => 1,
                    "Lower-IP-Precedence"     => 2,
                    "Transmit"                => 0,
                    "Transmit-On-Buffer-Full" => 4,
                },
                84 => {
                    "Buffer"                  => 3,
                    "Drop"                    => 1,
                    "Lower-IP-Precedence"     => 2,
                    "Transmit"                => 0,
                    "Transmit-On-Buffer-Full" => 4,
                },
                85 => {
                    "Access-Tunnel" => 1,
                    "Both"          => 3,
                    "Data-Tunnel"   => 2,
                    "None"          => 0
                },
                92 => { Disabled => 0, Enabled => 1, Passive => 2 },
                93 => { Disabled => 0, Enabled => 1, Passive => 2 },
                95 => { Disabled => 0, Enabled => 1 },
                98 => {
                    Best_Effort => 0,
                    Bronze      => 1,
                    From_DSCP   => 4,
                    Gold        => 3,
                    Silver      => 2
                },
                99  => { HMAC_MD5 => 3, MD5 => 1, MD5_RFC2002 => 2 },
                100 =>
                  { Delay_GTP_Response => 2, No_Early_PDUs => 1, None => 0 },
                103 => { Disabled => 0, Enabled => 1 },
                105 =>
                  { Delay_GTP_Response => 2, No_Early_PDUs => 1, None => 0 },
                106 => { Accept => 1, Deny => 0 },
                107 => { Accept => 1, Deny => 0 },
                108 => { Accept => 1, Deny => 0 },
                111 => {
                    "AF11"         => 10,
                    "AF12"         => 12,
                    "AF13"         => 14,
                    "AF21"         => 18,
                    "AF22"         => 20,
                    "AF23"         => 22,
                    "AF31"         => 26,
                    "AF32"         => 28,
                    "AF33"         => 30,
                    "AF41"         => 34,
                    "AF42"         => 36,
                    "AF43"         => 38,
                    "Best-Effort"  => 0,
                    "EF"           => 46,
                    "Pass-Through" => 1,
                },
                112 => {
                    "AF11"         => 10,
                    "AF12"         => 12,
                    "AF13"         => 14,
                    "AF21"         => 18,
                    "AF22"         => 20,
                    "AF23"         => 22,
                    "AF31"         => 26,
                    "AF32"         => 28,
                    "AF33"         => 30,
                    "AF41"         => 34,
                    "AF42"         => 36,
                    "AF43"         => 38,
                    "Best-Effort"  => 0,
                    "EF"           => 46,
                    "Pass-Through" => 1,
                },
                113 => {
                    "AF11"         => 10,
                    "AF12"         => 12,
                    "AF13"         => 14,
                    "AF21"         => 18,
                    "AF22"         => 20,
                    "AF23"         => 22,
                    "AF31"         => 26,
                    "AF32"         => 28,
                    "AF33"         => 30,
                    "AF41"         => 34,
                    "AF42"         => 36,
                    "AF43"         => 38,
                    "Best-Effort"  => 0,
                    "EF"           => 46,
                    "Pass-Through" => 1,
                },
                114 => {
                    "AF11"         => 10,
                    "AF12"         => 12,
                    "AF13"         => 14,
                    "AF21"         => 18,
                    "AF22"         => 20,
                    "AF23"         => 22,
                    "AF31"         => 26,
                    "AF32"         => 28,
                    "AF33"         => 30,
                    "AF41"         => 34,
                    "AF42"         => 36,
                    "AF43"         => 38,
                    "Best-Effort"  => 0,
                    "EF"           => 46,
                    "Pass-Through" => 1,
                },
                115 => {
                    "AF11"         => 10,
                    "AF12"         => 12,
                    "AF13"         => 14,
                    "AF21"         => 18,
                    "AF22"         => 20,
                    "AF23"         => 22,
                    "AF31"         => 26,
                    "AF32"         => 28,
                    "AF33"         => 30,
                    "AF41"         => 34,
                    "AF42"         => 36,
                    "AF43"         => 38,
                    "Best-Effort"  => 0,
                    "EF"           => 46,
                    "Pass-Through" => 1,
                },
                116 => {
                    "AF11"         => 10,
                    "AF12"         => 12,
                    "AF13"         => 14,
                    "AF21"         => 18,
                    "AF22"         => 20,
                    "AF23"         => 22,
                    "AF31"         => 26,
                    "AF32"         => 28,
                    "AF33"         => 30,
                    "AF41"         => 34,
                    "AF42"         => 36,
                    "AF43"         => 38,
                    "Best-Effort"  => 0,
                    "EF"           => 46,
                    "Pass-Through" => 1,
                },
                123 => { Disabled => 0, Enabled => 1 },
                126 => { Disabled => 0, Enabled => 1 },
                128 => {
                    custom_prepaid   => 1,
                    no_prepaid       => 0,
                    standard_prepaid => 2,
                    wimax_prepaid    => 4,
                },
                129 => { prepaid_duration => 0, prepaid_volume => 1 },
                130 => { Disabled         => 0, Enabled        => 1 },
                133 => { Disabled         => 0, Enabled        => 1 },
                134 => { Disabled         => 0, Enabled        => 1 },
                135 => {
                    "current_time"                             => 0,
                    "last-airlink-activity-time"               => 2,
                    "last-airlink-activity-time-last-reported" => 3,
                    "last-user-layer3-activity-time"           => 1,
                },
                140 =>
                  { QOSCHANGE => 0, SGSNCHANGE => 500, TARIFFTIMECHANGE => 1 },
                143 => { "Session-Disconnect" => 1 },
                144 => { No         => 0, Yes     => 1 },
                146 => { Disabled   => 0, Enabled => 1 },
                150 => { None       => 0, ROHC    => 2, VJ => 1, VJ_ROHC => 3 },
                151 => { Optimistic => 1, Reliable => 0, Unidirectional => 2 },
                153 => { Any        => 0, Downlink => 2, Uplink         => 1 },
                156 => {
                    "local-alloc"             => 1,
                    "local-alloc-validate"    => 2,
                    "no-local-alloc-validate" => 0,
                },
                157 => { "auto-renew" => 0, "disconnect" => 1 },
                163 => { Disabled     => 0, Enabled      => 1 },
                164 => {
                    NoneOrDisabled => 0,
                    NVSE_Custom1   => 2,
                    NVSE_Custom2   => 3,
                    Starent_NVSE   => 1,
                },
                165 => { Disabled => 0, Enabled => 1 },
                170 => { No       => 0, Yes     => 1 },
                172 => { No       => 0, Yes     => 1 },
                173 => { No       => 0, Yes     => 1 },
                174 => { Disabled => 0, Enabled => 1 },
                187 =>
                  { Always => 1, NAI_Prefix_MSID_Mismatch => 2, Never => 0 },
                188 => {
                    Disabled              => 0,
                    EnabledOrNVSE_Starent => 1,
                    NVSE_CUstom1          => 2,
                    NVSE_Custom2          => 3,
                },
                192 => {
                    "flow-based-all"       => 1,
                    "flow-based-auxiliary" => 0,
                    "flow-based-none"      => 2,
                    "main-a10-only"        => 4,
                    "session-based"        => 3,
                },
                196 => { Disabled => 0, Enabled => 1 },
                198 => { False    => 0, True    => 1 },
                219 => {
                    Handicapped_Welfare => 8,
                    Kids_Locator        => 6,
                    Normal_Subscriber   => 0,
                    Reserved            => 9,
                    Ting_100            => 1,
                    Ting_2000           => 7,
                    Ting_500            => 2,
                    Ting_Buddy          => 3,
                    Ting_Nolimit_SMS    => 5,
                    Ting_Star           => 4,
                },
                221 => { Both => 3, None => 0, Receive => 1, Transmit => 2 },
                225 => { Disabled         => 0, Enabled          => 1 },
                236 => { No               => 0, Yes              => 1 },
                253 => { Send             => 1, Suppress         => 0 },
                256 => { ORIGINATING_ROLE => 0, TERMINATING_ROLE => 1 },
                267 => {
                    "3XX_Redirection"            => 3,
                    "4XX_Request_Failure"        => 4,
                    "5XX_Server_Failure"         => 5,
                    "6XX_Global_Failure"         => 6,
                    "End_Of_Subscriber_Dialog"   => 2,
                    "Internal_Error"             => 9,
                    "Normal_End_Of_Session"      => 0,
                    "Successful_Transaction"     => 1,
                    "Unspecified_Error"          => 7,
                    "Unsuccessful_Session_Setup" => 8,
                },
                268 => { "I-CSCF"         => 2, "P-CSCF" => 1, "S-CSCF" => 0 },
                274 => { False            => 0, True              => 1 },
                282 => { Disable          => 0, Enable            => 1 },
                283 => { Disable          => 0, Enable            => 1 },
                284 => { Disable          => 0, Enable            => 1 },
                285 => { Disable          => 0, Enable            => 1 },
                291 => { Disable          => 0, Enable            => 1 },
                292 => { Disable          => 0, Enable            => 1 },
                293 => { Disable          => 0, Enable            => 1 },
                294 => { Disable          => 0, Enable            => 1 },
                298 => { Disable          => 0, Enable            => 1 },
                299 => { No               => 0, Yes               => 1 },
                306 => { Disabled         => 0, Enabled           => 1 },
                310 => { "Active-Handoff" => 0, "Location-Update" => 1 },
                313 => {
                    Administrative => 6,
                    Inspector      => 19650516,
                    NAS_Prompt     => 7,
                    Security_Admin => 19660618,
                },
                314 => {
                    Alloc_Dhcp_Client  => 1,
                    Alloc_Local_Pool   => 0,
                    Alloc_No_Alloc     => 2,
                    Alloc_Static_Alloc => 3,
                },
                316   => { No       => 0, Yes     => 1 },
                317   => { No       => 0, Yes     => 1 },
                318   => { No       => 0, Yes     => 1 },
                65530 => { Disabled => 0, Enabled => 1 },
            },
            8741 => {
                1 => {
                    "Access-To-VPN"      => 4,
                    "Bypass-Filters"     => 2,
                    "Internet-Access"    => 9,
                    "L2TP-Client-Access" => 6,
                    "Limited-Management" => 5,
                    "Remote-Access"      => 1,
                    "VPN-Client-Access"  => 3,
                    "Wireless-Add-ACL"   => 8,
                    "Wireless-Guest"     => 7,
                },
            },
            8742 => {
                27 => {
                    "Deleted-Device"  => 3,
                    "Personal-Device" => 1,
                    "Shared-Device"   => 2
                },
                38 => { "AirGroup-v1" => 1, "AirGroup-v2" => 2 },
            },
            10415 => {
                21 => {
                    "3GPP2-1xRTT"    => 104,
                    "3GPP2-eHRPD"    => 102,
                    "3GPP2-HRPD"     => 103,
                    "EUTRAN"         => 6,
                    "GAN"            => 4,
                    "GERAN"          => 2,
                    "HSPA-Evolution" => 5,
                    "IEEE-802.16e"   => 101,
                    "UTRAN"          => 1,
                    "Virtual"        => 7,
                    "WLAN"           => 3,
                },
                27 => {
                    "Allocate-IPv4-Address"  => 1,
                    "Allocate-IPv4-and-IPv6" => 3,
                    "Allocate-IPv6-Prefix"   => 2,
                    "Do-Not-Allocate"        => 0,
                },
            },
            11344 => {
                127 => {
                    "Accounting"           => 2,
                    "All"                  => 31,
                    "Auth-Acct"            => 3,
                    "Authentication"       => 1,
                    "Client"               => 32,
                    "Home-Server"          => 128,
                    "Internal"             => 16,
                    "None"                 => 0,
                    "Proxy-Accounting"     => 8,
                    "Proxy-Auth-Acct"      => 12,
                    "Proxy-Authentication" => 4,
                    "Server"               => 64,
                },
                173 => {
                    "Admin-Down"      => 4,
                    "Alive"           => 0,
                    "Connection-Fail" => 5,
                    "Dead"            => 2,
                    "Idle"            => 3,
                    "Zombie"          => 1,
                },
                190 => {
                    "Authentication-Infrastructure-Not-Trusted"         => 1010,
                    "Authentication-Infrastructure-Unavailable"         => 1009,
                    "Bad-CSR"                                           => 1025,
                    "Bad-Identity-in-CSR"                               => 1024,
                    "Challenge-Algorithm-Mismatch"                      => 1018,
                    "Challenge-Expired"                                 => 1017,
                    "Client-Certificate-Not-Supplied"                   => 1019,
                    "Client-Certificate-Rejected"                       => 1020,
                    "Clock-Skew-Detected"                               => 4,
                    "Clock-Skew-Too-Great"                              => 1011,
                    "Contact-Administrator"                             => 5,
                    "Failure"                                           => 2,
                    "General-PKI-Error"                                 => 1027,
                    "Inner-Method-Channel-Binding-Data-Failed"          => 1030,
                    "Inner-Method-Channel-Binding-Missing-Info"         => 1029,
                    "Inner-Method-Channel-Binding-Not-Supplied"         => 1028,
                    "Inner-Method-Error"                                => 1001,
                    "Internal-CA-Error"                                 => 1026,
                    "Invalid-Inner-Realm"                               => 1012,
                    "Realm-Mismatch-Inner-Outer-Identity"               => 1021,
                    "Success"                                           => 1,
                    "Token-Out-of-Sync-Admin-Intervention-Required"     => 1013,
                    "Token-Out-of-Sync-PIN-Change-Required"             => 1014,
                    "Token-Revoked"                                     => 1015,
                    "Tokens-Exhausted"                                  => 1016,
                    "Tunnel-Compromise-Error"                           => 2001,
                    "Unexpected-TLVs"                                   => 2002,
                    "Unspecified-Authentication-Failure"                => 1003,
                    "Unspecified-Authentication-Infrastructure-Problem" => 1002,
                    "Unspecified-Authorization-Failure"                 => 1004,
                    "Unsupported-Algorithm-in-CSR"                      => 1022,
                    "Unsupported-Extension-in-CSR"                      => 1023,
                    "User-Account-Authorizations-Change-Soon"           => 3,
                    "User-Account-Credential-Expires-Soon"              => 2,
                    "User-Account-Credentials-Change-Requires"          => 6,
                    "User-Account-Credentials-Incorrect"                => 1031,
                    "User-Account-Credentials-Unavailable"              => 1005,
                    "User-Account-Expired"                              => 1006,
                    "User-Account-Expires-Soon"                         => 1,
                    "User-Account-Locked-Admin-Intervention-Required"   => 1008,
                    "User-Account-Locked-Try-Again-Later"               => 1007,
                },
            },
            11862 =>
              { "0" => { BYE => 1, INVITE => 0, OTHER => 3, REGISTER => 2 } },
            12740 => {
                6 => {
                    "group-administrator"                => 0,
                    "pool-administrator"                 => 1,
                    "pool-administrator-ro-entire-group" => 2,
                    "volume-administrator"               => 3,
                },
            },
            13209 => {
                8  => { Absolute => 1, Relative => 0 },
                11 => {
                    "Disabled-Account"         => 6,
                    "Expired-Account"          => 19,
                    "Inactive-Access-Node"     => 4,
                    "Inactive-Account"         => 18,
                    "Incomplete-Account"       => 20,
                    "Inconsistent-Access-Node" => 5,
                    "Internal-Error"           => 8,
                    "LDAP-Failed"              => 17,
                    "License-Limit-Reached"    => 21,
                    "Max-Session"              => 11,
                    "No-Accessprofile"         => 7,
                    "No-Credits"               => 10,
                    "No-Zone-Access"           => 3,
                    "Opaque-Failed"            => 15,
                    "Realm-Error"              => 9,
                    "Realm-Inactive"           => 14,
                    "Remote-Server-Reject"     => 12,
                    "Ruleset-Failed"           => 24,
                    "Ruleset-Reject"           => 23,
                    "Service-Closed"           => 16,
                    "Unsupported-Service"      => 22,
                    "User-Not-Found"           => 1,
                    "Wrong-Password"           => 2,
                },
                42 => { "Auto"      => 1, "IP-Request" => 2, "User" => 0 },
                43 => { "CoA-Login" => 1 },
                57 => { "Simulate-EAP-TLS" => 1 },
            },
            14179 =>
              { 2 => { Bronze => 3, Gold => 1, Platinum => 2, Silver => 0 } },
            14501 => {
                2 => {
                    "No-Access"         => 0,
                    "Read-Only-Access"  => 1,
                    "Read-Write-Access" => 2
                },
            },
            14559 => {},
            14823 => {
                27 => {
                    "Deleted-Device"  => 3,
                    "Personal-Device" => 1,
                    "Shared-Device"   => 2
                },
                38 => { "AirGroup-v1" => 1, "AirGroup-v2" => 2 },
                49 => { Critical => 0, High => 1, Low => 2 },
                50 => {
                    "Client-Mode"         => 2,
                    "Infrastructure-Mode" => 1,
                    "Multi-Domain-Mode"   => 3,
                },
                52 => { DSCP    => 0, None        => 2, QoS => 1 },
                58 => { Disable => 0, Enable      => 1 },
                64 => { None    => 0, Promiscuous => 1, Secondary => 2 },
                68 => {
                    "DDP-Boostrap-Authorization" => 1,
                    "DDP-Identity-Update"        => 2,
                    "DDP-Net-Access"             => 3,
                },
            },
            14988 => {
                6 => {
                    "104-bit-WEP"   => 2,
                    "40-bit-WEP"    => 1,
                    "AES-CCM"       => 3,
                    "No-encryption" => 0,
                    "TKIP"          => 4,
                },
                27 => { "802.1ad" => 1, "802.1q" => 0 },
            },
            16313 => { 10 => { "No-Show" => 0, "Show" => 1 } },
            16445 => {
                65411 => { GERAN => 0, NONE   => 2, UTRAN => 1 },
                65414 => { North => 0, South  => 1 },
                65415 => { Depth => 1, Height => 0 },
                65423 => {
                    "CSG-Capable"     => 0,
                    "Not-CSG-Capable" => 1,
                    "R99"             => 0,
                    "Rel-4"           => 1,
                    "Rel-5"           => 2,
                    "Rel-6"           => 3,
                    "Rel-7"           => 4,
                    "Rel-8"           => 5,
                },
            },
            16459 => {
                172 => {
                    "FXO"       => 3,
                    "H.323"     => 2,
                    "Internal"  => 0,
                    "ISDN-PRI"  => 6,
                    "SIP"       => 1,
                    "T1-E1-CAS" => 4,
                    "T1-E1-CCS" => 5,
                },
                174 => {
                    "Ethernet"      => 0,
                    "FXO"           => 1,
                    "ISDN"          => 4,
                    "T1-E1-Network" => 3,
                    "T1-E1-User"    => 2,
                },
                195 => {
                    "Call-Forward-Busy"     => 2,
                    "Call-Forward-NoAnswer" => 3,
                    "Call-Forward-Uncondit" => 1,
                    "Call-Park"             => 5,
                    "Call-Pickup"           => 6,
                    "Call-Tranfer"          => 4,
                    "Hunt-Group"            => 8,
                    "ManyExtension-Ringing" => 7,
                    "No-Reason"             => 0,
                },
                196 => {
                    "Call-Is-Redirected" => 0,
                    "Call-Origin-OnHook" => 1,
                    "Call-Temin-OnHook"  => 2,
                    "Disconected-by-CAC" => 3,
                    "Other"              => 4,
                },
            },
            17713 => {
                1 => {
                    "Deliberately-Bad" => 4,
                    "Invalid"          => 0,
                    "Read-Only"        => 1,
                    "Security-Officer" => 3,
                    "System-Admin"     => 2,
                },
                50 => {
                    "Admin"     => 3,
                    "Install"   => 2,
                    "Read-Only" => 5,
                    "User"      => 4
                },
                51 => { High => 1, Low => 2, Normal => 0 },
            },
            18022 => {
                1 => {
                    MAINTENANCE  => 3,
                    PROVISIONING => 2,
                    RETRIEVE     => 4,
                    SUPERUSER    => 1
                },
                4 => { N => 0, Y => 1 },
                5 => { N => 0, Y => 1 },
                6 => { N => 0, Y => 1 },
            },
            18681 => {
                31 => { "Pre-Shared-Key" => 0, "X509-Subject-CommonName" => 1 }
            },
            19382 =>
              { 8 => { "Internet" => 3, "MMS-Picture" => 1, "Unused" => 2 } },
            21074 => {
                2 => { ETHERNET_CS => 1, IPV4_CS => 0 },
                3 => {
                    "QAM16_1/2" => 5,
                    "QAM16_3/4" => 6,
                    "QAM64_1/2" => 7,
                    "QAM64_2/3" => 8,
                    "QAM64_3/4" => 9,
                    "QAM64_5/6" => 10,
                    "QPSK_1/2"  => 3,
                    "QPSK_3/4"  => 4,
                },
                4 => {
                    "QAM16_1/2" => 5,
                    "QAM16_3/4" => 6,
                    "QAM64_1/2" => 7,
                    "QAM64_2/3" => 8,
                    "QAM64_3/4" => 9,
                    "QAM64_5/6" => 10,
                    "QPSK_1/2"  => 3,
                    "QPSK_3/4"  => 4,
                },
            },
            21274 => {
                2 => {
                    camiantService => 104,
                    camiantUser    => 102,
                    camiantView    => 101
                },
            },
            23782 => {
                105 => { Disabled => 2, Enabled => 1 },
                107 => { Disabled => 2, Enabled => 1 },
                108 => { Disabled => 2, Enabled => 1 },
                110 => { No       => 2, Yes     => 1 },
                111 => { No       => 2, Yes     => 1 },
                113 => { Allow    => 2, Deny    => 1 },
            },
            24023 => {
                11 => { "Disabled"  => 0, "Full-Packet-Local-PCAP" => 1 },
                12 => { "Allow-All" => 0, "Deny-RADIUS"            => 1 },
            },
            24757 => {
                1 => {
                    "DHCP-Proxy"          => 2,
                    "DHCP-Relay"          => 1,
                    "eAFF-IPv4-Transport" => 1,
                    "eAFF-IPv6-Transport" => 2,
                    "eCFF-IPv4-Transport" => 1,
                    "eCFF-IPv6-Transport" => 2,
                    "eFA"                 => 4,
                    "eHAv4"               => 4,
                    "eHAv6"               => 8,
                    "FA"                  => 4,
                    "Flow-Based"          => 2,
                    "Hotline-Profile-Id"  => 1,
                    "HTTP-Redirection"    => 4,
                    "IP-Redirection"      => 8,
                    "IP-Session-Based"    => 1,
                    "NAS-Filter-Rule"     => 2,
                    "No-Accounting"       => 0,
                    "Not-Supported"       => 0,
                    "PMIP-Client"         => 8,
                    "Supported"           => 1,
                },
                23 => {
                    "CMIP4"       => 3,
                    "CMIP6"       => 4,
                    "Ethernet-CS" => 5,
                    "PMIP4"       => 2,
                    "Reserved-0"  => 0,
                    "Reserved-1"  => 1,
                },
                28 => {
                    "Bi-Directional" => 3,
                    "Downlink"       => 2,
                    "Ethernet"       => 3,
                    "FF"             => 4,
                    "IN"             => 1,
                    "IPv4-CS"        => 1,
                    "IPv6-CS"        => 2,
                    "OUT"            => 2,
                    "Reserved-0"     => 0,
                    "Uplink"         => 1,
                },
                29 => {
                    "Best-Effort"             => 2,
                    "Control"                 => 12,
                    "Data"                    => 13,
                    "Extended-rtPS"           => 5,
                    "Location-Based-Services" => 8,
                    "Message"                 => 11,
                    "Multi-Player-Gaming"     => 7,
                    "Music-Photo-Download"    => 6,
                    "nrtPS"                   => 3,
                    "Robust-Browser"          => 2,
                    "rtPS"                    => 4,
                    "Secure-Browser-VPN"      => 3,
                    "Streaming-Live-TV"       => 5,
                    "Streaming-Video"         => 4,
                    "Text-Audio-Books"        => 9,
                    "UGS"                     => 6,
                    "Video-Conversation"      => 10,
                    "VoIP"                    => 1,
                },
                35 => {
                    "Duration-Metering" => 2,
                    "Multi-Services"    => 32,
                    "Pools"             => 8,
                    "Rating-Groups"     => 16,
                    "Resource-Metering" => 4,
                    "Tariff-Switch"     => 64,
                    "Volume-Metering"   => 1,
                },
                36 => { "Dynamic-Authorization" => 1 },
                37 => {
                    "Access-Service-Terminated"  => 8,
                    "Balance-Check"              => 1,
                    "Client-Service-Termination" => 7,
                    "Initial-Request"            => 2,
                    "One-Time-Charging"          => 10,
                    "Pre-Initialization"         => 1,
                    "Price-Enquiry"              => 2,
                    "Quota-Reached"              => 4,
                    "Redirect-Or-Filter"         => 3,
                    "Remote-Forced-Disconnect"   => 6,
                    "Request-More-Quota"         => 2,
                    "Service-Not-Established"    => 9,
                    "Terminate"                  => 1,
                    "Threshold-Reached"          => 3,
                    "TITSU-Approaching"          => 5,
                },
                58 => { No => 0, Yes => 1 },
                60 => {
                    "BS-Sends-RES-Cmd"           => 65535,
                    "Deregister-MS"              => 0,
                    "MS-Completed-IPv6-Handover" => 6,
                    "MS-Idle"                    => 5,
                    "MS-Terminate"               => 4,
                    "Resume-Traffic"             => 3,
                    "Suspend-MS-Traffic"         => 1,
                    "Suspend-User-Traffic"       => 2,
                },
                82 => { False => 0, True => 1 },
                84 => {
                    "Activate"         => 4,
                    "Admit"            => 2,
                    "Bi-Directional"   => 3,
                    "Downlink"         => 2,
                    "Dst-Assigned"     => 2,
                    "Dynamic"          => 8,
                    "Ethernet"         => 3,
                    "IPv4-CS"          => 1,
                    "IPv6-CS"          => 2,
                    "Provisioned"      => 1,
                    "Src-Assigned"     => 1,
                    "Src-Dst-Assigned" => 3,
                    "Uplink"           => 1,
                },
                89  => { Fixed => 1, Mobile => 3, Nomadic => 2 },
                90  => { No    => 0, Yes    => 1 },
                143 => {
                    "Accounting"                         => 15,
                    "Authentication-Information-Answer"  => 2,
                    "Authentication-Information-Request" => 1,
                    "Cancel-Location-Answer"             => 6,
                    "Cancel-Location-Request"            => 5,
                    "Delete-Subscriber-Data-Answer"      => 12,
                    "Delete-Subscriber-Data-Request"     => 11,
                    "Insert-Subscriber-Data-Answer"      => 10,
                    "Insert-Subscriber-Data-Request"     => 9,
                    "Notification-Answer"                => 14,
                    "Notification-Request"               => 13,
                    "Purge-UE-Answer"                    => 8,
                    "Purge-UE-Request"                   => 7,
                    "Update-Location-Answer"             => 4,
                    "Update-Location-Request"            => 3,
                },
                144 => { Yes => 0 },
                155 => {
                    INITIAL_ATTACH_PROCEDURE => 4,
                    MME_UPDATE_PROCEDURE     => 0,
                    SUBSCRIPTION_WITHDRAWAL  => 2,
                },
                156 => { "Active-Location-Retrieval" => 0 },
            },
            25053 => {
                106 => { ChosenBySGSN => 2, SentByMS => 1, Subscribed => 0 },
                107 => { NotRequired  => 0, Required => 1 },
                109 => { Others       => 2, SCG      => 1 },
                110 => { Failure      => 1, Success  => 0 },
                112 => {
                    "DummyIMSI"   => 2,
                    "EAP-SIM"     => 10,
                    "LocalRadius" => 7,
                    "Postpaid"    => 5,
                    "PPP-SIM"     => 1,
                    "Prepaid"     => 6,
                    "ProxyRadius" => 8,
                    "RadiusSIM"   => 4,
                    "SoftSIM"     => 3,
                    "Voucher"     => 9,
                },
                125 => {
                    "L2GRE"             => 6,
                    "L3GRE"             => 5,
                    "Local-Breakout"    => 3,
                    "Local-Breakout-AP" => 4,
                    "PMIP"              => 8,
                    "QinQL3"            => 7,
                    "TTG"               => 2,
                },
                126 => { "Accounting-Off" => 0, "Accounting-On" => 1 },
            },
            25506 => {
                20 => {
                    "PortalClear"       => 5,
                    "Result"            => 4,
                    "SetPolicy"         => 3,
                    "Terminate-Request" => 2,
                    "Trigger-Request"   => 1,
                },
                29 => { Manage => 3, Monitor => 1, System => 2, Visit => 0 },
            },
            26928 => {
                1 => {
                    "Read-Only-Admin"  => 0,
                    "Read-Write-Admin" => 2,
                    "Super-Admin"      => 1
                },
                4   => { Deny          => 2, Permit => 0, Restricted => 1 },
                9   => { "COA-Request" => 2, "Disconnect-Request" => 1 },
                213 => { "Non-Service" => 2, "Service"            => 1 },
            },
            27880 => {
                13 => {
                    "Access-Info-Discarded"        => 43,
                    "Allotted-Timeout"             => 602,
                    "Attended-Transfer"            => 601,
                    "Bearercapability-Notauth"     => 57,
                    "Bearercapability-Notavail"    => 58,
                    "Bearercapability-Notimpl"     => 65,
                    "Blind-Transfer"               => 600,
                    "Call-Awarded-Delivery"        => 7,
                    "Call-Rejected"                => 21,
                    "Chan-Not-Implemented"         => 66,
                    "Channel-Unacceptable"         => 6,
                    "Crash"                        => 500,
                    "Destination-Out-Of-Order"     => 27,
                    "Exchange-Routing-Error"       => 25,
                    "Facility-Not-Implemented"     => 69,
                    "Facility-Not-Subscribed"      => 50,
                    "Facility-Rejected"            => 29,
                    "IE-Nonexist"                  => 99,
                    "Incoming-Call-Barred"         => 54,
                    "Incompatible-Destination"     => 88,
                    "Interworking"                 => 127,
                    "Invalid-Call-Reference"       => 81,
                    "Invalid-IE-Contents"          => 100,
                    "Invalid-Msg-Unspecified"      => 95,
                    "Invalid-Number-Format"        => 28,
                    "Lose-Race"                    => 502,
                    "Manager-Request"              => 503,
                    "Mandatory-IE-Length-Error"    => 103,
                    "Mandatory-IE-Missing"         => 96,
                    "Media-Timeout"                => 604,
                    "Message-Type-Nonexist"        => 97,
                    "Network-Out-Of-Order"         => 38,
                    "No-Answer"                    => 19,
                    "No-Route-Destination"         => 3,
                    "No-Route-Transit-Net"         => 2,
                    "No-User-Response"             => 18,
                    "None"                         => 0,
                    "Normal-Circuit-Congestion"    => 34,
                    "Normal-Clearing"              => 16,
                    "Normal-Temporary-Failure"     => 41,
                    "Normal-Unspecified"           => 31,
                    "Number-Changed"               => 22,
                    "Originator-Cancel"            => 487,
                    "Outgoing-Call-Barred"         => 52,
                    "Picked-Off"                   => 605,
                    "Pre-Empted"                   => 45,
                    "Protocol-Error"               => 111,
                    "Recovery-On-Timer-Expire"     => 102,
                    "Redirecto-To-New-Destination" => 23,
                    "Requested-Chan-Unavail"       => 44,
                    "Response-To-Status-Enquiry"   => 30,
                    "Service-Not-Implemented"      => 79,
                    "Service-Unavailable"          => 63,
                    "Subscriber-Absent"            => 20,
                    "Success"                      => 142,
                    "Switch-Congestion"            => 42,
                    "System-Shutdown"              => 501,
                    "Unallocated-Number"           => 1,
                    "User-Busy"                    => 17,
                    "User-Challenge"               => 603,
                    "User-Not-Registered"          => 606,
                    "Wrong-Call-State"             => 101,
                    "Wrong-Message"                => 98,
                },
            },
            28557 => {
                2 => {
                    "HS-User-8021x"    => 2,
                    "HS-User-Admin"    => 16,
                    "HS-User-l2tp"     => 1,
                    "HS-User-normal"   => 8,
                    "HS-User-smartvpn" => 4,
                },
                4 => {
                    "HS-Admin-Console" => 1,
                    "HS-Admin-HTTP"    => 8,
                    "HS-Admin-HTTPS"   => 16,
                    "HS-Admin-SSH"     => 4,
                    "HS-Admin-Telnet"  => 2,
                },
                6 => {
                    "HS-Mobile-ChinaMobile"  => 1,
                    "HS-Mobile-ChinaTelecom" => 3,
                    "HS-Mobile-ChinaUnicom"  => 2,
                },
            },
            30065 => { 6 => { complete => 2, start => 1 } },
            35265 => {
                11 => {
                    "Access-Denied"             => 9,
                    "Incomplete-Number"         => 2,
                    "No-Answer"                 => 7,
                    "Out-of-Order"              => 6,
                    "RADIUS-Server-Unavailable" => 11,
                    "Unassigned-Number"         => 3,
                    "Unavailable-Trunk"         => 8,
                    "Unavailable-Voice-Channel" => 10,
                    "Unsuccessful-Other-Cause"  => 4,
                    "User-Answer"               => 1,
                    "User-Busy"                 => 5,
                },
            },
            35987 => {
                13 => {
                    "Access-Info-Discarded"        => 43,
                    "Allotted-Timeout"             => 602,
                    "Attended-Transfer"            => 601,
                    "Bearercapability-Notauth"     => 57,
                    "Bearercapability-Notavail"    => 58,
                    "Bearercapability-Notimpl"     => 65,
                    "Blind-Transfer"               => 600,
                    "Call-Awarded-Delivery"        => 7,
                    "Call-Rejected"                => 21,
                    "Chan-Not-Implemented"         => 66,
                    "Channel-Unacceptable"         => 6,
                    "Crash"                        => 500,
                    "Destination-Out-Of-Order"     => 27,
                    "Exchange-Routing-Error"       => 25,
                    "Facility-Not-Implemented"     => 69,
                    "Facility-Not-Subscribed"      => 50,
                    "Facility-Rejected"            => 29,
                    "IE-Nonexist"                  => 99,
                    "Incoming-Call-Barred"         => 54,
                    "Incompatible-Destination"     => 88,
                    "Interworking"                 => 127,
                    "Invalid-Call-Reference"       => 81,
                    "Invalid-IE-Contents"          => 100,
                    "Invalid-Msg-Unspecified"      => 95,
                    "Invalid-Number-Format"        => 28,
                    "Lose-Race"                    => 502,
                    "Manager-Request"              => 503,
                    "Mandatory-IE-Length-Error"    => 103,
                    "Mandatory-IE-Missing"         => 96,
                    "Media-Timeout"                => 604,
                    "Message-Type-Nonexist"        => 97,
                    "Network-Out-Of-Order"         => 38,
                    "No-Answer"                    => 19,
                    "No-Route-Destination"         => 3,
                    "No-Route-Transit-Net"         => 2,
                    "No-User-Response"             => 18,
                    "None"                         => 0,
                    "Normal-Circuit-Congestion"    => 34,
                    "Normal-Clearing"              => 16,
                    "Normal-Temporary-Failure"     => 41,
                    "Normal-Unspecified"           => 31,
                    "Number-Changed"               => 22,
                    "Originator-Cancel"            => 487,
                    "Outgoing-Call-Barred"         => 52,
                    "Picked-Off"                   => 605,
                    "Pre-Empted"                   => 45,
                    "Protocol-Error"               => 111,
                    "Recovery-On-Timer-Expire"     => 102,
                    "Redirecto-To-New-Destination" => 23,
                    "Requested-Chan-Unavail"       => 44,
                    "Response-To-Status-Enquiry"   => 30,
                    "Service-Not-Implemented"      => 79,
                    "Service-Unavailable"          => 63,
                    "Subscriber-Absent"            => 20,
                    "Success"                      => 142,
                    "Switch-Congestion"            => 42,
                    "System-Shutdown"              => 501,
                    "Unallocated-Number"           => 1,
                    "User-Busy"                    => 17,
                    "User-Challenge"               => 603,
                    "User-Not-Registered"          => 606,
                    "Wrong-Call-State"             => 101,
                    "Wrong-Message"                => 98,
                },
            },
            43823 => {
                6 => {
                    ARP       => 6,
                    Auth      => 0,
                    CHAP      => 3,
                    DHCP      => 1,
                    DHCPv6    => 7,
                    MAC_QinQ  => 5,
                    MS_CHAPv2 => 4,
                    PAP       => 2,
                },
                10 => { "Check-Acct" => 1 },
                37 => { Discover     => 0, Inform => 1, Request => 2 },
                70 => { Rebind => 6, Renew => 5, Request => 3, Solicit => 1 },
            },
            49426 => {
                8 => {
                    Deleted      => 1,
                    Disabled     => 2,
                    Disputes     => 3,
                    Exhausted    => 6,
                    Expired      => 4,
                    Unknown      => 5,
                    VLANmismatch => 8,
                    WrongMAC     => 7,
                },
            },
            61349 => {
                10 => {
                    "Account-Does-Not-Exist"     => 9,
                    "Account-EQP-Token-Mismatch" => 32,
                    "Cannot-Login-Time"          => 33,
                    "Challenge-Dyna-Reject"      => 7,
                    "EQP-Expiration-Error"       => 31,
                    "Msg-PWD-Reject"             => 28,
                    "Org-Reject"                 => 34,
                    "PIN-Word-Error"             => 24,
                    "Push-Check-Code-Error"      => 20,
                    "Push-Code-Error"            => 21,
                    "RADIUS-Key-Parse-Error"     => 8,
                    "Role-Reject"                => 2,
                    "Single-Only-Dyna-Reject"    => 22,
                    "Source-IP-Error"            => 25,
                    "Static-PWD-Error"           => 23,
                    "Static-PWD-Expired"         => 28,
                    "Static-PWD-Or-PIN-Error"    => 2324,
                    "Static-Reject"              => 3,
                    "Strategy-Config-Error"      => 30,
                    "Token-Expired"              => 16,
                    "Unknown-Error"              => 4294967295,
                },
            },
        },
    },
    "Net::Radius::Dictionary",
);

=head1 AUTHOR

Inverse inc. <info@inverse.ca>

=head1 COPYRIGHT

Copyright (C) 2005-2025 Inverse inc.

=head1 LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
USA.

=cut

1;
